<?php
// api/src/Controller/WorkerTest.php

namespace App\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;

use App\Entity\Worker;
use App\Entity\Task;
use App\Entity\Trolley;
use App\Entity\MobileLogin;

class WorkerTimeline extends AbstractController
{
    public function __invoke(Worker $data): array
    {
        $day = $this->get("request_stack")->getCurrentRequest()->get('day');

        $entityManager = $this->getDoctrine()->getManager();

        /**
         * @var App\Repository\TaskRepository
         */
        $taskRepository = $entityManager->getRepository(Task::class);

        /**
         * @var App\Repository\TrolleyRepository
         */
        $trolleyRepository = $entityManager->getRepository(Trolley::class);

        /**
         * @var App\Repository\MobileLoginRepository
         **/
        $mobileLoginRepository = $entityManager->getRepository(MobileLogin::class);

        $timelineDate = new \DateTime($day ? $day : 'NOW');

        $dateFrom = clone $timelineDate;
        $dateTo = clone $timelineDate;

        $dateFrom->modify('today');
        $dateTo->modify('tomorrow');

        $tasks = $taskRepository->findByWorkerIdDate($data->getId(), $dateFrom, $dateTo);
        $trolleys = $trolleyRepository->findByWorkerIdDate($data->getId(), $dateFrom, $dateTo);
        $logins = $mobileLoginRepository->findByWorkerIdDate($data->getId(), $dateFrom, $dateTo);

        $timeline = [];

        foreach ($trolleys as $t) {
            $timeline[] = [
                'entity' => 'trolley',
                'type' => $t->getType(),
                'date' => $t->getRegisteredAt(),
                'number' => $t->getTrolley(),
            ];
        }

        foreach ($tasks as $t) {
            if ($t->getStartedAt()) {
                $timeline[] = [
                    'entity' => 'task',
                    'type' => 'start',
                    'date' => $t->getStartedAt(),
                    'number' => $t->getRowNumber(),
                ];
            }

            if ($t->getFinishedAt()) {
                $timeline[] = [
                    'entity' => 'task',
                    'type' => 'finish',
                    'date' => $t->getFinishedAt(),
                    'number' => $t->getRowNumber(),
                ];
            }
        }

        foreach ($logins as $l) {
            $timeline[] = [
                'entity' => 'mobileLogin',
                'type' => $l->getType(),
                'date' => $l->getFinishedAt(),
                'reason' => $l->getReason(),
            ];
        }
        usort($timeline, function ($a, $b) {
            return ($a['date'] < $b['date']) ? -1 : 1;
        });

        return $timeline;
    }
}
