<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\ORM\Mapping as ORM;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use App\Uuid;
use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * @ApiResource()
 * @ApiFilter(
 *   SearchFilter::class, 
 *   properties={
 *     "positionId": "exact", 
 *     "sectionId": "exact", 
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class, 
 *   properties={
 *     "positionId",
 *     "rawPositionId",
 *     "sectionId",
 *     "rawSectionId",
 *   }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\ApplicationRepository")
 * @ORM\Table(
 *   name="application",
 *   indexes={
 *     @ORM\Index(
 *       name="application_position", 
 *       columns={"position_id"}
 *     ),
 *     @ORM\Index(
 *       name="application_section", 
 *       columns={"section_id"}
 *     ),
 *     @ORM\Index(
 *       name="application_raw_position", 
 *       columns={"raw_position_id"}
 *     ),
 *     @ORM\Index(
 *       name="application_raw_section", 
 *       columns={"raw_section_id"}
 *     ),
 *   }
 * )
 */
class Application
{
    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     */
    private $id;

    /**
     * @ORM\Column(type="guid", nullable=true)
     */
    private $positionId;

    /**
     * @ORM\Column(type="guid", nullable=true)
     */
    private $sectionId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Section")
     */
    private $section;

    /**
     * @ORM\Column(type="guid", nullable=true)
     */
    private $rawSectionId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Position")
     */
    private $position;

    /**
     * @ORM\Column(type="guid", nullable=true)
     */
    private $rawPositionId;

    /**
     * @ORM\Column(type="json", nullable=true)
     */
    private $raw = [];

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(type="datetimetz")
     */
    private $createdAt;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="update")
     * @ORM\Column(type="datetimetz")
     */
    private $updatedAt;

    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getSection(): ?Section
    {
        return $this->section;
    }

    public function setSection(?Section $section): self
    {
        $this->section = $section;

        return $this;
    }

    public function getRawSectionId(): ?string
    {
        return $this->rawSectionId;
    }

    public function setRawSectionId(?string $rawSectionId): self
    {
        $this->rawSectionId = $rawSectionId;

        return $this;
    }

    public function getPosition(): ?Position
    {
        return $this->position;
    }

    public function setPosition(?Position $position): self
    {
        $this->position = $position;

        return $this;
    }

    public function getRawPositionId(): ?string
    {
        return $this->rawPositionId;
    }

    public function setRawPositionId(?string $rawPositionId): self
    {
        $this->rawPositionId = $rawPositionId;

        return $this;
    }

    public function getRaw(): ?array
    {
        return $this->raw;
    }

    public function setRaw(?array $raw): self
    {
        $this->raw = $raw;

        return $this;
    }

    public function getCreatedAt(): ?\DateTimeInterface
    {
        return $this->createdAt;
    }

    public function getUpdatedAt(): ?\DateTimeInterface
    {
        return $this->updatedAt;
    }

    public function getPositionId(): ?string
    {
        return $this->positionId;
    }

    public function setPositionId(?string $positionId): self
    {
        $this->positionId = $positionId;

        return $this;
    }

    public function getSectionId(): ?string
    {
        return $this->sectionId;
    }

    public function setSectionId(?string $sectionId): self
    {
        $this->sectionId = $sectionId;

        return $this;
    }
}
