<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;

use Doctrine\ORM\Mapping as ORM;
use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Component\Serializer\Annotation\Groups;

use App\Uuid;


/**
 * @ApiResource()
 * @ORM\Entity(repositoryClass="App\Repository\AuditRepository")
 *@ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "tableId": "exact",
 *     "tableName": "ipartial",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "actionTimestamp",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * 
 * @ApiFilter(
 *   DateFilter::class,
 *   properties={
 *     "actionTimestamp",
 *   }
 * )
 * @ORM\Table(
 *   name="audit",
 *   indexes={
 *     @ORM\Index(
 *       name="audit_table_id",
 *       columns={"table_id"}
 *     ),
 *   }
 * )
 */
class Audit
{
    /**
     * @ORM\Id()
     * @ORM\GeneratedValue()
     * @ORM\Column(type="integer", nullable=true)
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read"})
     */
    private $tableId;

    /**
     * @ORM\Column(type="text")
     * @Groups({"read"})
     */
    private $tableName;

    /**
     * @ORM\Column(type="text")
     * @Groups({"read"})
     */
    private $userName;

    /**
    * @ORM\Column(type="datetimetz")
     * @Groups({"read"})
     */
    private $actionTimestamp;

    /**
     * @ORM\Column(type="text")
     * @Groups({"read"})
     */
    private $action;

    /**
     * @ORM\Column(type="json", nullable=true)
     * @Groups({"read"})
     */
    private $oldValues = [];

    /**
     * @ORM\Column(type="json")
     * @Groups({"read"})
     */
    private $newValues;

    /**
     * @ORM\Column(type="json", nullable=true)
     * @Groups({"read"})
     */
    private $updatedCols = [];

    /**
     * @ORM\Column(type="text")
     * @Groups({"read"})
     */
    private $query;


    public function getId(): ?int
    {
        return $this->id;
    }

    public function getTableId(): ?string
    {
        return $this->tableId;
    }

    public function setTableId(string $tableId): self
    {
        $this->tableId = $tableId;

        return $this;
    }

    public function getTableName(): ?string
    {
        return $this->tableName;
    }

    public function setTableName(string $tableName): self
    {
        $this->tableName = $tableName;

        return $this;
    }

    public function getUserName(): ?string
    {
        return $this->userName;
    }

    public function setUserName(string $userName): self
    {
        $this->userName = $userName;

        return $this;
    }

    public function getActionTimestamp(): ?\DateTimeInterface
    {
        return $this->actionTimestamp;
    }

    public function setActionTimestamp(\DateTimeInterface $actionTimestamp): self
    {
        $this->actionTimestamp = $actionTimestamp;

        return $this;
    }

    public function getAction(): ?string
    {
        return $this->action;
    }

    public function setAction(string $action): self
    {
        $this->action = $action;

        return $this;
    }

    public function getOldValues(): ?array
    {
        return $this->oldValues;
    }

    public function setOldValues(?array $oldValues): self
    {
        $this->oldValues = $oldValues;

        return $this;
    }

    public function getNewValues(): ?array
    {
        return $this->newValues;
    }

    public function setNewValues(array $newValues): self
    {
        $this->newValues = $newValues;

        return $this;
    }

    public function getUpdatedCols(): ?array
    {
        return $this->updatedCols;
    }

    public function setUpdatedCols(?array $updatedCols): self
    {
        $this->updatedCols = $updatedCols;

        return $this;
    }

    public function getQuery(): ?string
    {
        return $this->query;
    }

    public function setQuery(string $query): self
    {
        $this->query = $query;

        return $this;
    }
}
