<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Serializer\Annotation\MaxDepth;

use App\Uuid;
use App\Traits\DateTimeTrait as dateTimeTrait;
use Symfony\Component\Serializer\Annotation\Groups;
use Symfony\Component\Validator\Constraints as Assert;

use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;
/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "checkMetricId": "exact",
 *     "mark": "ipartial",
 *     "minQuality": "exact",
 *     "maxQuality": "exact",
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *     "id",
 *     "checkMetricId",
 *     "mark",
 *     "minQuality",
 *     "maxQuality",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "id",
 *     "checkMetricId",
 *     "mark",
 *     "minQuality",
 *     "maxQuality",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": null
 *  }
 * )
 * @ApiResource()
 * @ORM\Entity(repositoryClass="App\Repository\CheckMetricQualityLimitRepository")
 */
class CheckMetricQualityLimit
{
    use dateTimeTrait;

    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="UUID")
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="guid")
     * @Groups({"read"})
     */
    private $checkMetricId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\CheckMetric")
     * @ORM\JoinColumn(nullable=false, name="check_metric_id", referencedColumnName="id", onDelete="CASCADE")
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $checkMetric;

    /**
     * @ORM\Column(type="string", length=1, nullable=false)
     * @Groups({"read"})
     */
    private $mark;

    /**
     * @ORM\Column(type="string", nullable=false)
     * @Groups({"read"})
     */
    private $minQuality;

    /**
     * @ORM\Column(type="string", nullable=false)
     * @Groups({"read"})
     */
    private $maxQuality;


    public function getId(): ?string
    {
        return $this->id;
    }

    public function setId(?string $id): self
    {
        $this->id = $id;

        return $this;
    }

    public function getCheckMetricId(): ?string
    {
        return $this->checkMetricId;
    }

    public function setCheckMetricId(?string $checkMetricId): self
    {
        $this->checkMetricId = $checkMetricId;

        return $this;
    }

    public function getCheckMetric(): ?CheckMetric
    {
        return $this->checkMetric;
    }

    public function setCheckMetric(?CheckMetric $checkMetric): self
    {
        $this->checkMetric = $checkMetric;

        return $this;
    }

    public function getMark(): ?string
    {
        return $this->mark;
    }

    public function setMark(?string $mark): self
    {
        $this->mark = $mark;

        return $this;
    }

    public function getMinQuality(): ?string
    {
        return $this->minQuality;
    }

    public function setMinQuality(?string $minQuality): self
    {
        $this->minQuality = $minQuality;

        return $this;
    }

    public function getMaxQuality(): ?string
    {
        return $this->maxQuality;
    }

    public function setMaxQuality(?string $maxQuality): self
    {
        $this->maxQuality = $maxQuality;

        return $this;
    }
}
