<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;
use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Serializer\Annotation\MaxDepth;

use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use Symfony\Component\Serializer\Annotation\Groups;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\RangeFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;
use Doctrine\ORM\Mapping\UniqueConstraint;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "workerId": "exact",
 *     "sectionId": "exact",
 *     "priority": "exact",
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *     "workerId",
 *     "sectionId",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "workerId",
 *     "sectionId",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": null
 *  }
 * )
 * @ApiResource()
 * @ORM\Entity(repositoryClass="App\Repository\CheckPriorityRepository")
 * @ORM\Table(
 *  indexes= {
 *    @ORM\Index(
 *      name="check_priority_workerId",
 *      columns={ "worker_id" }
 *    ),
 *    @ORM\Index(
 *      name="check_priority_sectionId",
 *      columns={ "section_id" }
 *    ),
 *  },
 *   uniqueConstraints={
 *     @UniqueConstraint(name="check_priority_workerId_sectionId",
 *       columns={
 *         "worker_id", "section_id"
 *       }
 *     ),
 *   }
 * )
 */
class CheckPriority
{
    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @ORM\GeneratedValue(strategy="UUID")
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="guid", nullable=false)
     * @Groups({"read"})
     */
    private $workerId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Worker")
     * @ORM\JoinColumn(nullable=false)
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $worker;

    /**
     * @ORM\Column(type="guid", nullable=false)
     * @Groups({"read"})
     */
    private $sectionId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Section")
     * @ORM\JoinColumn(nullable=false)
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $section;

    /**
     * @ORM\Column(type="smallint", options={"default" : 1})
     * @Groups({"read"})
     */
    private $priority;

    /**
     * @ORM\Column(type="datetimetz", nullable=true)
     * @Groups({"read"})
     */
    private $lastCheck;

    /**
     * @ORM\Column(type="boolean", options={"default" : false})
     * @Groups({"read"})
     */
    private $isChecking = false;

    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getWorkerId(): ?string
    {
        return $this->workerId;
    }

    public function setWorkerId(?string $workerId): self
    {
        $this->workerId = $workerId;

        return $this;
    }

    public function getWorker(): ?Worker
    {
        return $this->worker;
    }

    public function setWorker(?Worker $worker): self
    {
        $this->worker = $worker;

        return $this;
    }

    public function getSectionId(): ?string
    {
        return $this->sectionId;
    }

    public function setSectionId(?string $sectionId): self
    {
        $this->sectionId = $sectionId;

        return $this;
    }

    public function getSection(): ?Section
    {
        return $this->section;
    }

    public function setSection(?Section $section): self
    {
        $this->section = $section;

        return $this;
    }

    public function getPriority(): ?int
    {
        return $this->priority;
    }

    public function setPriority(int $priority): self
    {
        $this->priority = $priority;

        return $this;
    }

    public function getLastCheck(): ?\DateTimeInterface
    {
        return $this->lastCheck;
    }

    public function setLastCheck(?\DateTimeInterface $lastCheck): self
    {
        $this->lastCheck = $lastCheck;

        return $this;
    }

    public function getIsChecking(): bool
    {
        return $this->isChecking;
    }

    public function setIsChecking(bool $isChecking): self
    {
        $this->isChecking = $isChecking;

        return $this;
    }
}
