<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\ORM\Mapping as ORM;

use App\Uuid;
use App\Traits\DateTimeTrait as dateTimeTrait;
use Symfony\Component\Serializer\Annotation\MaxDepth;
use Symfony\Component\Serializer\Annotation\Groups;
use Symfony\Component\Validator\Constraints as Assert;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\RangeFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;
use Doctrine\ORM\Mapping\UniqueConstraint;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   DateFilter::class,
 *   properties={
 *     "createdAt",
 *     "updatedAt",
 *   }
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "code": "exact",
 *     "collectableId": "exact",
 *     "plantId": "exact",
 *     "greenhouseId": "exact",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "createdAt",
 *     "updatedAt",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ORM\Table(
 *   name="code_metric",
 *   indexes={
 *     @ORM\Index(
 *       name="code_metric_code",
 *       columns={"code"}
 *     ),
 *     @ORM\Index(
 *       name="code_metric_collectable_id",
 *       columns={"collectable_id"}
 *     ),
 *     @ORM\Index(
 *       name="code_metric_greenhouse_id",
 *       columns={"greenhouse_id"}
 *     ),
 *     @ORM\Index(
 *       name="code_metric_plant_id",
 *       columns={"plant_id"}
 *     ),
 *     @ORM\Index(
 *       name="code_metric_created_at",
 *       columns={"created_at"}
 *     ),
 *     @ORM\Index(
 *       name="code_metric_updated_at",
 *       columns={"updated_at"}
 *     ),
 *   },
 *   uniqueConstraints={
 *     @UniqueConstraint(name="code_metric_code_code_collectableId",
 *       columns={
 *         "code", "collectable_id"
 *       }
 *     ),
 *   },
 * )
 * @ORM\Entity(repositoryClass="App\Repository\CodeMetricRepository")
 */
class CodeMetric
{
    use dateTimeTrait;

    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="UUID")
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="guid")
     * @Groups({"read"})
     */
    private $code;

    /**
     * @ORM\Column(type="guid")
     * @Groups({"read"})
     */
    private $collectableId;

    /**
     * @ORM\Column(type="guid")
     * @Groups({"read"})
     */
    private $plantId;

    /**
     * @ORM\Column(type="guid")
     * @Groups({"read"})
     */
    private $greenhouseId;

    public function getId(): ?string
    {
        return $this->id;
    }

    public function setId(?string $id): self
    {
        $this->id = $id;

        return $this;
    }

    public function getCode(): ?string
    {
        return $this->code;
    }

    public function setCode(string $code): self
    {
        $this->code = $code;

        return $this;
    }

    public function getCollectableId(): ?string
    {
        return $this->collectableId;
    }

    public function setCollectableId(string $collectableId): self
    {
        $this->collectableId = $collectableId;

        return $this;
    }

    public function getPlantId(): ?string
    {
        return $this->plantId;
    }

    public function setPlantId(string $plantId): self
    {
        $this->plantId = $plantId;

        return $this;
    }

    public function getGreenhouseId(): ?string
    {
        return $this->greenhouseId;
    }

    public function setGreenhouseId(string $greenhouseId): self
    {
        $this->greenhouseId = $greenhouseId;

        return $this;
    }
}
