<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;
use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Serializer\Annotation\Groups;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;

use ApiPlatform\Core\Serializer\Filter\GroupFilter;

/**
 * @ApiResource()
 * @ApiFilter(
 *   SearchFilter::class, 
 *   properties={
 *     "id": "exact",   
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class, 
 *   properties={
 *     "parentId",
 *     "altId",
 *     "rawParentId",
 *     "rawAltId",     
 *   }
 * )
 * @ApiFilter(
 *  GroupFilter::class,
 *  arguments={
 *      "parameterName": "groups",
 *      "overrideDefaultGroups": true,
 *      "whitelist": {
 *          "read",
 *          "mobile",
 *      }
 *  }
 * )
 * @ORM\Table(
 *   name="department",
 *   indexes={
 *     @ORM\Index(
 *       name="department_parent_id", 
 *       columns={"parent_id"}
 *     ),
 *     @ORM\Index(
 *       name="department_alt_id", 
 *       columns={"alt_id"}
 *     ),
 *     @ORM\Index(
 *       name="department_raw_parent_id", 
 *       columns={"raw_parent_id"}
 *     ),
 *     @ORM\Index(
 *       name="department_raw_alt_id", 
 *       columns={"raw_alt_id"}
 *     ),
 *   }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\DepartmentRepository")
 */
class Department
{
    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read", "mobile"})
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     * @Groups({"read", "mobile"})
     */
    private $name;

    /**
     * @ORM\Column(type="guid", nullable=true)
     */
    private $parentId;

    /**
     * @ORM\Column(type="guid", nullable=true)
     */
    private $altId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Department")
     */
    private $parent;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(type="datetimetz")
     */
    private $createdAt;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="update")
     * @ORM\Column(type="datetimetz")
     */
    private $updatedAt;

    /**
     * @ORM\Column(type="json", nullable=true)
     */
    private $raw = [];

    /**
     * @Groups({"read"})
     */
    private $structure = [];

    /**
     * @ORM\Column(type="guid", nullable=true)
     */
    private $rawParentId;

    /**
     * @ORM\Column(type="guid", nullable=true)
     */
    private $rawAltId;    

    public function setId(?string $id): void
    {
        $this->id = $id;
    }     

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function getParentId(): ?string
    {
        return $this->parentId;
    }

    public function setParentId(?string $parentId): self
    {
        $this->parentId = $parentId;

        return $this;
    }

    public function getAltId(): ?string
    {
        return $this->altId;
    }

    public function setAltId(?string $altId): self
    {
        $this->altId = $altId;

        return $this;
    }

    public function getParent(): ?self
    {
        return $this->parent;
    }

    public function setParent(?self $parent): self
    {
        $this->parent = $parent;

        return $this;
    }

    public function getCreatedAt(): ?\DateTimeInterface
    {
        return $this->createdAt;
    }

    public function getUpdatedAt(): ?\DateTimeInterface
    {
        return $this->updatedAt;
    }

    public function getRaw(): ?array
    {
        return $this->raw;
    }

    public function setRaw(?array $raw): self
    {
        $this->raw = $raw;

        return $this;
    }

    public function getStructure(): ?array
    {
        $structure = $this->parent && $this->parent->getStructure() ?
            $this->parent->getStructure() :
            [];

        $structure[] = [
          'level' => count($structure),
          'id' => $this->getId(),
          'name' => $this->getName(),
        ];

        return $structure;
    }

    public function getRawParentId(): ?string
    {
        return $this->rawParentId;
    }

    public function setRawParentId(?string $rawParentId): self
    {
        $this->rawParentId = $rawParentId;

        return $this;
    }

    public function getRawAltId(): ?string
    {
        return $this->rawAltId;
    }

    public function setRawAltId(?string $rawAltId): self
    {
        $this->rawAltId = $rawAltId;

        return $this;
    }
}
