<?php declare(strict_types=1);

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;
use ApiPlatform\Core\Annotation\ApiProperty;
use App\Traits\DateTimeTrait as dateTimeTrait;

use Symfony\Component\Serializer\Annotation\MaxDepth;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;

use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\RangeFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;

use Symfony\Component\Serializer\Annotation\Groups;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "name": "ipartial",
 *     "description": "ipartial",
 *     "length": "exact",
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *     "parentId",
 *     "length",
 *   }
 * )
 * @ApiFilter(
 *   RangeFilter::class,
 *   properties={
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "name",
 *     "description",
 *     "parentId",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": {
 *          "name",
 *          "description",
 *          "id",
 *          "parentId",
 *          "length",
 *      }
 *  }
 * )
 *  @ORM\Table(
 *   name="greenhouse",
 *   indexes={
 *     @ORM\Index(
 *       name="greenhouse_parent_id",
 *       columns={"parent_id"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_name",
 *       columns={"name"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_raw_parent_id",
 *       columns={"raw_parent_id"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_is_folder",
 *       columns={"is_folder"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_description",
 *       columns={"description"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_department_id",
 *       columns={"department_id"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_raw_department_id",
 *       columns={"raw_department_id"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_comment",
 *       columns={"comment"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_sown_area",
 *       columns={"sown_area"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_raw_greenhouse_topology",
 *       columns={"raw_greenhouse_topology"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_green_house_topology",
 *       columns={"green_house_topology"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_raw_work_parameters",
 *       columns={"raw_work_parameters"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_raw_work_parameters",
 *       columns={"raw_work_parameters"}
 *     ),
 *     @ORM\Index(
 *       name="greenhouse_raw",
 *       columns={"raw"}
 *     ),
 *   }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\GreenhouseRepository")
 *
 * @uses Catalog_актСтруктураТеплиц
 */
class Greenhouse
{
    use dateTimeTrait;

    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @var string|null
     *
     * @ORM\Column(type="string", length=128, nullable=true)
     * @Groups({"read"})
     */
    private $name;

    /**
     * @var Greenhouse|null
     *
     * @ORM\ManyToOne(targetEntity="App\Entity\Greenhouse")
     * @ORM\JoinColumn(name="parent_id", referencedColumnName="id")
     * @Groups({"read"})
     */
    private $parentId;

    /**
     * @var string|null
     *
     * @ORM\Column(type="guid",  nullable=true)
     */
    private $rawParentId;

    /**
     * @var bool
     *
     * @ORM\Column(type="boolean", options={"default": false})
     */
    private $isFolder;

    /**
     * @var string|null
     *
     * @ORM\Column(type="text", nullable=true)
     * @Groups({"read"})
     */
    private $description;

    /**
     * @var string|null
     *
     * @ORM\Column(type="guid", nullable=true)
     */
    private $departmentId;

    /**
     * @var string|null
     *
     * @ORM\Column(type="guid", nullable=true)
     */
    private $rawDepartmentId;

    /**
     * @var string|null
     *
     * @ORM\Column(type="text", nullable=true)
     */
    private $comment;

    /**
     * @ORM\Column(type="string", nullable=true)
     */
    private $sownArea;

    /**
     * @ORM\Column(type="smallint", nullable=true)
     * @Groups({"read"})
     */
    private $length = null;

    /**
     * @ORM\Column(type="json_array", nullable=true, options={"jsonb"=true})
     */
    private $rawGreenhouseTopology = [];

    /**
     * @todo: OneToMany(ТопологияТеплицы)
     * @ORM\Column(type="json_array", nullable=true, options={"jsonb"=true})
     */
    private $greenHouseTopology = [];

    /**
     * @ORM\Column(type="json_array", nullable=true, options={"jsonb"=true})
     */
    private $rawWorkParameters = [];

    /**
     * @todo: OneToMany(НастройкиПараметровВыполненияРабот)
     * @ORM\Column(type="json_array", nullable=true, options={"jsonb"=true})
     */
    private $workParameters = [];

    /**
     * @ORM\Column(type="json_array", nullable=true, options={"jsonb"=true})
     */
    private $raw = [];

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\GreenhouseSection", mappedBy="greenhouse")
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $greenhouseSections;

    public function __construct()
    {
        $this->greenhouseSections = new ArrayCollection();
    }

    public function setId(?string $id): Greenhouse
    {
        $this->id = $id;

        return $this;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getParentId(): ?Greenhouse
    {
        return $this->parentId;
    }

    public function setParentId(?Greenhouse $parentId): Greenhouse
    {
        $this->parentId = $parentId;

        return $this;
    }

    public function getRawParentId(): ?string
    {
        return $this->rawParentId;
    }

    public function setRawParentId(?string $rawParentId): Greenhouse
    {
        $this->rawParentId = $rawParentId;

        return $this;
    }

    public function getIsFolder(): ?bool
    {
        return $this->isFolder;
    }

    public function setIsFolder(bool $isFolder): Greenhouse
    {
        $this->isFolder = $isFolder;

        return $this;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): Greenhouse
    {
        $this->name = $name;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(?string $description): Greenhouse
    {
        $this->description = $description;

        return $this;
    }

    public function getDepartmentId(): ?string
    {
        return $this->departmentId;
    }

    public function setDepartmentId(?string $departmentId): Greenhouse
    {
        $this->departmentId = $departmentId;

        return $this;
    }

    public function getRawDepartmentId(): ?string
    {
        return $this->rawDepartmentId;
    }

    public function setRawDepartmentId(?string $rawDepartmentId): Greenhouse
    {
        $this->rawDepartmentId = $rawDepartmentId;

        return $this;
    }

    public function getComment(): ?string
    {
        return $this->comment;
    }

    public function setComment(?string $comment): Greenhouse
    {
        $this->comment = $comment;

        return $this;
    }

    public function getSownArea(): ?string
    {
        return $this->sownArea;
    }

    public function setSownArea(?string $sownArea): Greenhouse
    {
        $this->sownArea = $sownArea;

        return $this;
    }

        public function getLength(): ?int
    {
        return $this->length;
    }

    public function setLength(?int $length): self
    {
        $this->length = $length;

        return $this;
    }

    public function getRawGreenhouseTopology(): ?array
    {
        return $this->rawGreenhouseTopology;
    }

    public function setRawGreenhouseTopology(?array $rawGreenhouseTopology): Greenhouse
    {
        $this->rawGreenhouseTopology = $rawGreenhouseTopology;

        return $this;
    }

    public function getGreenHouseTopology(): ?array
    {
        return $this->greenHouseTopology;
    }

    /**
     * @todo: OneToMany
     */
    public function setGreenHouseTopology(?array $greenHouseTopology): Greenhouse
    {
        $this->greenHouseTopology = $greenHouseTopology;

        return $this;
    }

    public function getRawWorkParameters(): ?array
    {
        return $this->rawWorkParameters;
    }

    public function setRawWorkParameters(?array $rawWorkParameters): Greenhouse
    {
        $this->rawWorkParameters = $rawWorkParameters;

        return $this;
    }

    public function getWorkParameters(): ?array
    {
        return $this->workParameters;
    }

    /**
     * TODO: OneToMany
     */
    public function setWorkParameters(?array $workParameters): Greenhouse
    {
        $this->workParameters = $workParameters;

        return $this;
    }

    public function getRaw(): ?array
    {
        return $this->raw;
    }

    public function setRaw(?array $raw): Greenhouse
    {
        $this->raw = $raw;

        return $this;
    }

    /**
     * @return Collection|GreenhouseSection[]
     */
    public function getGreenhouseSections(): Collection
    {
        return $this->greenhouseSections;
    }

    public function addGreenhouseSection(GreenhouseSection $greenhouseSection): self
    {
        if (!$this->greenhouseSections->contains($greenhouseSection)) {
            $this->greenhouseSections[] = $greenhouseSection;
            $greenhouseSection->setGreenhouse($this);
        }

        return $this;
    }

    public function removeGreenhouseSection(GreenhouseSection $greenhouseSection): self
    {
        if ($this->greenhouseSections->contains($greenhouseSection)) {
            $this->greenhouseSections->removeElement($greenhouseSection);
            // set the owning side to null (unless already changed)
            if ($greenhouseSection->getGreenhouse() === $this) {
                $greenhouseSection->setGreenhouse(null);
            }
        }

        return $this;
    }

}
