<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;
use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Component\Validator\Constraints as Assert;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\BooleanFilter;
use Symfony\Component\Serializer\Annotation\Groups;
use Doctrine\ORM\Mapping\UniqueConstraint;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use Symfony\Component\Serializer\Annotation\MaxDepth;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;

/**
 * @ApiResource(
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   }, 
 * )
 * @ORM\Entity(repositoryClass="App\Repository\GreenhouseSectionRepository")
 * @ORM\Table(
 *   name="greenhousesection",
 *   indexes={
 *     @ORM\Index(
 *       name="greenhousesection_greenhouse",
 *       columns={"greenhouse_id"}
 *     ),
 *     @ORM\Index(
 *       name="greenhousesection_section",
 *       columns={"section_id"}
 *     ),
 *   },
 *   uniqueConstraints={
 *     @UniqueConstraint(name="sectionId_greenhouseId",
 *       columns={
 *         "section_id", "greenhouse_id"
 *       }
 *     ),
 *   },
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "greenhouseId": "exact",
 *     "sectionId": "exact",
 *     "section.hasQualityCheck": "exact",
 *     "onPause": "exact",
 *   }
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": {
 *          "name",
 *          "module",
 *          "sectionId",
 *          "greenhouseId",
 *          "minLeadTime",
 *          "maxLeadTime",
 *          "onPause",
 *          "pauseChangedAt",
 *          "id",
 *          "manager",
 *      }
 *  }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *    "section.name",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *   BooleanFilter::class,
 *   properties={
 *     "onPause",
 *     "section.isQuality",
 *     "section.isHarvesting",
 *     "section.isPhenology",
 *     "section.isGuarding",
 *     "section.isSpraying",
 *   }
 * )
 */
class GreenhouseSection
{
    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read"})
     */
    private $sectionId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Section", inversedBy="greenhouseSections")
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $section;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read"})
     */
    private $greenhouseId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Greenhouse", inversedBy="greenhouseSections")
     */
    private $greenhouse;

    /**
     * @ORM\Column(type="boolean", options={"default" : false})
     * @Groups({"read"})
     */
    private $onPause;

    /**
     * @ORM\Column(type="datetimetz", nullable=true)
     * @Groups({"read"})
     */
    private $pauseChangedAt;

    /**
     * @ORM\Column(type="string", nullable=true)
     * @Groups({"read"})
     */
    private $manager;

    /**
     * @Groups({"read"})
     */
    private $name;

    /**
     * @Groups({"read"})
     */
    private $module;

    /**
     * @ORM\Column(type="smallint", options={"default" : 1})
     * @Groups({"read"})
     */
    private $minLeadTime;

    /**
     * @ORM\Column(type="smallint", nullable=true, options={"default" : null})
     * @Groups({"read"})
     */
    private $maxLeadTime;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(type="datetimetz")
     */
    private $createdAt;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="update")
     * @ORM\Column(type="datetimetz")
     */
    private $updatedAt;

    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getSection(): ?Section
    {
        return $this->section;
    }

    public function setSection(?Section $section): self
    {
        $this->section = $section;

        return $this;
    }

    public function getGreenhouse(): ?Greenhouse
    {
        return $this->greenhouse;
    }

    public function setGreenhouse(?Greenhouse $greenhouse): self
    {
        $this->greenhouse = $greenhouse;

        return $this;
    }

    public function getOnPause(): ?bool
    {
        return $this->onPause;
    }

    public function setOnPause(bool $onPause): self
    {
        $this->onPause = $onPause;

        return $this;
    }

    public function getPauseChangedAt(): ?\DateTimeInterface
    {
        return $this->pauseChangedAt;
    }

    public function setPauseChangedAt(\DateTimeInterface $pauseChangedAt): self
    {
        $this->pauseChangedAt = $pauseChangedAt;

        return $this;
    }

    public function getManager(): ?string
    {
        return $this->manager;
    }

    public function setManager(string $manager): self
    {
        $this->manager = $manager;

        return $this;
    }

    public function getCreatedAt(): ?\DateTimeInterface
    {
        return $this->createdAt;
    }

    public function getUpdatedAt(): ?\DateTimeInterface
    {
        return $this->updatedAt;
    }

    public function getSectionId(): ?string
    {
        return $this->sectionId;
    }

    public function setSectionId(?string $sectionId): self
    {
        $this->sectionId = $sectionId;

        return $this;
    }

    public function getGreenhouseId(): ?string
    {
        return $this->greenhouseId;
    }

    public function setGreenhouseId(?string $greenhouseId): self
    {
        $this->greenhouseId = $greenhouseId;

        return $this;
    }

    public function setCreatedAt(\DateTimeInterface $createdAt): self
    {
        $this->createdAt = $createdAt;

        return $this;
    }

    public function setUpdatedAt(\DateTimeInterface $updatedAt): self
    {
        $this->updatedAt = $updatedAt;

        return $this;
    }

    public function getName(): ?string
    {
        return $this->section ? $this->section->getName() : "";
    }

    public function getModule(): ?string
    {
        return $this->section ? $this->section->getModule() : "";
    }

    public function getMinLeadTime(): ?int
    {
        return $this->minLeadTime;
    }

    public function setMinLeadTime(?int $minLeadTime): self
    {
        $this->minLeadTime = $minLeadTime;

        return $this;
    }

    public function getMaxLeadTime(): ?int
    {
        return $this->maxLeadTime;
    }

    public function setMaxLeadTime(?int $maxLeadTime): self
    {
        $this->maxLeadTime = $maxLeadTime;

        return $this;
    }
}
