<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;

use Symfony\Component\Serializer\Annotation\MaxDepth;
use Symfony\Component\Serializer\Annotation\Groups;

use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping\UniqueConstraint;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 *   itemOperations={"get", "put", "patch"},
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "taskId": "exact",
 *     "task.workerId": "exact",
 *     "task.rowId": "exact",
 *     "valve.greenhouseId": "exact",
 *     "valveId": "exact",
 *     "valve.number": "exact",
 *   }
 * )
 * @ApiFilter(
 *   DateFilter::class,
 *   properties={
 *     "registeredAt",
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *     "taskId",
 *     "valveId",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "taskId",
 *     "valveId",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": null
 *  }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\HistoricalValveRepository")
 */
class HistoricalValve
{
    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="UUID")
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="guid", nullable=false)
     * @Groups({"read"})
     */
    private $taskId;
    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Task")
     * @ORM\JoinColumn(nullable=false)
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $task;

    /**
     * @ORM\Column(type="guid", nullable=false)
     * @Groups({"read"})
     */
    private $valveId;
    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Valve")
     * @ORM\JoinColumn(nullable=false)
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $valve;

    /**
     * @ORM\Column(type="datetimetz")
     * @Groups({"read"})
     */
    private $registeredAt;

    /**
     * @ORM\Column(type="float", nullable=true)
     * @Groups({"read"})
     */
    private $volume;

    /**
     * @ORM\Column(type="float", nullable=true)
     * @Groups({"read"})
     */
    private $electricConduction;

    /**
     * @ORM\Column(type="float", nullable=true)
     * @Groups({"read"})
     */
    private $potentialHydrogen;

    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getTaskId(): ?string
    {
        return $this->taskId;
    }

    public function setTaskId(?string $taskId): self
    {
        $this->taskId = $taskId;

        return $this;
    }

    public function getTask(): ?Task
    {
        return $this->task;
    }

    public function setTask(?Task $task): self
    {
        $this->task = $task;

        return $this;
    }

    public function getValveId(): ?string
    {
        return $this->valveId;
    }

    public function setValveId(?string $valveId): self
    {
        $this->valveId = $valveId;

        return $this;
    }

    public function getValve(): ?Valve
    {
        return $this->valve;
    }

    public function setValve(?Valve $valve): self
    {
        $this->valve = $valve;

        return $this;
    }

    public function getRegisteredAt(): ?\DateTimeInterface
    {
        return $this->registeredAt;
    }

    public function setRegisteredAt(\DateTimeInterface $registeredAt): self
    {
        $this->registeredAt = $registeredAt;

        return $this;
    }

    public function getVolume(): ?float
    {
        return $this->volume;
    }

    public function setVolume(?float $volume): self
    {
        $this->volume = $volume;

        return $this;
    }

    public function getElectricConduction(): ?float
    {
        return $this->electricConduction;
    }

    public function setElectricConduction(?float $electricConduction): self
    {
        $this->electricConduction = $electricConduction;

        return $this;
    }

    public function getPotentialHydrogen(): ?float
    {
        return $this->potentialHydrogen;
    }

    public function setPotentialHydrogen(?float $potentialHydrogen): self
    {
        $this->potentialHydrogen = $potentialHydrogen;

        return $this;
    }
}
