<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

use App\Uuid;
use App\Traits\DateTimeTrait as dateTimeTrait;
use Symfony\Component\Serializer\Annotation\MaxDepth;
use Symfony\Component\Serializer\Annotation\Groups;
use Symfony\Component\Validator\Constraints as Assert;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\RangeFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   DateFilter::class,
 *   properties={
 *     "createdAt",
 *     "updatedAt",
 *   }
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "name": "ipartial",
 *     "color": "ipartial",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "name",
 *     "color",
 *     "orderBy",
 *     "createdAt",
 *     "updatedAt",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": {
 *          "name",
 *          "color",
 *          "orderBy",
 *          "createdAt",
 *          "updatedAt",
 *      }
 *  }
 * )
 * @ORM\Table(
 *   name="intensity",
 *   indexes={
 *     @ORM\Index(
 *       name="intensity_name",
 *       columns={"name"}
 *     ),
 *     @ORM\Index(
 *       name="intensity_color",
 *       columns={"color"}
 *     ),
 *     @ORM\Index(
 *       name="intensity_order_by",
 *       columns={"order_by"}
 *     ),
 *   }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\IntensityRepository")
 */
class Intensity
{
    use dateTimeTrait;

    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     * @Groups({"read"})
     */
    private $name;

    /**
     * @ORM\Column(type="string", length=255)
     * @Groups({"read"})
     */
    private $color;

    /**
     * @ORM\Column(type="smallint", options={"default": 0})
     * @Groups({"read"})
     */
    private $orderBy = 0;



    public function getId(): ?string
    {
        return $this->id;
    }

    public function setId(?string $id): self
    {
        $this->id = $id;

        return $this;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function getColor(): ?string
    {
        return $this->color;
    }

    public function setColor(string $color): self
    {
        $this->color = $color;

        return $this;
    }

    public function getOrderBy(): ?int
    {
        return $this->orderBy;
    }

    public function setOrderBy(int $orderBy): self
    {
        $this->orderBy = $orderBy;

        return $this;
    }


}
