<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\ORM\Mapping as ORM;

use Symfony\Component\Serializer\Annotation\MaxDepth;
use Symfony\Component\Serializer\Annotation\Groups;
use Symfony\Component\Validator\Constraints as Assert;

use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\RangeFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;
use Doctrine\ORM\Mapping\UniqueConstraint;
/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "pestId": "exact",
 *     "intensityId": "exact",
 *     "pest.name": "ipartial",
 *     "intensity.name": "ipartial",
 *     "description": "exact",
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *     "pestId",
 *     "intensityId",
 *     "description",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "pestId",
 *     "intensityId",
 *     "description",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": {
 *          "pestId",
 *          "intensityId",
 *          "description",
 *      }
 *  }
 * )
 * @ApiResource()
 * @ORM\Entity(repositoryClass="App\Repository\IntensityDescriptionRepository")
 * @ORM\Table(
 *  indexes= {
 *    @ORM\Index(
 *      name="intensity_decriptions_pestId",
 *      columns={ "pest_id" }
 *    ),
 *    @ORM\Index(
 *      name="intensity_decriptions_intensityId",
 *      columns={ "intensity_id" }
 *    ),
 *  },
 *   uniqueConstraints={
 *     @UniqueConstraint(name="intensity_decriptions_pestId_intensityId",
 *       columns={
 *         "pest_id", "intensity_id"
 *       }
 *     ),
 *   },
 * )
 */
class IntensityDescription
{
    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @ORM\GeneratedValue(strategy="UUID")
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="guid", nullable=false)
     * @Groups({"read"})
     */
    private $pestId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Pest")
     * @ORM\JoinColumn(nullable=true, name="pest_id", referencedColumnName="id", onDelete="CASCADE")
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $pest;

    /**
     * @ORM\Column(type="guid", nullable=false)
     * @Groups({"read"})
     */
    private $intensityId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Intensity")
     * @ORM\JoinColumn(nullable=true)
     * @Groups({"read"})
     */
    private $intensity;

    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read"})
     */
    private $description;

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(?string $description): self
    {
        $this->description = $description;

        return $this;
    }

    public function getPestId(): ?string
    {
        return $this->pestId;
    }

    public function setPestId(?string $pestId): self
    {
        $this->pestId = $pestId;

        return $this;
    }

    public function getPest(): ?Pest
    {
        return $this->pest;
    }

    public function setPest(?Pest $pest): self
    {
        $this->pest = $pest;

        return $this;
    }

    public function getIntensityId(): ?string
    {
        return $this->intensityId;
    }

    public function setIntensityId(?string $intensityId): self
    {
        $this->intensityId = $intensityId;

        return $this;
    }

    public function getIntensity(): ?Intensity
    {
        return $this->intensity;
    }

    public function setIntensity(?Intensity $intensity): self
    {
        $this->intensity = $intensity;

        return $this;
    }
}
