<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;
use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Component\Validator\Constraints as Assert;

use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;

/**
 * @ApiResource()
 * @ApiFilter(
 *   SearchFilter::class, 
 *   properties={
 *     "type": "exact", 
 *     "isProcessed": "exact",
 *   }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\MobileRequestRepository")
 * @ORM\Table(
 *   name="mobile_request",
 *   indexes={
 *     @ORM\Index(
 *       name="mobile_request_type", 
 *       columns={"type"}
 *     ),
 *     @ORM\Index(
 *       name="mobile_request_is_processed", 
 *       columns={"is_processed"}
 *     ),
 *   }
 * )
 */
class MobileRequest
{
    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $type;

    /**
     * @ORM\Column(type="json")
     */
    private $raw = [];

    /**
     * @ORM\Column(type="json")
     */
    private $meta = [];

    /**
     * @ORM\Column(type="boolean")
     */
    private $isProcessed;

    /**
     * @ORM\Column(type="smallint")
     */
    private $triesAmount;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(type="datetimetz")
     */
    private $createdAt;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="update")
     * @ORM\Column(type="datetimetz")
     */
    private $updatedAt;

    public function setId(?string $id): void
    {
        $this->id = $id;
    }    

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getType(): ?string
    {
        return $this->type;
    }

    public function setType(string $type): self
    {
        $this->type = $type;

        return $this;
    }

    public function getRaw(): ?array
    {
        return $this->raw;
    }

    public function setRaw(array $raw): self
    {
        $this->raw = $raw;

        return $this;
    }

    public function getMeta(): ?array
    {
        return $this->meta;
    }

    public function setMeta(array $meta): self
    {
        $this->meta = $meta;

        return $this;
    }

    public function getIsProcessed(): ?bool
    {
        return $this->isProcessed;
    }

    public function setIsProcessed(bool $isProcessed): self
    {
        $this->isProcessed = $isProcessed;

        return $this;
    }

    public function getTriesAmount(): ?int
    {
        return $this->triesAmount;
    }

    public function setTriesAmount(int $triesAmount): self
    {
        $this->triesAmount = $triesAmount;

        return $this;
    }

    public function getCreatedAt(): ?\DateTimeInterface
    {
        return $this->createdAt;
    }

    public function getUpdatedAt(): ?\DateTimeInterface
    {
        return $this->updatedAt;
    }
}
