<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

use App\Uuid;
use App\Traits\DateTimeTrait as dateTimeTrait;
use Symfony\Component\Serializer\Annotation\MaxDepth;
use Symfony\Component\Serializer\Annotation\Groups;
use Symfony\Component\Validator\Constraints as Assert;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\RangeFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   DateFilter::class,
 *   properties={
 *     "createdAt",
 *     "updatedAt",
 *   }
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "name": "ipartial",
 *     "type": "exact",
 *     "isActive": "exact",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "name",
 *     "createdAt",
 *     "updatedAt",
 *     "isActive",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": {
 *          "isActive",
 *          "name",
 *          "createdAt",
 *          "updatedAt",
 *      }
 *  }
 * )
 * @ORM\Table(
 *   name="pest",
 *   indexes={
 *     @ORM\Index(
 *       name="pest_name",
 *       columns={"name"}
 *     ),
 *   }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\PestRepository")
 */
class Pest
{
    use dateTimeTrait;

    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     * @Groups({"read"})
     */
    private $name;

    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read"})
     */
    private $type;

    /**
     * @ORM\Column(type="boolean", options={"default" : true})
     * @Groups({"read"})
     */
    private $isActive = true;


    public function getId(): ?string
    {
        return $this->id;
    }

    public function setId(?string $id): self
    {
        $this->id = $id;

        return $this;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function getType(): ?string
    {
        return $this->type;
    }

    public function setType(?string $type): self
    {
        $this->type = $type;

        return $this;
    }

    public function getIsActive(): ?bool
    {
        return $this->isActive;
    }

    public function setIsActive(?bool $isActive): self
    {
        $this->isActive = $isActive;

        return $this;
    }

}
