<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;
use App\Traits\DateTimeTrait as dateTimeTrait;
use ApiPlatform\Core\Annotation\ApiProperty;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Serializer\Annotation\Groups;
use Doctrine\ORM\Mapping\UniqueConstraint;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\RangeFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\NumericFilter;
use Symfony\Component\Serializer\Annotation\MaxDepth;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   }
 * )
 *
 *  @ApiFilter(
 *   DateFilter::class,
 *   properties={
 *     "createdAt",
 *     "updatedAt",
 *   }
 * )
 *
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "sectionId": "exact",
 *     "rowId": "exact",
 *     "row.greenhouseId": "exact",
 *     "planTemplateId": "exact",
 *   }
 * )
 *
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *     "planTemplateId",
 *   }
 * )
 *
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "createdAt",
 *     "updatedAt",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 *
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": {
 *          "createdAt",
 *          "updatedAt",
 *      }
 *  }
 * )
 *
 * @ApiFilter(
 *   RangeFilter::class,
 *   properties={
 *     "row.rowNumber",
 *   }
 * )
 *
 * @ApiFilter(
 *   NumericFilter::class,
 *   properties={
 *     "dow",
 *     "shift",
 *     "exclusive",
 *     "pass",
 *   }
 * )
 *
 * @ORM\Table(name="plan", uniqueConstraints={
 *   @UniqueConstraint(name="sectionId_rowId_pass",
 *     columns={
 *       "section_id", "row_id", "pass"
 *     }
 *   ),
 * })
 *
 * @ORM\Entity(repositoryClass="App\Repository\PlanRepository")
 */
class Plan
{
    use dateTimeTrait;

    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="guid")
     * @Groups({"read"})
     */
    private $rowId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Row")
     * @Groups({"read"})
     */
    private $row;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read"})
     */
    private $sectionId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Section")
     * @Groups({"read"})
     */
    private $section;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read"})
     */
    private $planTemplateId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\PlanTemplate")
     * @Groups({"read"})
     */
    private $planTemplate;

    /**
     * @ORM\Column(type="boolean")
     * @Groups({"read"})
     */
    private $isActive;

    /**
     * @ORM\Column(type="smallint")
     * @Groups({"read"})
     */
    private $dow;

    /**
     * @ORM\Column(type="smallint", options={"default": 0})
     * @Groups({"read"})
     */
    private $exclusive;

    /**
     * @ORM\Column(type="smallint", options={"default": 1})
     * @Groups({"read"})
     */
    private $direction;

    /**
     * @ORM\Column(type="smallint", options={"default": 0})
     * @Groups({"read"})
     */
    private $shift;

    /**
     * @ORM\Column(type="smallint", options={"default": 0})
     * @Groups({"read"})
     */
    private $pass;

    public function getId()
    {
        return $this->id;
    }

    public function setId(string $id): self
    {
        $this->id = $id;

        return $this;
    }

    public function getRowId(): ?string
    {
        return $this->rowId;
    }

    public function setRowId(string $rowId): self
    {
        $this->rowId = $rowId;

        return $this;
    }

    public function getRow(): ?Row
    {
        return $this->row;
    }

    public function setRow(?Row $row): self
    {
        $this->row = $row;

        return $this;
    }

    public function getSectionId(): ?string
    {
        return $this->sectionId;
    }

    public function setSectionId(?string $sectionId): self
    {
        $this->sectionId = $sectionId;

        return $this;
    }

    public function getSection(): ?Section
    {
        return $this->section;
    }

    public function setSection(?Section $section): self
    {
        $this->section = $section;

        return $this;
    }

    public function getPlanTemplateId(): ?string
    {
        return $this->planTemplateId;
    }

    public function setPlanTemplateId(?string $planTemplateId): self
    {
        $this->planTemplateId = $planTemplateId;

        return $this;
    }

    public function getPlanTemplate(): ?PlanTemplate
    {
        return $this->planTemplate;
    }

    public function setPlanTemplate(?PlanTemplate $planTemplate): self
    {
        $this->planTemplate = $planTemplate;

        return $this;
    }


    public function getIsActive(): ?bool
    {
        return $this->isActive;
    }

    public function setIsActive(bool $isActive): self
    {
        $this->isActive = $isActive;

        return $this;
    }

    public function getDow(): ?int
    {
        return $this->dow;
    }

    public function setDow(int $dow): self
    {
        $this->dow = $dow;

        return $this;
    }

    public function getExclusive(): ?int
    {
        return $this->exclusive;
    }

    public function setExclusive(?int $exclusive): self
    {
        $this->exclusive = $exclusive;

        return $this;
    }

    public function getDirection(): ?int
    {
        return $this->direction;
    }

    public function setDirection(int $direction): self
    {
        $this->direction = $direction;

        return $this;
    }

    public function getShift(): ?int
    {
        return $this->shift;
    }

    public function setShift(int $shift): self
    {
        $this->shift = $shift;

        return $this;
    }

    public function getPass(): ?int
    {
        return $this->pass;
    }

    public function setPass(int $pass): self
    {
        $this->pass = $pass;

        return $this;
    }
}
