<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;
use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Component\Validator\Constraints as Assert;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;

/**
 * @ApiResource(
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   }
 * )
 * @ApiFilter(
 *   SearchFilter::class, 
 *   properties={
 *     "id": "exact", 
 *     "workerId": "exact", 
 *     "positionId": "exact", 
 *     "isProcessed": "exact",
 *   }
 * )
 * @ApiFilter(
 *   DateFilter::class, 
 *   properties={
 *     "period",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class, 
 *   properties={
 *     "period",
 *   }, 
 *   arguments={"orderParameterName"="order"}
 * )
 * @ORM\Entity(repositoryClass="App\Repository\PositionHistoryRepository")
 * @ORM\Table(
 *   name="position_history",
 *   indexes={
 *     @ORM\Index(
 *       name="position_history_worker", 
 *       columns={"worker_id"}
 *     ),
 *     @ORM\Index(
 *       name="position_history_period", 
 *       columns={"period"}
 *     ),
 *     @ORM\Index(
 *       name="position_history_is_processed", 
 *       columns={"is_processed"}
 *     ),
 *   }
 * )
 */
class PositionHistory
{
    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     */
    private $id;

    /**
     * @ORM\Column(type="datetimetz")
     */
    private $period;

    /**
     * @ORM\Column(type="boolean")
     */
    private $active;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $event;

    /**
     * @ORM\Column(type="json", nullable=true)
     */
    private $raw = [];

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(type="datetimetz")
     */
    private $createdAt;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="update")
     * @ORM\Column(type="datetimetz")
     */
    private $updatedAt;

    /**
     * @ORM\Column(type="guid", nullable=true)
     */
    private $workerId;

    /**
     * @ORM\Column(type="guid", nullable=true)
     */
    private $positionId;

    /**
     * @ORM\Column(type="guid", nullable=true)
     */
    private $departmentId;

    /**
     * @ORM\Column(type="boolean", nullable=true)
     */
    private $isProcessed;    

    public function setId(?string $id): void
    {
        $this->id = $id;
    }    

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getPeriod(): ?\DateTimeInterface
    {
        return $this->period;
    }

    public function setPeriod(\DateTimeInterface $period): self
    {
        $this->period = $period;

        return $this;
    }

    public function getActive(): ?bool
    {
        return $this->active;
    }

    public function setActive(bool $active): self
    {
        $this->active = $active;

        return $this;
    }

    public function getEvent(): ?string
    {
        return $this->event;
    }

    public function setEvent(string $event): self
    {
        $this->event = $event;

        return $this;
    }

    public function getRaw(): ?array
    {
        return $this->raw;
    }

    public function setRaw(?array $raw): self
    {
        $this->raw = $raw;

        return $this;
    }

    public function getCreatedAt(): ?\DateTimeInterface
    {
        return $this->createdAt;
    }

    public function getUpdatedAt(): ?\DateTimeInterface
    {
        return $this->updatedAt;
    }

    public function getWorkerId(): ?string
    {
        return $this->workerId;
    }

    public function setWorkerId(?string $workerId): self
    {
        $this->workerId = $workerId;

        return $this;
    }

    public function getPositionId(): ?string
    {
        return $this->positionId;
    }

    public function setPositionId(?string $positionId): self
    {
        $this->positionId = $positionId;

        return $this;
    }

    public function getDepartmentId(): ?string
    {
        return $this->departmentId;
    }

    public function setDepartmentId(?string $departmentId): self
    {
        $this->departmentId = $departmentId;

        return $this;
    }

    public function getIsProcessed(): ?bool
    {
        return $this->isProcessed;
    }

    public function setIsProcessed(?bool $isProcessed): self
    {
        $this->isProcessed = $isProcessed;

        return $this;
    }    
}
