<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use Doctrine\ORM\Mapping as ORM;
use ApiPlatform\Core\Annotation\ApiProperty;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\Common\Collections\ArrayCollection;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\RangeFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\NumericFilter;
use Symfony\Component\Serializer\Annotation\Groups;
use Doctrine\Common\Collections\Collection;
use Symfony\Component\Serializer\Annotation\MaxDepth;
use Gedmo\Mapping\Annotation as Gedmo;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   }
 * )
 * 
 * @ApiFilter(
 *   SearchFilter::class, 
 *   properties={
 *     "greenhouseId": "exact",
 *     "type": "exact",
 *   }
 * )
 * 
 * @ApiFilter(
 *   RangeFilter::class,
 *   properties={
 *     "rowNumber",
 *   }
 * )
 * 
 * @ApiFilter(
 *   OrderFilter::class,
 *   arguments={"orderParameterName"="order"},
 *   properties={
 *     "orderBy",
 *     "rowNumber",
 *   },
 * )
 * 
 * @ORM\Table(
 *   name="row",
 *   indexes={
 *     @ORM\Index(
 *      name="row_greenhouse_row",
 *      columns={"greenhouse_id", "row_number"}
 *     ),
 *   }
 * )
 * 
 * @ORM\Entity(repositoryClass="App\Repository\RowRepository")
 */
class Row
{
    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="smallint")
     * @Groups({"read"})
     */
    private $rowNumber;

    /**
     * @ORM\Column(type="smallint", options={"default": 0})
     * @Groups({"read"})
     */
    private $orderBy = 0;

    /**
     * @ORM\Column(type="guid")
     * @Groups({"read"})
     */
    private $greenhouseId;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\PlantPhenology", mappedBy="row")
     */
    private $plantPhenologies;

    /**
     * @ORM\Column(type="boolean", options={"default" : false})
     * @Groups({"read"})
     */
    private $isBlockEnd = false;

    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read"})
     */
    private $type;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(type="datetimetz")
     */
    private $createdAt;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="update")
     * @ORM\Column(type="datetimetz")
     */
    private $updatedAt;

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getRowNumber(): ?int
    {
        return $this->rowNumber;
    }

    public function setRowNumber(int $rowNumber): self
    {
        $this->rowNumber = $rowNumber;

        return $this;
    }

    public function getOrderBy(): ?int
    {
        return $this->orderBy;
    }

    public function setOrderBy(int $orderBy): self
    {
        $this->orderBy = $orderBy;

        return $this;
    }

    public function getGreenhouseId(): ?string
    {
        return $this->greenhouseId;
    }

    public function setGreenhouseId(string $greenhouseId): self
    {
        $this->greenhouseId = $greenhouseId;

        return $this;
    }

    public function getPlantPhenologies()
    {
        return $this->plantPhenologies;
    }

    public function getIsBlockEnd(): bool
    {
        return $this->isBlockEnd;
    }

    public function setIsBlockEnd(bool $isBlockEnd): self
    {
        $this->isBlockEnd = $isBlockEnd;

        return $this;
    }

    public function getType(): ?string
    {
        return $this->type;
    }

    public function setType(?string $type): self
    {
        $this->type = $type;

        return $this;
    }

    public function getCreatedAt(): ?\DateTimeInterface
    {
        return $this->createdAt;
    }

    public function getUpdatedAt(): ?\DateTimeInterface
    {
        return $this->updatedAt;
    }
}
