<?php

namespace App\Entity;

use Symfony\Component\Serializer\Annotation\Groups;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Annotation\ApiResource;
use Gedmo\Mapping\Annotation as Gedmo;
use ApiPlatform\Core\Annotation\ApiProperty;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping as ORM;
use App\Traits\DateTimeTrait as dateTimeTrait;
use Symfony\Component\Validator\Constraints\Uuid;
use Doctrine\ORM\Mapping\UniqueConstraint;

/**
 * @ApiResource()
 * @ORM\Entity(repositoryClass="App\Repository\RowRangeRepository")
 * @ORM\Table(
 *  indexes= {
 *    @ORM\Index(
 *      name="row_range_section",
 *      columns={ "section_id" }
 *    ),
 *    @ORM\Index(
 *      name="row_range_mini_planId",
 *      columns={ "mini_plan_id" }
 *    ),
 *    @ORM\Index(
 *      name="row_range_dow",
 *      columns={ "dow" }
 *    ),
 *  },
 *   uniqueConstraints={
 *     @UniqueConstraint(name="row_range_sectionId_mini_planId_dow",
 *       columns={
 *         "section_id", "mini_plan_id", "dow"
 *       }
 *     ),
 *   },
 * )
 * @ApiFilter(
 *   DateFilter::class,
 *   properties={
 *     "createdAt",
 *     "updatedAt",
 *   }
 * )
 * @ApiFilter(
 *  SearchFilter::class,
 *  properties={
 *    "id": "exact",
 *    "sectionId": "exact",
 *    "mini_planId": "exact",
 *    "dow": "exact",
 *  }
 * )
 */
class RowRange
{
    use dateTimeTrait;
    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @ORM\GeneratedValue(strategy="UUID")
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read"})
     */
    private $sectionId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Section", inversedBy="greenhouseSections")
     * @Groups({"read"})
     */
    private $section;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read"})
     */
    private $mini_planId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\MiniPlan")
     * @Groups({"read"})
     */
    private $mini_plan;

    /**
     * @ORM\Column(type="smallint")
     * @Groups({"read"})
     */
    private $dow;

    /**
     * @ORM\Column(type="string", length=100, nullable=false)
     * @Groups({"read"})
     */
    private $range;

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getSectionId(): ?string
    {
        return $this->sectionId;
    }

    public function setSectionId(?string $sectionId): self
    {
        $this->sectionId = $sectionId;

        return $this;
    }

    public function getSection(): ?Section
    {
        return $this->section;
    }

    public function setSection(?Section $section): self
    {
        $this->section = $section;

        return $this;
    }

    public function getMiniPlanId(): ?string
    {
        return $this->mini_planId;
    }

    public function setMiniPlanId(?string $mini_planId): self
    {
        $this->mini_planId = $mini_planId;

        return $this;
    }

    public function getMiniPlan(): ?MiniPlan
    {
        return $this->mini_plan;
    }

    public function setMiniPlan(?MiniPlan $mini_plan): self
    {
        $this->mini_plan = $mini_plan;

        return $this;
    }


    public function getDow(): ?int
    {
        return $this->dow;
    }

    public function setDow(int $dow): self
    {
        $this->dow = $dow;

        return $this;
    }

    public function getRange(): ?string
    {
        return $this->range;
    }

    public function setRange(?string $range): RowRange
    {
        $this->range = $range;

        return $this;
    }
}
