<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\ORM\Mapping as ORM;
use App\Traits\DateTimeTrait as dateTimeTrait;
use Symfony\Component\Validator\Constraints\Uuid;
use Symfony\Component\Validator\Constraints as Assert;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use App\Entity\Greenhouse;

/**
 * @ApiResource(
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   }
 * )
 * @ApiFilter(
 *   DateFilter::class, 
 *   properties={
 *     "period",
 *   }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\RowStatusRepository")
 *
 * @uses InformationRegister_актСтатусыРядовТеплицы
 */
class RowStatus
{
    use dateTimeTrait;

    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     */
    private $id;

    /**
     * @ORM\Column(type="integer")
     */
    private $rowNumber;

    /**
     * @ORM\Column(type="datetimetz")
     */
    private $period;

    /**
     * @var Greenhouse|null
     *
     * @ORM\OneToOne(targetEntity="App\Entity\Greenhouse")
     * @ORM\JoinColumn(name="greenhouse_id", referencedColumnName="id")
     */
    private $greenHouseId;

    /**
     * @var string|null
     *
     * @ORM\Column(type="guid",  nullable=true)
     */
    private $rawGreenHouseId;

    /**
     * @var string|null
     *
     * @ORM\Column(type="guid",  nullable=true)
     */
    private $stateId;

    /**
     * @var string|null
     *
     * @ORM\Column(type="guid",  nullable=true)
     */
    private $rawStateId;

    /**
     * @ORM\Column(type="json_array",nullable=true,options={"jsonb"=true})
     */
    private $raw = [];

    public function setId(?string $id): RowStatus
    {
        $this->id = $id;

        return $this;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getRowNumber(): ?int
    {
        return $this->rowNumber;
    }

    public function setRowNumber(int $rowNumber): RowStatus
    {
        $this->rowNumber = $rowNumber;

        return $this;
    }

    public function getPeriod(): ?\DateTimeInterface
    {
        return $this->period;
    }

    public function setPeriod(\DateTimeInterface $period): RowStatus
    {
        $this->period = $period;

        return $this;
    }

    public function getGreenHouse(): ?Greenhouse
    {
        return $this->greenHouseId;
    }

    public function setGreenHouse(?Greenhouse $greenHouseId): RowStatus
    {
        $this->greenHouseId = $greenHouseId;

        return $this;
    }

    public function getStateId(): ?string
    {
        return $this->stateId;
    }

    public function setStateId(?string $stateId): RowStatus
    {
        $this->stateId = $stateId;

        return $this;
    }

    public function getRaw(): ?array
    {
        return $this->raw;
    }

    public function setRaw(?array $raw): RowStatus
    {
        $this->raw = $raw;

        return $this;
    }

    public function getRawGreenHouseId(): ?string
    {
        return $this->rawGreenHouseId;
    }

    public function setRawGreenHouseId(?string $rawGreenHouseId): RowStatus
    {
        $this->rawGreenHouseId = $rawGreenHouseId;

        return $this;
    }

    public function getRawStateId(): ?string
    {
        return $this->rawStateId;
    }

    public function setRawStateId(?string $rawStateId): RowStatus
    {
        $this->rawStateId = $rawStateId;

        return $this;
    }
}
