<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use Doctrine\ORM\Mapping as ORM;
use ApiPlatform\Core\Annotation\ApiProperty;
use Symfony\Component\Serializer\Annotation\MaxDepth;

use App\Uuid;
use App\Traits\DateTimeTrait as dateTimeTrait;
use Symfony\Component\Serializer\Annotation\Groups;
use Symfony\Component\Validator\Constraints as Assert;

use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;
use Doctrine\ORM\Mapping\UniqueConstraint;
/**
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "sectionId": "exact",
 *     "mark": "ipartial",
 *     "minQuality": "exact",
 *     "maxQuality": "exact",
 *     "minTime": "exact",
 *     "maxTime": "exact",
 *     "category": "exact",
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *     "id",
 *     "sectionId",
 *     "section",
 *     "mark",
 *     "minQuality",
 *     "maxQuality",
 *     "minTime",
 *     "maxTime",
 *     "category",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "id",
 *     "sectionId",
 *     "section",
 *     "mark",
 *     "minQuality",
 *     "maxQuality",
 *     "minTime",
 *     "maxTime",
 *     "category",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": null
 *  }
 * )
 *  @ORM\Table(
 *  indexes= {
 *    @ORM\Index(
 *      name="section_quality_time_limit_section_id",
 *      columns={ "section_id" }
 *    ),
 *    @ORM\Index(
 *      name="section_quality_time_limit_category",
 *      columns={ "category" }
 *    ),
 *    @ORM\Index(
 *      name="section_quality_time_limit_mark",
 *      columns={ "mark" }
 *    ),
 *  },
 *   uniqueConstraints={
 *     @UniqueConstraint(name="section_quality_time_limit",
 *       columns={
 *         "section_id", "category", "mark"
 *       }
 *     ),
 *   },
 * ) 
 * @ApiResource()
 * @ORM\Entity(repositoryClass="App\Repository\SectionQualityTimeLimitRepository")
 */
class SectionQualityTimeLimit
{
    use dateTimeTrait;

    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="UUID")
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="guid")
     * @Groups({"read"})
     */
    private $sectionId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Section")
     * @ORM\JoinColumn(nullable=true, name="section_id", referencedColumnName="id", onDelete="CASCADE")
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $section;

    /**
     * @ORM\Column(type="string", length=1, nullable=false)
     * @Groups({"read"})
     */
    private $mark;

    /**
     * @ORM\Column(type="string", nullable=false)
     * @Groups({"read"})
     */
    private $minQuality;

    /**
     * @ORM\Column(type="string", nullable=false)
     * @Groups({"read"})
     */
    private $maxQuality;

    /**
     * @ORM\Column(type="string", nullable=false)
     * @Groups({"read"})
     */
    private $minTime;

    /**
     * @ORM\Column(type="string", nullable=false)
     * @Groups({"read"})
     */
    private $maxTime;

    /**
     * @ORM\Column(type="string", length=255, nullable=false, options={"default" : "cucumber"})
     * @Groups({"read"})
     */
    private $category;

    public function getId(): ?string
    {
        return $this->id;
    }

    public function setId(?string $id): self
    {
        $this->id = $id;

        return $this;
    }

    public function getCategory(): ?string
    {
        return $this->category;
    }

    public function setCategory(?string $category): self
    {
        $this->category = $category;

        return $this;
    }

    public function getSectionId(): ?string
    {
        return $this->sectionId;
    }

    public function setSectionId(?string $sectionId): self
    {
        $this->sectionId = $sectionId;

        return $this;
    }

    public function getSection(): ?Section
    {
        return $this->section;
    }

    public function setSection(?Section $section): self
    {
        $this->section = $section;

        return $this;
    }

    public function getMark(): ?string
    {
        return $this->mark;
    }

    public function setMark(?string $mark): self
    {
        $this->mark = $mark;

        return $this;
    }

    public function getMinQuality(): ?string
    {
        return $this->minQuality;
    }

    public function setMinQuality(?string $minQuality): self
    {
        $this->minQuality = $minQuality;

        return $this;
    }

    public function getMaxQuality(): ?string
    {
        return $this->maxQuality;
    }

    public function setMaxQuality(?string $maxQuality): self
    {
        $this->maxQuality = $maxQuality;

        return $this;
    }

    public function getMinTime(): ?string
    {
        return $this->minTime;
    }

    public function setMinTime(?string $minTime): self
    {
        $this->minTime = $minTime;

        return $this;
    }

    public function getMaxTime(): ?string
    {
        return $this->maxTime;
    }

    public function setMaxTime(?string $maxTime): self
    {
        $this->maxTime = $maxTime;

        return $this;
    }
}