<?php declare(strict_types=1);

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use Doctrine\ORM\Mapping as ORM;
use App\Entity\Greenhouse;
use App\Traits\DateTimeTrait as dateTimeTrait;
use ApiPlatform\Core\Annotation\ApiProperty;
use Symfony\Component\Validator\Constraints as Assert;

use Symfony\Component\Serializer\Annotation\Groups;
use Symfony\Component\Serializer\Annotation\MaxDepth;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ORM\Entity(repositoryClass="App\Repository\StructureRepository")
 *
 * @uses Catalog_актСтруктураПосевныхПлощадей
 */
class Structure
{
    use dateTimeTrait;

    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @var string|null
     *
     * @ORM\Column(type="string", length=128, nullable=true)
     * @Groups({"read"})
     */
    private $name;

    /**
     * @var Greenhouse|null
     *
     * @ORM\OneToOne(targetEntity="App\Entity\Greenhouse")
     * @ORM\JoinColumn(name="greenhouse_id", referencedColumnName="id")
     * @Groups({"read"})
     */
    private $greenHouseId;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read"})
     */
    private $rawGreenHouseId;

    /**
     * @ORM\OneToOne(targetEntity="App\Entity\Structure")
     * @ORM\JoinColumn(name="parent_id", referencedColumnName="id")
     * @Groups({"read"})
     */
    private $parentId;

    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     * @Groups({"read"})
     */
    private $rawParentId;

    /**
     * @ORM\Column(type="boolean", options={"default": false})
     * @Groups({"read"})
     */
    private $isFolder;

    /**
     * @ORM\Column(type="text", nullable=true)
     * @Groups({"read"})
     */
    private $description;

    /**
     * @ORM\Column(type="text", nullable=true)
     * @Groups({"read"})
     */
    private $comment;

    /**
     * @ORM\Column(type="datetimetz", nullable=true)
     * @Groups({"read"})
     */
    private $startedAt;

    /**
     * @ORM\Column(type="datetimetz", nullable=true)
     * @Groups({"read"})
     */
    private $finishedAt;

    /**
     * @ORM\Column(type="text", nullable=true)
     * @Groups({"read"})
     */
    private $regularExpr;

    /**
     * @ORM\Column(type="float", nullable=true)
     * @Groups({"read"})
     */
    private $landingArea;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read"})
     */
    private $batonicalVarietyId;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read"})
     */
    private $rawBatonicalVarietyId;

    /**
     * @todo: OneToMany(ТопологияТеплицы)
     * @ORM\Column(type="json_array", nullable=true, options={"jsonb"=true})
     * @Groups({"read"})
     */
    private $greenHouseTopology = [];

    /**
     * @ORM\Column(type="json_array", nullable=true, options={"jsonb"=true})
     * @Groups({"read"})
     */
    private $rawGreenHouseTopology = [];

    /**
     * @ORM\Column(type="json_array", nullable=true, options={"jsonb"=true})
     * @Groups({"read"})
     */
    private $raw = [];

    public function setId(?string $id): Structure
    {
        $this->id = $id;

        return $this;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): Structure
    {
        $this->name = $name;

        return $this;
    }

    public function getGreenHouseId(): ?Greenhouse
    {
        return $this->greenHouseId;
    }

    public function setGreenHouseId(?Greenhouse $greenHouseId): Structure
    {
        $this->greenHouseId = $greenHouseId;

        return $this;
    }

    public function getRawGreenHouseId(): ?string
    {
        return $this->rawGreenHouseId;
    }

    public function setRawGreenHouseId(?string $rawGreenHouseId): Structure
    {
        $this->rawGreenHouseId = $rawGreenHouseId;

        return $this;
    }

    public function getParentId(): ?Structure
    {
        return $this->parentId;
    }

    public function setParentId(?Structure $parentId): Structure
    {
        $this->parentId = $parentId;

        return $this;
    }

    public function getRawParentId(): ?string
    {
        return $this->rawParentId;
    }

    public function setRawParentId(?string $rawParentId): Structure
    {
        $this->rawParentId = $rawParentId;

        return $this;
    }

    public function getIsFolder(): ?bool
    {
        return $this->isFolder;
    }

    public function setIsFolder(bool $isFolder): Structure
    {
        $this->isFolder = $isFolder;

        return $this;
    }

    public function getDescription(): ?string
    {
        return $this->description;
    }

    public function setDescription(?string $description): Structure
    {
        $this->description = $description;

        return $this;
    }

    public function getComment(): ?string
    {
        return $this->comment;
    }

    public function setComment(?string $comment): Structure
    {
        $this->comment = $comment;

        return $this;
    }

    public function getStartedAt(): ?\DateTimeInterface
    {
        return $this->startedAt;
    }

    public function setStartedAt(?\DateTimeInterface $startedAt): Structure
    {
        $this->startedAt = $startedAt;

        return $this;
    }

    public function getFinishedAt(): ?\DateTimeInterface
    {
        return $this->finishedAt;
    }

    public function setFinishedAt(?\DateTimeInterface $finishedAt): Structure
    {
        $this->finishedAt = $finishedAt;

        return $this;
    }

    public function getRegularExpr(): ?string
    {
        return $this->regularExpr;
    }

    public function setRegularExpr(?string $regularExpr): Structure
    {
        $this->regularExpr = $regularExpr;

        return $this;
    }

    public function getLandingArea(): ?float
    {
        return $this->landingArea;
    }

    public function setLandingArea(?float $landingArea): Structure
    {
        $this->landingArea = $landingArea;

        return $this;
    }

    public function getBatonicalVarietyId(): ?string
    {
        return $this->batonicalVarietyId;
    }

    public function setBatonicalVarietyId(?string $batonicalVarietyId): Structure
    {
        $this->batonicalVarietyId = $batonicalVarietyId;

        return $this;
    }

    public function getRawBatonicalVarietyId(): ?string
    {
        return $this->rawBatonicalVarietyId;
    }

    public function setRawBatonicalVarietyId(?string $rawBatonicalVarietyId): Structure
    {
        $this->rawBatonicalVarietyId = $rawBatonicalVarietyId;

        return $this;
    }

    public function getGreenHouseTopology(): ?array
    {
        return $this->greenHouseTopology;
    }

    /**
     * @todo: OneToMany
     */
    public function setGreenHouseTopology(?array $greenHouseTopology): Structure
    {
        $this->greenHouseTopology = $greenHouseTopology;

        return $this;
    }

    public function getRawGreenHouseTopology(): ?array
    {
        return $this->rawGreenHouseTopology;
    }

    public function setRawGreenHouseTopology(?array $rawGreenHouseTopology): Structure
    {
        $this->rawGreenHouseTopology = $rawGreenHouseTopology;

        return $this;
    }

    public function getRaw(): ?array
    {
        return $this->raw;
    }

    public function setRaw(?array $raw): Structure
    {
        $this->raw = $raw;

        return $this;
    }
}
