<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;
use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Component\Validator\Constraints as Assert;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\BooleanFilter;
use Symfony\Component\Serializer\Annotation\Groups;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\RangeFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;
use Symfony\Component\Serializer\Annotation\MaxDepth;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "greenhouseId": "exact",
 *     "technicalWindowSections.sectionId": "exact",
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *   }
 * )
 * @ApiFilter(
 *   RangeFilter::class,
 *   properties={
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "id",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": null
 *  }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\TechnicalWindowRepository")
 */
class TechnicalWindow
{
    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

        /**
     * @ORM\Column(type="guid", nullable=false)
     * @Groups({"read"})
     */
    private $greenhouseId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Greenhouse")
     * @Groups({"read"})
     */
    private $greenhouse;

    /**
     * @ORM\Column(type="time", nullable=false)
     * @Groups({"read"})
     */
    private $start;

    /**
     * @ORM\Column(type="time", nullable=false)
     * @Groups({"read"})
     */
    private $finish;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\TechnicalWindowSection", mappedBy="technicalWindow", cascade={"persist", "remove"})
     * @Groups({"read"})
     */
    private $technicalWindowSections;

    public function __construct()
    {
        $this->technicalWindowSections = new ArrayCollection();
    }

    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getGreenhouse(): ?Greenhouse
    {
        return $this->greenhouse;
    }

    public function setGreenhouse(?Greenhouse $greenhouse): self
    {
        $this->greenhouse = $greenhouse;

        return $this;
    }

    public function getGreenhouseId(): ?string
    {
        return $this->greenhouseId;
    }

    public function setGreenhouseId(?string $greenhouseId): self
    {
        $this->greenhouseId = $greenhouseId;

        return $this;
    }

    public function getStart(): ?\DateTimeInterface
    {
        return $this->start;
    }

    public function setStart(\DateTimeInterface $start): self
    {
        $this->start = $start;

        return $this;
    }

    public function getFinish(): ?\DateTimeInterface
    {
        return $this->finish;
    }

    public function setFinish(\DateTimeInterface $finish): self
    {
        $this->finish = $finish;

        return $this;
    }

    /**
     * @return Collection|TechnicalWindowSection[]
     */
    public function getTechnicalWindowSections(): Collection
    {
        return $this->technicalWindowSections;
    }

    public function addTechnicalWindowSection(TechnicalWindowSection $technicalWindowSection): self
    {
        if (!$this->technicalWindowSections->contains($technicalWindowSection)) {
            $this->technicalWindowSections[] = $technicalWindowSection;
            $technicalWindowSection->setTechnicalWindow($this);
        }

        return $this;
    }

    public function removeTechnicalWindowSection(TechnicalWindowSection $technicalWindowSection): self
    {
        if ($this->technicalWindowSections->contains($technicalWindowSection)) {
            $this->technicalWindowSections->removeElement($technicalWindowSection);
            // set the owning side to null (unless already changed)
            if ($technicalWindowSection->getTechnicalWindow() === $this) {
                $technicalWindowSection->setTechnicalWindow(null);
            }
        }

        return $this;
    }


}
