<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;
use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Component\Validator\Constraints as Assert;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\BooleanFilter;
use Symfony\Component\Serializer\Annotation\Groups;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\RangeFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;
use Doctrine\ORM\Mapping\UniqueConstraint;
use Symfony\Component\Serializer\Annotation\MaxDepth;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "sectionId": "exact",
 *     "technicalWindowId": "exact",
 *     "technicalWindow.greenhouseId": "exact",
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *   }
 * )
 * @ApiFilter(
 *   RangeFilter::class,
 *   properties={
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *    "section.name",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": null
 *  }
 * )
 *  @ORM\Table(
 *  indexes= {
 *    @ORM\Index(
 *      name="technical_window_section_section_id",
 *      columns={ "section_id" }
 *    ),
 *    @ORM\Index(
 *      name="technical_window_section_technical_window_id",
 *      columns={ "technical_window_id" }
 *    ),
 *  },
 *   uniqueConstraints={
 *     @UniqueConstraint(name="technical_window_section_section_id_technical_window_id",
 *       columns={
 *         "section_id", "technical_window_id"
 *       }
 *     ),
 *   },
 * ) 
 * @ORM\Entity(repositoryClass="App\Repository\TechnicalWindowSectionRepository")
 */
class TechnicalWindowSection
{
    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="guid", nullable=false)
     * @Groups({"read"})
     */
    private $sectionId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Section")
     * @ORM\JoinColumn(nullable=true, name="section_id", referencedColumnName="id", onDelete="CASCADE")
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $section;

    /**
     * @ORM\Column(type="guid", nullable=false)
     * @Groups({"read"})
     */
    private $technicalWindowId;
    
    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\TechnicalWindow", inversedBy="technicalWindowSections")
     * @ORM\JoinColumn(nullable=false)
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $technicalWindow;

    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getSection(): ?Section
    {
        return $this->section;
    }

    public function setSection(?Section $section): self
    {
        $this->section = $section;

        return $this;
    }

    public function getTechnicalWindow(): ?TechnicalWindow
    {
        return $this->technicalWindow;
    }

    public function setTechnicalWindow(?TechnicalWindow $technicalWindow): self
    {
        $this->technicalWindow = $technicalWindow;

        return $this;
    }

    public function getTechnicalWindowId(): String
    {
        return $this->technicalWindowId;
    }

    public function setTechnicalWindowId(String $technicalWindow): self
    {
        $this->technicalWindowId = $technicalWindowId;

        return $this;
    }
}

