<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\ORM\Mapping as ORM;

use App\Uuid;
use Symfony\Component\Serializer\Annotation\Groups;
use Symfony\Component\Validator\Constraints as Assert;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;

/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "value": "exact",
 *     "sectionId": "exact",
 *     "workerId": "exact",
 *     "taskCheckId": "exact",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *      "value",
 *      "sectionId",
 *      "workerId",
 *      "taskCheckId",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": {
 *          "id",
 *          "value",
 *          "sectionId",
 *          "workerId",
 *          "taskCheckId",
 *      }
 *  }
 * )
 * @ORM\Table(
 *   name="transaction",
 *   indexes={
 *     @ORM\Index(
 *      name="transaction_value",
 *      columns={"value"}
 *    ),
 *     @ORM\Index(
 *      name="transaction_section_id",
 *      columns={"section_id"}
 *    ),
 *     @ORM\Index(
 *      name="transaction_worker_id",
 *      columns={"worker_id"}
 *    ),
 *     @ORM\Index(
 *      name="transaction_task_check_id",
 *      columns={"task_check_id"}
 *    ),
 *   }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\TransactionRepository")
 */
class Transaction
{
    /**
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     * @Groups({"read"})
     */
    private $value;

    /**
     * @ORM\Column(type="guid")
     * @Groups({"read"})
     */
    private $sectionId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Section")
     * @Groups({"read"})
     */
    private $section;

    /**
     * @ORM\Column(type="guid")
     * @Groups({"read"})
     */
    private $workerId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Worker")
     * @Groups({"read"})
     */
    private $worker;

    /**
     * @ORM\Column(type="guid")
     * @Groups({"read"})
     */
    private $taskCheckId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\TaskCheck")
     * @Groups({"read"})
     */
    private $taskCheck;

    public function getId(): ?string
    {
        return $this->id;
    }

    public function setId(?string $id): self
    {
        $this->id = $id;

        return $this;
    }

    public function getValue(): ?string
    {
        return $this->value;
    }

    public function setValue(string $value): self
    {
        $this->value = $value;

        return $this;
    }

    public function getSectionId(): ?string
    {
        return $this->sectionId;
    }

    public function setSectionId(?string $sectionId): self
    {
        $this->sectionId = $sectionId;

        return $this;
    }

    public function getSection(): ?Section
    {
        return $this->section;
    }

    public function setSection(?Section $section): self
    {
        $this->section = $section;

        return $this;
    }

    public function getWorkerId(): ?string
    {
        return $this->workerId;
    }

    public function setWorkerId(?string $workerId): self
    {
        $this->workerId = $workerId;

        return $this;
    }

    public function getWorker(): ?Worker
    {
        return $this->worker;
    }

    public function setWorker(?Worker $worker): self
    {
        $this->worker = $worker;

        return $this;
    }

    public function getTaskCheckId(): ?string
    {
        return $this->taskCheckId;
    }

    public function setTaskCheckId(?string $taskCheckId): self
    {
        $this->taskCheckId = $taskCheckId;

        return $this;
    }

    public function getTaskCheck(): ?TaskCheck
    {
        return $this->taskCheck;
    }

    public function setTaskCheck(?TaskCheck $taskCheck): self
    {
        $this->taskCheck = $taskCheck;

        return $this;
    }

}
