<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;

use Symfony\Component\Serializer\Annotation\MaxDepth;
use Symfony\Component\Serializer\Annotation\Groups;

use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping\UniqueConstraint;
/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "greenhouseId": "exact",
 *     "workDescription": "exact",
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *     "greenhouseId",
 *     "workDescription",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "greenhouseId",
 *     "workDescription",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": null
 *  }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\ValveRepository")
 * @ORM\Table(
 *   name="valve",
 *   indexes={
 *     @ORM\Index(
 *       name="valve_greenhouse", 
 *       columns={"greenhouse_id"}
 *     ),
 *     @ORM\Index(
 *       name="valve_number", 
 *       columns={"number"}
 *     ),
 *     @ORM\Index(
 *       name="valve_work_description", 
 *       columns={"work_description"}
 *     ),
 *   },
 *   uniqueConstraints={
 *      @UniqueConstraint(name="greenhouseId_number_workDescription",
 *      columns={
 *          "greenhouse_id", "number", "work_description"
 *      }),
 *   },
 * )
 */
class Valve
{
    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="boolean", options={"default" : false})
     * @Groups({"read"})
     */
    private $volume= false;

    /**
     * @ORM\Column(type="boolean", options={"default" : false})
     * @Groups({"read"})
     */
    private $potentialHydrogen= false;

    /**
     * @ORM\Column(type="boolean", options={"default" : false})
     * @Groups({"read"})
     */
    private $electricConduction= false;

    /**
     * @ORM\Column(type="string", length=50)
     * @Groups({"read"})
     */
    private $workDescription;

    /**
     * @ORM\Column(type="smallint")
     * @Groups({"read"})
     */
    private $number;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read"})
     */
    private $greenhouseId;

    /**
     * @ORM\ManyToOne(targetEntity="App\Entity\Greenhouse")
     * @ORM\JoinColumn(nullable=false)
     * @MaxDepth(1)
     * @Groups({"read"})
     */
    private $greenhouse;

    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getVolume(): ?bool
    {
        return $this->volume;
    }

    public function setVolume(?bool $volume): self
    {
        $this->volume = $volume;

        return $this;
    }

    public function getPotentialHydrogen(): ?bool
    {
        return $this->potentialHydrogen;
    }

    public function setPotentialHydrogen(?bool $potentialHydrogen): self
    {
        $this->potentialHydrogen = $potentialHydrogen;

        return $this;
    }

    public function getElectricConduction(): ?bool
    {
        return $this->electricConduction;
    }

    public function setElectricConduction(?bool $electricConduction): self
    {
        $this->electricConduction = $electricConduction;

        return $this;
    }

    public function getGreenhouseId(): ?string
    {
        return $this->greenhouseId;
    }

    public function setGreenhouseId(?string $greenhouseId): self
    {
        $this->greenhouseId = $greenhouseId;

        return $this;
    }

    public function getWorkDescription(): ?string
    {
        return $this->workDescription;
    }

    public function setWorkDescription(string $workDescription): self
    {
        $this->workDescription = $workDescription;

        return $this;
    }

    public function getNumber(): ?int
    {
        return $this->number;
    }

    public function setNumber(int $number): self
    {
        $this->number = $number;

        return $this;
    }

    public function getGreenhouse(): ?Greenhouse
    {
        return $this->greenhouse;
    }

    public function setGreenhouse(?Greenhouse $greenhouse): self
    {
        $this->greenhouse = $greenhouse;

        return $this;
    }
}
