<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;

use Symfony\Component\Serializer\Annotation\MaxDepth;
use Symfony\Component\Serializer\Annotation\Groups;

use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\ORM\Mapping\UniqueConstraint;
/**
 * @ApiResource(
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true
 *   },
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "workDescription": "exact",
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *     "workDescription",
 *   }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "workDescription",
 *     "measurementDescription",
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": null
 *  }
 * )
 * @ApiResource()
 * @ORM\Entity(repositoryClass="App\Repository\ValveLimitRepository")
 * @ORM\Table(
 *   uniqueConstraints={
 *      @UniqueConstraint(name="workDescription_measurementDescription",
 *      columns={
 *          "work_description", "measurement_description"
 *      }),
 *   },
 * )
 */
class ValveLimit
{
    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read"})
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     * @Groups({"read"})
     */
    private $workDescription;

    /**
     * @ORM\Column(type="string", length=255)
     * @Groups({"read"})
     */
    private $measurementDescription;

    /**
     * @ORM\Column(type="float")
     * @Groups({"read"})
     */
    private $minLimit;

    /**
     * @ORM\Column(type="float")
     * @Groups({"read"})
     */
    private $maxLimit;

    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getWorkDescription(): ?string
    {
        return $this->workDescription;
    }

    public function setWorkDescription(string $workDescription): self
    {
        $this->workDescription = $workDescription;

        return $this;
    }

    public function getMeasurementDescription(): ?string
    {
        return $this->measurementDescription;
    }

    public function setMeasurementDescription(string $measurementDescription): self
    {
        $this->measurementDescription = $measurementDescription;

        return $this;
    }

    public function getMinLimit(): ?float
    {
        return $this->minLimit;
    }

    public function setMinLimit(?float $minLimit): self
    {
        $this->minLimit = $minLimit;

        return $this;
    }

    public function getMaxLimit(): ?float
    {
        return $this->maxLimit;
    }

    public function setMaxLimit(?float $maxLimit): self
    {
        $this->maxLimit = $maxLimit;

        return $this;
    }
}
