<?php

namespace App\Entity;

use ApiPlatform\Core\Annotation\ApiResource;
use ApiPlatform\Core\Annotation\ApiProperty;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use App\Uuid;
use Gedmo\Mapping\Annotation as Gedmo;
use Symfony\Component\Validator\Constraints as Assert;
use App\Controller\WorkerImport;
use App\Controller\WorkerTrolleyUnbind;
use App\Controller\WorkerInfo;
use App\Controller\WorkerTimeline;
use App\Controller\WorkerAssign;
use App\Controller\WorkerMakeScreenshot;
use App\Controller\WorkerUploadBackup;
use App\Controller\WorkerSignOut;
use ApiPlatform\Core\Annotation\ApiFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\SearchFilter;
use Symfony\Component\Serializer\Annotation\Groups;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\DateFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\ExistsFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\RangeFilter;
use ApiPlatform\Core\Bridge\Doctrine\Orm\Filter\OrderFilter;
use ApiPlatform\Core\Serializer\Filter\PropertyFilter;

use ApiPlatform\Core\Serializer\Filter\GroupFilter;

/**
 * @ApiResource(
 *   itemOperations={
 *     "get",
 *     "delete",
 *     "put",
 *     "patch",
 *     "get_import"={
 *         "method"="GET",
 *         "path"="/workers/{id}/import",
 *         "controller"=WorkerImport::class,
 *         "openapi_context" = {
 *            "parameters" = {
 *               {
 *                  "name" = "id",
 *                  "in" = "path",
 *                  "required" = "true",
 *                  "type" = "string"
 *               },
 *            }
 *         }
 *     },
 *     "get_assign"={
 *         "method"="GET",
 *         "path"="/workers/{id}/assign",
 *         "controller"=WorkerAssign::class,
 *         "openapi_context" = {
 *            "parameters" = {
 *               {
 *                  "name" = "id",
 *                  "in" = "path",
 *                  "required" = "true",
 *                  "type" = "string"
 *               },
 *            }
 *         }
 *     },
 *     "get_info"={
 *         "method"="GET",
 *         "path"="/workers/{id}/info",
 *         "controller"=WorkerInfo::class,
 *         "openapi_context" = {
 *            "parameters" = {
 *               {
 *                  "name" = "id",
 *                  "in" = "path",
 *                  "required" = "true",
 *                  "type" = "string"
 *               },
 *            }
 *         }
 *     },
 *     "get_trolley_unbind"={
 *         "method"="GET",
 *         "path"="/workers/{id}/trolley-unbind",
 *         "controller"=WorkerTrolleyUnbind::class,
 *         "openapi_context" = {
 *            "parameters" = {
 *               {
 *                  "name" = "id",
 *                  "in" = "path",
 *                  "required" = "true",
 *                  "type" = "string"
 *               },
 *            }
 *         }
 *     },
 *     "get_timeline"={
 *         "method"="GET",
 *         "path"="/workers/{id}/timeline",
 *         "controller"=WorkerTimeline::class,
 *         "openapi_context" = {
 *            "parameters" = {
 *               {
 *                  "name" = "id",
 *                  "in" = "path",
 *                  "required" = "true",
 *                  "type" = "string"
 *               },
 *               {
 *                  "name" = "day",
 *                  "in" = "query",
 *                  "required" = "true",
 *                  "type" = "date"
 *               },
 *            }
 *         }
 *     },
 *     "get_make_screenshot"={
 *         "method"="GET",
 *         "path"="/workers/{id}/make-screenshot",
 *         "controller"=WorkerMakeScreenshot::class,
 *         "openapi_context" = {
 *            "parameters" = {
 *               {
 *                  "name" = "id",
 *                  "in" = "path",
 *                  "required" = "true",
 *                  "type" = "string"
 *               },
 *            }
 *         }
 *     },
 *     "get_upload_backup"={
 *         "method"="GET",
 *         "path"="/workers/{id}/upload-backup",
 *         "controller"=WorkerUploadBackup::class,
 *         "openapi_context" = {
 *            "parameters" = {
 *               {
 *                  "name" = "id",
 *                  "in" = "path",
 *                  "required" = "true",
 *                  "type" = "string"
 *               },
 *            }
 *         }
 *     },
 *     "get_sign_out"={
 *         "method"="GET",
 *         "path"="/workers/{id}/sign-out",
 *         "controller"=WorkerSignOut::class,
 *         "openapi_context" = {
 *            "parameters" = {
 *               {
 *                  "name" = "id",
 *                  "in" = "path",
 *                  "required" = "true",
 *                  "type" = "string"
 *               },
 *            }
 *         }
 *     },
 *   },
 *   normalizationContext={"groups"={"read"}, "enable_max_depth"=true},
 *   attributes={
 *     "pagination_client_items_per_page"=true,
 *   },
 * )
 * @ApiFilter(
 *   DateFilter::class,
 *   properties={
 *     "spreadTill",
 *   }
 * )
 * @ApiFilter(
 *   SearchFilter::class,
 *   properties={
 *     "id": "exact",
 *     "code": "exact",
 *     "isActive": "exact",
 *     "exclusive": "exact",
 *     "name": "ipartial",
 *     "greenhouseId": "exact",
 *     "ratings.sectionId": "exact",
 *     "notes": "ipartial",
 *     "searchable": "ipartial",
 *     "trolleyId": "exact",
 *     "versionName": "ipartial",
 *     "schedule": "ipartial",
 *     "birthDate": "ipartial",
 *   }
 * )
 * @ApiFilter(
 *   ExistsFilter::class,
 *   properties={
 *     "greenhouseId",
 *     "departmentId",
 *     "rawDepartmentId",
 *     "positionId",
 *     "rawPositionId",
 *     "spreadTill",
 *     "trolleyId"
 *   }
 * )
 * @ApiFilter(
 *   RangeFilter::class,
 *   properties={
 *     "taskCount",
 *     "ratings.ratingInt",
 *   }
 * )
 * @ApiFilter(
 *  GroupFilter::class,
 *  arguments={
 *      "parameterName": "groups",
 *      "overrideDefaultGroups": true,
 *      "whitelist": {
 *          "read",
 *          "section",
 *          "assign",
 *      }
 *  }
 * )
 * @ApiFilter(
 *  PropertyFilter::class,
 *  arguments={
 *      "parameterName": "properties",
 *      "overrideDefaultProperties": false,
 *      "whitelist": null,
 *  }
 * )
 * @ApiFilter(
 *   OrderFilter::class,
 *   properties={
 *     "name",
 *     "code",
 *     "exclusive",
 *     "taskCount",
 *     "isActive"
 *   },
 *   arguments={"orderParameterName"="order"}
 * )
 * @ORM\Table(
 *   name="worker",
 *   indexes={
 *     @ORM\Index(
 *       name="worker_code",
 *       columns={"code"}
 *     ),
 *     @ORM\Index(
 *       name="worker_name",
 *       columns={"name"}
 *     ),
 *     @ORM\Index(
 *       name="worker_notes",
 *       columns={"notes"}
 *     ),
 *     @ORM\Index(
 *       name="worker_searchable",
 *       columns={"searchable"}
 *     ),
 *     @ORM\Index(
 *       name="worker_exclusive",
 *       columns={"exclusive"}
 *     ),
 *     @ORM\Index(
 *       name="worker_is_active",
 *       columns={"is_active"}
 *     ),
 *     @ORM\Index(
 *       name="worker_greenhouse_id",
 *       columns={"greenhouse_id"}
 *     ),
 *     @ORM\Index(
 *       name="worker_department_id",
 *       columns={"department_id"}
 *     ),
 *     @ORM\Index(
 *       name="worker_spread_till",
 *       columns={"spread_till"}
 *     ),
 *     @ORM\Index(
 *       name="worker_raw_department_id",
 *       columns={"raw_department_id"}
 *     ),
 *     @ORM\Index(
 *       name="worker_position_id",
 *       columns={"position_id"}
 *     ),
 *     @ORM\Index(
 *       name="worker_raw_position_id",
 *       columns={"raw_position_id"}
 *     ),
 *     @ORM\Index(
 *       name="worker_trolley_id",
 *       columns={"trolley_id"}
 *     ),
 *      @ORM\Index(
 *       name="worker_trolley_name",
 *       columns={"trolley_name"}
 *     ),
 *      @ORM\Index(
 *       name="worker_section_query",
 *       columns={"spread_till", "greenhouse_id", "is_active"}
 *     ),
 *   }
 * )
 * @ORM\Entity(repositoryClass="App\Repository\WorkerRepository")
 */
class Worker
{
    /**
     * @var Uuid
     * @ApiProperty(identifier=true)
     * @ORM\Id
     * @ORM\Column(type="guid", unique=true)
     * @Assert\Uuid
     * @Groups({"read", "section", "assign"})
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=200)
     * @Groups({"read", "section", "assign"})
     */
    private $name;

    /**
     * @ORM\Column(type="string", length=5)
     * @Groups({"read", "section", "assign"})
     */
    private $code;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="create")
     * @ORM\Column(type="datetimetz")
     * @Groups({"read", "assign"})
     */
    private $createdAt;

    /**
     * @var \DateTime
     * @Gedmo\Timestampable(on="update")
     * @ORM\Column(type="datetimetz")
     * @Groups({"read", "assign"})
     */
    private $updatedAt;

    /**
     * @Groups({"read", "assign"})
     * @ORM\Column(type="json", nullable=true)
     */
    private $raw = [];

    /**
     * @Groups({"read", "assign"})
     * @ORM\Column(type="guid", nullable=true)
     */
    private $positionId;

    /**
     * @Groups({"read", "assign"})
     * @ORM\Column(type="guid", nullable=true)
     */
    private $greenhouseId;

    /**
     * @Groups({"read", "assign"})
     * @ORM\ManyToOne(targetEntity="App\Entity\Greenhouse")
     */
    private $greenhouse;

    /**
     * @Groups({"read", "assign"})
     * @ORM\Column(type="guid", nullable=true)
     */
    private $trolleyId;

    /**
     * @Groups({"read", "assign"})
     * @ORM\Column(type="string", length=200, nullable=true)
     */
    private $trolleyName;

    /**
     * @Groups({"read", "assign"})
     * @ORM\Column(type="guid", nullable=true)
     */
    private $departmentId;

    /**
     * @Groups({"read", "assign"})
     * @ORM\ManyToOne(targetEntity="App\Entity\Position")
     */
    private $position;

    /**
     * @Groups({"read", "assign"})
     * @ORM\ManyToOne(targetEntity="App\Entity\Department")
     */
    private $department;

    /**
     * @Groups({"read", "assign"})
     */
    private $exchangers;

    /**
     * @ORM\Column(type="boolean", nullable=true)
     * @Groups({"read", "assign"})
     */
    private $isActive;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read", "assign"})
     */
    private $rawPositionId;

    /**
     * @ORM\Column(type="guid", nullable=true)
     * @Groups({"read", "assign"})
     */
    private $rawDepartmentId;

    /**
     * @ORM\Column(type="smallint")
     * @Groups({"read", "assign"})
     */
    private $taskCount;


    /**
     * @ORM\OneToMany(targetEntity="App\Entity\Rating", mappedBy="worker")
     * @Groups({"read", "assign"})
     */
    private $ratings;

    /**
     * @ORM\Column(type="datetimetz", nullable=true)
     */
    private $taskCountDate;

    /**
     * @ORM\Column(type="datetimetz", nullable=true)
     * @Groups({"read", "section", "assign"})
     */
    private $spreadTill;

    private $relativeSpreadTill;

    /**
     * @Groups({"read"})
     */
    private $earnings = [ // src/EventListener/class WorkerEarnings.php
        "monthEarned" => 0,
        "monthForecast" => 0,
    ];

    /**
     * @Groups({"read", "assign"})
     */
    private $rowNumber = null; // src/EventListener/class WorkerRowNumber.php

    /**
     * @Groups({"read", "assign"})
     */
    private $totalTodayTasks = 0;

    /**
     * @ORM\Column(type="boolean", options={"default" : false})
     * @Groups({"read", "assign"})
     */
    private $nfcMode = true;

    /**
     * @ORM\Column(type="smallint", options={"default" : 0})
     * @Groups({"read", "assign"})
     */
    private $exclusive = 0;

    /**
     * @ORM\Column(type="text", nullable=true)
     * @Groups({"read", "section", "assign"})
     */
    private $notes;

    /**
     * @ORM\Column(type="text", nullable=true)
     */
    private $searchable;

    /**
     * @ORM\Column(type="string", length=200, nullable=true)
     * @Groups({"read", "assign"})
     */
    private $versionName;

    /**
     * @ORM\Column(type="string", length=200, nullable=true)
     * @Groups({"read", "assign"})
     */
    private $phoneName;

    /**
     * @ORM\Column(type="boolean", options={"default" : true})
     * @Groups({"read", "assign"})
     */
    private $phoneMode = true;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\CheckPriority", mappedBy="worker")
     */
    private $checkPriorities;

    /**
     * @ORM\Column(type="text", nullable=true)
     * @Groups({"read", "assign"})
     */
    private $schedule;

    /**
     * @ORM\Column(type="date", nullable=true)
     * @Groups({"read", "assign"})
     */
    private $birthDate;

    public function __construct()
    {
        $this->ratings = new ArrayCollection();
        $this->checkPriorities = new ArrayCollection();
    }

    public function setId(?string $id): void
    {
        $this->id = $id;
    }

    public function getId(): ?string
    {
        return $this->id;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): self
    {
        $this->name = $name;

        return $this;
    }

    public function getCode(): ?string
    {
        return $this->code;
    }

    public function setCode(string $code): self
    {
        $this->code = $code;

        return $this;
    }

    public function getCreatedAt(): ?\DateTimeInterface
    {
        return $this->createdAt;
    }

    public function getUpdatedAt(): ?\DateTimeInterface
    {
        return $this->updatedAt;
    }

    public function getRaw(): ?array
    {
        return $this->raw;
    }

    public function setRaw(?array $raw): self
    {
        $this->raw = $raw;

        return $this;
    }

    public function getPositionId(): ?string
    {
        return $this->positionId;
    }

    public function setPositionId(?string $positionId): self
    {
        $this->positionId = $positionId;

        return $this;
    }

    public function getGreenhouseId(): ?string
    {
        return $this->greenhouseId;
    }

    public function setGreenhouseId(?string $greenhouseId): self
    {
        $this->greenhouseId = $greenhouseId;

        return $this;
    }

    public function getGreenhouse(): ?Greenhouse
    {
        return $this->greenhouse;
    }

    public function setGreenhouse(?Greenhouse $greenhouse): self
    {
        $this->greenhouse = $greenhouse;

        return $this;
    }

    public function getTrolleyId(): ?string
    {
        return $this->trolleyId;
    }

    public function setTrolleyId(?string $trolleyId): self
    {
        $this->trolleyId = $trolleyId;

        return $this;
    }

    public function getTrolleyName(): ?string
    {
        return $this->trolleyName;
    }

    public function setTrolleyName(?string $trolleyName): self
    {
        $this->trolleyName = $trolleyName;

        return $this;
    }

    public function getDepartmentId(): ?string
    {
        return $this->departmentId;
    }

    public function setDepartmentId(?string $departmentId): self
    {
        $this->departmentId = $departmentId;

        return $this;
    }

    public function getPosition(): ?Position
    {
        return $this->position;
    }

    public function setPosition(?Position $position): self
    {
        $this->position = $position;

        return $this;
    }

    public function getDepartment(): ?Department
    {
        return $this->department;
    }

    public function setDepartment(?Department $department): self
    {
        $this->department = $department;

        return $this;
    }

    public function getExchangers(): ?array
    {
        return [
            [
                'name' => 'common',
                'bindingKey' => 'SESSION-ID',
            ],
            [
                'name' => $this->getId(),
                'bindingKey' => 'SESSION-ID',
            ],
            [
                'name' => 'testExchange',
                'bindingKey' => $this->getId(),
        ],
            [
                'name' => 'taskInfoExchange',
                'bindingKey' => $this->getId(),
            ],
            [
                'name' => $this->getDepartmentId() . '.' . $this->getPositionId(),
                'bindingKey' => $this->getId(),
        ],
            [
                'name' => 'greenHouse',
                'bindingKey' => '#',
            ],
        ];
    }

    public function getIsActive(): ?bool
    {
        return $this->isActive;
    }

    public function setIsActive(?bool $isActive): self
    {
        $this->isActive = $isActive;

        return $this;
    }

    public function getRawPositionId(): ?string
    {
        return $this->rawPositionId;
    }

    public function setRawPositionId(?string $rawPositionId): self
    {
        $this->rawPositionId = $rawPositionId;

        return $this;
    }

    public function getRawDepartmentId(): ?string
    {
        return $this->rawDepartmentId;
    }

    public function setRawDepartmentId(?string $rawDepartmentId): self
    {
        $this->rawDepartmentId = $rawDepartmentId;

        return $this;
    }

    public function getTaskCount(): ?int
    {
        return $this->taskCount;
    }

    public function setTaskCount(int $taskCount): self
    {
        $this->taskCount = $taskCount;

        return $this;
    }

    /**
     * @return Collection|Rating[]
     */
    public function getRatings(): Collection
    {
        return $this->ratings;
    }

    public function addRating(Rating $rating): self
    {
        if (!$this->ratings->contains($rating)) {
            $this->ratings[] = $rating;
            $rating->setWorker($this);
        }

        return $this;
    }

    public function removeRating(Rating $rating): self
    {
        if ($this->ratings->contains($rating)) {
            $this->ratings->removeElement($rating);
            // set the owning side to null (unless already changed)
            if ($rating->getWorker() === $this) {
                $rating->setWorker(null);
            }
        }

        return $this;
    }

    public function getTaskCountDate(): ?\DateTimeInterface
    {
        return $this->taskCountDate;
    }

    public function setTaskCountDate(?\DateTimeInterface $taskCountDate): self
    {
        $this->taskCountDate = new \DateTime('NOW');

        return $this;
    }

    public function getSpreadTill(): ?\DateTimeInterface
    {
        return $this->spreadTill;
    }

    public function setSpreadTill(?\DateTimeInterface $spreadTill): self
    {
        $this->spreadTill = $spreadTill;

        return $this;
    }

    public function setRelativeSpreadTill(?int $spreadTillMinutes): self
    {
        $spreadTill = $this->spreadTill ? : new \DateTime('now');
        $now = new \DateTime('now');

        if($spreadTillMinutes) {
            $now->modify('+' . $spreadTillMinutes . ' minutes');
        }

        if($now > $spreadTill) {
            $this->spreadTill = $now;
        }

        return $this;
    }

    public function getEarnings(): ?array
    {
        return $this->earnings;
    }

    public function setEarnings(?array $earnings): self
    {
        $this->earnings = $earnings;

        return $this;
    }

    public function getRowNumber(): ?int
    {
        return $this->rowNumber;
    }

    public function setRowNumber(?int $rowNumber): self
    {
        $this->rowNumber = $rowNumber;

        return $this;
    }

    public function getTotalTodayTasks(): ?int
    {
        return $this->totalTodayTasks;
    }

    public function setTotalTodayTasks(?int $totalTodayTasks): self
    {
        $this->totalTodayTasks = $totalTodayTasks;

        return $this;
    }

    public function getNfcMode(): ?bool
    {
        return $this->nfcMode;
    }

    public function setNfcMode(bool $nfcMode): self
    {
        $this->nfcMode = $nfcMode;

        return $this;
    }

    public function getExclusive(): ?int
    {
        return $this->exclusive;
    }

    public function setExclusive(int $exclusive): self
    {
        $this->exclusive = $exclusive;

        return $this;
    }

    public function getNotes(): ?string
    {
        return $this->notes;
    }

    public function setNotes(?string $notes): self
    {
        $this->notes = $notes;

        return $this;
    }

    public function getSearchable(): ?string
    {
        return $this->searchable;
    }

    public function setSearchable(?string $searchable): self
    {
        $this->searchable = $searchable;

        return $this;
    }

    public function getVersionName(): ?string
    {
        return $this->versionName;
    }

    public function setVersionName(?string $versionName): self
    {
        $this->versionName = $versionName;

        return $this;
    }

    public function getPhoneName(): ?string
    {
        return $this->phoneName;
    }

    public function setPhoneName(?string $phoneName): self
    {
        $this->phoneName = $phoneName;

        return $this;
    }

    public function getPhoneMode(): ?bool
    {
        return $this->phoneMode;
    }

    public function setPhoneMode(bool $phoneMode): self
    {
        $this->phoneMode = $phoneMode;

        return $this;
    }

    public function getSchedule(): ?string
    {
        return $this->schedule;
    }

    public function setSchedule(?string $schedule): self
    {
        $this->schedule = $schedule;

        return $this;
    }

    public function setBirthDate(?\DateTimeInterface $birthDate): self
    {
        $this->birthDate = $birthDate;

        return $this;
    }

    public function getBirthDate(): ?\DateTimeInterface
    {
        return $this->birthDate;
    }

    /**
     * @return Collection|CheckPriority[]
     */
    public function getCheckPriorities(): Collection
    {
        return $this->checkPriorities;
    }

    public function addCheckPriority(CheckPriority $checkPriority): self
    {
        if (!$this->checkPriorities->contains($checkPriority)) {
            $this->checkPriorities[] = $checkPriority;
            $checkPriority->setWorkerId($this);
        }

        return $this;
    }

    public function removeCheckPriority(CheckPriority $checkPriority): self
    {
        if ($this->checkPriorities->contains($checkPriority)) {
            $this->checkPriorities->removeElement($checkPriority);
            // set the owning side to null (unless already changed)
            if ($checkPriority->getWorkerId() === $this) {
                $checkPriority->setWorkerId(null);
            }
        }

        return $this;
    }
}
