<?php

// src/EventListener/class TaskEventListener.php
namespace App\EventListener;

use App\Entity\Task;
use App\Entity\Worker;
use App\Entity\Sync;
use App\Entity\Collectable;
use App\Entity\Metric;
use App\Entity\PlantPhenology;
use App\Entity\Row;
use App\Entity\GreenhouseSection;

use Doctrine\ORM\Event\LifecycleEventArgs;
use Doctrine\ORM\Event\PreUpdateEventArgs;
use Doctrine\ORM\Event\OnFlushEventArgs;

use Symfony\Component\HttpFoundation\RequestStack;

class TaskEventListener
{
    protected $requestStack;

    public function __construct(RequestStack $requestStack)
    {
        $this->requestStack = $requestStack;
    }

    // the entity listener methods receive two arguments:
    // the entity instance and the lifecycle event
    public function postLoad(Task $task, LifecycleEventArgs $event)
    {
      $entityManager = $event->getObjectManager();

      $taskRepository = $entityManager->getRepository(Task::class);
      $syncRepository = $entityManager->getRepository(Sync::class);
      $collectableRepository = $entityManager->getRepository(Collectable::class);
      $metricRepository = $entityManager->getRepository(Metric::class);
      $taskRepository = $entityManager->getRepository(Task::class);
      $plantRepository = $entityManager->getRepository(PlantPhenology::class);
      $rowRepository = $entityManager->getRepository(Row::class);
      $greenhouseSectionRepository = $entityManager->getRepository(GreenhouseSection::class);

      $groups = [];
      $properties = [];

      if($this->requestStack) { 
        $request = $this->requestStack->getCurrentRequest();

        if($request) {
          $groups = $request->query->get('groups');
          $properties = $request->query->get('properties');
        }
      }

      $isQuick = is_array($groups) && (in_array('section', $groups) || in_array('mobile', $groups));
      $isSync = is_array($properties) && in_array('sync', $properties);
      $isRow = is_array($properties) && (in_array('rowType', $properties) || in_array('rowOrderBy', $properties));
      $isQuality = is_array($properties) && in_array('qualityTask', $properties);
      $isTaskLimit = is_array($properties) && in_array('taskLimit', $properties);
      $isInProgress = is_array($properties) && in_array('inProgress', $properties);

      if(!$isQuick || $isSync) {
        $sync = $syncRepository->find($task->getId());

        if($sync) {
          $task->setSync($sync);
        }
      }

      $taskId = $task->getId();
      $rowNumber = $task->getRowNumber();
      $greenhouseId = $task->getGreenhouseId();
      $sectionId = $task->getSectionId();
      $qualityTaskId = $task->getQualityTaskId();

      if(!$isQuick || $isRow) {
        $row = $rowRepository->findRowByRowNumber($greenhouseId, $rowNumber);

        if($row) {
          $task->setRowType($row->getType());
          $task->setRowOrderBy($row->getOrderBy());
        }
      }

      // if($sectionId === Task::PHENOLOGY_ID) {
      //   $collectables = $collectableRepository->findAllActive();

      //   if($collectables) {
      //     $task->setCollectables($collectables);
      //   }
        
      //   $relatedTasks = $taskRepository->getPhenologyTasksIds($taskId, $rowNumber, $greenhouseId, $sectionId);

      //   array_unshift($relatedTasks, ['id' => $taskId]);

      //   $metrics = $metricRepository->getMetrics($relatedTasks);
      //   $task->setMeasurements($metrics);

      //   $plants = $plantRepository->getTaskPlants($row->getId());
      //   $task->setPlants($plants);
      // }

      if ((!$isQuick || $isQuality) && $qualityTaskId) {
        $qualityTask = $taskRepository->getQualityTaskById($qualityTaskId);

        if ($qualityTask) {
          $task->setQualityTask($qualityTask[0]);
        }
      }

      if(!$isQuick || $isTaskLimit) {
        $greenhouseSection = $greenhouseSectionRepository->findMySection($greenhouseId, $sectionId);
        if($greenhouseSection && $greenhouseSection->getMinLeadTime()) {
          $task->setTaskLimit($greenhouseSection->getMinLeadTime());
        }
      }

      if(!$isQuick || $isInProgress) {
        $this->getInProgress($task, $event);
      }

      // $this->getTaskTodaySectionTasksCount($task, $event);
    }

    public function preUpdate(Task $task, PreUpdateEventArgs $event)
    {
      if(!isset($event->getEntityChangeSet()['toExchange'])) {
        $task->setToExchange(true);
      }

      if(
        isset($event->getEntityChangeSet()['startAt']) ||
        isset($event->getEntityChangeSet()['finishAt'])
      ) {
        $task->setIsActive($task->getFinishAt() != $task->getStartAt());
      }      

      if(isset($event->getEntityChangeSet()['workerId'])) {
        if($event->getEntityChangeSet()['workerId'][0]) {
          $task->setPreviousWorkerId($event->getEntityChangeSet()['workerId'][0]);
        }
      }
      // ... do something to notify the changes
    }

    public function getInProgress(Task $task, LifecycleEventArgs $event)
    {

      $entityManager = $event->getObjectManager();
      $taskRepository = $entityManager->getRepository(Task::class);

      $count = $taskRepository->getCountTasksInProgress($task->getId(), $task->getGreenhouseId(), $task->getRowNumber());

      $task->setInProgress($count ? true : false);

        // ... do something to notify the changes
    }

    public function getTaskTodaySectionTasksCount(Task $task, LifecycleEventArgs $event)
    {
      $entityManager = $event->getObjectManager();
      $taskRepository = $entityManager->getRepository(Task::class);

      $tomorrow = new \DateTime('tomorrow');
      $today = new \DateTime('today');

      $count = $taskRepository->getTasksCountBySection($task->getSectionId(), $today, $tomorrow);

      $task->setTodaySectionTasksCount($count);

      $workerRepository = $entityManager->getRepository(Worker::class);
      $count = $workerRepository->getQualifiedWorkersOnline($task->getSectionId(), $task->getRating());

      $task->setQualifiedWorkersOnline($count);

        // ... do something to notify the changes
    }

    public function onFlush(OnFlushEventArgs $args)
    {
    }
}