<?php

// src/EventListener/class TrolleyEventListener.php
namespace App\EventListener;

use App\Entity\Trolley;
use App\Entity\Sync;
use Doctrine\ORM\Event\LifecycleEventArgs;
use Doctrine\ORM\Event\PreUpdateEventArgs;

use Symfony\Component\HttpFoundation\RequestStack;

class TrolleyEventListener
{
    protected $requestStack;

    public function __construct(RequestStack $requestStack)
    {
        $this->requestStack = $requestStack;
    }

    // the entity listener methods receive two arguments:
    // the entity instance and the lifecycle event
    public function postLoad(Trolley $trolley, LifecycleEventArgs $event)
    {
      //$this->getInProgress($task, $event);

      $entityManager = $event->getObjectManager();
      $trolleyRepository = $entityManager->getRepository(Trolley::class);
      $syncRepository = $entityManager->getRepository(Sync::class);

      $groups = [];
      $properties = [];

      if($this->requestStack) { 
        $request = $this->requestStack->getCurrentRequest();

        if($request) {
          $groups = $request->query->get('groups');
          $properties = $request->query->get('properties');
        }
      }

      $isQuick = is_array($groups) && in_array('quick', $groups);
      $isSync = is_array($properties) && in_array('sync', $properties);
      $isPrevious = is_array($properties) && in_array('previous', $properties);

      if(!$isQuick || $isPrevious) {
        $previous = $trolleyRepository->findPrevious($trolley);

        if($previous) {
          $trolley->setPrevious($previous);
        }
      }

      if(!$isQuick || $isSync) {
        $sync = $syncRepository->find($trolley->getId());
        
        if($sync) {
          $trolley->setSync($sync);
        }
      }

      // ... do something to notify the changes
    }
}
