<?php

// src/EventListener/class WorkerEventListener.php
namespace App\EventListener;

use App\Entity\Worker;
use App\Entity\Task;
use Doctrine\ORM\Event\LifecycleEventArgs;
use Doctrine\ORM\Event\PreUpdateEventArgs;
use Doctrine\ORM\Event\OnFlushEventArgs;

use Symfony\Component\HttpFoundation\RequestStack;

class WorkerEventListener
{
    protected $requestStack;

    public function __construct(RequestStack $requestStack)
    {
        $this->requestStack = $requestStack;
    }

    // the entity listener methods receive two arguments:
    // the entity instance and the lifecycle event
    public function postLoad(Worker $worker, LifecycleEventArgs $event)
    {
      $groups = [];
      $properties = [];

      if($this->requestStack) { 
        $request = $this->requestStack->getCurrentRequest();

        if($request) {
          $groups = $request->query->get('groups');
          $properties = $request->query->get('properties');
        }
      }

      $isQuick = is_array($groups) && (in_array('section', $groups) || in_array('assign', $groups));
      $isRowNumber = is_array($properties) && in_array('workerRowNumber', $properties);

      if(!$isQuick || $isRowNumber) {
        $this->loadRowNumber($worker, $event);
      }
      // $this->loadEarnings($worker, $event);
      // $this->loadTotalTodayTasks($worker, $event);

      // ... do something to notify the changes
    }

    public function preUpdate(Worker $worker, PreUpdateEventArgs $event)
    {  
      if($worker->getGreenhouseId() && !$worker->getRawDepartmentId()) {
        $departments = [
          '7698def5-d66c-11e7-8110-40a8f0260033' => '5f519a99-a9ae-11e7-a90f-005056ac182c', // № 6 (Томаты)
          '1abec4c4-0d22-11e6-942a-005056ac0e86' => 'd92adf67-3760-11e7-b77d-005056ac182c', // № 1 (Огурцы)
          '9890c293-da19-11e9-a2f2-005056a3e110' => 'b95c5736-8397-11e9-a2e9-005056a3e110', // № 8 (Огурцы)
          '10a6ab25-0d22-11e6-942a-005056ac0e86' => 'df65b893-3760-11e7-b77d-005056ac182c', // № 2 (Томаты)
          'ab4581b0-9f8b-11e8-a2d6-005056a3e110' => '27bdce5c-9566-11e8-a2d0-005056a398e7', // № 5 (Томаты)
          'a5ae0818-da19-11e9-a2f2-005056a3e110' => 'c64299dc-8397-11e9-a2e9-005056a3e110', // № 9 (Огурцы)
          '230e8905-ff37-11e6-80fe-40a8f0260032' => 'de965dd9-c104-11e6-80f8-40a8f0260032', // № 3 (Томаты)
          '2b8e7299-ff37-11e6-80fe-40a8f0260032' => 'de965ddb-c104-11e6-80f8-40a8f0260032', // № 4 (Томаты)
          '880954d5-d66c-11e7-8110-40a8f0260033' => '7cf8a7ee-a9ae-11e7-a90f-005056ac182c', // № 7 (Томаты)
        ];

        $departmentId = $departments[$worker->getGreenhouseId()] ;

        if($departmentId) {
          $worker->setRawDepartmentId($departmentId);
          $worker->setDepartmentId($departmentId);
        }
      }
    }

    public function onFlush(OnFlushEventArgs $args)
    {
      $em = $args->getEntityManager();
      $uow = $em->getUnitOfWork();

      foreach ($uow->getScheduledEntityUpdates() as $entity) {
        if ($entity instanceof Worker) {
          if(
            isset($uow->getEntityChangeSet($entity)['greenhouseId'])
          ) {
            $taskRepository = $em->getRepository(Task::class);

            $tasks = $taskRepository->getWorkerTasksNotStarted($entity->getId(), $uow->getEntityChangeSet($entity)['greenhouseId'][0]);

            if($tasks) {
              foreach($tasks as $task) {
                $task->setForceWorkerId(null) ;
                $em->persist($task); 
                $uow->computeChangeSet($em->getClassMetadata(get_class($task)), $task);
              }
            }
          }   
        }
      }
    }

    public function loadEarnings(Worker $worker, LifecycleEventArgs $event)
    {

      $rowPrice = 0;
      $averageDaysMonth = 29.5;

      $earnings = $worker->getEarnings();

      $entityManager = $event->getObjectManager();
      $taskRepository = $entityManager->getRepository(Task::class);

      $monthStart = new \DateTime('first day of this month');
      $monthTasks = $taskRepository->getCountTasksDatePeriod($worker->getId(), $monthStart);

      $now = new \DateTime('NOW');
      $diff = $now->diff($monthStart)->format("%a") ? : 1;

      $earnings['monthEarned'] = round($monthTasks * $rowPrice);
      $earnings['monthForecast'] = round(($earnings['monthEarned'] / $diff) * $averageDaysMonth);

      $worker->setEarnings($earnings);

        // ... do something to notify the changes
    }

    public function loadRowNumber(Worker $worker, LifecycleEventArgs $event)
    {

      $entityManager = $event->getObjectManager();
      $taskRepository = $entityManager->getRepository(Task::class);

      $rowNumber = $taskRepository->getTaskInProgress($worker->getId());

      $worker->setRowNumber($rowNumber);

        // ... do something to notify the changes
    }

    public function loadTotalTodayTasks(Worker $worker, LifecycleEventArgs $event)
    {

      $entityManager = $event->getObjectManager();
      $taskRepository = $entityManager->getRepository(Task::class);

      $today = new \DateTime('today');
      $now = new \DateTime('NOW');
      $countFinished = $taskRepository->getCountTasksDatePeriod($worker->getId(), $today);
      $countActive = $taskRepository->getCountTasksDatePeriodActive($worker->getId(), $now);

      $worker->setTotalTodayTasks($countFinished + $countActive);

        // ... do something to notify the changes
    }
}
