<?php

declare(strict_types=1);

namespace DoctrineMigrations;

use Doctrine\DBAL\Schema\Schema;
use Doctrine\Migrations\AbstractMigration;

/**
 * Auto-generated Migration: Please modify to your needs!
 */
final class Version20200428062124 extends AbstractMigration
{
    public function getDescription() : string
    {
        return '';
    }

    public function up(Schema $schema) : void
    {
        // this up() migration is auto-generated, please modify it to your needs
        $this->abortIf($this->connection->getDatabasePlatform()->getName() !== 'postgresql', 'Migration can only be executed safely on \'postgresql\'.');

        $this->addSql('CREATE SEQUENCE audit_id_seq INCREMENT BY 1 MINVALUE 1 START 1');
        $this->addSql('CREATE TABLE audit (id SERIAL NOT NULL, table_id UUID NOT NULL, table_name TEXT NOT NULL, user_name TEXT NOT NULL, action_timestamp TIMESTAMP(0) WITH TIME ZONE DEFAULT CURRENT_TIMESTAMP NOT NULL, action TEXT NOT NULL, old_values JSONB DEFAULT NULL, new_values JSONB DEFAULT NULL, updated_cols JSONB DEFAULT NULL, query TEXT DEFAULT NULL, PRIMARY KEY(id))');

        $this->addSql('create or replace function ifModifiedFunc() returns trigger as $body$
DECLARE
    js_new jsonb := row_to_json(NEW)::jsonb;
    js_old jsonb := row_to_json(OLD)::jsonb;
begin
    if tg_op = \'UPDATE\' then
        insert into audit (table_id, table_name, user_name, action, old_values, new_values, updated_cols, query)
        values (OLD.id, tg_table_name::text, current_user::text, \'u\', js_old, js_new,
        js_new - js_old, current_query());
        return new;
    elsif tg_op = \'DELETE\' then
        insert into audit (table_id, table_name, user_name, action, old_values, query)
        values (OLD.id, tg_table_name::text, current_user::text, \'d\', js_old, current_query());
        return old;
    elsif tg_op = \'INSERT\' then
        insert into audit (table_id, table_name, user_name, action, new_values, query)
        values (NEW.id, tg_table_name::text, current_user::text, \'i\', js_new, current_query());
        return new;
    end if;
end;
$body$
language plpgsql');

        $this->addSql('create trigger syncAudit after insert or update or delete on sync for each row execute procedure ifModifiedFunc()');
        $this->addSql('create trigger taskAudit after insert or update or delete on task for each row execute procedure ifModifiedFunc()');
        
        // --
        // -- https://github.com/glynastill/pg_jsonb_delete_op
        // -- Glyn Astill 16/01/2015
        // -- Attempt at hstore style delete operator for jsonb
        // --

        $this->addSql('SET search_path = \'public\'');

        $this->addSql('CREATE OR REPLACE FUNCTION jsonb_delete_left(a jsonb, b text)
RETURNS jsonb AS
$BODY$
    SELECT COALESCE(
        (
            SELECT (\'{\' || string_agg(to_json(key) || \':\' || value, \',\') || \'}\')
            FROM jsonb_each(a)
            WHERE key <> b
        )
    , \'{}\')::jsonb;
$BODY$
LANGUAGE sql IMMUTABLE STRICT');

        $this->addSql('COMMENT ON FUNCTION jsonb_delete_left(jsonb, text) IS \'delete key in second argument from first argument\'');

        $this->addSql('CREATE OPERATOR - ( PROCEDURE = jsonb_delete_left, LEFTARG = jsonb, RIGHTARG = text)');
        $this->addSql('COMMENT ON OPERATOR - (jsonb, text) IS \'delete key from left operand\'');

        $this->addSql('CREATE OR REPLACE FUNCTION jsonb_delete_left(a jsonb, b text[])
RETURNS jsonb AS
$BODY$
    SELECT COALESCE(
        (
            SELECT (\'{\' || string_agg(to_json(key) || \':\' || value, \',\') || \'}\')
            FROM jsonb_each(a)
            WHERE key <> ALL(b)
        )
    , \'{}\')::jsonb;
$BODY$
LANGUAGE sql IMMUTABLE STRICT');

        $this->addSql('COMMENT ON FUNCTION jsonb_delete_left(jsonb, text[]) IS \'delete keys in second argument from first argument\'');

        $this->addSql('CREATE OPERATOR - ( PROCEDURE = jsonb_delete_left, LEFTARG = jsonb, RIGHTARG = text[])');
        $this->addSql('COMMENT ON OPERATOR - (jsonb, text[]) IS \'delete keys from left operand\'');

        $this->addSql('CREATE OR REPLACE FUNCTION jsonb_delete_left(a jsonb, b jsonb)
RETURNS jsonb AS
$BODY$
    SELECT COALESCE(
        (
            SELECT (\'{\' || string_agg(to_json(key) || \':\' || value, \',\') || \'}\')
            FROM jsonb_each(a)
            WHERE NOT (\'{\' || to_json(key) || \':\' || value || \'}\')::jsonb <@ b
        )
    , \'{}\')::jsonb;
$BODY$
LANGUAGE sql IMMUTABLE STRICT');

        $this->addSql('COMMENT ON FUNCTION jsonb_delete_left(jsonb, jsonb) IS \'delete matching pairs in second argument from first argument\'');

        $this->addSql('CREATE OPERATOR - ( PROCEDURE = jsonb_delete_left, LEFTARG = jsonb, RIGHTARG = jsonb)');
        $this->addSql('COMMENT ON OPERATOR - (jsonb, jsonb) IS \'delete matching pairs from left operand\'');
    
    }

    public function down(Schema $schema) : void
    {
        // this down() migration is auto-generated, please modify it to your needs
        $this->abortIf($this->connection->getDatabasePlatform()->getName() !== 'postgresql', 'Migration can only be executed safely on \'postgresql\'.');

        $this->addSql('CREATE SCHEMA public');

        $this->addSql('DROP SEQUENCE audit_id_seq CASCADE');
        $this->addSql('DROP TABLE audit');

        $this->addSql('DROP FUNCTION ifModifiedFunc');
        $this->addSql('DROP TRIGGER IF EXISTS syncAudit ON sync');
        $this->addSql('DROP TRIGGER IF EXISTS taskAudit ON task');
    }
}
