<?php

namespace App\Repository;

use App\Entity\Metric;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Common\Persistence\ManagerRegistry;

/**
 * @method Metric|null find($id, $lockMode = null, $lockVersion = null)
 * @method Metric|null findOneBy(array $criteria, array $orderBy = null)
 * @method Metric[]    findAll()
 * @method Metric[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class MetricRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Metric::class);
    }

    // /**
    //  * @return Metric[] Returns an array of Metric objects
    //  */
    /*
    public function findByExampleField($value)
    {
        return $this->createQueryBuilder('m')
            ->andWhere('m.exampleField = :val')
            ->setParameter('val', $value)
            ->orderBy('m.id', 'ASC')
            ->setMaxResults(10)
            ->getQuery()
            ->getResult()
        ;
    }
    */

    public function getMetrics($relatedTasks)
    {
        if (empty($relatedTasks)) return [];
        
        $finalMetrics = [];

        foreach($relatedTasks as $task) {
            $id = $task['id'];

            $metrics = $this->createQueryBuilder('m')
                ->select('DISTINCT m.code, m.parentId, m.plantId, m.taskId')
                ->where('m.taskId = :taskId')
                ->setParameter('taskId', $id)
                ->getQuery()
                ->getResult()
            ;

            $uniqMetrics = [];
            
            foreach($metrics as $m) {
                if (!in_array($m['code'], $uniqMetrics)) {
                    $uniqMetrics[] = $m['code'];
                    $finalMetrics[$m['code']] = [
                        "barcode" => $m['code'],
			"parentId" => $m['parentId'],
		        "taskId" => $m['taskId'],	
                        "plantId" => $m['plantId'],
                    ];
                }
            }
        }

        $metrics = [];
        foreach($finalMetrics as $barcode => $metric) {
            $metrics[] = $metric;
        }

        return $metrics;
    }

    /*
    public function findOneBySomeField($value): ?Metric
    {
        return $this->createQueryBuilder('m')
            ->andWhere('m.exampleField = :val')
            ->setParameter('val', $value)
            ->getQuery()
            ->getOneOrNullResult()
        ;
    }
    */
}
