<?php

namespace App\Repository;

use App\Entity\Trolley;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Common\Persistence\ManagerRegistry;

/**
 * @method Trolley|null find($id, $lockMode = null, $lockVersion = null)
 * @method Trolley|null findOneBy(array $criteria, array $orderBy = null)
 * @method Trolley[]    findAll()
 * @method Trolley[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class TrolleyRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Trolley::class);
    }

    public function findByWorkerIdDate($workerId, $dateFrom, $dateTo)
    {
        return $this->createQueryBuilder('t')
            ->where('t.workerId = :workerId')
            ->andWhere('t.registeredAt IS NOT NULL')
            ->andWhere('t.registeredAt >= :dateFrom')
            ->andWhere('t.registeredAt <= :dateTo')
            ->orderBy('t.registeredAt', 'ASC')
            ->setParameter('dateFrom', $dateFrom)
            ->setParameter('dateTo', $dateTo)
            ->setParameter('workerId', $workerId)
            ->getQuery()
            ->getResult()
        ;
    }

    public function getSyncTrolley($task): ?Trolley
    {
        if(!$task->getFinishedAt()) {
            return null;
        }

        $dateFrom = clone $task->getFinishedAt();
        $dateTo = clone $task->getFinishedAt();

        //$dateTo->add(new \DateInterval('PT12M'));
        $dateFrom->sub(new \DateInterval('PT15H'));

        return $this->createQueryBuilder('t')
            ->where('t.workerId = :workerId')
            ->andWhere('t.type = :type')
            ->andWhere('t.registeredAt IS NOT NULL')
            ->andWhere('t.registeredAt >= :dateFrom')
            ->andWhere('t.registeredAt <= :dateTo')
            ->orderBy('t.registeredAt', 'DESC')
            ->setMaxResults(1)
            ->setParameter('dateFrom', $dateFrom)
            ->setParameter('dateTo', $dateTo)
            ->setParameter('type', 'start')
            ->setParameter('workerId', $task->getWorkerId())
            ->getQuery()
            ->getOneOrNullResult()
        ;
    }

    public function findPrevious($trolley): ?Trolley
    {
        if($trolley->getType() === 'finish') {
            $dateFrom = clone $trolley->getRegisteredAt();
            $dateFrom->modify('today');

            return $this->createQueryBuilder('t')
                //->andWhere('t.trolley = :trolley')
                ->andWhere('t.id != :id')
                ->andWhere('t.workerId = :workerId')
                //->andWhere('t.type = :type')
                ->andWhere('t.registeredAt IS NOT NULL')
                ->andWhere('t.registeredAt >= :dateFrom')
                ->andWhere('t.registeredAt < :dateTo')
                ->orderBy('t.registeredAt', 'DESC')
                ->setMaxResults(1)
                //->setParameter('trolley', $trolley->getTrolley())
                ->setParameter('id', $trolley->getId())
                ->setParameter('workerId', $trolley->getWorkerId())
                //->setParameter('type', 'start')
                ->setParameter('dateFrom', $dateFrom)
                ->setParameter('dateTo', $trolley->getRegisteredAt())
                ->getQuery()
                ->getOneOrNullResult()
            ;
        // } elseif($trolley->getType() === 'start') {
        //     $dateTo = clone $trolley->getRegisteredAt();
        //     $dateTo->modify('midnight');

        //     return $this->createQueryBuilder('t')
        //         ->andWhere('t.trolley = :trolley')
        //         ->andWhere('t.id != :id')
        //         ->andWhere('t.workerId = :workerId')
        //         ->andWhere('t.type = :type')
        //         ->andWhere('t.registeredAt IS NOT NULL')
        //         ->andWhere('t.registeredAt >= :dateFrom')
        //         ->andWhere('t.registeredAt < :dateTo')
        //         ->orderBy('t.registeredAt', 'ASC')
        //         ->setMaxResults(1)
        //         ->setParameter('trolley', $trolley->getTrolley())
        //         ->setParameter('id', $trolley->getId())
        //         ->setParameter('workerId', $trolley->getWorkerId())
        //         ->setParameter('type', 'start')
        //         ->setParameter('dateFrom', $trolley->getRegisteredAt())
        //         ->setParameter('dateTo', $dateTo)
        //         ->getQuery()
        //         ->getOneOrNullResult()
        //     ;
        } else {
            return null;
        }
    }

    // /**
    //  * @return Trolley[] Returns an array of Trolley objects
    //  */
    /*
    public function findByExampleField($value)
    {
        return $this->createQueryBuilder('t')
            ->andWhere('t.exampleField = :val')
            ->setParameter('val', $value)
            ->orderBy('t.id', 'ASC')
            ->setMaxResults(10)
            ->getQuery()
            ->getResult()
        ;
    }
    */

    /*
    public function findOneBySomeField($value): ?Trolley
    {
        return $this->createQueryBuilder('t')
            ->andWhere('t.exampleField = :val')
            ->setParameter('val', $value)
            ->getQuery()
            ->getOneOrNullResult()
        ;
    }
    */
}
