<?php

namespace App\Repository;

use App\Entity\Worker;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Common\Persistence\ManagerRegistry;

/**
 * @method Worker|null find($id, $lockMode = null, $lockVersion = null)
 * @method Worker|null findOneBy(array $criteria, array $orderBy = null)
 * @method Worker[]    findAll()
 * @method Worker[]    findBy(array $criteria, array $orderBy = null, $limit = null, $offset = null)
 */
class WorkerRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Worker::class);
    }

    public function getCount()
    {
        return $this->createQueryBuilder('w')
            ->select('count(w.id)', 'r')
            ->getQuery()
            ->getSingleScalarResult();
        ;
    }

    public function getQualifiedWorkersOnline(
        ?string $sectionId, 
        int $rating
    ) {
        $now = new \DateTime('NOW');

        $q = $this->createQueryBuilder('w')
            ->select('count(w.id)')
            ->leftJoin('w.ratings', 'r')
            ->where('w.spreadTill >= :now')
            ->andWhere('r.sectionId = :sectionId')
            ->andWhere('r.ratingInt >= :rating')
            ->setParameter('sectionId', $sectionId)
            ->setParameter('rating', $rating)
            ->setParameter('now', $now);

        return $q
            ->getQuery()
            ->getSingleScalarResult();
        ;
    }

    // /**
    //  * @return Worker[] Returns an array of Worker objects
    //  */
    /*
    public function findByExampleField($value)
    {
        return $this->createQueryBuilder('w')
            ->andWhere('w.exampleField = :val')
            ->setParameter('val', $value)
            ->orderBy('w.id', 'ASC')
            ->setMaxResults(10)
            ->getQuery()
            ->getResult()
        ;
    }
    */

    /*
    public function findOneBySomeField($value): ?Worker
    {
        return $this->createQueryBuilder('w')
            ->andWhere('w.exampleField = :val')
            ->setParameter('val', $value)
            ->getQuery()
            ->getOneOrNullResult()
        ;
    }
    */
}
