import React, { useState, useEffect, useMemo, useCallback } from "react";
import { useSelector } from "react-redux";

import _ from "lodash";

import moment from "../../library/helpers/moment";

import { Input, Spin, Badge } from "antd";
import { ConfigProvider } from "antd";
import Form from "@iso/components/uielements/form";
import Radio, { RadioGroup } from "@iso/components/uielements/radio";
import InputNumber from "@iso/components/InputNumber";
import Modal from "@iso/components/Feedback/Modal";
import { DateRangepicker } from "@iso/components/uielements/datePicker";
import Checkbox from "@iso/components/uielements/checkbox";
import { request } from "@iso/lib/helpers/utility";
import AutoComplete, {
  AutoCompleteOption,
} from "@iso/components/uielements/autocomplete";

import Select, { SelectOption } from "@iso/components/uielements/select";

import locale from "antd/lib/locale-provider/ru_RU";

const RangePicker = DateRangepicker;
const FormItem = Form.Item;
const Option = SelectOption;

const NOT_ASSIGNED = "NOT_ASSIGNED";
const ASSIGNED = "ASSIGNED";
const INITIAL = "INITIAL";
const BLUR = "BLUR";
const SEARCH = "SEARCH";
const SELECTED = "SELECTED";

/* eslint-disable import/first */
import { Label, Fieldset } from "./ModalTask.styles";

const ModalTask = (props) => {
  const {
    task,
    isWorkingTime,
    hasAccessToLightEdit,
    hasAccessToHardEdit,
    isModalTask,
    greenhouseSections,
    isLoadingLastFinishedTask,
    onChangeTask,
    handleRangeSelect,
    onChangeProperties,
    onOkModal,
    onSelectQualitySection,
    onModalTask,
    handleWorkerSelect,
    hasAccessToEditWorker,
  } = props;
  const [selectedQualitySection, setSelectedQualitySection] = useState(false);

  const { greenhouses, greenhouseId } = useSelector((state) =>
    _.get(state, "App", null)
  );

  const [autoComplete, setAutoComplete] = useState([]);
  const [query, setQuery] = useState("");
  const fetchAutoComplite = async (query, greenhouseId) => {
    const response = await request("workers", {
      order: {
        'name': 'asc',
      },
      greenhouseId,
      properties: ["id", "name", "code", "spreadTill"],
      searchable: query,
      isActive: true,
      itemsPerPage: 20,
      page: 1,
    });
    setAutoComplete(response["hydra:member"]);
  };

  const throttledFetchAutoComplite = useMemo(
    () =>
      _.throttle(fetchAutoComplite, 500, {
        leading: false,
      }),
    []
  );

  useEffect(() => {
    throttledFetchAutoComplite(query, greenhouseId);
  }, [greenhouseId, query, throttledFetchAutoComplite]);

  const isStartedTask = _.get(task, "startedAt") || _.get(task, "isFinished");

  const hasAccessToTaskEdit = isStartedTask
    ? hasAccessToHardEdit
    : hasAccessToLightEdit;

  const currentGreenhouse = useMemo(
    () => _.filter(greenhouses, (item) => item.id === greenhouseId),
    [greenhouses, greenhouseId]
  );

  const [status, setStatus] = useState(INITIAL);

  useEffect(() => {
    if (!isModalTask) {
      setSelectedQualitySection(false);
    }
  }, [isModalTask]);

  const getWorkerName = (workerId) => {
    const finded = _.find(autoComplete, (a) => a.id === workerId);
    return finded ? finded.name : "";
  };
  const getValue = () => {
    switch (status) {
      case ASSIGNED:
      case SELECTED:
      case BLUR:
        return task.workerName === NOT_ASSIGNED ? "" : task.workerName;
      case INITIAL:
      case NOT_ASSIGNED:
        return "";
      case "SEARCH":
        return query;
      default:
        console.error("error status:    ", status);
    }
  };

  useEffect(() => {
    if (task && task.workerName) {
      setStatus(ASSIGNED);
    } else {
      setStatus(NOT_ASSIGNED);
    }
  }, [task]);

  const clearDebounce = useMemo(
    () =>
      _.debounce(() => {
        setQuery("");
      }, 600),
    []
  );

  const onOk = useCallback(() => {
    onOkModal();
    clearDebounce();
  }, [clearDebounce, onOkModal]);

  const onCloseCancel = useCallback(() => {
    onModalTask();
    clearDebounce();
  }, [clearDebounce, onModalTask]);

  const taskId = _.get(task, "taskId", null);

  const isActiveSaveButton = _.get(task, "isQuality")
    ? task.qualityTaskId
      ? !!task.qualityTask
      : true
    : true;

  return (
    <Modal
      visible={isModalTask}
      onClose={() => onCloseCancel()}
      onCancel={() => onCloseCancel()}
      okText={'Сохранить'}
      okButtonProps={{
        disabled: isLoadingLastFinishedTask || !isActiveSaveButton,
      }}
      onOk={() => onOk()}
      disabled={true}
      title={
        task && (
          <>
            {'Изменить задачу ' + task.name}
            <br />
            <small>{taskId ? taskId : task.id}</small>
          </>
        )
      }
      width={580}
    >
      <Form>
        {task && (
          <>
            <Fieldset>
              <Label>Основные параметры</Label>
              <FormItem label="Рейтинг" hasFeedback>
                <RadioGroup
                  name={'rating'}
                  value={task.rating}
                  onChange={({ target: { value } }) =>
                    onChangeTask('rating', value)
                  }
                >
                  {_.map(Array(11), (item, index) => {
                    return (
                      <Radio
                        disabled={!hasAccessToLightEdit}
                        key={index}
                        value={index}
                      >
                        {index}
                      </Radio>
                    );
                  })}
                </RadioGroup>
              </FormItem>
              <FormItem label="Сотрудник" hasFeedback>
                <AutoComplete
                  onSearch={setQuery}
                  onSelect={(workerId) => {
                    handleWorkerSelect(workerId, getWorkerName(workerId));
                    setStatus(SELECTED);
                  }}
                  placeholder="[не назначено]"
                  disabled={!hasAccessToEditWorker}
                  value={getValue()}
                  onBlur={() => {
                    if (status === SEARCH) {
                      setStatus(BLUR);
                    }
                  }}
                  onChange={() => {
                    setStatus(SEARCH);
                  }}
                >
                  <AutoCompleteOption value={NOT_ASSIGNED} key={0}>
                    [не назначено]
                  </AutoCompleteOption>
                  {_.map(autoComplete, (w) => (
                    <AutoCompleteOption value={w.id} key={w.id}>
                      {moment(w.spreadTill) > moment()? (
                        <Badge status="success" />
                      ) : (
                        <Badge status="default" />
                      )}
                      {` ${w.code} | ${_.get(
                        currentGreenhouse[0],
                        'description'
                      )} | ${w.name}`}
                    </AutoCompleteOption>
                  ))}
                </AutoComplete>
                {!hasAccessToEditWorker && (
                  <small style={{ color: 'red', marginTop: '-10px' }}>
                    Нельзя редактировать сотрудника в нерабочие часы
                  </small>
                )}
              </FormItem>
              <FormItem label="Дата и время" hasFeedback>
                <ConfigProvider locale={locale}>
                  <RangePicker
                    disabled={!hasAccessToHardEdit}
                    locale={locale}
                    ranges={{
                      Сегодня: [moment(), moment()],
                      'Этот месяц': [moment(), moment().endOf('month')],
                    }}
                    value={[
                      task.startedAt ? moment(task.startedAt) : null,
                      task.finishedAt ? moment(task.finishedAt) : null,
                    ]}
                    showTime
                    onChange={handleRangeSelect}
                    format="YYYY/MM/DD HH:mm:ss"
                    allowClear={true}
                  />
                </ConfigProvider>
              </FormItem>
              <Checkbox
                disabled={!hasAccessToHardEdit}
                onChange={({ target: { checked } }) =>
                  onChangeTask('isFinished', checked)
                }
                checked={task.isFinished}
              >
                Выполнено / Факт
              </Checkbox>
            </Fieldset>
            <Fieldset>
              <Label>Параметры выполнения</Label>

              <FormItem label="Группа" hasFeedback>
                <InputNumber
                  name="exclusive"
                  min={0}
                  max={999}
                  disabled={!hasAccessToLightEdit}
                  value={task.exclusive}
                  onChange={({ target: { value } }) =>
                    onChangeTask('exclusive', value)
                  }
                />
              </FormItem>
              {task.isQuality && (
                <FormItem label="Проверяемый вид работ" hasFeedback>
                  <Select
                    dropdownMatchSelectWidth={false}
                    value={
                      _.get(task, 'qualitySectionId') ||
                      _.get(task, 'qualityTask.sectionId') ||
                      'Выберите вид работ для проверки'
                    }
                    onChange={(value) => {
                      onChangeTask('qualitySectionId', value);
                      onSelectQualitySection(value, task.rowNumber);
                      setSelectedQualitySection(true);
                    }}
                  >
                    {_.map(
                      _.sortBy(
                        _.filter(
                          greenhouseSections,
                          (gs) => gs.module != 'quality'
                        ),
                        ['name']
                      ),
                      (g) => {
                        return (
                          <Option value={g.sectionId} key={g.sectionId}>
                            {' '}
                            {g.name}{' '}
                          </Option>
                        );
                      }
                    )}
                  </Select>
                </FormItem>
              )}
              {task.isQuality &&
                (isLoadingLastFinishedTask ? (
                  <Spin style={{ marginTop: 10 }} />
                ) : task.qualityTask ? (
                  <small>
                    <div>Последняя выполненная задача:</div>
                    <div>{_.get(task, 'qualityTask.sectionName')}</div>
                    <div>{_.get(task, 'qualityTask.workerName')}</div>
                    <div>
                      {'Завершена: '}
                      {_.get(task, 'qualityTask.finishedAt')
                        ? moment(_.get(task, 'qualityTask.finishedAt')).format(
                            'LLLL'
                          )
                        : null}
                    </div>
                  </small>
                ) : (
                  selectedQualitySection && (
                    <small style={{ color: 'red' }}>
                      Выполненные задачи по выбранному виду работ не найдены
                    </small>
                  )
                ))}
              {_.map(task.properties, (p) => (
                <FormItem key={p.id} label={p.name} hasFeedback>
                  <Input
                    placeholder={p.description}
                    value={p.value}
                    onChange={({ target: { value } }) =>
                      onChangeProperties(p.id, value)
                    }
                    disabled
                  />
                </FormItem>
              ))}
            </Fieldset>
            <Fieldset>
              <Label>1C</Label>
              <Checkbox
                onChange={({ target: { checked } }) =>
                  onChangeTask('toSend', checked)
                }
                checked={task.toSend}
                disabled
              >
                Отправить
              </Checkbox>
            </Fieldset>
          </>
        )}
      </Form>
    </Modal>
  );
};

export default ModalTask;
