import React from 'react';
import moment from 'moment';
import Input from '@iso/components/uielements/input';
import { DateRangepicker } from '@iso/components/uielements/datePicker';
import Modal from '@iso/components/Feedback/Modal';
import { CalendarModalBody } from './Calendar.styles';

import DeleteButton from './DeleteButton';
const RangePicker = DateRangepicker;

const localeDatePicker = {
  lang: {
    placeholder: 'Выбрать дату',
    rangePlaceholder: ['Дата начала', 'Дата окончания'],
    today: 'Сегодня',
    now: 'Сейчас',
    backToToday: 'Вернуться к сегодня',
    ok: 'OK',
    clear: 'Очистить',
    month: 'Месяц',
    year: 'Год',
    timeSelect: 'Выбрать время',
    dateSelect: 'Выбрать дату',
    monthSelect: 'Выбрать месяц',
    yearSelect: 'Выбрать год',
    decadeSelect: 'Выбрать декаду',
    yearFormat: 'YYYY',
    dateFormat: 'M/D/YYYY',
    dayFormat: 'D',
    dateTimeFormat: 'M/D/YYYY HH:mm:ss',
    monthFormat: 'MMMM',
    monthBeforeYear: true,
    previousMonth: 'Предыдущий месяц (PageUp)',
    nextMonth: 'Следующий месяц (PageDown)',
    previousYear: 'Прошлый год (Control + left)',
    nextYear: 'Следующий год (Control + right)',
    previousDecade: 'Прошлая декада',
    nextDecade: 'Следующая декада',
    previousCentury: 'Прошлый век',
    nextCentury: 'Следующий век',
  },
  timePickerLocale: {
    placeholder: 'Выбрать время',
  },
};
export default function({ modalVisible, selectedData, setModalData }) {
  const handleOk = () => {
    setModalData('ok', selectedData);
  };
  const handleCancel = () => {
    setModalData('cancel');
  };

  const handleDelete = () => {
    setModalData('delete', selectedData);
  };
  const visible = modalVisible ? true : false;
  if (!visible) return null;

  const title = selectedData && selectedData.title ? selectedData.title : '';
  const desc = selectedData && selectedData.desc ? selectedData.desc : '';
  const start =
    selectedData && selectedData.start ? moment(selectedData.start) : '';
  const end = selectedData && selectedData.end ? moment(selectedData.end) : '';
  const onChangeTitle = event => {
    selectedData.title = event.target.value;
    setModalData('updateValue', selectedData);
  };
  const onChangeDesc = event => {
    selectedData.desc = event.target.value;
    setModalData('updateValue', selectedData);
  };
  const onChangeFromTimePicker = value => {
    try {
      selectedData.start = value[0].toDate();
      selectedData.end = value[1].toDate();
    } catch (e) {}
    setModalData('updateValue', selectedData);
  };
  return (
    <div>
      <Modal
        title={modalVisible === 'update' ? 'Обновить' : 'Задать'}
        visible={visible}
        onOk={handleOk}
        onCancel={handleCancel}
        okText="ОК"
        cancelText="Отмена"
      >
        <CalendarModalBody>
          <div className="isoCalendarInputWrapper">
            <Input
              value={title}
              placeholder="Set Title"
              onChange={onChangeTitle}
            />
          </div>

          <div className="isoCalendarInputWrapper">
            <Input
              value={desc}
              placeholder="Set Description"
              onChange={onChangeDesc}
            />
          </div>

          <div className="isoCalendarDatePicker">
            <RangePicker
              locale={localeDatePicker}
              ranges={{
                Today: [moment(), moment()],
                'Этот месяц': [moment(), moment().endOf('month')],
              }}
              value={[start, end]}
              showTime
              format="YYYY/MM/DD HH:mm:ss"
              onChange={onChangeFromTimePicker}
            />
            <DeleteButton handleDelete={handleDelete} />
          </div>
        </CalendarModalBody>
      </Modal>
    </div>
  );
}
