import React, { lazy, Suspense } from "react";
import { Route, useRouteMatch, Switch } from "react-router-dom";
import { useSelector } from "react-redux";
import Loader from "@iso/components/utility/loader";

import _ from "lodash";

const NotAllowedComponent = lazy(() =>
  import("@iso/containers/Pages/NotAllowed")
);

const routes = [
  {
    path: "",
    component: lazy(() => import("@iso/containers/Widgets/Widgets")),
    exact: true,
  },
  {
    path: "inbox",
    component: lazy(() => import("@iso/containers/Mail/Mail")),
  },
  {
    path: "my-profile",
    component: lazy(() => import("@iso/containers/Profile/Profile")),
  },
  {
    path: "quiz/:quizid",
    component: lazy(() => import("@iso/containers/Quiz/SingleQuiz")),
  },
  // {
  //   path: 'quiz',
  //   component: lazy(() => import('@iso/containers/Quiz/Quiz')),
  // },
  {
    path: "swiperslider",
    component: lazy(() =>
      import("@iso/containers/UIElements/SwiperSlider/SwiperSlider")
    ),
  },
  {
    path: "scrum-board",
    component: lazy(() => import("@iso/containers/ScrumBoard")),
    exact: false,
  },
  {
    path: "mailbox",
    component: lazy(() => import("@iso/containers/Mail/Mail")),
  },
  {
    path: "calendar",
    component: lazy(() => import("@iso/containers/Calendar/Calendar")),
  },
  {
    path: "googlemap",
    component: lazy(() => import("@iso/containers/Map/GoogleMap/GoogleMap")),
  },
  {
    path: "leafletmap",
    component: lazy(() => import("@iso/containers/Map/Leaflet/Leaflet")),
  },
  {
    path: "table_ant",
    component: lazy(() => import("@iso/containers/Tables/AntTables/AntTables")),
  },
  {
    path: "allFormComponent",
    component: lazy(() => import("@iso/containers/Forms/Forms")),
  },
  {
    path: "InputField",
    component: lazy(() => import("@iso/containers/Forms/Input/Input")),
  },
  {
    path: "editor",
    component: lazy(() => import("@iso/containers/Forms/Editor/Editor")),
  },
  {
    path: "stepperForms",
    component: lazy(() =>
      import("@iso/containers/Forms/StepperForms/StepperForms")
    ),
  },
  {
    path: "FormsWithValidation",
    component: lazy(() =>
      import("@iso/containers/Forms/FormsWithValidation/FormsWithValidation")
    ),
  },
  {
    path: "progress",
    component: lazy(() => import("@iso/containers/Forms/Progress/Progress")),
  },
  {
    path: "button",
    component: lazy(() => import("@iso/containers/Forms/Button/Button")),
  },
  {
    path: "tab",
    component: lazy(() => import("@iso/containers/Forms/Tab/Tab")),
  },
  {
    path: "autocomplete",
    component: lazy(() =>
      import("@iso/containers/Forms/AutoComplete/AutoComplete")
    ),
  },
  {
    path: "checkbox",
    component: lazy(() => import("@iso/containers/Forms/Checkbox/Checkbox")),
  },
  {
    path: "radiobox",
    component: lazy(() => import("@iso/containers/Forms/Radiobox/Radiobox")),
  },
  {
    path: "selectbox",
    component: lazy(() => import("@iso/containers/Forms/Select/Select")),
  },
  {
    path: "transfer",
    component: lazy(() => import("@iso/containers/Forms/Transfer/Transfer")),
  },
  {
    path: "gridLayout",
    component: lazy(() => import("@iso/containers/Box/GridLayout")),
  },
  {
    path: "notes",
    component: lazy(() => import("@iso/containers/Note/Note")),
  },
  {
    path: "todo",
    component: lazy(() => import("@iso/containers/Todo/Todo")),
  },
  {
    path: "articles",
    component: lazy(() =>
      import("@iso/containers/FirestoreCRUD/Article/Article")
    ),
  },
  {
    path: "investors",
    component: lazy(() =>
      import("@iso/containers/FirestoreCRUD/Investor/Investor")
    ),
  },
  {
    path: "contacts",
    component: lazy(() => import("@iso/containers/Contacts/Contacts")),
  },
  {
    path: "alert",
    component: lazy(() => import("@iso/containers/Feedback/Alert/Alert")),
  },
  {
    path: "modal",
    component: lazy(() => import("@iso/containers/Feedback/Modal/Modal")),
  },
  {
    path: "message",
    component: lazy(() => import("@iso/containers/Feedback/Message/Message")),
  },
  {
    path: "notification",
    component: lazy(() =>
      import("@iso/containers/Feedback/Notification/Notification")
    ),
  },
  {
    path: "Popconfirm",
    component: lazy(() =>
      import("@iso/containers/Feedback/Popconfirm/Popconfirm")
    ),
  },
  {
    path: "spin",
    component: lazy(() => import("@iso/containers/Feedback/Spin/Spin")),
  },
  {
    path: "shuffle",
    component: lazy(() => import("@iso/containers/Shuffle/Shuffle")),
  },
  {
    path: "affix",
    component: lazy(() => import("@iso/containers/Navigation/Affix")),
  },
  {
    path: "breadcrumb",
    component: lazy(() =>
      import("@iso/containers/UIElements/Breadcrumb/Breadcrumb")
    ),
  },
  {
    path: "backToTop",
    component: lazy(() => import("@iso/containers/Navigation/BackToTop")),
  },
  {
    path: "dropdown",
    component: lazy(() =>
      import("@iso/containers/UIElements/Dropdown/Dropdown")
    ),
  },
  {
    path: "op_badge",
    component: lazy(() => import("@iso/containers/UIElements/Badge/Badge")),
  },
  {
    path: "op_card",
    component: lazy(() => import("@iso/containers/UIElements/Card/Card")),
  },
  {
    path: "op_carousel",
    component: lazy(() =>
      import("@iso/containers/UIElements/Carousel/Carousel")
    ),
  },
  {
    path: "op_collapse",
    component: lazy(() =>
      import("@iso/containers/UIElements/Collapse/Collapse")
    ),
  },
  {
    path: "op_tooltip",
    component: lazy(() => import("@iso/containers/UIElements/Tooltip/Tooltip")),
  },
  {
    path: "rating",
    component: lazy(() => import("@iso/containers/UIElements/Rating/Rating")),
  },
  {
    path: "tree",
    component: lazy(() => import("@iso/containers/UIElements/Tree/Tree")),
  },
  {
    path: "op_tag",
    component: lazy(() => import("@iso/containers/UIElements/Tag/Tag")),
  },
  {
    path: "op_timeline",
    component: lazy(() =>
      import("@iso/containers/UIElements/Timeline/Timeline")
    ),
  },
  {
    path: "pagination",
    component: lazy(() =>
      import("@iso/containers/UIElements/Pagination/Pagination")
    ),
  },
  {
    path: "op_popover",
    component: lazy(() => import("@iso/containers/UIElements/Popover/Popover")),
  },
  {
    path: "googleChart",
    component: lazy(() =>
      import("@iso/containers/Charts/GoogleChart/GoogleChart")
    ),
  },
  {
    path: "reecharts",
    component: lazy(() => import("@iso/containers/Charts/Recharts/Recharts")),
  },
  {
    path: "menu",
    component: lazy(() => import("@iso/containers/Navigation/NavigationMenu")),
  },
  {
    path: "ReactChart2",
    component: lazy(() =>
      import("@iso/containers/Charts/ReactChart2/ReactChart2")
    ),
  },
  {
    path: "card",
    component: lazy(() => import("@iso/containers/Ecommerce/Card/Card")),
  },
  {
    path: "cart",
    component: lazy(() => import("@iso/containers/Ecommerce/Cart/Cart")),
  },
  {
    path: "checkout",
    component: lazy(() =>
      import("@iso/containers/Ecommerce/Checkout/Checkout")
    ),
  },
  {
    path: "shop",
    component: lazy(() =>
      import("@iso/containers/Ecommerce/Algolia/InstantSearch")
    ),
  },
  {
    path: "reactDates",
    component: lazy(() =>
      import("@iso/containers/AdvancedUI/ReactDates/ReactDates")
    ),
  },
  {
    path: "codeMirror",
    component: lazy(() =>
      import("@iso/containers/AdvancedUI/CodeMirror/CodeMirror")
    ),
  },
  {
    path: "uppy",
    component: lazy(() => import("@iso/containers/AdvancedUI/Uppy/Uppy")),
  },
  {
    path: "dropzone",
    component: lazy(() =>
      import("@iso/containers/AdvancedUI/Dropzone/Dropzone")
    ),
  },
  {
    path: "youtubeSearch",
    component: lazy(() =>
      import("@iso/containers/YoutubeSearch/YoutubeSearch")
    ),
  },
  {
    path: "frappeChart",
    component: lazy(() =>
      import("@iso/containers/Charts/FrappeChart/FrappeChart")
    ),
  },
  {
    path: "invoice/:invoiceId",
    component: lazy(() => import("@iso/containers/Invoice/SingleInvoice")),
  },
  {
    path: "invoice",
    component: lazy(() => import("@iso/containers/Invoice/Invoices")),
  },
  {
    path: "chat/:workerId",
    component: lazy(() => import("@iso/containers/Chat/Chat")),
  },
  {
    path: "chat",
    component: lazy(() => import("@iso/containers/Chat/Chat")),
  },

  {
    path: "githubSearch",
    component: lazy(() => import("@iso/containers/GithubSearch/GithubSearch")),
  },
  {
    path: "blank_page",
    component: lazy(() => import("@iso/containers/BlankPage")),
  },
  {
    path: "audit/:id",
    component: lazy(() => import("@iso/containers/AuditHistory/AuditHistory")),
  },
  {
    path: "tasks",
    component: lazy(() => import("@iso/containers/Task/Task")),
  },
  {
    path: "trolleys",
    component: lazy(() => import("@iso/containers/Trolley/Trolley")),
  },
  {
    path: "empas",
    component: lazy(() => import("@iso/containers/Empas/Empas")),
  },
  {
    path: "chemical",
    component: lazy(() => import("@iso/containers/Chemical/Chemical")),
  },
  {
    path: "phenology",
    component: lazy(() => import("@iso/containers/Phenology/Phenology")),
  },
  {
    path: "plant-phenology",
    component: lazy(() =>
      import("@iso/containers/PlantPhenology/PlantPhenology")
    ),
  },
  {
    path: "plant-protection",
    component: lazy(() =>
      import("@iso/containers/PlantProtection/PlantProtection")
    ),
  },
  {
    path: "metrics",
    component: lazy(() => import("@iso/containers/Metric/Metric")),
  },
  {
    path: "task-metrics",
    component: lazy(() => import("@iso/containers/TaskMetric/TaskMetric")),
  },
  {
    path: "quality-control",
    component: lazy(() =>
      import("@iso/containers/QualityControl/QualityControl")
    ),
  },
  {
    path: "audit",
    component: lazy(() => import("@iso/containers/Audit/Audit")),
  },
  {
    path: "culture",
    component: lazy(() => import("@iso/containers/Culture/Culture")),
  },
  {
    path: "structure",
    component: lazy(() => import("@iso/containers/Structure/Structure")),
  },
  {
    path: "row-state",
    component: lazy(() => import("@iso/containers/RowState/RowState")),
  },
  {
    path: "properties",
    component: lazy(() => import("@iso/containers/Property/Property")),
  },
  {
    path: "settings",
    component: lazy(() => import("@iso/containers/Setting/Setting")),
  },
  {
    path: "greenhouses",
    component: lazy(() => import("@iso/containers/Greenhouse/Greenhouse")),
  },
  {
    path: "departments",
    component: lazy(() => import("@iso/containers/Department/Department")),
  },
  {
    path: "positions",
    component: lazy(() => import("@iso/containers/Position/Position")),
  },
  {
    path: "ratings",
    component: lazy(() => import("@iso/containers/Rating/Rating")),
  },
  {
    path: "sections",
    component: lazy(() => import("@iso/containers/Sections/Sections")),
  },
  {
    path: "flows",
    component: lazy(() => import("@iso/containers/Flow/Flow")),
  },
  {
    path: "plans/:id",
    component: lazy(() => import("@iso/containers/PlanHistory/PlanHistory")),
  },
  {
    path: "plans",
    component: lazy(() => import("@iso/containers/Plan/Plan")),
  },
  {
    path: "ordering",
    component: lazy(() => import("@iso/containers/Ordering/Ordering")),
  },
  {
    path: "reports",
    component: lazy(() => import("@iso/containers/BlankPage")),
  },
  {
    path: "workers",
    component: lazy(() => import("@iso/containers/Worker/Worker")),
  },
  {
    path: "users",
    component: lazy(() => import("@iso/containers/User/User")),
  },
  {
    path: "section",
    component: lazy(() => import("@iso/containers/Section/Section")),
  },
];

export default function AppRouter() {
  const { url } = useRouteMatch();

  const { allowedRoutes } = useSelector((state) =>
    _.get(state, "Auth.userPermissions", {})
  );

  return (
    <Suspense fallback={<Loader />}>
      <Switch>
        {routes.map((route, idx) => {
          return _.includes(allowedRoutes, route.path) ? (
            <Route exact={route.exact} key={idx} path={`${url}/${route.path}`}>
              <route.component {...route.props} />
            </Route>
          ) : (
            <Route exact={route.exact} key={idx} path={`${url}/${route.path}`}>
              <NotAllowedComponent />
            </Route>
          );
        })}
      </Switch>
    </Suspense>
  );
}
