import React from "react";
import { useDispatch, useSelector } from "react-redux";
import empasActions from "@iso/redux/empas/actions";
import workerActions from "@iso/redux/workers/actions";
import Button from "@iso/components/uielements/button";
import _ from "lodash";
import LayoutContentWrapper from "@iso/components/utility/layoutWrapper";
import Box from "@iso/components/utility/box";
import ContentHolder from "@iso/components/utility/contentHolder";
import Modal from "@iso/components/Feedback/Modal";
import { FilterDropdown } from "@iso/components/Tables/HelperCells";
import { Icon } from "antd";
import Form from "@iso/components/uielements/form";
import DatePicker from "@iso/components/uielements/datePicker";

import AutoComplete, {
  AutoCompleteOption,
} from "@iso/components/uielements/autocomplete";

import locale from "antd/lib/locale-provider/ru_RU";

import { ConfigProvider } from "antd";

import {
  Fieldset,
  Label,
  TitleWrapper,
  ComponentTitle,
  TableWrapper,
  StatusTag,
} from "./Empas.styles";

import moment from "moment-timezone";
import "moment/locale/ru";

moment.tz.setDefault("Europe/Moscow");
moment.locale("ru");

const FormItem = Form.Item;

const {
  loadFromAgroInvest,
  saveIntoAgroInvest,
  toggleModal,
  update,
  setFilters,
  toggleDisabled,
} = empasActions;

const { loadAutocomplete, setAutocomplete } = workerActions;

export default function Empas() {
  const {
    empases,
    isLoading,
    totalItems,
    modalActive,
    itemsPerPage,
    page,
    empas,
    filters,
    isDisabled,
  } = useSelector((state) => state.Empas);

  const { greenhouses } = useSelector((state) => state.App);

  const { autocomplete } = useSelector((state) => state.Workers);

  const dispatch = useDispatch();

  const [state, setState] = React.useState({
    searchEmpasNumber: "",
    filterEmpasNumberDropdownVisible: false,
    searchWorkerName: "",
    filterWorkerNameDropdownVisible: false,
    searchManagerName: "",
    filterManagerNameDropdownVisible: false,
  });

  const onInputChange = (key, value) => {
    setState({ ...state, [key]: value });
  };

  const onInputChangeThrottled = _.throttle(
    (key, value) => onInputChange(key, value),
    500,
    {
      leading: false,
    }
  );

  const onSearch = () => {
    let { searchEmpasNumber, searchWorkerName, searchManagerName } = state;

    const newFilters = _.cloneDeep(filters);
    newFilters.empasNumber = searchEmpasNumber;
    newFilters["worker.name"] = searchWorkerName;
    newFilters["manager.name"] = searchManagerName;
    dispatch(setFilters(newFilters, 1));
  };

  React.useEffect(() => {
    dispatch(loadFromAgroInvest());
    dispatch(loadAutocomplete());
  }, [dispatch]);

  const dataSource = [];
  Object.keys(empases).map((empas, index) => {
    return dataSource.push({
      ...empases[empas],
      key: empas,
    });
  });

  const handleRecord = (actionName, empas) => {
    dispatch(saveIntoAgroInvest(empas, actionName));
  };

  const callToggleDisabled = () => {
    dispatch(toggleDisabled());
  };

  const empasUpdate = (key, value) => {
    if (key) empas[key] = value;
    dispatch(update(empas));
  };

  const reload = () => {
    dispatch(loadFromAgroInvest());
  };

  const dropFilters = () => {
    dispatch(setFilters({}, 1));
  };

  const handleTableChange = (pagination, newFilters, sorter) => {
    newFilters.empas = filters.empas;
    newFilters["worker.name"] = filters["worker.name"];
    newFilters["manager.name"] = filters["manager.name"];
    dispatch(setFilters(newFilters, pagination.current));
  };

  const handleWorkerSearch = (value) => {
    dispatch(setAutocomplete(value));
  };

  const handleWorkerSelect = (value) => {
    empasUpdate("workerId", value ? value : null);
  };

  const handleDateSelect = (value) => {
    empas.registeredAt = value ? value.format() : null;

    dispatch(update(empas));
  };

  // const propertiesUpdate = (id, value) => {
  //   const p = _.find(empas.properties, { id });

  //   if(p) {
  //     p.value = value;

  //     dispatch(update(empas));
  //   }
  // }

  const handleWorkerSearchThrottled = _.throttle(handleWorkerSearch, 2000, {
    leading: false,
  });

  const displayWorkerSettings =
    _.get(filters, "type[0]") && _.get(filters, "type[0]") != "refill";

  const columns = [
    {
      title: "Эмпас",
      dataIndex: "empasNumber",
      key: "empasNumber",
      sorter: (a, b) => {
        if (a.empasNumber < b.empasNumber) return -1;
        if (a.empasNumber > b.empasNumber) return 1;
        return 0;
      },
      filterDropdown: (
        <FilterDropdown
          searchText=""
          onInputChange={({ target: { value } }) =>
            onInputChangeThrottled("searchEmpasNumber", value)
          }
          onSearch={onSearch}
        />
      ),
      filterIcon: (
        <Icon
          type="search"
          style={{ color: filters.empasNumber ? "#108ee9" : "#aaa" }}
        />
      ),
      filterDropdownVisible: state.filterEmpasNumberDropdownVisible,
      onFilterDropdownVisibleChange: (visible) => {
        setState({ ...state, filterEmpasNumberDropdownVisible: visible });
        document.getElementById("tableFilterInput").focus();
      },
      render: (text, row) => {
        return (
          <StatusTag key="empasNumber" className="empasNumber">
            {row.empasNumber}
          </StatusTag>
        );
      },
    },
    {
      title: "Теплица",
      dataIndex: "greenhouse",
      key: "greenhouseId",
      filters: _.map(greenhouses, (g) => {
        return {
          text: g.description,
          value: g.id,
        };
      }),
      filteredValue: filters["greenhouseId"] || [],
      filterMultiple: false,
      sorter: (a, b) => {
        const aGreenhouseName = _.get(
          _.find(greenhouses, (g) => g.id === a.greenhouseId),
          "description",
          null
        );
        const bGreenhouseName = _.get(
          _.find(greenhouses, (g) => g.id === b.greenhouseId),
          "description",
          null
        );

        if (aGreenhouseName < bGreenhouseName) return -1;
        if (aGreenhouseName > bGreenhouseName) return 1;
        return 0;
      },
      render: (text, row) => {
        return (
          <>
            {_.get(
              _.find(greenhouses, (g) => g.id === row.greenhouseId),
              "description",
              row.greenhouseId
            )}
          </>
        );
      },
    },
    // {
    //   title: "Мастер",
    //   dataIndex: "managerId",
    //   key: "managerId",
    //   filterDropdown: (
    //     <FilterDropdown
    //       searchText=""
    //       onInputChange={({ target: { value } }) =>
    //         onInputChangeThrottled("searchManagerName", value)
    //       }
    //       onSearch={onSearch}
    //     />
    //   ),
    //   filterIcon: (
    //     <Icon
    //       type="search"
    //       style={{ color: filters["manager.name"] ? "#108ee9" : "#aaa" }}
    //     />
    //   ),
    //   filterDropdownVisible: state.filterManagerNameDropdownVisible,
    //   onFilterDropdownVisibleChange: (visible) => {
    //     setState({ ...state, filterManagerNameDropdownVisible: visible });
    //     document.getElementById("tableFilterInput").focus();
    //   },
    //   sorter: (a, b) => {
    //     if (_.get(a, "manager.name", "") < _.get(b, "manager.name", ""))
    //       return -1;
    //     if (_.get(a, "manager.name", "") > _.get(b, "manager.name", ""))
    //       return 1;
    //     return 0;
    //   },
    //   render: (text, row) => {
    //     return _.get(row, "manager.name", "Н/Д");
    //   },
    // },
    {
      title: "Сотрудники",
      dataIndex: "empasesDetail",
      key: "workers",
      filterDropdown: displayWorkerSettings ? (
        <FilterDropdown
          searchText={_.get(filters, "worker.name", "")}
          onInputChange={({ target: { value } }) =>
            onInputChangeThrottled("searchWorkerName", value)
          }
          onSearch={onSearch}
        />
      ) : null,
      filterIcon: (
        <Icon
          type="search"
          style={{ color: filters["worker.name"] ? "#108ee9" : "#aaa" }}
        />
      ),
      filterDropdownVisible: state.filterWorkerNameDropdownVisible,
      onFilterDropdownVisibleChange: (visible) => {
        setState({ ...state, filterWorkerNameDropdownVisible: visible });
        document.getElementById("tableFilterInput").focus();
      },
      sorter: displayWorkerSettings
        ? (a, b) => {
            if (_.get(a, "worker.name", "") < _.get(b, "worker.name", ""))
              return -1;
            if (_.get(a, "worker.name", "") > _.get(b, "worker.name", ""))
              return 1;
            return 0;
          }
        : null,
      render: (data, row) => {
        return (
          <>
            {_.get(filters, "type[0]") === "refill" ||
            !_.get(filters, "type[0]", false) ? (
              _.map(_.get(data, "workers", []), (worker) => {
                return (
                  <div key={worker.id}>
                    <span>{`${worker.code}`}</span>
                    <br />
                    <span>{`${worker.name}`}</span>
                    <br />
                    <br />
                  </div>
                );
              })
            ) : (
              <>
                <span>{`${_.get(row, "worker.code", "n/a")}`}</span>
                <br />
                <span>{`${_.get(row, "worker.name", "")}`}</span>
              </>
            )}
          </>
        );
      },
    },
    {
      title: "Обработанные ряды",
      dataIndex: "empasesDetail",
      key: "rowsDetails",
      align: "center",
      render: (data, row) => {
        return data ? (
          <div>
            <span>{`Всего рядов: ${data.finishedTasksCount}`}</span>
            <br />
            <span>{`${
              data.finishedRows ? data.finishedRows.join(", ") : null
            }`}</span>
          </div>
        ) : null;
      },
    },
    {
      title: "Детали",
      dataIndex: "type",
      key: "type",
      filters: [
        {
          text: "Заправка",
          value: "refill",
        },
        {
          text: "Привязка",
          value: "start",
        },
        {
          text: "Отвязка",
          value: "finish",
        },
      ],
      filteredValue: filters["type"] || [],
      filterMultiple: false,
      sorter: (a, b) => {
        if (_.get(a, "type", "") < _.get(b, "type", "")) return -1;
        if (_.get(a, "type", "") > _.get(b, "type", "")) return 1;
        return 0;
      },
      render: (text, row) => {
        return (
          <>
            <StatusTag key="empasType" className="empasNumber">
              {(row.type === "refill" && "Заправка") ||
                (row.type === "start" && "Привязка") ||
                (row.type === "finish" && "Отвязка") ||
                "НЕИЗВЕСТНО"}
            </StatusTag>
            <br />
            Название: <b>{_.get(row, "chemical.name", "Н/Д")}</b>
            <br />
            Концентрация: <b>{_.get(row, "sprayConcentration", "Н/Д")}</b>
            <br />
            Давление: <b>{_.get(row, "sprayPressure", "Н/Д")}</b>
            <br />
            Скорость робота: <b>{_.get(row, "robotSpeed", "Н/Д")}</b>
            <br />
            Объем: <b>{_.get(row, "sprayVolume", "Н/Д")}</b>
          </>
        );
      },
    },
    {
      title: "Зарегистрировано",
      dataIndex: "registeredAt",
      className: "noWrapCell",
      key: "registeredAt",
      filters: [
        {
          text: "Вчера",
          value: JSON.stringify({
            before: moment().utc().subtract(1, "days").endOf("day").format(),
            after: moment().utc().subtract(1, "days").startOf("day").format(),
          }),
        },
        {
          text: "Сегодня",
          value: JSON.stringify({
            before: moment().utc().endOf("day").format(),
            after: moment().utc().startOf("day").format(),
          }),
        },
        {
          text: "Завтра",
          value: JSON.stringify({
            before: moment().utc().add(1, "days").endOf("day").format(),
            after: moment().utc().add(1, "days").startOf("day").format(),
          }),
        },
        {
          text: "Эта неделя",
          value: JSON.stringify({
            before: moment().utc().endOf("week").format(),
            after: moment().utc().startOf("week").format(),
          }),
        },
        {
          text: "Прошлая неделя",
          value: JSON.stringify({
            before: moment().utc().subtract(1, "weeks").endOf("week").format(),
            after: moment().utc().subtract(1, "weeks").startOf("week").format(),
          }),
        },
      ],
      filteredValue: filters["registeredAt"] || [],
      filterMultiple: false,
      sorter: (a, b) => {
        if (moment(a.registeredAt) < moment(b.registeredAt)) return -1;
        if (moment(a.registeredAt) > moment(b.registeredAt)) return 1;
        return 0;
      },

      render: (text, row) => {
        return row.registeredAt
          ? moment(row.registeredAt).format("LLL")
          : "N/A";
      },
    },
  ];

  return (
    <LayoutContentWrapper>
      <Box>
        <ContentHolder style={{ marginTop: 0, overflow: "hidden" }}>
          <TitleWrapper>
            <ComponentTitle>
              Эмпасы <small>всего найдено: {totalItems}</small>
            </ComponentTitle>
            <div>
              <Button
                type="primary"
                shape="circle"
                loading={isLoading}
                icon="filter"
                onClick={dropFilters}
                style={{ marginLeft: "10px" }}
              />
              <Button
                type="primary"
                shape="circle"
                loading={isLoading}
                icon="reload"
                onClick={reload}
                style={{ marginLeft: "10px" }}
              />
            </div>
          </TitleWrapper>

          <Modal
            visible={modalActive}
            onClose={() => dispatch(toggleModal(null))}
            title={
              <>
                <span onDoubleClick={callToggleDisabled}>
                  {"Изменить эмпас " + empas.empasNumber}
                </span>
                <br />
                <small>{empas.id}</small>
              </>
            }
            okText={"Сохранить"}
            onOk={() => handleRecord("update", empas)}
            onCancel={() => dispatch(toggleModal(null))}
            okButtonProps={{ disabled: isDisabled }}
            cancelButtonProps={{ disabled: isDisabled }}
          >
            <Form>
              <Fieldset>
                <Label>Основные параметры</Label>

                <FormItem label="Сотрудник" hasFeedback>
                  <AutoComplete
                    onSearch={handleWorkerSearchThrottled}
                    onSelect={handleWorkerSelect}
                    placeholder="Input here"
                    defaultValue={empas.workerName}
                    disabled={isDisabled}
                  >
                    <AutoCompleteOption value="" key={0}>
                      [не назначено]
                    </AutoCompleteOption>
                    {autocomplete.map((w) => {
                      return (
                        <AutoCompleteOption value={w.id} key={w.id}>
                          {w.name}
                        </AutoCompleteOption>
                      );
                    })}
                  </AutoComplete>
                </FormItem>

                <FormItem label="Дата и время" hasFeedback>
                  <ConfigProvider locale={locale}>
                    <DatePicker
                      locale={locale}
                      value={
                        empas.registeredAt ? moment(empas.registeredAt) : null
                      }
                      showTime
                      format="YYYY/MM/DD HH:mm:ss"
                      onChange={handleDateSelect}
                      disabled={isDisabled}
                      allowClear={false}
                    />
                  </ConfigProvider>
                </FormItem>
              </Fieldset>
            </Form>
          </Modal>

          <TableWrapper
            rowKey="key"
            columns={columns}
            bordered={true}
            dataSource={dataSource}
            loading={isLoading}
            className="isoSimpleTable"
            onChange={handleTableChange}
            pagination={{
              defaultPageSize: itemsPerPage,
              hideOnSinglePage: true,
              total: totalItems,
              current: page,
              showTotal: (total, range) => {
                return `Показано ${range[0]}-${range[1]} из ${totalItems} записей`;
              },
            }}
          />
        </ContentHolder>
      </Box>
    </LayoutContentWrapper>
  );
}
