import React from "react";
import { useDispatch, useSelector } from "react-redux";
import flowActions from "@iso/redux/flow/actions";
import Button from "@iso/components/uielements/button";
import _ from "lodash";
import LayoutContentWrapper from "@iso/components/utility/layoutWrapper";
import Box from "@iso/components/utility/box";
import ContentHolder from "@iso/components/utility/contentHolder";
import Modal from "@iso/components/Feedback/Modal";
import { FilterDropdown } from "@iso/components/Tables/HelperCells";
import { Icon } from "antd";
import Form from "@iso/components/uielements/form";
import Input from "@iso/components/uielements/input";

import {
  Fieldset,
  Label,
  TitleWrapper,
  ComponentTitle,
  TableWrapper,
  ActionWrapper,
} from "./Flow.styles";

import moment from "moment-timezone";
import "moment/locale/ru";

moment.tz.setDefault("Europe/Moscow");
moment.locale("ru");

const FormItem = Form.Item;

const {
  loadFromAgroInvest,
  saveIntoAgroInvest,
  toggleModal,
  update,
  setFilters,
} = flowActions;

export default function Flow() {
  const {
    flows,
    isLoading,
    totalItems,
    modalActive,
    itemsPerPage,
    page,
    flow,
    filters,
  } = useSelector((state) => state.Flow);

  const {
    blocksPermissions: { flows: flowsPermissions },
  } = useSelector((state) => _.get(state, "Auth.userPermissions"));

  const { edit: hasAccessToEdit } = flowsPermissions;

  const dispatch = useDispatch();

  const [state, setState] = React.useState({
    searchFlowName: "",
    filterFlowNameDropdownVisible: false,
  });

  const onInputChange = (key, value) => {
    setState({ ...state, [key]: value });
  };

  const onInputChangeThrottled = _.throttle(
    (key, value) => onInputChange(key, value),
    500,
    {
      leading: false,
    }
  );

  const onSearch = () => {
    let { searchFlowName } = state;

    const newFilters = _.cloneDeep(filters);
    newFilters.name = searchFlowName;

    dispatch(setFilters(newFilters, 1));
  };

  React.useEffect(() => {
    dispatch(loadFromAgroInvest());
  }, [dispatch]);

  const dataSource = [];
  Object.keys(flows).map((flow, index) => {
    return dataSource.push({
      ...flows[flow],
      key: flow,
    });
  });

  const handleRecord = (actionName, flow) => {
    dispatch(saveIntoAgroInvest(flow, actionName));
  };

  const handleModal = (flow = null) => {
    dispatch(toggleModal(flow));
  };

  const flowUpdate = (key, value) => {
    if (key) flow[key] = value;
    dispatch(update(flow));
  };

  const reload = () => {
    dispatch(loadFromAgroInvest());
  };

  const dropFilters = () => {
    dispatch(setFilters({}, 1));
  };

  const handleTableChange = (pagination, newFilters, sorter) => {
    newFilters.name = filters.name;

    dispatch(setFilters(newFilters, pagination.current));
  };

  const columns = [
    {
      title: "Название",
      dataIndex: "name",
      key: "name",
      sorter: (a, b) => {
        if (a.name < b.name) return -1;
        if (a.name > b.name) return 1;
        return 0;
      },
      filterDropdown: (
        <FilterDropdown
          searchText=""
          onInputChange={({ target: { value } }) =>
            onInputChangeThrottled("searchFlowName", value)
          }
          onSearch={onSearch}
        />
      ),
      filterIcon: (
        <Icon
          type="search"
          style={{ color: filters.name ? "#108ee9" : "#aaa" }}
        />
      ),
      filterDropdownVisible: state.filterFlowNameDropdownVisible,
      onFilterDropdownVisibleChange: (visible) => {
        setState({ ...state, filterFlowNameDropdownVisible: visible });
        document.getElementById("tableFilterInput").focus();
      },
      render: (text, row) => {
        return row.name;
      },
    },
    {
      title: "Описание",
      dataIndex: "description",
      key: "description",
      sorter: (a, b) => {
        if (a.description < b.description) return -1;
        if (a.description > b.description) return 1;
        return 0;
      },
      render: (text, row) => {
        return row.description;
      },
    },
    {
      title: "Теплица",
      dataIndex: "rawGreenHouseId",
      key: "rawGreenHouseId",
      sorter: (a, b) => {
        if (a.rawGreenHouseId < b.rawGreenHouseId) return -1;
        if (a.rawGreenHouseId > b.rawGreenHouseId) return 1;
        return 0;
      },
      render: (text, row) => {
        return _.get(row, "greenhouse.description", "n/a");
      },
    },
    {
      title: "Посевная",
      dataIndex: "ПосевнаяПлощадь_Key",
      key: "ПосевнаяПлощадь_Key",
      sorter: (a, b) => {
        if (a.ПосевнаяПлощадь_Key < b.ПосевнаяПлощадь_Key) return -1;
        if (a.ПосевнаяПлощадь_Key > b.ПосевнаяПлощадь_Key) return 1;
        return 0;
      },
      render: (text, row) => {
        return _.get(row, "structure.description", "n/a");
      },
    },
    {
      title: "Свойства",
      dataIndex: "props",
      key: "props",
      sorter: (a, b) => {
        if (a.props < b.props) return -1;
        if (a.props > b.props) return 1;
        return 0;
      },
      render: (text, row) => {
        return (
          <ul style={{ padding: 0 }}>
            <li>
              Цена:{" "}
              <b>
                {_.get(
                  row,
                  "raw.Товары[" + (_.size(row.raw.Товары) - 1) + "].Цена",
                  "n/a"
                )}
              </b>
            </li>
            <li>
              Объем:{" "}
              <b>
                {_.get(
                  row,
                  "raw.Товары[" + (_.size(row.raw.Товары) - 1) + "].Объем",
                  "n/a"
                )}
              </b>
            </li>
            <li>
              Стоимость:{" "}
              <b>
                {_.get(
                  row,
                  "raw.Товары[" + (_.size(row.raw.Товары) - 1) + "].Стоимость",
                  "n/a"
                )}
              </b>
            </li>
            <li>
              Дата Начала:{" "}
              <b>
                {moment(
                  _.get(
                    row,
                    "raw.Товары[" +
                      (_.size(row.raw.Товары) - 1) +
                      "].ДатаНачала",
                    "n/a"
                  )
                ).calendar()}
              </b>
            </li>
            <li>
              Дата Окончания:{" "}
              <b>
                {moment(
                  _.get(
                    row,
                    "raw.Товары[" +
                      (_.size(row.raw.Товары) - 1) +
                      "].ДатаОкончания",
                    "n/a"
                  )
                ).calendar()}
              </b>
            </li>
            <li>
              Проходов В Неделю:{" "}
              <b>
                {_.get(
                  row,
                  "raw.Товары[" +
                    (_.size(row.raw.Товары) - 1) +
                    "].ПроходовВНеделю",
                  "n/a"
                )}
              </b>
            </li>
            <li>
              Количество Недель:{" "}
              <b>
                {_.get(
                  row,
                  "raw.Товары[" +
                    (_.size(row.raw.Товары) - 1) +
                    "].КоличествоНедель",
                  "n/a"
                )}
              </b>
            </li>
          </ul>
        );
      },
    },
    {
      title: "Изменить",
      key: "action",
      width: "60px",
      className: "noWrapCell",
      render: (text, row) => {
        return (
          <ActionWrapper>
            {hasAccessToEdit ? (
              <a onClick={() => handleModal(row)} href="# ">
                <i className="ion-android-create" />
              </a>
            ) : (
              <a disabled href="# ">
                <i className="ion-android-create" style={{ color: "#aaa" }} />
              </a>
            )}
          </ActionWrapper>
        );
      },
    },
  ];

  return (
    <LayoutContentWrapper>
      <Box>
        <ContentHolder style={{ marginTop: 0, overflow: "hidden" }}>
          <TitleWrapper>
            <ComponentTitle>
              Технологические карты <small>всего: {totalItems}</small>
            </ComponentTitle>
            <div>
              <Button
                type="primary"
                shape="circle"
                disabled={!hasAccessToEdit}
                loading={isLoading}
                icon="plus"
                onClick={() => dispatch(toggleModal(null))}
                style={{ marginLeft: "10px" }}
              />
              <Button
                type="primary"
                shape="circle"
                loading={isLoading}
                icon="filter"
                onClick={dropFilters}
                style={{ marginLeft: "10px" }}
              />
              <Button
                type="primary"
                shape="circle"
                loading={isLoading}
                icon="reload"
                onClick={reload}
                style={{ marginLeft: "10px" }}
              />
            </div>
          </TitleWrapper>

          <Modal
            visible={modalActive}
            onClose={() => dispatch(toggleModal(null))}
            title={
              <>
                {flow.id ? "Изменить параметр " + flow.name : "Добавить"}
                <br />
                <small>{flow.id ? flow.id : "n/a"}</small>
              </>
            }
            okText={"Сохранить"}
            onOk={() => handleRecord("update", flow)}
            onCancel={() => dispatch(toggleModal(null))}
            okButtonProps={{ disabled: !hasAccessToEdit }}
            cancelButtonProps={{ disabled: false }}
          >
            <Form>
              <Fieldset>
                <Label>Основные свойства</Label>
                <FormItem label="Название" hasFeedback>
                  <Input
                    placeholder="Имя объекта"
                    value={flow.name}
                    onChange={({ target: { value } }) =>
                      flowUpdate("name", value)
                    }
                  />
                </FormItem>
              </Fieldset>
            </Form>
          </Modal>

          <TableWrapper
            rowKey="key"
            columns={columns}
            bordered={true}
            dataSource={dataSource}
            loading={isLoading}
            className="isoSimpleTable"
            onChange={handleTableChange}
            pagination={{
              defaultPageSize: itemsPerPage,
              hideOnSinglePage: true,
              total: totalItems,
              current: page,
              showTotal: (total, range) => {
                return `Показано ${range[0]}-${range[1]} из ${totalItems} записей`;
              },
            }}
          />
        </ContentHolder>
      </Box>
    </LayoutContentWrapper>
  );
}
