import React, { useState, useEffect, useMemo } from "react";
import { useDispatch, useSelector } from "react-redux";
import greenhouseActions from "@iso/redux/greenhouse/actions";
import Button from "@iso/components/uielements/button";
import _ from "lodash";
import LayoutContentWrapper from "@iso/components/utility/layoutWrapper";
import Box from "@iso/components/utility/box";
import ContentHolder from "@iso/components/utility/contentHolder";
import Modal from "@iso/components/Feedback/Modal";
import { FilterDropdown } from "@iso/components/Tables/HelperCells";
import { Icon } from "antd";
import Form from "@iso/components/uielements/form";
import Input from "@iso/components/uielements/input";
import Select, { SelectOption } from "@iso/components/uielements/select";

import { Col, Row } from "antd";

import {
  Fieldset,
  Label,
  TitleWrapper,
  ComponentTitle,
  TableWrapper,
  ActionWrapper,
  StatusTag,
} from "./Greenhouse.styles";

import { List, Divider } from "antd";

import moment from "moment-timezone";
import "moment/locale/ru";

moment.tz.setDefault("Europe/Moscow");
moment.locale("ru");

const Option = SelectOption;

const FormItem = Form.Item;

const {
  loadFromAgroInvest,
  saveIntoAgroInvest,
  toggleModal,
  update,
  setFilters,
  getSection,
  createGreenhouseSection,
  deleteGreenhouseSection,
  // removeGreengouseSection,
  addParent,
  // addSection,
  // saveSection,
  changeTime,
} = greenhouseActions;

export default function Greenhouse() {
  const {
    greenhouses,
    isLoading,
    totalItems,
    modalActive,
    itemsPerPage,
    page,
    greenhouse,
    filters,
    sections,
    // newSectionName
  } = useSelector((state) => state.Greenhouse);

  const { allowedGreenhouses } = useSelector((state) => state.App);

  const {
    blocksPermissions: { greenhouses: greenhousesPermissions },
  } = useSelector((state) => _.get(state, "Auth.userPermissions"));

  const { edit: hasAccessToEdit } = greenhousesPermissions;

  const dispatch = useDispatch();

  const [deletedGreenhouseSections, setDeletedGreenhouseSections] = useState(
    []
  );
  const [filterParent, setFilterParent] = useState(null);
  const [valueSelect, setValueSelect] = useState([]);
  const [greenhouseSections, setGreenhouseSections] = useState([]);
  const [addSections, setAddSections] = useState([]);
  const [sectionData, setSectionData] = useState([]);
  const [timeName, setTimeName] = useState(null);
  const [changeTimeData, setChangeTimeData] = useState([]);
  const [state, setState] = useState({
    searchGreenhouseName: "",
    filterGreenhouseNameDropdownVisible: false,
  });

  const sectionsName = useMemo(
    () =>
      _.size(greenhouseSections) > 0 ? _.map(greenhouseSections, "name") : null,
    [greenhouseSections]
  );

  useEffect(() => {
    if (greenhouseSections) {
      for (let i = 0; i < sections.length; i++) {
        for (let j = 0; j < greenhouseSections.length; j++) {
          if (sections[i].name === greenhouseSections[j].name) {
            break;
          }
          setSectionData((prev) => {
            const newArray = _.filter(
              prev,
              (item) => item.name !== greenhouseSections[j].name
            );
            return [...newArray];
          });
        }
      }
    }
  }, [sections, greenhouseSections]);

  useEffect(() => {
    return () => {
      setValueSelect(null);
    };
  }, [sectionsName]);

  useEffect(() => {
    if (valueSelect) {
      const newSectionData = _.filter(
        sectionData,
        (item) => !_.includes(valueSelect, item.name)
      );

      if (_.size(newSectionData) !== _.size(sectionData)) {
        setSectionData(newSectionData);
      }
    }
  }, [valueSelect, sectionData]);

  useEffect(() => {
    setGreenhouseSections(greenhouse.greenhouseSections);
    setSectionData(sections);

    return () => {
      setGreenhouseSections([]);
      setAddSections([]);
      setSectionData([]);
      setChangeTimeData([]);
      setTimeName(null);
    };
  }, [greenhouse, sections]);

  const onInputChange = (key, value) => {
    setState({ ...state, [key]: value });
  };

  const onInputChangeThrottled = _.throttle(
    (key, value) => onInputChange(key, value),
    500,
    {
      leading: false,
    }
  );

  const onSearch = () => {
    let { searchGreenhouseName } = state;

    setState({
      ...state,
      filterGreenhouseNameDropdownVisible: false,
    });

    const newFilters = _.cloneDeep(filters);
    newFilters.name = searchGreenhouseName;

    dispatch(setFilters(newFilters, 1));
  };

  React.useEffect(() => {
    dispatch(getSection());
    dispatch(loadFromAgroInvest());
  }, [dispatch]);

  React.useEffect(() => {
    dispatch(loadFromAgroInvest());
  }, [dispatch, filterParent]);

  const dataSource = [];
  Object.keys(greenhouses).map((greenhouse, index) => {
    return dataSource.push({
      ...greenhouses[greenhouse],
      key: greenhouse,
    });
  });

  const handleRecord = (actionName, greenhouse) => {
    dispatch(saveIntoAgroInvest(greenhouse, actionName));
  };

  const handleModal = (greenhouse = null) => {
    dispatch(toggleModal(greenhouse));
  };

  const greenhouseUpdate = (key, value) => {
    if (key) greenhouse[key] = value;
    dispatch(update(greenhouse));
  };

  const reload = () => {
    dispatch(loadFromAgroInvest());
  };

  const dropFilters = () => {
    dispatch(setFilters({}, 1));
  };

  const onChangeAddTime = (sectionName, value) => {
    const result = _.filter(addSections, (item) => item.name === sectionName);
    result[0].minLeadTime = value;

    setAddSections((prev) => {
      const filter = _.filter(prev, (item) => item.name !== sectionName);

      return [...filter, ...result];
    });
  };

  const onChangeTime = (sectionName, value) => {
    const result = _.filter(
      greenhouseSections,
      (item) => item.name === sectionName
    );
    result[0].minLeadTime = value;

    setChangeTimeData((prev) => {
      const filter = _.filter(prev, (item) => item.name !== sectionName);

      return [...filter, ...result];
    });
  };

  const handleTableChange = (pagination, newFilters, sorter) => {
    newFilters.name = filters.name;

    if (_.size(newFilters.parent)) {
      if (newFilters.parent[0] === "С корневой теплицей") {
        dispatch(addParent({ value: true }));
        setFilterParent(true);
      } else if (newFilters.parent[0] === "Без корневой теплицы") {
        dispatch(addParent({ value: false }));
        setFilterParent(false);
      } else if (_.size(newFilters.parent[0]) === 0) {
        dispatch(addParent({ value: null }));
        setFilterParent(null);
      }
    }
    dispatch(setFilters(newFilters, pagination.current));
  };

  const onChangeSelect = (value) => {
    if (_.size(value)) {
      setValueSelect((prev) => {
        const filterOne = _.filter(prev, (item) => item === value);
        if (_.size(filterOne)) {
          const filter = _.filter(prev, (item) => item !== value);
          return [...filter];
        }
        if (!prev) {
          return [value];
        }
        return [...prev, value];
      });

      const prevAddSections = _.filter(
        addSections,
        (item) => item.name !== value
      );
      const sectionItem = _.filter(sectionData, (item) => item.name === value);

      const prevNewSection = [...prevAddSections, ...sectionItem];

      const currentAddSections = [];
      for (let i = 0; i < prevNewSection.length; i++) {
        let result = null;
        for (let j = 0; j < greenhouseSections.length; j++) {
          if (
            _.size(greenhouseSections) &&
            prevNewSection[i].name === greenhouseSections[j].name
          ) {
            result = null;
            break;
          }
          result = prevNewSection[i];
        }
        if (result) {
          currentAddSections.push(result);
        }
      }
      if (_.size(currentAddSections)) {
        setAddSections(currentAddSections);
      }
      if (!_.size(greenhouseSections)) {
        setAddSections((prev) => {
          const filter = _.filter(prev, (item) => item.name !== value);

          return [...filter, ...sectionItem];
        });
      }
    }
  };

  const onSubmit = () => {
    if (_.size(addSections)) {
      dispatch(
        createGreenhouseSection({
          selected: addSections,
          greenhouse: greenhouse.id,
        })
      );
    }

    if (_.size(deletedGreenhouseSections)) {
      dispatch(deleteGreenhouseSection(deletedGreenhouseSections));
      setDeletedGreenhouseSections([]);
    }

    if (_.size(changeTimeData)) {
      dispatch(changeTime(changeTimeData));
    }
  };

  const onCancel = () => {
    dispatch(toggleModal(null));

    setDeletedGreenhouseSections([]);
  };

  const onDeleteAddSections = (value) => {
    const newSections = _.filter(addSections, (item) => item.name !== value);
    setValueSelect((prev) => {
      const newArray = _.filter(prev, (item) => item !== value);

      return [...newArray];
    });
    const item = _.filter(sections, (s) => s.name === value);
    setSectionData((prev) => [...prev, ...item]);
    setAddSections(newSections);
  };

  const onDeleteGreenhouseSections = (value) => {
    const newSections = _.filter(
      greenhouseSections,
      (item) => item.name !== value
    );
    const newDeleted = _.filter(
      deletedGreenhouseSections,
      (item) => item.name !== value
    );
    const newItemDeleted = _.filter(
      greenhouseSections,
      (item) => item.name === value
    );

    setDeletedGreenhouseSections([...newDeleted, ...newItemDeleted]);
    setGreenhouseSections(newSections);
  };

  const generateActionButtons = (row) => {
    const allowedGreenhouseIds = _.map(allowedGreenhouses, (g) => g.id);
    const isAttachedUser = _.includes(allowedGreenhouseIds, row.id);

    const style = isAttachedUser
      ? {}
      : {
          opacity: "0.3",
        };

    return (
      <ActionWrapper>
        <button
          onClick={() => handleModal(row)}
          disabled={!isAttachedUser || !hasAccessToEdit}
        >
          <i className="ion-android-create" style={{ ...style }} />
        </button>
      </ActionWrapper>
    );
  };

  const columns = [
    {
      title: "КОД",
      dataIndex: "name",
      key: "name",
      sorter: (a, b) => {
        if (a.name < b.name) return -1;
        if (a.name > b.name) return 1;
        return 0;
      },
      filterDropdown: (
        <FilterDropdown
          searchText=""
          onInputChange={({ target: { value } }) =>
            onInputChangeThrottled("searchGreenhouseName", value)
          }
          onSearch={onSearch}
        />
      ),
      filterIcon: (
        <Icon
          type="search"
          style={{ color: filters.name ? "#108ee9" : "#aaa" }}
        />
      ),
      filterDropdownVisible: state.filterGreenhouseNameDropdownVisible,
      onFilterDropdownVisibleChange: (visible) => {
        setState({ ...state, filterGreenhouseNameDropdownVisible: visible });
        document.getElementById("tableFilterInput").focus();
      },
      render: (text, row) => {
        return row.name;
      },
    },
    {
      title: "Название",
      dataIndex: "description",
      key: "description",
      sorter: (a, b) => {
        if (a.description < b.description) return -1;
        if (a.description > b.description) return 1;
        return 0;
      },
      render: (text, row) => {
        const greenhouseLength = _.get(row, "length", "");

        return (
          <>
            <div>{row.description}</div>
            <br />
            <small>
              длина: {greenhouseLength ? `${greenhouseLength} м.` : "n/a"}
            </small>
          </>
        );
      },
    },
    {
      title: "Структура",
      dataIndex: "parentId",
      key: "parentId",
      sorter: (a, b) => {
        if (a.parentId < b.parentId) return -1;
        if (a.parentId > b.parentId) return 1;
        return 0;
      },
      render: (text, row) => {
        return _.get(row, "parentId.description", "n/a");
      },
    },
    {
      title: "Вид работы",
      dataIndex: "sectionId",
      key: "sectionId",
      sorter: (a, b) => {
        if (a.sectionId < b.sectionId) return -1;
        if (a.sectionId > b.sectionId) return 1;
        return 0;
      },
      render: (text, row) => {
        const greenhouseSections = _.get(row, "greenhouseSections", null);
        const isgreenhouseSections = _.size(greenhouseSections) > 0;

        return isgreenhouseSections
          ? _.map(greenhouseSections, (item, keyIndex) => (
              <div key={keyIndex}>
                <span>{item.name},&nbsp;</span>
                <br />
              </div>
            ))
          : "n/a";
      },
    },
    {
      title: "Корневая теплица",
      dataIndex: "parent",
      className: "noWrapCell",
      filters: [
        {
          text: "С корневой теплицей",
          value: "С корневой теплицей",
        },
        {
          text: "Без корневой теплицы",
          value: "Без корневой теплицы",
        },
      ],
      filterMultiple: false,
      render: (text, row) => {
        let className;
        if (filterParent) {
          className = "finished";
        } else {
          className = "notFinished";
        }
        return (
          <StatusTag className={className}>
            {filterParent ? "Yes" : "No"}
          </StatusTag>
        );
      },
    },
    {
      title: "Actions",
      key: "action",
      width: "60px",
      className: "noWrapCell",
      render: (text, row) => generateActionButtons(row),
    },
  ];

  const rowStyle = {
    width: "100%",
    display: "flex",
    flexFlow: "row wrap",
  };
  const colStyle = {
    marginBottom: "16px",
  };
  const gutter = 16;

  const renderOptionItems = React.useMemo(
    () =>
      _.map(_.sortBy(sectionData, ["name"]), (item) => (
        <Option key={item["@id"]} value={item.name}>
          {item.name}
        </Option>
      )),
    [sectionData]
  );

  return (
    <LayoutContentWrapper>
      <Box>
        <ContentHolder style={{ marginTop: 0, overflow: "hidden" }}>
          <TitleWrapper>
            <ComponentTitle>
              Теплицы <small>всего: {totalItems}</small>
            </ComponentTitle>
            <div>
              <Button
                type="primary"
                shape="circle"
                loading={isLoading}
                icon="filter"
                onClick={dropFilters}
                style={{ marginLeft: "10px" }}
              />
              <Button
                type="primary"
                shape="circle"
                loading={isLoading}
                icon="reload"
                onClick={reload}
                style={{ marginLeft: "10px" }}
              />
            </div>
          </TitleWrapper>

          <Modal
            visible={modalActive}
            onClose={() => dispatch(toggleModal(null))}
            title={
              <>
                {greenhouse.id
                  ? "Изменить параметр " + greenhouse.name
                  : "Добавить"}
                <br />
                <small>{greenhouse.id ? greenhouse.id : "n/a"}</small>
              </>
            }
            okText={"Сохранить"}
            onOk={() => {
              if (!hasAccessToEdit) return;
              handleRecord("update", greenhouse);
              onSubmit();
            }}
            onCancel={onCancel}
            okButtonProps={{ disabled: !hasAccessToEdit }}
            cancelButtonProps={{ disabled: false }}
          >
            <Form>
              <Fieldset>
                <Label>Основные свойства</Label>
                <FormItem label="Имя теплицы" hasFeedback>
                  <Input
                    placeholder="Имя теплицы"
                    value={greenhouse.description}
                    onChange={({ target: { value } }) =>
                      greenhouseUpdate("description", value)
                    }
                  />
                </FormItem>
                <FormItem label="Длина теплицы в метрах" hasFeedback>
                  <Input
                    placeholder="Длина теплицы"
                    value={greenhouse.length}
                    onChange={({ target: { value } }) =>
                      greenhouseUpdate("length", value)
                    }
                  />
                </FormItem>
                <FormItem label="Название" hasFeedback>
                  <Input
                    placeholder="Имя объекта"
                    value={greenhouse.name}
                    onChange={({ target: { value } }) =>
                      greenhouseUpdate("name", value)
                    }
                  />
                </FormItem>
                <Row style={rowStyle} gutter={gutter} justify="start">
                  <Col md={24} sm={24} xs={24} style={colStyle}>
                    <Box title="Виды работ в теплице">
                      <Select
                        style={{ width: "100%" }}
                        placeholder="Please select"
                        value={valueSelect ? valueSelect : "Выберите из списка"}
                        onChange={(value) => onChangeSelect(value)}
                      >
                        {renderOptionItems}
                      </Select>
                      <ContentHolder>
                        <Divider orientation="left">Текущие работы</Divider>

                        {sectionsName && (
                          <List
                            size="small"
                            bordered
                            dataSource={sectionsName}
                            renderItem={(item, key) => {
                              const section = _.filter(
                                greenhouseSections,
                                (g) => g.name === item
                              );
                              const minLeadTime = _.get(
                                section[0],
                                "minLeadTime",
                                null
                              );
                              const isTime = timeName === item;
                              return (
                                <List.Item onClick={() => setTimeName(item)}>
                                  <div>
                                    <div style={{ width: "86%" }}>{item}</div>
                                    <div style={{ display: "grid" }}>
                                      <small>
                                        Время выполнения:&nbsp;
                                        {minLeadTime ? minLeadTime : 1}
                                      </small>
                                      {isTime && (
                                        <Input
                                          style={{
                                            width: "200px",
                                            height: "40px",
                                          }}
                                          placeholder="Укажите время выполнения"
                                          onChange={({ target: { value } }) =>
                                            onChangeTime(item, value)
                                          }
                                        />
                                      )}
                                    </div>
                                  </div>
                                  <Icon
                                    style={{
                                      position: "absolute",
                                      marginLeft: "86%",
                                    }}
                                    type="delete"
                                    onClick={() =>
                                      onDeleteGreenhouseSections(item)
                                    }
                                  />
                                </List.Item>
                              );
                            }}
                          />
                        )}

                        {_.size(addSections) > 0 && (
                          <>
                            <Divider orientation="left">
                              Добавленные работы
                            </Divider>
                            <List
                              size="smail"
                              bordered
                              dataSource={_.map(addSections, "name")}
                              renderItem={(item, key) => {
                                const section = _.filter(
                                  addSections,
                                  (s) => s.name === item
                                );
                                const minLeadTime = _.get(
                                  section[0],
                                  "minLeadTime",
                                  null
                                );
                                const isTime = timeName === item;
                                return (
                                  <List.Item onClick={() => setTimeName(item)}>
                                    <div>
                                      <div style={{ width: "86%" }}>{item}</div>
                                      <div style={{ display: "grid" }}>
                                        <small>
                                          Время выполнения:&nbsp;
                                          {minLeadTime ? minLeadTime : 1}
                                        </small>
                                        {isTime && (
                                          <Input
                                            style={{
                                              width: "200px",
                                              height: "40px",
                                            }}
                                            placeholder="Укажите время выполнения"
                                            onChange={({ target: { value } }) =>
                                              onChangeAddTime(item, value)
                                            }
                                          />
                                        )}
                                      </div>
                                    </div>
                                    <Icon
                                      style={{
                                        position: "absolute",
                                        marginLeft: "86%",
                                      }}
                                      type="delete"
                                      onClick={() => onDeleteAddSections(item)}
                                    />
                                  </List.Item>
                                );
                              }}
                            />
                          </>
                        )}
                      </ContentHolder>
                    </Box>
                  </Col>
                </Row>
              </Fieldset>
            </Form>
          </Modal>

          <TableWrapper
            rowKey="key"
            columns={columns}
            bordered={true}
            dataSource={dataSource}
            loading={isLoading}
            className="isoSimpleTable"
            onChange={handleTableChange}
            pagination={{
              defaultPageSize: itemsPerPage,
              hideOnSinglePage: true,
              total: totalItems,
              current: page,
              showTotal: (total, range) => {
                return `Показано ${range[0]}-${range[1]} из ${totalItems} записей`;
              },
            }}
          />
        </ContentHolder>
      </Box>
    </LayoutContentWrapper>
  );
}
