import { Descriptions } from "antd";
import styled from "styled-components";
import { palette } from "styled-theme";
import Table from "../Tables/AntTables/AntTables.styles";

const TableWrapper = styled(Table)`
  margin-bottom: 50px;
  .ant-table-bordered .ant-table-thead > tr > th,
  .ant-table-bordered .ant-table-tbody > tr > td {
    white-space: normal;
    &.noWrapCell {
      white-space: nowrap;
    }

    @media only screen and (max-width: 920px) {
      white-space: nowrap;
    }
  }
`;
const CheckMetricWrapper = styled.div`
  overflow-y: auto;
  height: 600px;
  margin-top: 30px;
`;
const DescriptionsWrapper = styled(Descriptions)`
  .ant-descriptions-item-label {
    font-size: 13px;
  }
  .ant-descriptions-item-content {
    font-size: 12px;
  }
  margin-bottom: 30px;
`;

const Fieldset = styled.div`
  width: 100%;
  display: flex;
  flex-direction: column;
  margin-bottom: 20px;

  &:last-child {
    margin-bottom: 0;
  }
`;

const Label = styled.label`
  font-size: 13px;
  color: ${palette("text", 1)};
  line-height: 1.5;
  font-weight: 500;
  padding: 0;
  margin: 0 0 8px;
`;

const StatusTag = styled.span`
  padding: 0 5px;
  margin: 0 5px;
  height: 20px;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  border-radius: 2px;
  background-color: ${palette("primary", 0)};
  font-size: 12px;
  color: #ffffff;
  text-transform: capitalize;

  &.online {
    background-color: ${palette("info", 0)};
  }

  &.offline {
    background-color: ${palette("warning", 0)};
  }

  &.nfcOn {
    background-color: ${palette("info", 0)};
  }

  &.nfcOff {
    background-color: ${palette("warning", 0)};
  }

  &.active {
    background-color: ${palette("success", 0)};
  }

  &.inactive {
    background-color: ${palette("error", 0)};
  }

  &.workerExclusive {
    background-color: ${palette("warning", 0)};
  }

  &.workerExclusive-0 {
    background-color: #d64161;
    color: #ffffff;
  }

  &.workerExclusive-1 {
    background-color: #ff7b25;
    color: #ffffff;
  }

  &.workerExclusive-2 {
    background-color: #6b5b95;
    color: #ffffff;
  }

  &.workerExclusive-3 {
    background-color: #feb236;
    color: #000000;
  }

  &.workerExclusive-4 {
    background-color: #3e4444;
    color: #ffffff;
  }

  &.workerExclusive-5 {
    background-color: #82b74b;
    color: #ffffff;
  }
`;

const TitleWrapper = styled.div`
  display: flex;
  justify-content: space-between;
  margin-bottom: 20px;
  flex-wrap: no-wrap;
  align-items: top;
  padding: 0;
`;

const InlineGroupWrapper = styled.div`
  display: inline-block;
  margin: 5px 0;
`;

const ComponentTitle = styled.h3`
  font-size: 16px;
  font-weight: 500;
  color: ${palette("text", 0)};
  margin: 5px 0;
`;
const ActionsTitle = styled.div`
  display: flex;
`;

export {
  TitleWrapper,
  ComponentTitle,
  TableWrapper,
  StatusTag,
  Fieldset,
  Label,
  ActionsTitle,
  InlineGroupWrapper,
  DescriptionsWrapper,
  CheckMetricWrapper,
};
