import _ from "lodash";
import React, { useEffect } from "react";

import Chart from "react-apexcharts";
import { useDispatch, useSelector } from "react-redux";
import actions from "@iso/redux/monitoringGraph/actions";
import { Grid } from "react-flexbox-grid";
import {
  ComponentTitle,
  TitleWrapper,
  InlineGroupWrapper,
} from "./MonitoringGraph.styles";
import { Select } from "antd";
import moment from "moment";
const { Option } = Select;
const MonitoringGraph = () => {
  const { greenhouseId } = useSelector((state) => state.App);

  const { pestInfestations, pests, pestId, isLoadingPests } = useSelector(
    (state) => state.MonitoringGraph
  );

  const dispatch = useDispatch();

  useEffect(() => {
    dispatch(actions.loadFromAgroInvest());
  }, [dispatch, greenhouseId]);

  const pestName = _.find(pests, ({ id }) => id === pestId)?.name;
  const filename = `${pestName}-${moment(new Date()).format(
    "MMMM-Do-YYYY-h:mm:ss"
  )}`;

  const options = {
    chart: {
      offsetX: 0,
      defaultLocale: "ru",
      toolbar: {
        export: {
          csv: {
            filename,
          },
          svg: {
            filename,
          },
          png: {
            filename,
          },
        },
      },
      locales: [
        {
          name: "ru",
          options: {
            months: [
              "Январь",
              "Февраль",
              "Март",
              "Апрель",
              "Май",
              "Июнь",
              "Июль",
              "Август",
              "Сентябрь",
              "Октябрь",
              "Ноябрь",
              "Декабрь",
            ],
            shortMonths: [
              "Янв",
              "Фев",
              "Мар",
              "Апр",
              "Май",
              "Июн",
              "Июл",
              "Авг",
              "Сен",
              "Окт",
              "Ноя",
              "Дек",
            ],
            days: [
              "Воскресенье",
              "Понедельник",
              "Вторник",
              "Среда",
              "Четверг",
              "Пятница",
              "Суббота",
            ],
            shortDays: ["Вс", "Пн", "Вт", "Ср", "Чт", "Пт", "Сб"],
            toolbar: {
              exportToSVG: "Скачать SVG",
              exportToPNG: "Скачать PNG",
              exportToCSV: "Скачать CSV",
              menu: "Меню",
              selection: "Выбор",
              selectionZoom: "Выбор масштабирование",
              zoomIn: "Увеличить",
              zoomOut: "Уменьшить",
              pan: "Panning",
              reset: "Cброс масштабирование",
            },
          },
        },
      ],
    },
    xaxis: {
      type: "datetime",
    },
    yaxis: {
      tickAmount: 10,
    },
    markers: {
      size: 1,
    },
    dataLabels: {
      enabled: false,
    },
    title: {
      text: pestName,
      align: "left",
    },
  };
  const changePest = (pestId) => {
    dispatch(actions.setPestId(pestId));
  };
  return (
    <Grid fluid>
      <TitleWrapper>
        <ComponentTitle id="headerMonitorInfo">
          <InlineGroupWrapper>
            Вредители/Болезни: &nbsp;
            <Select
              dropdownMatchSelectWidth={false}
              style={{ minWidth: 120 }}
              value={pestName}
              disabled={isLoadingPests}
              loading={isLoadingPests}
              onChange={changePest}
            >
              {pests.map(({ name, id }) => (
                <Option key={id} value={id}>
                  {name}
                </Option>
              ))}
            </Select>
          </InlineGroupWrapper>
        </ComponentTitle>
      </TitleWrapper>
      <Chart
        options={options}
        series={pestInfestations}
        type="line"
        width={"100%"}
        height={"500px"}
      />
    </Grid>
  );
};

export default MonitoringGraph;
