import Button from "@iso/components/uielements/button";
import DatePicker from "@iso/components/uielements/datePicker";
import _ from "lodash";
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import {
  TableWrapper,
  ComponentTitle,
  TitleWrapper,
  InlineGroupWrapper,
  ActionsTitle,
} from "./MonitoringInfo.styles";
import moment from "moment";
import { Input, Select } from "antd";
import { Grid, Row, Col } from "react-flexbox-grid";
import Modal from "@iso/components/Feedback/Modal";
import actions from "@iso/redux/monitoringInfo/actions";
import { initState } from "@iso/redux/monitoringInfo/reducers";
import Form from "@iso/components/uielements/form";
import html2pdf from "html2pdf.js";
import html2canvas from "html2canvas";
import jsPDF from "jspdf";
const { Option } = Select;

const splitTableByPages = () => {
  const tableTemplate = document
    .querySelector("#leftColumn .ant-table-wrapper")
    .cloneNode(true);
  tableTemplate.style.paddingBottom = 0;
  tableTemplate.style.marginBottom = 0;
  tableTemplate.querySelector(`.ant-table-tbody`).innerHTML = null;

  const rightTableTemplate = document
    .querySelector("#rightColumn .ant-table-wrapper")
    .cloneNode(true);
  rightTableTemplate.style.paddingBottom = 0;
  rightTableTemplate.style.marginBottom = 0;
  rightTableTemplate.querySelector(`.ant-table-tbody`).innerHTML = null;

  let leftBodyElement = document.querySelector(`#leftColumn .ant-table-tbody`);
  const leftTblRows = leftBodyElement && leftBodyElement.childNodes;
  let rightBodyElement = document.querySelector(
    `#rightColumn .ant-table-tbody`
  );
  const rightTblRows = rightBodyElement && rightBodyElement.childNodes;
  if (leftTblRows) {
    const countRowsFirstPage = 35;
    const firstPageRows = _.take(leftTblRows, countRowsFirstPage);
    const otherPageRows = _.drop(leftTblRows, countRowsFirstPage);
    const otherPageChunks = _.chunk(otherPageRows, 45);
    const unionRows = [firstPageRows, ...otherPageChunks];
    const leftTables = unionRows.map((rows) => {
      const copyTemplate = tableTemplate.cloneNode(true);
      const bodyCopy = copyTemplate.querySelector(`.ant-table-tbody`);
      rows.forEach((row) => {
        bodyCopy.appendChild(row.cloneNode(true));
      });
      return copyTemplate;
    });
    const rightPageChunks = _.chunk(rightTblRows, 45);
    const rightTables = rightPageChunks.map((rows) => {
      const copyTemplate = rightTableTemplate.cloneNode(true);
      const bodyCopy = copyTemplate.querySelector(`.ant-table-tbody`);
      rows.forEach((row) => {
        bodyCopy.appendChild(row.cloneNode(true));
      });
      return copyTemplate;
    });

    return [...leftTables, ...rightTables];
  }
};

const createFirstPage = (greenhouseId, tableNode) => {
  var element = document.getElementById("headerMonitorInfo");
  let headnode = document.createElement("h2");
  let textnode = document.createTextNode(`Теплица: ${greenhouseId}`);
  headnode.appendChild(textnode);
  headnode.appendChild(element.cloneNode(true));
  headnode.appendChild(tableNode);
  return headnode;
};
const exportHTMLToPDF = async (greenhouseId) => {
  const [firstPageTable, ...otherPageTables] = splitTableByPages();
  const firstPage = createFirstPage(greenhouseId, firstPageTable);

  var opt = {
    margin: [15, 15],
    filename: `${"Monitoring-paginated"}-${moment(new Date()).format(
      "MMMM-Do-YYYY-h:mm:ss"
    )}`,
    image: { type: "jpeg", quality: 0.95 },
    html2canvas: {
      useCORS: true,
      scale: 2,
    },
    jsPDF: {
      unit: "mm",
      format: "a4",
      orientation: "portrait",
      compress: true,
    },
  };

  const firstPagePdf = html2pdf().set(opt).from(firstPage).toPdf();
  const pdf = otherPageTables.reduce((acc, table) => {
    return acc
      .get("pdf")
      .then(function (pdf) {
        pdf.addPage();
      })
      .from(table)
      .toContainer()
      .toCanvas()
      .toPdf();
  }, firstPagePdf);
  return pdf.save();
};

const exportGeneralHTMLToPDF = async (greenhouseId) => {
  const general = document.querySelector("#general");
  let headnode = document.createElement("h2");
  let textnode = document.createTextNode(`Теплица: ${greenhouseId}`);
  headnode.appendChild(textnode);
  headnode.style.display = "none";
  general.prepend(headnode);
  await html2canvas(general, {
    onclone: function (documentClone) {
      documentClone.querySelector("#actionsTitle").remove();
      documentClone.querySelector("h2").style.display = "block";
    },
  }).then((canvas) => {
    const componentWidth = general.offsetWidth;
    const componentHeight = general.offsetHeight;

    const orientation = componentWidth >= componentHeight ? "l" : "p";

    const imgData = canvas.toDataURL("image/png");
    const pdf = new jsPDF({
      orientation,
      unit: "px",
      compress: true,
    });

    pdf.internal.pageSize.width = componentWidth;
    pdf.internal.pageSize.height = componentHeight;
    pdf.setFontSize(40);
    pdf.text("Octonyan loves jsPDF", 35, 25);
    pdf.addImage(imgData, "PNG", 0, 0, componentWidth, componentHeight);
    pdf.save(
      `${"Monitoring-general"}-${moment(new Date()).format(
        "MMMM-Do-YYYY-h:mm:ss"
      )}`
    );
  });
  textnode.remove();
};

const SelectedPest = ({ selectedPest, changeCellParamId, intensitys }) => {
  const { intensityId, id } = selectedPest;
  return (
    <>
      <Form.Item label="Интенсивность поражения" hasFeedback>
        <Select
          dropdownMatchSelectWidth={false}
          value={intensityId}
          onChange={changeCellParamId(id, "intensityId")}
        >
          {intensitys?.map(({ id, color, name }) => {
            return (
              <Option key={id} value={id}>
                <div
                  style={{
                    minWidth: "16px",
                    width: "16px",
                    height: "16px",
                    backgroundColor: color,
                    borderColor: color,
                    verticalAlign: "text-bottom",
                    borderRadius: "50%",
                    marginRight: "10px",
                    display: "inline-block",
                  }}
                />
                {name}
              </Option>
            );
          })}
        </Select>
      </Form.Item>
      <Form.Item label="Дата излечения:" hasFeedback>
        <DatePicker
          onChange={(date) => {
            const formatedDate = date && date?.format();
            changeCellParamId(id, "curedAt")(formatedDate);
          }}
        />
      </Form.Item>
    </>
  );
};
const ColorCell = ({ cell, pestInfestation }) => {
  const dispatch = useDispatch();
  const color = pestInfestation.intensity?.color || "inherit";
  const style = {
    height: "20px",
    backgroundColor: color,
  };
  if (pestInfestation.pest.name) {
    return (
      <div
        shape="circle"
        style={style}
        onClick={() => dispatch(actions.toggleModal(cell))}
      />
    );
  }
  return <div shape="circle" disabled style={style} />;
};
const shelfs = _.range(1, 31);
const columns = [
  {
    title: "Ряды/Пролёты",
    dataIndex: "rowNumber",
    align: "center",
    width: "100px",
  },
  ...shelfs.map((shelf) => ({
    title: shelf,
    dataIndex: `${shelf}`,
    key: shelf,
    align: "center",
    width: "20px",
    render: (cell) => {
      const pestInfestation = _.maxBy(cell, "intensity.orderBy");
      const concatedPestsName = cell.reduce(
        (acc, { pest }) =>
          `${acc} \n${
            pest.name || "Болезней и вредителей не зарегистрировано"
          }`,
        ""
      );
      return {
        props: {
          title: concatedPestsName,
        },
        children: <ColorCell cell={cell} pestInfestation={pestInfestation} />,
      };
    },
  })),
];

const reversedColumns = [...columns].reverse();
const isEven = (number) => number % 2 === 0;

const MonitoringInfo = () => {
  const dispatch = useDispatch();
  const {
    isLoading,
    isLoadingPestInfestations,
    dateAfter,
    dateBefore,
    rowStart,
    rowEnd,
    pests,
    isLoadingPests,
    intensitys,
    workers,
    isLoadingWorkers,
    pestId,
    workerId,
    cell,
    modalActive,
    fillRows,
  } = useSelector((state) => state.MonitoringInfo);

  const { greenhouseId, greenhouses } = useSelector((state) => state.App);

  const {
    blocksPermissions: { ["plant-protection"]: plantProtectionPermissions },
  } = useSelector((state) => _.get(state, "Auth.userPermissions"));

  const {
    ["monitoring"]: { edit: hasAccessToEdit },
  } = plantProtectionPermissions.blocks;

  const greenhouseDescription = _.get(
    _.find(greenhouses, (g) => g.id === greenhouseId),
    "description",
    null
  );

  const evenRows = fillRows.filter((row) => isEven(row.orderBy));

  const oddRows = fillRows.filter((row) => !isEven(row.orderBy));

  const [selectedPestId, setSelectedPestId] = useState(null);
  const [isDownload, setIsDownload] = useState(false);
  const [rowStartValue, setRowStartValue] = useState(rowStart);
  const [rowEndValue, setRowEndValue] = useState(rowEnd);
  const handleChangeRowStart = (e) => setRowStartValue(e.target.value);
  const handleChangeRowEnd = (e) => setRowEndValue(e.target.value);

  useEffect(() => {
    dispatch(actions.loadFromAgroInvest());
  }, [dispatch, greenhouseId]);

  useEffect(() => {
    if (modalActive) {
      setSelectedPestId(null);
    }
  }, [modalActive]);

  const changeCellParamId = (id, param) => (selectedId) => {
    const copyCell = [...cell];

    const index = copyCell.findIndex(
      (pestInfestation) => pestInfestation.id === id
    );
    copyCell[index] = { ...copyCell[index], [param]: selectedId };
    dispatch(actions.update(copyCell));
  };

  const changeDateBefore = (date) => {
    dispatch(actions.setDateBefore(date.utc().endOf("day").format()));
  };
  const changeDateAfter = (date) => {
    dispatch(actions.setDateAfter(date.utc().format()));
  };
  const changeRowStart = ({ target: { value } }) => {
    if (value !== rowStart) {
      dispatch(actions.setRowStart(value));
    }
  };
  const changeRowEnd = ({ target: { value } }) => {
    if (value !== rowEnd) {
      dispatch(actions.setRowEnd(value));
    }
  };
  const changePest = (pestId) => {
    dispatch(actions.setPestId(pestId));
  };

  const changeWorker = (workerId) => {
    dispatch(actions.setWorkerId(workerId));
  };

  const handleRefreshRow = () => {
    dispatch(actions.refresh());
  };

  const dropFilters = () => {
    dispatch(actions.resetFilters());
    setRowStartValue(initState.rowStart);
    setRowEndValue(initState.rowEnd);
  };

  const selectedPest = cell.find(({ id }) => id === selectedPestId);
  const pestName = _.find(pests, ({ id }) => id === pestId)?.name;
  return (
    <Grid fluid id="general">
      <TitleWrapper>
        <ComponentTitle id="headerMonitorInfo">
          <InlineGroupWrapper>
            Период: &nbsp;
            <DatePicker
              value={moment(dateAfter)}
              onChange={changeDateAfter}
              allowClear={false}
            />
            &nbsp; &mdash; &nbsp;
            <DatePicker
              value={moment(dateBefore).utc()}
              onChange={changeDateBefore}
              allowClear={false}
            />
            &nbsp;
          </InlineGroupWrapper>
          <InlineGroupWrapper>
            Ряд: &nbsp;
            <Input
              style={{ width: 50 }}
              value={rowStartValue}
              onChange={handleChangeRowStart}
              onPressEnter={changeRowStart}
              onBlur={changeRowStart}
            />
            &nbsp; &mdash; &nbsp;
            <Input
              style={{ width: 50 }}
              value={rowEndValue}
              onChange={handleChangeRowEnd}
              onPressEnter={changeRowEnd}
              onBlur={changeRowEnd}
            />
            &nbsp;
          </InlineGroupWrapper>
          <InlineGroupWrapper>
            Вредители/Болезни: &nbsp;
            <Select
              dropdownMatchSelectWidth={false}
              style={{ minWidth: 120 }}
              value={pestName}
              disabled={isLoadingPests}
              loading={isLoadingPests}
              onChange={changePest}
            >
              {pests.map(({ name, id }) => (
                <Option key={id} value={id}>
                  {name}
                </Option>
              ))}
            </Select>
            &nbsp;
          </InlineGroupWrapper>
          <InlineGroupWrapper>
            Имя Сотрудника: &nbsp;
            <Select
              disabled={isLoadingWorkers}
              dropdownMatchSelectWidth={false}
              loading={isLoadingWorkers}
              style={{ width: 300 }}
              value={workerId}
              onChange={changeWorker}
            >
              {workers.map((worker) => (
                <Option key={worker.id} value={worker.id}>
                  {worker.name}
                </Option>
              ))}
            </Select>
          </InlineGroupWrapper>
        </ComponentTitle>
        <ActionsTitle id="actionsTitle">
          <Button
            type="primary"
            shape="circle"
            title="Скачать pdf постраничный вид"
            loading={isLoading || isDownload}
            icon="cloud-download"
            onClick={async () => {
              setIsDownload(true);
              await exportHTMLToPDF(greenhouseDescription);
              setIsDownload(false);
            }}
          />
          <Button
            type="primary"
            shape="circle"
            title="Скачать pdf общий вид"
            loading={isLoading || isDownload}
            icon="download"
            style={{ marginLeft: "10px" }}
            onClick={async () => {
              setIsDownload(true);
              await exportGeneralHTMLToPDF(greenhouseDescription);
              setIsDownload(false);
            }}
          />
          <Button
            type="primary"
            shape="circle"
            loading={isLoading}
            icon="filter"
            onClick={dropFilters}
            style={{ marginLeft: "10px" }}
          />
          <Button
            type="primary"
            shape="circle"
            loading={isLoading}
            icon="reload"
            onClick={handleRefreshRow}
            style={{ marginLeft: "10px" }}
          />
        </ActionsTitle>
      </TitleWrapper>
      <Modal
        visible={modalActive}
        onClose={() => dispatch(actions.toggleModal(null))}
        title={`Ряд: ${_.head(cell)?.task?.rowNumber} Пролёт ${
          _.head(cell)?.shelfNumber
        }`}
        okText={"Сохранить"}
        onOk={() => {
          dispatch(actions.saveIntoAgroInvest(cell, "update"));
        }}
        okButtonProps={{ disabled: !hasAccessToEdit }}
        onCancel={() => dispatch(actions.toggleModal(null))}
      >
        <Form>
          <Form.Item label="Список вредителей" hasFeedback>
            <Select
              dropdownMatchSelectWidth={false}
              value={selectedPestId}
              onChange={setSelectedPestId}
            >
              {cell.map(({ id, pest }) => {
                return (
                  <Option key={id} value={id}>
                    {pest.name}
                  </Option>
                );
              })}
            </Select>
          </Form.Item>
          {selectedPest && (
            <SelectedPest
              selectedPest={selectedPest}
              changeCellParamId={changeCellParamId}
              pests={pests}
              intensitys={intensitys}
            />
          )}
        </Form>
      </Modal>
      <Grid fluid>
        <Row>
          <Col id="leftColumn" xs={6} style={{ overflowX: "auto" }}>
            <TableWrapper
              rowClassName={(record) => {
                if (record.isBlockEnd) {
                  return "ant-row-border-bottom";
                }
              }}
              loading={isLoading || isLoadingPestInfestations}
              columns={reversedColumns}
              dataSource={evenRows}
              pagination={false}
              bordered={true}
              rowKey={(record) => record.orderBy}
            />
          </Col>
          <Col id="rightColumn" xs={6} style={{ overflowX: "auto" }}>
            <TableWrapper
              rowClassName={(record) => {
                if (record.isBlockEnd) {
                  return "ant-row-border-bottom";
                }
              }}
              loading={isLoading || isLoadingPestInfestations}
              columns={columns}
              dataSource={oddRows}
              pagination={false}
              bordered={true}
              rowKey={(record) => record.orderBy}
            />
          </Col>
        </Row>
      </Grid>
    </Grid>
  );
};
export default MonitoringInfo;
