import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import Button from "@iso/components/uielements/button";
import LayoutContentWrapper from "@iso/components/utility/layoutWrapper";
import Box from "@iso/components/utility/box";
import orderingActions from "@iso/redux/ordering/actions";
import ContentHolder from "@iso/components/utility/contentHolder";
import { Card } from "antd";
import _ from "lodash";
import "react-flexbox-grid/dist/react-flexbox-grid.css";
import { Grid, Row, Col } from "react-flexbox-grid";
// import { quarantineRows } from '@iso/config/sections.config';

import { TitleWrapper, ComponentTitle } from "./Ordering.styles";

import moment from "moment-timezone";
import "moment/locale/ru";

moment.updateLocale("ru", { week: { dow: 1 } });

moment.tz.setDefault("Europe/Moscow");

const { loadFromAgroInvest, refreshRows, saveToAgroInvest } = orderingActions;

export default function Ordering() {
  const { rows, isLoading, totalItems } = useSelector(
    (state) => state.Ordering
  );

  const [ordering, setOrdering] = useState([]);
  const [maxOrdering, setMaxOrdering] = useState(2);

  const { greenhouseId } = useSelector((state) => state.App);

  const {
    blocksPermissions: { ["ordering"]: orderingPermissions },
  } = useSelector((state) => _.get(state, "Auth.userPermissions"));

  const { edit: hasAccessToEdit } = orderingPermissions;

  const dispatch = useDispatch();

  useEffect(() => {
    dispatch(refreshRows());
  }, [dispatch]);

  useEffect(() => {
    const maxRow = _.maxBy(rows, "orderBy");
    setOrdering(rows);
    if (maxRow) {
      setMaxOrdering(maxRow.orderBy);
    }
  }, [rows]);

  useEffect(() => {
    dispatch(loadFromAgroInvest(greenhouseId));
  }, [dispatch, greenhouseId]);

  const addOrderBy = (orderBy) => {
    setOrdering(
      _.map(ordering, (r) =>
        r.orderBy >= orderBy ? { ...r, orderBy: r.orderBy + 1 } : { ...r }
      )
    );
    setMaxOrdering(maxOrdering + 1);
  };
  const addBlockEnd = (orderBy) => {
    setOrdering(
      _.map(ordering, (r) =>
        r.orderBy === orderBy ? { ...r, isBlockEnd: true } : { ...r }
      )
    );
  };
  const removeBlockEnd = (orderBy) => {
    setOrdering(
      _.map(ordering, (r) =>
        r.orderBy === orderBy ? { ...r, isBlockEnd: false } : { ...r }
      )
    );
  };

  const swapOrder = (orderBy) => {
    setOrdering(
      _.map(ordering, (r) => {
        const previosOrderBy = orderBy - 1;
        if (r.orderBy === previosOrderBy) {
          return { ...r, orderBy: r.orderBy + 1 };
        }
        if (r.orderBy === orderBy) {
          return { ...r, orderBy: r.orderBy - 1 };
        }
        return { ...r };
      })
    );
  };

  const subOrderBy = (orderBy) => {
    setOrdering(
      _.map(ordering, (r) =>
        r.orderBy > orderBy ? { ...r, orderBy: r.orderBy - 1 } : { ...r }
      )
    );
    setMaxOrdering(maxOrdering - 1);
  };

  const reload = () => {
    dispatch(refreshRows());
    dispatch(loadFromAgroInvest(greenhouseId));
  };

  const saveOrdering = () => {
    dispatch(saveToAgroInvest(ordering));
  };

  const ButtonBlockEnd = ({ isBlockEnd, orderBy }) => {
    return isBlockEnd ? (
      <Button onClick={() => removeBlockEnd(orderBy)}>
        Убрать окончание секции
      </Button>
    ) : (
      <Button onClick={() => addBlockEnd(orderBy)}>
        Отметить окончание секции
      </Button>
    );
  };
  const ButtonSwapOrder = ({ isBlockEnd, orderBy }) => {
    return (
      <Button onClick={() => swapOrder(orderBy)}>
        Поменять с противоположной позицией
      </Button>
    );
  };

  const orderingContent = !isLoading ? (
    <Grid fluid>
      <Row>
        <Col xs={12} md={6}>
          {_.map(_.range(2, maxOrdering + 1, 2), (orderBy) => {
            const row = _.find(ordering, (r) => r.orderBy === orderBy);

            return (
              <Card key={orderBy}>
                {row ? (
                  <div
                    style={{
                      display: "flex",
                      justifyContent: "space-between",
                      alignItems: "center",
                      height: 72,
                    }}
                  >
                    <h2>
                      Ряд {row.rowNumber} <small>Позиция: {row.orderBy}</small>
                    </h2>
                    {hasAccessToEdit && (
                      <div style={{ display: "flex", flexDirection: "column" }}>
                        <Button onClick={() => addOrderBy(orderBy)}>
                          Добавить промежуток выше
                        </Button>
                        <ButtonBlockEnd
                          isBlockEnd={row.isBlockEnd}
                          orderBy={orderBy}
                        />
                        <ButtonSwapOrder orderBy={orderBy} />
                      </div>
                    )}
                  </div>
                ) : (
                  <div
                    style={{
                      display: "flex",
                      justifyContent: "space-between",
                      alignItems: "center",
                      height: 72,
                    }}
                  >
                    <h2>
                      <small>Позиция: {orderBy}</small>
                    </h2>
                    {hasAccessToEdit && (
                      <div style={{ display: "flex", flexDirection: "column" }}>
                        <Button
                          className="error"
                          onClick={() => subOrderBy(orderBy)}
                        >
                          Удалить
                        </Button>
                        <ButtonSwapOrder orderBy={orderBy} />
                      </div>
                    )}
                  </div>
                )}
              </Card>
            );
          })}
        </Col>
        <Col xs={12} md={6}>
          {_.map(_.range(1, maxOrdering + 1, 2), (orderBy) => {
            const row = _.find(ordering, (r) => r.orderBy === orderBy);

            return (
              <Card key={orderBy}>
                {row ? (
                  <div
                    style={{
                      display: "flex",
                      justifyContent: "space-between",
                      alignItems: "center",
                      height: 72,
                    }}
                  >
                    <h2>
                      Ряд {row.rowNumber} <small>Позиция: {row.orderBy}</small>
                    </h2>
                    {hasAccessToEdit && (
                      <div style={{ display: "flex", flexDirection: "column" }}>
                        <Button
                          style={{ width: "100%" }}
                          onClick={() => addOrderBy(orderBy)}
                        >
                          Добавить позицию выше
                        </Button>
                        <ButtonBlockEnd
                          isBlockEnd={row.isBlockEnd}
                          orderBy={orderBy}
                        />
                      </div>
                    )}
                  </div>
                ) : (
                  <div
                    style={{
                      display: "flex",
                      justifyContent: "space-between",
                      height: 72,
                    }}
                  >
                    <h2>
                      <small>Позиция: {orderBy}</small>
                    </h2>
                    <div style={{ flex: "auto" }} />
                    {hasAccessToEdit && (
                      <Button
                        className="error"
                        onClick={() => subOrderBy(orderBy)}
                      >
                        Удалить
                      </Button>
                    )}
                  </div>
                )}
              </Card>
            );
          })}
        </Col>
      </Row>
    </Grid>
  ) : null;

  return (
    <LayoutContentWrapper>
      <Box>
        <ContentHolder style={{ marginTop: 0, overflow: "hidden" }}>
          <TitleWrapper>
            <ComponentTitle>
              Структура теплицы:
              <small> Всего найдено: {totalItems || 0}</small>
            </ComponentTitle>

            <div>
              <Button
                type="primary"
                style={{ marginRight: 10 }}
                disabled={isLoading || !hasAccessToEdit}
                onClick={() => saveOrdering()}
              >
                Сохранить структуру
              </Button>
              <Button
                type="primary"
                shape="circle"
                loading={isLoading}
                icon="reload"
                onClick={reload}
              />
            </div>
          </TitleWrapper>
        </ContentHolder>

        {orderingContent}
      </Box>
    </LayoutContentWrapper>
  );
}
