import React, { useState } from 'react';
import { Link } from 'react-router-dom';
import isEmpty from 'lodash/isEmpty';
import { notification } from '@iso/components';
import { validateEmail } from '@iso/lib/helpers/validators/isEmail';
import Input from '@iso/components/uielements/input';
import Button from '@iso/components/uielements/button';
import IntlMessages from '@iso/components/utility/intlMessages';
import ForgotPasswordStyleWrapper from './ForgotPassword.styles';
import { request } from '@iso/lib/helpers/utility';
import { resetPassword } from '@iso/lib/firebase/firebase.authentication.util';
import { translate } from '@iso/lib/helpers/translate';

export default function() {
  const [email, setEmail] = useState('');
  const [isFormSent, setFormSent] = useState(false);

  const handleResetPassword = async () => {
    const validateEmailError = validateEmail(email);

    if (validateEmailError) {
      notification('error', validateEmailError);
      return;
    }

    try {
      await request('managers', { email }).then(res => {
        if (isEmpty(res["hydra:member"])) {
          throw new Error('Пользователь не найден, он мог быть удален.');
        }
      })

      await resetPassword(email);

      setFormSent(true);
    } catch(error) {
      notification('error', translate(error.code) || error.message)
    }
  }

  const renderFormForgotPassword = () => (
    <>
      <div className="isoFormHeadText">
        <h3>
          <IntlMessages id="page.forgetPassSubTitle" />
        </h3>
        <p>
          <IntlMessages id="page.forgetPassDescription" />
        </p>
      </div>

      <div className="isoForgotPassForm">
        <div className="isoInputWrapper">
          <Input onChange={(event) => setEmail(event.target.value)} size="large" placeholder="Email" />
        </div>

        <div className="isoInputWrapper">
          <Button type="primary" onClick={handleResetPassword}>
            <IntlMessages id="page.sendRequest" />
          </Button>
        </div>
      </div>
    </>
  )

  const renderSuccessMessage = () => (
    <div className="isoFormHeadText">
      <h3>
        <IntlMessages id="page.forgetPassSubTitleSuccess" />
      </h3>
      <p>
        <IntlMessages id="page.forgetPassDescriptionSuccess" />
      </p>
    </div>
  )

  return (
    <ForgotPasswordStyleWrapper className="isoForgotPassPage">
      <div className="isoFormContentWrapper">
        <div className="isoFormContent">
          <div className="isoLogoWrapper">
            <Link to="/dashboard">
              <IntlMessages id="page.forgetPassTitle" />
            </Link>
          </div>
          {isFormSent ? renderSuccessMessage() : renderFormForgotPassword()}
        </div>
      </div>
    </ForgotPasswordStyleWrapper>
  );
}
