import React from 'react';
import { Link, Redirect, useHistory, useLocation } from 'react-router-dom';
import { useSelector, useDispatch } from 'react-redux';
import Input from '@iso/components/uielements/input';
import Checkbox from '@iso/components/uielements/checkbox';
import Button from '@iso/components/uielements/button';
import IntlMessages from '@iso/components/utility/intlMessages';
// import FirebaseLoginForm from '../../FirebaseForm/FirebaseForm';
import authAction from '@iso/redux/auth/actions';
import appAction from '@iso/redux/app/actions';
// import Auth0 from '../../Authentication/Auth0/Auth0';
import { request } from '@iso/lib/helpers/utility';
import { translate } from '@iso/lib/helpers/translate';
import {
  notification
} from '@iso/components';

import _ from 'lodash'

import  { signInWithEmail } from '@iso/lib/feathers/feathers.authentication.util';
import SignInStyleWrapper from './SignIn.styles';

const { login } = authAction;
const { clearMenu } = appAction;

const fakeApiCall = false;

export default function SignIn() {
  let history = useHistory();
  let location = useLocation();
  const dispatch = useDispatch();
  const isLoggedIn = useSelector(state => state.Auth.idToken);

  const [redirectToReferrer, setRedirectToReferrer] = React.useState(false);

  const [state, setState] = React.useState({
    visible: false,
    email: '',
    password: '',
    confirmLoading: false,
  });

  React.useEffect(() => {
    if (isLoggedIn) {
      setRedirectToReferrer(true);
    }
  }, [isLoggedIn]);

  const handleChange = e => {
    const {
      name,
      value
    } = e.target;

    setState({
      ...state,
      [name]: value,
    });
  };

  const handleLogin = async () => {
    const {
      email,
      password
    } = state;
    if (!(email || password)) {
      notification('error', 'Пожалуйста, введите email и пароль');
      return;
    }
    setState({
      ...state,
      confirmLoading: true,
    });
    let user;
    let userData;
    let message;

    try {
      await signInWithEmail(email, password).then(authUser => {
        user = authUser;
      });
      await request('managers', { email }).then(res => {
        if (!_.isEmpty(res["hydra:member"])) userData = res["hydra:member"][0]
        else {
          throw new Error('Error loading user data from AgroInvest')
        }
      })
    } catch (error) {
      message = translate(error.code) || error.message;
      console.log(error.message, 'Error');
    }

    if (user && userData) {
      const token = await user.accessToken;
      userData.lastLoggedAt = user.manager.lastLoggedAt;
      dispatch(login(token, userData));
      history.push('/dashboard');
    } else {
      notification('error', message);
      setState({
        ...state,
        confirmLoading: false,
      });
    }
  };

  // const handleResetPassword = () => {
  //   const {
  //     email
  //   } = state;
  //   if (!email) {
  //     notification('error', `Please fill in email.`);
  //     return;
  //   }
  //   resetPassword(email)
  //     .then(() =>
  //       notification('success', `Password reset email sent to ${email}.`)
  //     )
  //     .catch(error => notification('error', 'Email address not found.'));
  // };

  function handleFakeLogin(e, token = false) {
    e.preventDefault();
    if (token) {
      dispatch(login(token));
    } else {
      dispatch(login());
    }
    dispatch(clearMenu());
    history.push('/dashboard');
  }

  let { from } = location.state || { from: { pathname: '/dashboard' } };

  if (redirectToReferrer) {
    return <Redirect to={from} />;
  }
  return (
    <SignInStyleWrapper className="isoSignInPage">
      <div className="isoLoginContentWrapper">
        <div className="isoLoginContent">
          <div className="isoLogoWrapper">
            <Link to="/dashboard">
              <IntlMessages id="page.signInTitle" />
            </Link>
          </div>
          <div className="isoSignInForm">
            <form>
              <div className="isoInputWrapper">
                <Input
                  name="email"
                  size="large"
                  placeholder="Email"
                  autoComplete="true"
                  value={state.email}
                  onChange={handleChange}
                />
              </div>

              <div className="isoInputWrapper">
                <Input
                  name="password"
                  size="large"
                  type="password"
                  placeholder="Password"
                  autoComplete="false"
                  value={state.password}
                  onChange={handleChange}
                />
              </div>

              <div className="isoInputWrapper isoLeftRightComponent">
                <Button type="primary" onClick={fakeApiCall ? handleFakeLogin : handleLogin}>
                  <IntlMessages id="page.signInButton" />
                </Button>
              </div>

            </form>
          </div>
        </div>
      </div>
    </SignInStyleWrapper>
  );
}
