import React, { useState, useEffect } from 'react';
import { useSelector } from 'react-redux';
import _ from 'lodash';
import moment from 'moment-timezone';
import 'moment/locale/ru';

import LayoutContentWrapper from '@iso/components/utility/layoutWrapper';
import Box from '@iso/components/utility/box';
import ContentHolder from '@iso/components/utility/contentHolder';
import Select, { SelectOption } from '@iso/components/uielements/select';

import PhenologyContent from './PhenologyContent';
import ReferenceBooks from './ReferenceBooks';
import HistoricalValves from "./HistoricalValves";
import ValveLimit from '@iso/containers/ValveLimit/ValveLimit';

moment.tz.setDefault('Europe/Moscow');
moment.locale('ru');

const Option = SelectOption;

export default function Phenology() {
  const {
    blocksPermissions: { phenology: phenologyPermissions },
  } = useSelector((state) => _.get(state, 'Auth.userPermissions'));

  const {
    ['phenology']: { read: hasAccessToPhenologyRead },
    ['reference-books']: { read: hasAccessToReferenceBooksRead },
    ['historicalValves']: { read: hasAccessToParameters },
    'valve-limit': { read: hasAccessToValveLimitRead },
  } = phenologyPermissions.blocks;

  const { isLoading } = useSelector((state) => state.Phenology);

  const [selectedPage, setSelectedPage] = useState(null);

  useEffect(() => {
    if (!_.isEmpty(phenologyPermissions)) {
      setSelectedPage(pages[0]?.pageId);
    }
  }, [phenologyPermissions]);

  const pages = _.compact([
    hasAccessToPhenologyRead
      ? { name: "Фенология", pageId: 1 }
      : null,
    hasAccessToReferenceBooksRead
      ? { name: "Справочник (вытяжки)", pageId: 2 }
      : null,
    hasAccessToValveLimitRead ?
      { name: 'Граничные значения (вытяжки)', pageId: 3 }
      : null,
    hasAccessToParameters
      ? { name: "Исторические показания", pageId: 4 }
      : null,
  ]);

  const currentPage = pages.find(({ pageId }) => pageId === selectedPage);

  return (
    <LayoutContentWrapper>
      <Box>
        <ContentHolder style={{ marginTop: 0, overflow: 'hidden' }}>
          <Select
            style={{ marginBottom: '34px' }}
            dropdownMatchSelectWidth={false}
            defaultValue="Ничего не выбрано"
            value={currentPage?.name || 'Ничего не выбрано'}
            onChange={setSelectedPage}
            disabled={isLoading}
          >
            {pages.map(({ pageId, name }) => (
              <Option key={pageId} value={pageId}>
                {' '}
                {name}{' '}
              </Option>
            ))}
          </Select>

          <>
            {selectedPage === 1 && (
              <PhenologyContent />
            )}
            {selectedPage === 2 && (
              <ReferenceBooks />
            )}
            {selectedPage === 3 && (
              <ValveLimit />
            )}
            {selectedPage === 4 && (
              <HistoricalValves />
            )}
          </>
        </ContentHolder>
      </Box>
    </LayoutContentWrapper>
  );
}
