import React, { useEffect } from 'react';
import { useSelector, useDispatch } from "react-redux";
import _sortBy from 'lodash/sortBy';
import _uniqBy from 'lodash/uniqBy';

import actions from "@iso/redux/phenology/actions";

import Checkbox from '@iso/components/uielements/checkbox';

import { MEASUREMENTS } from './constants';

import { TableWrapper } from './Phenology.styles';

const {
  loadFromAgroInvest,
  setReferenceBookTableValue,
} = actions;

const ReferenceBooks = () => {
  const {
    valves,
    isLoading,
  } = useSelector((state) => state.Phenology);

  const { greenhouseId } = useSelector((state) => state.App);

  const dispatch = useDispatch();

  useEffect(() => {
    dispatch(loadFromAgroInvest());
  }, [greenhouseId, dispatch]);

  const valvesColumns = _sortBy(_uniqBy(valves, 'number'), 'number')
    .map(({ id, number }, index) => ({
      title: number,
      dataIndex: id,
      render: (value, { measurementsName, ...others }) => {
        return (
          <Checkbox
            onChange={({ target }) => {
              dispatch(setReferenceBookTableValue({
                id: others[index].id,
                [measurementsName]: target.checked,
              }))
            }}
            checked={others[index][measurementsName]}
          />
        );
      },
    }));

  const columns = [
    {
      title: 'Вид работы',
      dataIndex: 'workDescription',
      render: (value, row, index) => {
        const rowSpans = [2, 0, 3, 0, 0, 3, 0, 0];

        return {
          children: value,
          props: {
            rowSpan: rowSpans[index]
          },
        };
      }
    },
    {
      title: 'Наименование измерений',
      dataIndex: 'measurementsName',
      render: (value, row) => MEASUREMENTS[value],
    },
    ...valvesColumns,
  ];

  const valvesOnDropper = valves.filter(({ workDescription }) => (
    workDescription === 'капельница'
  ));

  const valvesByHood = valves.filter(({ workDescription }) => (
    workDescription === 'вытяжка'
  ));

  const valvesByDrainage = valves.filter(({ workDescription }) => (
    workDescription === 'дренаж'
  ));

  const mapValvesToDataSource = valves => (
    _sortBy(valves, 'number')
      .reduce((obj, valve, index) => ({ ...obj, [index]: valve }), {})
  );

  const dataSource = [
    {
      key: 'Вытяжка_Ec',
      workDescription: 'Вытяжка',
      measurementsName: 'electricConduction',
      ...mapValvesToDataSource(valvesByHood)
    },
    {
      key: 'Вытяжка_pH',
      workDescription: 'Вытяжка',
      measurementsName: 'potentialHydrogen',
      ...mapValvesToDataSource(valvesByHood)
    },
    {
      key: 'Дренаж_объём',
      workDescription: 'Дренаж',
      measurementsName: 'volume',
      ...mapValvesToDataSource(valvesByDrainage)
    },
    {
      key: 'Дренаж_Ec',
      workDescription: 'Дренаж',
      measurementsName: 'electricConduction',
      ...mapValvesToDataSource(valvesByDrainage)
    },
    {
      key: 'Дренаж_pH',
      workDescription: 'Дренаж',
      measurementsName: 'potentialHydrogen',
      ...mapValvesToDataSource(valvesByDrainage)
    },
    {
      key: 'Капельница_объём',
      workDescription: 'Капельница',
      measurementsName: 'volume',
      ...mapValvesToDataSource(valvesOnDropper),
    },
    {
      key: 'Капельница_Ec',
      workDescription: 'Капельница',
      measurementsName: 'electricConduction',
      ...mapValvesToDataSource(valvesOnDropper),
    },
    {
      key: 'Капельница_pH',
      workDescription: 'Капельница',
      measurementsName: 'potentialHydrogen',
      ...mapValvesToDataSource(valvesOnDropper),
    },
  ];

  return (
    <TableWrapper
      rowKey="key"
      columns={columns}
      bordered={true}
      dataSource={dataSource}
      loading={isLoading}
      className="isoSimpleTable"
      pagination={false}
    />
  );
}

export default ReferenceBooks;
