import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Link } from "react-router-dom";
import Button from "@iso/components/uielements/button";
import LayoutContentWrapperScrollable from "@iso/components/utility/layoutWrapperScrollable";
import Box from "@iso/components/utility/box";
import planActions from "@iso/redux/plan/actions";
import ContentHolder from "@iso/components/utility/contentHolder";
import Tabs, { TabPane } from "@iso/components/uielements/tabs";
import Modal from "@iso/components/Feedback/Modal";
import { Icon, Input } from "antd";
import InputNumber from "@iso/components/InputNumber";
import _ from "lodash";
import "react-flexbox-grid/dist/react-flexbox-grid.css";
import { Grid, Row, Col } from "react-flexbox-grid";
// import { quarantineRows } from '@iso/config/sections.config';
import ReactJson from "react-json-view";
import Form from "@iso/components/uielements/form";
import Radio, { RadioGroup } from "@iso/components/uielements/radio";
import TemplateEditor from "./TemplateEditor";
import { Button as ButtonAntd } from "antd";
import sectionActions from "@iso/redux/section/actions";

import {
  DateCell,
  ImageCell,
  LinkCell,
  TextCell,
  BlockCell,
} from "@iso/components/Tables/HelperCells";

import {
  PlanSelect,
  TitleWrapper,
  ComponentTitle,
  TableWrapper,
  StatusTag,
} from "./Plan.styles";

import Select, { SelectOption } from "@iso/components/uielements/select";

import moment from "moment-timezone";
import "moment/locale/ru";

moment.updateLocale("ru", { week: { dow: 1 } });

moment.tz.setDefault("Europe/Moscow");

const Option = SelectOption;
const FormItem = Form.Item;

const {
  loadFromAgroInvest,
  setPage,
  // setDay,
  setSection,
  setPass,
  setDetails,
  setTemplate,
  refreshRows,
  selectRows,
  enableRows,
  disableRows,
  deleteRows,
  toggleTemplateViewModal,
  toggleTemplateEditModal,
  setTemplateJson,
  resetTemplateId,
  getSectionsGreenhouse,
  setRows,
} = planActions;

const { getSections } = sectionActions;

export default function Plan(props) {
  const {
    rows,
    isLoading,
    day,
    totalItems,
    shift,
    keepShift,
    pass,
    keepDay,
    exclusive,
    keepExclusive,
    direction,
    keepDirection,
    templates,
    templateId,
    keepTemplate,
    templateViewModal,
    templateJson,
    greenhouseSections,
    planRowFrom,
    planRowTo,
  } = useSelector((state) => state.Plan);
  const { sections } = useSelector((state) => state.Section);
  const { greenhouseId } = useSelector((state) => state.App);

  const {
    blocksPermissions: { plans: plansPermissions },
  } = useSelector((state) => _.get(state, "Auth.userPermissions"));

  const { edit: hasAccessToEdit, sectionsEdit: accessSectionsForEdit } =
    plansPermissions;

  const dispatch = useDispatch();

  const [section, updateSection] = useState({});

  const hasAccessToEditBySectionModule =
    !_.isEmpty(section) &&
    hasAccessToEdit &&
    (!accessSectionsForEdit ||
      _.includes(accessSectionsForEdit, _.get(section, "module")));

  const [dataSource, setDataSource] = useState({});

  React.useEffect(() => {
    if (!_.isEmpty(greenhouseSections)) {
      const localSectionId = localStorage.getItem("sectionId");
      const greenhouseSection = greenhouseSections.find(
        (item) => item.sectionId === localSectionId
      );
      if (greenhouseSection) {
        updateSection(greenhouseSection);
        return;
      }
      updateSection(greenhouseSections[0]);
    } else if (greenhouseSections !== null) {
      updateSection({});
    }
  }, [greenhouseSections]);

  useEffect(() => {
    dispatch(getSections());
  }, [dispatch]);

  useEffect(() => {
    dispatch(resetTemplateId());
    dispatch(refreshRows());
    dispatch(disableRows());
    dispatch(getSectionsGreenhouse());
  }, [dispatch, greenhouseId]);

  useEffect(() => {
    dispatch(resetTemplateId());
    dispatch(loadFromAgroInvest());
  }, [dispatch]);

  const reload = () => {
    dispatch(refreshRows());
    dispatch(loadFromAgroInvest());
  };

  const callEnableRows = () => {
    dispatch(enableRows());
  };

  const callDisableRows = () => {
    dispatch(disableRows());
  };

  const callDeleteRows = () => {
    dispatch(deleteRows());
  };

  const setDetailsForm = (e) => {
    const { name, value } = e.target;

    dispatch(setDetails(name, value));
  };

  const handleSetRows = (e) => {
    const { name, value } = e.target;

    dispatch(setRows(name, value));
  };

  const hanbleTabSelectionsClick = (page) => {
    const lastTaskIndex = tabsSections[page - 1].name.split("-")[1];

    if (rows[lastTaskIndex]) {
      return false;
    }

    if (!_.isNaN(page)) {
      dispatch(setPage(page));
    }
  };

  const handleCallModal = (id) => {
    const json = _.get(
      _.find(templates, (t) => t.id === id),
      "template",
      null
    );

    dispatch(setTemplateJson(json));
  };

  const handleChangeSection = React.useCallback(
    (sectionId) => {
      const newSection = _.find(sections, (item) => item.id === sectionId);
      updateSection({
        title: newSection.name,
        sectionId: newSection.id,
        module: newSection.module,
      });
      dispatch(setSection(sectionId));
      localStorage.setItem("sectionId", sectionId);
    },
    [dispatch, sections]
  );

  const handleChangePass = React.useCallback(
    (pass) => {
      dispatch(setPass(pass));
    },
    [dispatch]
  );

  const getSectionName = (sectionId) => {
    const section = _.find(sections, (section) => section.id === sectionId);
    return section ? section.name : sectionId;
  };

  const tabsSections = [
    {
      name: "Ряды",
      value: [1, 2],
    },
  ];

  React.useEffect(() => {
    if (!_.isEmpty(rows) && !isLoading) {
      let minOrdering = 1;
      let maxOrdering = 2;

      const maxRow = _.maxBy(_.toArray(rows), "orderBy");
      if (maxRow) {
        maxOrdering = maxRow.orderBy;
      }

      const minRow = _.minBy(_.toArray(rows), "orderBy");
      if (minRow) {
        minOrdering = minRow.orderBy;
      }

      if (minOrdering % 2 === 0) {
        minOrdering--;
      }

      const rowSelection = (selectedRowKeys, selectedRows, section) => {
        dispatch(selectRows(section, selectedRows));
      };

      const newData = {
        1: {
          range: _.range(minOrdering, maxOrdering + 1, 2),
          rows: [],
          rowSelection: {
            onChange: (selectedRowKeys, selectedRows) => {
              rowSelection(selectedRowKeys, selectedRows, 1);
            },
          },
        },
        2: {
          range: _.range(minOrdering + 1, maxOrdering + 1, 2),
          rows: [],
          rowSelection: {
            onChange: (selectedRowKeys, selectedRows) => {
              rowSelection(selectedRowKeys, selectedRows, 2);
            },
          },
        },
      };
      _.each(Object.keys(newData), (section) => {
        _.each(newData[section].range, (orderBy) => {
          const row = _.find(rows, (r) => r.orderBy === orderBy);

          newData[section].rows.push({
            id: _.get(row, "id", null),
            key: orderBy,
            orderBy,
            rowNumber: _.get(row, "rowNumber", null),
            greenhouseId: _.get(row, "greenhouseId", null),
            plan: _.get(row, "plan", null),
            templateId: _.get(row, "plan.planTemplateId", null),
            color:
              row && row.plan
                ? row.plan.isActive
                  ? "#90EE90"
                  : "#ddd"
                : "#fff",
          });
        });
      });
      setDataSource(newData);
    } else if (rows !== null && !isLoading) {
      setDataSource({});
    }
  }, [dispatch, isLoading, rows]);

  const renderCell = (object, type, key) => {
    const value = object[key];

    const isEmptyObject = _.isNil(object.rowNumber);

    switch (type) {
      case "ImageCell":
        return ImageCell(value);
      case "DateCell":
        return DateCell(value);
      case "LinkCell":
        return LinkCell(value);
      case "RowNumberCell":
        let dow = "N/A";
        if (object.plan) {
          switch (object.plan.dow) {
            case 0:
              dow = "ПН";
              break;
            case 1:
              dow = "ВТ";
              break;
            case 2:
              dow = "СР";
              break;
            case 3:
              dow = "ЧТ";
              break;
            case 4:
              dow = "ПТ";
              break;
            case 5:
              dow = "СБ";
              break;
            case 6:
              dow = "ВС";
              break;
            default:
              break;
          }
        }

        return BlockCell(
          !isEmptyObject && (
            <>
              <h2 style={{ fontSize: 26 }}>Ряд {value}</h2>
              <br />
              <StatusTag
                className={
                  object.plan ? `dowNumber-${object.plan.dow}` : "dowNumber"
                }
              >
                {dow}
              </StatusTag>
            </>
          )
        );
      case "InfoCell":
        return BlockCell(
          !isEmptyObject ? (
            <div style={{ height: 110 }}>
              <h2>
                {value ? getSectionName(value.sectionId) : "-- Не назначено --"}
              </h2>
              <br />
              {value ? (
                <>
                  <StatusTag className="info">
                    {value.shift}&nbsp;
                    <Icon type={value.direction ? "arrow-down" : "arrow-up"} />
                  </StatusTag>
                  <StatusTag
                    className={"rowNumberExclusive-" + value.exclusive}
                  >
                    Группа: {value.exclusive}
                  </StatusTag>
                  <StatusTag className="warning">
                    Проход: {value.pass + 1}
                  </StatusTag>
                  <ButtonAntd type="link">
                    <Link to={`/dashboard/audit/${value.id}`}>
                      <Icon type="history" />
                    </Link>
                  </ButtonAntd>
                </>
              ) : null}
              <br />
              {value ? (
                <ButtonAntd
                  type="link"
                  onClick={() => handleCallModal(value.planTemplateId)}
                >
                  {_.get(
                    _.find(templates, (t) => t.id === value.planTemplateId),
                    "name",
                    null
                  )}
                </ButtonAntd>
              ) : (
                <h1>-- Шаблон не назначен --</h1>
              )}
            </div>
          ) : (
            <div style={{ minHeight: 110 }} />
          )
        );
      case "TemplateCell":
        return BlockCell(
          !isEmptyObject ? (
            <>
              {value ? (
                <button onClick={() => handleCallModal(value)}>
                  {_.get(
                    _.find(templates, (t) => t.id === value),
                    "name",
                    null
                  )}
                </button>
              ) : (
                "-- Шаблон не назначен --"
              )}
            </>
          ) : null
        );
      default:
        return TextCell(value);
    }
  };

  const columnsLeft = [
    {
      title: "Ряд",
      key: "row",
      align: "center",
      width: 100,
      render: (object) => {
        return {
          props: {
            style: { background: object.color },
          },
          children: renderCell(object, "RowNumberCell", "rowNumber"),
        };
      },
    },
    {
      title: "Информация",
      key: "info",
      align: "center",
      render: (object) => {
        return {
          props: {
            style: { background: object.color },
          },
          children: renderCell(object, "InfoCell", "plan"),
        };
      },
    },
  ];

  const columnsRight = [
    {
      title: "Ряд",
      key: "row",
      align: "center",
      width: 100,
      render: (object) => {
        return {
          props: {
            style: { background: object.color },
          },
          children: renderCell(object, "RowNumberCell", "rowNumber"),
        };
      },
    },
    {
      title: "Информация",
      key: "info",
      align: "center",
      render: (object) => {
        return {
          props: {
            style: { background: object.color },
          },
          children: renderCell(object, "InfoCell", "plan"),
        };
      },
    },
  ];

  const margin = {
    margin: "0 0 8px 8px",
  };

  const operations = (
    <>
      <Button
        type="primary"
        disabled={!hasAccessToEditBySectionModule}
        style={margin}
        onClick={callEnableRows}
      >
        Сделать активным
      </Button>
      <Button
        type="danger"
        disabled={!hasAccessToEditBySectionModule}
        style={margin}
        onClick={callDisableRows}
      >
        Сделать неактивным
      </Button>
      <Button
        type="danger"
        disabled={!hasAccessToEditBySectionModule}
        style={margin}
        onClick={callDeleteRows}
      >
        Удалить план
      </Button>
      <Button
        type="primary"
        style={{ margin: "0 0 8px 32px" }}
        onClick={() => dispatch(toggleTemplateEditModal(true))}
        disabled={!hasAccessToEditBySectionModule}
      >
        Редактор шаблонов
      </Button>
    </>
  );

  const planContent = !isLoading ? (
    <Tabs
      defaultActiveKey="1"
      tabBarExtraContent={operations}
      onTabClick={(e) => e <= 6 && hanbleTabSelectionsClick(e)}
    >
      {_.map(tabsSections, (rows, key) => (
        <TabPane
          tab={
            <span>
              <Icon type="arrow-down" />
              {rows.name}
            </span>
          }
          key={key + 1}
        >
          <Grid fluid>
            <Row>
              <Col xs={12} md={6}>
                <TableWrapper
                  rowSelection={_.get(
                    dataSource,
                    "[2].rowSelection",
                    undefined
                  )}
                  pagination={false}
                  columns={columnsRight}
                  dataSource={_.get(dataSource, "[2].rows", undefined)}
                  className="isoSimpleTable"
                />
              </Col>
              <Col xs={12} md={6}>
                <TableWrapper
                  rowSelection={_.get(
                    dataSource,
                    "[1].rowSelection",
                    undefined
                  )}
                  pagination={false}
                  columns={columnsLeft}
                  dataSource={_.get(dataSource, "[1].rows", undefined)}
                  className="isoSimpleTable"
                />
              </Col>
            </Row>
          </Grid>
        </TabPane>
      ))}

      <TabPane
        tab={
          <span>
            <Icon type="audit" />
            Детали
          </span>
        }
        key="8"
      >
        <Form>
          <FormItem label="Сохранить день" hasFeedback>
            <RadioGroup
              onChange={setDetailsForm}
              name="keepDay"
              value={keepDay}
            >
              <Radio value={true}>Да</Radio>
              <Radio value={false}>Нет</Radio>
            </RadioGroup>
          </FormItem>
          <FormItem label="День недели" hasFeedback>
            <RadioGroup
              onChange={setDetailsForm}
              name="day"
              value={day}
              disabled={keepDay}
            >
              <Radio value={0}>ПН</Radio>
              <Radio value={1}>ВТ</Radio>
              <Radio value={2}>СР</Radio>
              <Radio value={3}>ЧТ</Radio>
              <Radio value={4}>ПТ</Radio>
              <Radio value={5}>СБ</Radio>
              <Radio value={6}>ВС</Radio>
            </RadioGroup>
          </FormItem>
          <FormItem label="Сохранить порядок" hasFeedback>
            <RadioGroup
              onChange={setDetailsForm}
              name="keepShift"
              value={keepShift}
            >
              <Radio value={true}>Да</Radio>
              <Radio value={false}>Нет</Radio>
            </RadioGroup>
          </FormItem>
          <FormItem label="Порядок выполнения" hasFeedback>
            <RadioGroup
              onChange={setDetailsForm}
              name="shift"
              value={shift}
              disabled={keepShift}
            >
              <Radio value={0}>0</Radio>
              <Radio value={1}>1</Radio>
              <Radio value={2}>2</Radio>
              <Radio value={3}>3</Radio>
              <Radio value={4}>4</Radio>
              <Radio value={5}>5</Radio>
              <Radio value={6}>6</Radio>
              <Radio value={7}>7</Radio>
              <Radio value={8}>8</Radio>
              <Radio value={9}>9</Radio>
            </RadioGroup>
          </FormItem>
          <FormItem label="Сохранить группу" hasFeedback>
            <RadioGroup
              onChange={setDetailsForm}
              name="keepExclusive"
              value={keepExclusive}
            >
              <Radio value={true}>Да</Radio>
              <Radio value={false}>Нет</Radio>
            </RadioGroup>
          </FormItem>
          <FormItem label="Группа" hasFeedback>
            <InputNumber
              name="exclusive"
              min={0}
              max={999}
              style={{ width: 200 }}
              disabled={keepExclusive}
              value={exclusive}
              onChange={setDetailsForm}
            />
          </FormItem>
          <FormItem label="Сохранить направление" hasFeedback>
            <RadioGroup
              onChange={setDetailsForm}
              name="keepDirection"
              value={keepDirection}
            >
              <Radio value={true}>Да</Radio>
              <Radio value={false}>Нет</Radio>
            </RadioGroup>
          </FormItem>
          <FormItem label="Направление" hasFeedback>
            <RadioGroup
              onChange={setDetailsForm}
              name="direction"
              value={direction}
              disabled={keepDirection}
            >
              <Radio value={1}>Прямое</Radio>
              <Radio value={0}>Обратное</Radio>
            </RadioGroup>
          </FormItem>

          <FormItem label="Сохранить шаблон" hasFeedback>
            <RadioGroup
              onChange={setDetailsForm}
              name="keepTemplate"
              value={keepTemplate}
            >
              <Radio value={true}>Да</Radio>
              <Radio value={false}>Нет</Radio>
            </RadioGroup>
          </FormItem>
          <FormItem label="Шаблон" hasFeedback>
            <PlanSelect
              dropdownMatchSelectWidth={false}
              value={templateId || undefined}
              placeholder={
                _.isEmpty(templates) ? "Шаблоны не найдены" : "Выберите шаблон"
              }
              onChange={(id) => dispatch(setTemplate(id))}
              disabled={keepTemplate}
            >
              {_.map(templates, (t) => (
                <Option value={t.id} key={t.id}>
                  {" "}
                  {t.name}{" "}
                </Option>
              ))}
            </PlanSelect>
          </FormItem>
        </Form>
      </TabPane>
    </Tabs>
  ) : null;

  return (
    <LayoutContentWrapperScrollable>
      <Box>
        <ContentHolder style={{ marginTop: 0, overflow: "hidden" }}>
          <TitleWrapper>
            <ComponentTitle>
              Вид работ: &nbsp;
              <Select
                dropdownMatchSelectWidth={false}
                // defaultValue={_.get(greenhouseSections, '[0].name', 'Выберите вид работ')}
                value={section.sectionId}
                onChange={handleChangeSection}
              >
                {_.map(_.sortBy(greenhouseSections, ["name"]), (g) => (
                  <Option value={g.sectionId} key={g.sectionId}>
                    {" "}
                    {g.name}{" "}
                  </Option>
                ))}
              </Select>
              &nbsp; Ряд: &nbsp;
              <Input
                style={{ width: 50 }}
                placeholder="От"
                name="planRowFrom"
                defaultValue={planRowFrom}
                onBlur={(e) => handleSetRows(e)}
              />
              &nbsp; &mdash; &nbsp;
              <Input
                style={{ width: 50 }}
                placeholder="До"
                name="planRowTo"
                defaultValue={planRowTo}
                onBlur={(e) => handleSetRows(e)}
              />
              &nbsp; Проход: &nbsp;
              <Select
                dropdownMatchSelectWidth={false}
                defaultValue={pass}
                onChange={handleChangePass}
              >
                <Option value={0}>1</Option>
                <Option value={1}>2</Option>
                <Option value={2}>3</Option>
                <Option value={3}>4</Option>
                <Option value={4}>5</Option>
                <Option value={5}>6</Option>
                <Option value={6}>7</Option>
                <Option value={7}>8</Option>
                <Option value={8}>9</Option>
                <Option value={9}>10</Option>
                <Option value={10}>11</Option>
                <Option value={11}>12</Option>
                <Option value={12}>13</Option>
                <Option value={13}>14</Option>
                <Option value={14}>15</Option>
                <Option value={15}>16</Option>
              </Select>
              <br />
              <small> Всего найдено: {totalItems || 0}</small>
            </ComponentTitle>

            <Button
              type="primary"
              shape="circle"
              loading={isLoading}
              icon="reload"
              onClick={reload}
            />
          </TitleWrapper>

          <Modal
            visible={templateViewModal}
            onCancel={() => dispatch(toggleTemplateViewModal(false))}
            title="Шаблон"
            footer={null}
          >
            <ReactJson
              src={templateJson}
              theme="monokai"
              collapsed={false}
              enableClipboard={true}
            />
          </Modal>

          <TemplateEditor />
        </ContentHolder>

        {planContent}
      </Box>
    </LayoutContentWrapperScrollable>
  );
}
