import styled from 'styled-components';
import { palette } from 'styled-theme';
import Table from '../Tables/AntTables/AntTables.styles';
import { Select } from 'antd'

const PlanSelect = styled(Select)`
  width: fit-content !important;
  min-width: 200px;

  .ant-select-selection-selected-value {
    margin-right: 10px;
  }
`;

const TitleWrapper = styled.div`
  display: flex;
  justify-content: space-between;
  margin-bottom: 20px;
  flex-wrap: wrap;
  align-items: center;
`;

const ComponentTitle = styled.h3`
  font-size: 16px;
  font-weight: 500;
  color: ${palette('text', 0)};
  margin: 5px 0;
`;

const TableWrapper = styled(Table)`
  .ant-table-bordered .ant-table-thead > tr > th,
  .ant-table-bordered .ant-table-tbody > tr > td {
    white-space: normal;
    &.noWrapCell {
      white-space: nowrap;
    }

    @media only screen and (max-width: 920px) {
      white-space: nowrap;
    }
  }
`;

const StatusTag = styled.span`
  padding: 0 5px;
  height: 20px;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  border-radius: 2px;
  background-color: ${palette('primary', 0)};
  font-size: 12px;
  color: #ffffff;
  text-transform: capitalize;

  &.success {
    background-color: ${palette('success', 0)};
  }

  &.warning {
    background-color: ${palette('warning', 0)};
  }

  &.info {
    background-color: ${palette('info', 0)};
  }

  &.error {
    background-color: ${palette('error', 0)};
  }

  &.rowNumber {
    background-color: ${palette('info', 0)};
  }

  &.dowNumber {
    background-color: black;
    color: white;
  }

  &.dowNumber-0 {
    background-color: red;
    color: white;
  }

  &.dowNumber-1 {
    background-color: orange;
    color: white;
  }

  &.dowNumber-2 {
    background-color: yellow;
    color: black;
  }

  &.dowNumber-3 {
    background-color: green;
    color: white;
  }

  &.dowNumber-4 {
    background-color: light-blue;
    color: white;
  }

  &.dowNumber-5 {
    background-color: blue;
    color: white;
  }

  &.dowNumber-6 {
    background-color: violet;
    color: black;
  }

  &.rowNumberQuarantine {
    background-color: ${palette('error', 0)};
  }

  &.rowNumberExclusive {
    background-color: ${palette('warning', 0)};
    margin: 0 10px;
  }

  &.rowNumberExclusive-0 {
    background-color: #d64161;
    color: #ffffff;
    margin: 0 10px;
  }

  &.rowNumberExclusive-1 {
    background-color: #ff7b25;
    color: #ffffff;
    margin: 0 10px;
  }

  &.rowNumberExclusive-2 {
    background-color: #6b5b95;
    color: #ffffff;
    margin: 0 10px;
  }

  &.rowNumberExclusive-3 {
    background-color: #feb236;
    color: #000000;
    margin: 0 10px;
  }

  &.rowNumberExclusive-4 {
    background-color: #3e4444;
    color: #ffffff;
    margin: 0 10px;
  }

  &.rowNumberExclusive-5 {
    background-color: #82b74b;
    color: #ffffff;
    margin: 0 10px;
  }

  &.rowNumberExclusive-6 {
    margin: 0 10px;
  }

  &.rowNumberExclusive-7 {
    margin: 0 10px;
  }

  &.rowNumberExclusive-8 {
    margin: 0 10px;
  }

  &.rowNumberExclusive-9 {
    margin: 0 10px;
  }
`;

const Fieldset = styled.div`
  width: 100%;
  display: flex;
  flex-direction: column;
  margin-bottom: 20px;

  &:last-child {
    margin-bottom: 0;
  }
`;

export {
  PlanSelect,
  TitleWrapper,
  ComponentTitle,
  TableWrapper,
  StatusTag,
  Fieldset,
};
