import React, { useState, useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';

import Modal from '@iso/components/Feedback/Modal';
import Form from '@iso/components/uielements/form';
import Select, { SelectOption } from '@iso/components/uielements/select';
import { Input, Button } from 'antd';

import planActions from '@iso/redux/plan/actions';

import _ from 'lodash';

import {
  Fieldset,
} from './Plan.styles';

const TemplateEditor = () => {
  const dispatch = useDispatch();

  const FormItem = Form.Item;
  const TextArea = Input.TextArea;

  const {
    templateEditModal,
  } = useSelector(
    state => state.Plan,
  );

  const {
    greenhouseId,
    templates,
    templateEdit,
    isLoadingTemplates,
    isSavingTemplate
  } = useSelector(
    state => state.Plan.templateEditing,
  );

  const {
    allowedGreenhouses,
  } = useSelector(
    state => state.App
  )

  const {
    toggleTemplateEditModal,
    setTemplateEditingOptions,
    loadTemplatesFromAgroInvest,
    saveTemplateIntoAgroInvest,
    setTemplateEdit,
    setDefaultTemplateFields,
  } = planActions;

  useEffect(() => {
    setCurrentTemplate({})
    dispatch(loadTemplatesFromAgroInvest())
  }, [dispatch, loadTemplatesFromAgroInvest])

  const [currentTemplate, setCurrentTemplate] = useState({
    name: null,
    template: null,
  })

  const handleSetOption = (field, value) => {
    console.log(field, value)
    setCurrentTemplate({})
    dispatch(setTemplateEditingOptions(field, value))

    dispatch(loadTemplatesFromAgroInvest())
  };

  const handleSetTemplate = (value) => {
    const template = _.find(templates, t => t.id === value)
    if (template) {
      setCurrentTemplate({
        name: template.name,
        template: JSON.stringify(template.template, null, '  ')
      })
      dispatch(setTemplateEdit(template))
    }
  }

  const createTemplate = () => {
    if (_.isEmpty(templateEdit) || templateEdit.id) {
      setCurrentTemplate({})
      dispatch(setDefaultTemplateFields())
    }
  }

  const generateSaveButton = () => {
    return (
      !_.isEmpty(templateEdit)
        ? [<Button
          type='primary'
          key='submit'
          loading={isSavingTemplate}
          onClick={() => dispatch(saveTemplateIntoAgroInvest(currentTemplate))}
        >Сохранить</Button>]
        : null
    )
  }

  return (
    <Modal
      visible={templateEditModal}
      onCancel={() => dispatch(toggleTemplateEditModal(false))}
      footer={generateSaveButton()}
    >
      <Form>
        <Fieldset>
          <FormItem label="Теплица" hasFeedback>
            <Select
              size="large"
              dropdownMatchSelectWidth={false}
              value={greenhouseId || undefined}
              placeholder='Выберите теплицу'
              onChange={(value) => handleSetOption('greenhouseId', value)}
            >
              {
                _.map(allowedGreenhouses, g => <SelectOption value={g.id} key={g.id}>{g.description}</SelectOption>)
              }
            </Select>
          </FormItem>
          {greenhouseId && <FormItem label="Шаблон" hasFeedback>
            <Select
              style={{ display: 'inline-block', width: 'calc(100% - 50px)', marginRight: '18px' }}
              size="large"
              dropdownMatchSelectWidth={false}
              placeholder={_.isEmpty(templates) ? isLoadingTemplates ? 'Загрузка' : 'Шаблоны не найдены' : 'Выберите шаблон'}
              value={_.get(_.find(templates, t => t.id === templateEdit.id), 'name', undefined)}
              loading={isLoadingTemplates}
              onChange={handleSetTemplate}
            >
              {
                _.map(templates, t => <SelectOption value={t.id} key={t.id}>{t.name}</SelectOption>)
              }
            </Select>
            <Button type="primary" icon="plus" onClick={createTemplate} />
          </FormItem>}
          {!_.isEmpty(templateEdit) && (<>
            <h2 style={{ marginTop: '20px' }}>Введите параметры:</h2>
            <FormItem label="Имя" hasFeedback>
              <Input
                placeholder="Имя"
                value={currentTemplate.name}
                onChange={({ target: { value } }) => setCurrentTemplate({ ...currentTemplate, name: value })}
              />
            </FormItem>
            <FormItem label="JSON" hasFeedback>
              <TextArea
                rows='10'
                value={currentTemplate.template}
                onChange={({ target: { value } }) => setCurrentTemplate({ ...currentTemplate, template: value })}
              />
            </FormItem>
          </>)}
        </Fieldset>
      </Form>
    </Modal>
  )
}

export default TemplateEditor
