import React, { useEffect, useState, useCallback, useMemo } from "react";
import { useDispatch, useSelector } from "react-redux";
import { useRouteMatch } from "react-router-dom";

import _ from "lodash";
import ReactJson from "react-json-view";

import planActions from "@iso/redux/plan/actions";

import LayoutContentWrapper from "@iso/components/utility/layoutWrapper";
import Box from "@iso/components/utility/box";
import ContentHolder from "@iso/components/utility/contentHolder";
import Modal from "@iso/components/Feedback/Modal";

import {
  TableWrapper,
  ComponentTitle,
  TitleWrapper,
  StatusTag
} from "./PlanHistory.styles";

export default function PlanHistory() {
  const match = useRouteMatch();
  const dispatch = useDispatch();

  const plan = useSelector((state) => _.get(state, "Plan", null));

  const { plans } = plan

  const planId = useMemo(() => _.get(match, "params.id", null), [
    match,
  ]);

  const [jsonData, setJsonData] = useState(null);
  const [modalJson, setModalJson] = useState(false);

  useEffect(() => {
    if (planId) {
      dispatch(planActions.getId(planId));
    }
    return () => {
      setJsonData(null);
      setModalJson(false);
    };
  }, [dispatch, planId]);

  const dataSource = [];
  Object.keys(plans).map((plan, index) => {
    return dataSource.push({
      ...plans[plan],
      key: plan,
    });
  })

  const totalPlans = useMemo(() => !!_.size(plans) && plans.length, [plans]);

  const onModalViewJson = useCallback(() => setModalJson((prev) => !prev), []);

  const getViewColumn = useCallback(
    (value) =>
      value ? (
        <button
          onClick={() => {
            onModalViewJson();
            setJsonData(value);
          }}
        >
          Показать
        </button>
      ) : (
        ""
      ),
    [onModalViewJson]
  );

  const columns = [
    {
      title: "id",
      dataINdex: "id",
      key: "id",
      render: (text, row) => {
          console.log('row', row)
        return row.id;
      },
    },
    {
      title: 'Ряд',
      dataIndex: "rowId",
      key: "rowId",
      render: (text, row) => {
        return getViewColumn(row.row);
      },
    },
    {
      title: 'Секции',
      dataIndex: 'sectionId',
      key: 'sectionId',
      render: (text, row) => {
        return getViewColumn(row.section)
      }
    },
    {
      title: 'Статус',
      dataIndex: 'isActive',
      key: 'isActive',
      render: (text, row) => {
        const isActive = _.get(row, 'isActive', false)
        return <StatusTag className={isActive ? 'active' : 'inactive'}>
          {isActive ? 'Активный' : 'Отключен'}
        </StatusTag>
      }
    },
    {
      title: 'Dow',
      dataIndex: 'dow',
      key: 'dow',
      render: (text, row) => {
        return row.dow
      }
    },
    {
      title: 'Exclusive',
      dataIndex: 'exclusive',
      key: 'exclusive',
      render: (text, row) => {
        return row.exclusive
      }
    },
    {
      title: 'Direction',
      dataIndex: 'direction',
      key: 'direction',
      render: (text, row) => {
        return row.direction
      }
    },
    {
      title: 'Shift',
      dataIndex: 'shift',
      key: 'shift',
      render: (text, row) => {
        return row.shift
      }
    },
    {
      title: 'Шаблон плана',
      dataIndex: 'planTemplateId',
      key: 'planTemplateId',
      render: (text, row) => {
        return getViewColumn(row.planTemplate)
      }
    },
    {
      title: 'Pass',
      dataIndex: 'pass',
      key: 'pass',
      render: (text, row) => {
        return row.pass
      }
    }
  ];

  return (
    <LayoutContentWrapper>
      <Box>
        <ContentHolder style={{ marginTop: 0, overflow: "hidden" }}>
          <TitleWrapper>
            <ComponentTitle>
              История планов <small>всего найдено: {totalPlans}</small>
            </ComponentTitle>
          </TitleWrapper>
          <Modal
            visible={modalJson}
            title="Данные из JSON"
            onCancel={onModalViewJson}
            onOk={onModalViewJson}
          >
            {jsonData && (
              <ReactJson
                src={jsonData}
                theme="monokai"
                collapsed={false}
                enableClipboard={true}
              />
            )}
          </Modal>
          <TableWrapper
            rowKey="key"
            columns={columns}
            bordered={true}
            dataSource={dataSource}
            className="isoSimpleTable"
            pagination={false}
          />
        </ContentHolder>
      </Box>
    </LayoutContentWrapper>
  );
}
