import React, { useState, useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";

import plantProtectionActions from "@iso/redux/plantProtection/actions";

import Button from "@iso/components/uielements/button";
import { Grid } from "react-flexbox-grid";
import Modal from "@iso/components/Feedback/Modal";
import { FilterDropdown } from "@iso/components/Tables/HelperCells";
import { Icon } from "antd";
import Form from "@iso/components/uielements/form";
import Input from "@iso/components/uielements/input";
import Switch from "@iso/components/uielements/switch";

import {
  TitleWrapper,
  ComponentTitle,
  TableWrapper,
  StatusTag,
  Fieldset,
  ActionWrapper,
} from "./PlantProtection.styles";

import _ from "lodash";

import Select, { SelectOption } from "@iso/components/uielements/select";
const FormItem = Form.Item;

const Option = SelectOption;

const pestTypes = ["cucumber", "tomato"];

const DeseasesAndPests = () => {
  const [pageData, setPageData] = useState(null);
  const [selectedPestType, setSelectedPestType] = useState(pestTypes[0]);
  const [modalName, setModalName] = useState("");
  const [modalStatus, setModalStatus] = useState("");

  const {
    pest,
    pests,
    isLoading,
    modalActive,
    filters,
    page,
    totalItems,
    itemsPerPage,
  } = useSelector((state) => state.PlantProtection);

  const {
    blocksPermissions: { ["plant-protection"]: plantProtectionPermissions },
  } = useSelector((state) => _.get(state, "Auth.userPermissions"));

  const {
    ["diseases-and-pests"]: { edit: hasAccessToEdit },
  } = plantProtectionPermissions.blocks;

  const dispatch = useDispatch();

  const onInputChange = (key, value) => {
    setState({ ...state, [key]: value });
  };

  const [state, setState] = React.useState({
    searchPestName: "",
    filterPestNameDropdownVisible: false,
  });

  const onInputChangeThrottled = _.throttle(
    (key, value) => onInputChange(key, value),
    500,
    {
      leading: false,
    }
  );

  const onSearch = () => {
    let { searchPestName } = state;

    const newFilters = _.cloneDeep(filters);
    newFilters.name = searchPestName;

    dispatch(setFilters(newFilters, 1));
  };

  const dropFilters = () => {
    dispatch(setFilters({}, 1));
  };

  const handleTableChange = (pagination, newFilters, sorter) => {
    newFilters.name = filters.name;

    dispatch(setFilters(newFilters, pagination.current));
  };

  const {
    loadFromAgroInvest,
    toggleModal,
    rowsLoadFromAgroInvest,
    saveIntoAgroInvest,
    update,
    deletePest,
    setFilters,
  } = plantProtectionActions;

  React.useEffect(() => {
    dispatch(loadFromAgroInvest());
  }, [dispatch, loadFromAgroInvest]);

  useEffect(() => {
    pests && setPageData(pests);
  }, [pests]);

  const handleModal = async (pest = null) => {
    if (pest) {
      setModalName(pest.name);
      setModalStatus(pest.isActive);
    } else {
      setModalName("");
      setModalStatus(true);
    }
    await dispatch(toggleModal(pest));
    dispatch(rowsLoadFromAgroInvest());
  };

  const handlePests = (pest) => {
    dispatch(deletePest(pest));
  };

  const pestUpdate = (key, value) => {
    if (key) pest[key] = value;
    dispatch(update(pest));
  };

  const handleRecord = (actionName, pest) => {
    pestUpdate("name", modalName);
    pestUpdate("isActive", modalStatus);
    pestUpdate("type", selectedPestType);
    dispatch(saveIntoAgroInvest(pest, actionName));
  };

  const generateActionButtons = (row) => {
    return (
      <ActionWrapper>
        {hasAccessToEdit ? (
          <a onClick={() => handleModal(row)} href="# ">
            <i className="ion-android-create" />
          </a>
        ) : (
          <a disabled href="# " style={{ opacity: 0.3 }}>
            <i className="ion-android-create" />
          </a>
        )}
      </ActionWrapper>
    );
  };

  const columnLeft = [
    {
      title: "Названия",
      dataIndex: "pest",
      key: "pest",
      filterDropdown: (
        <FilterDropdown
          searchText=""
          onInputChange={({ target: { value } }) =>
            onInputChangeThrottled("searchPestName", value)
          }
          onSearch={onSearch}
        />
      ),
      filterIcon: (
        <Icon
          type="search"
          style={{ color: filters.name ? "#108ee9" : "#aaa" }}
        />
      ),
      filterDropdownVisible: state.filterPestNameDropdownVisible,
      onFilterDropdownVisibleChange: (visible) => {
        setState({ ...state, filterPestNameDropdownVisible: visible });
        document.getElementById("tableFilterInput").focus();
      },
      render: (text, row) => {
        return row.name;
      },
    },
    {
      title: "Тип",
      dataIndex: "type",
      key: "type",
      width: "100px",
      filters: [
        {
          text: "Огурец",
          value: "cucumber",
        },
        {
          text: "Томат",
          value: "tomato",
        },
      ],
      filteredValue: filters["type"] || [],
      filterMultiple: false,
      render: (text, row) => {
        return (
          <StatusTag className={row.type}>
            {row.type === "cucumber" ? "Огурец" : "Томат"}
          </StatusTag>
        );
      },
    },
    {
      title: "Статус",
      key: "isActive",
      width: "100px",
      className: "noWrapCell",
      render: (text, row) => {
        return (
          <StatusTag className={row.isActive ? 'active' : 'inactive'}>
             {row.isActive ? 'Активно' : 'Не активно'}
          </StatusTag>
        );
      },
    },
    {
      title: "Изменить",
      key: "change",
      width: "60px",
      className: "noWrapCell",
      render: (text, row) => {
        return generateActionButtons(row);
      },
    },
    {
      title: "Удалить",
      key: "delete",
      width: "60px",
      className: "noWrapCell",
      render: (text, row) => {
        return hasAccessToEdit ? (
          <a onClick={() => handlePests(row)} href="# ">
            X
          </a>
        ) : (
          <a disabled style={{ opacity: 0.3 }} href="# ">
            X
          </a>
        );
      },
    },
  ];

  return (
    <>
      <TitleWrapper>
        <ComponentTitle>Болезни и вредители томатов и огурцов</ComponentTitle>
        <div>
          <Button
            type="primary"
            shape="circle"
            loading={isLoading}
            disabled={!hasAccessToEdit}
            icon="plus"
            onClick={() => handleModal()}
            style={{ marginLeft: "10px" }}
          />
        </div>
      </TitleWrapper>
      <Grid fluid>
        {pageData && (
          <TableWrapper
            rowKey="name"
            columns={columnLeft}
            bordered={true}
            onChange={handleTableChange}
            loading={isLoading}
            dataSource={pageData}
            className="isoSimpleTable"
            pagination={{
              defaultPageSize: itemsPerPage,
              hideOnSinglePage: true,
              total: totalItems,
              current: page,
            }}
          />
        )}
      </Grid>

      <Modal
        visible={modalActive}
        onClose={() => dispatch(toggleModal(null))}
        title={
          <>
            {pest.id ? `Изменить параметр "${pest.name}"` : "Добавить"}
            <br />
            <small>{pest.id ? pest.id : "n/a"}</small>
          </>
        }
        okText={"Сохранить"}
        onOk={() => handleRecord("PATCH", pest)}
        onCancel={() => dispatch(toggleModal(null))}
        okButtonProps={{ disabled: !hasAccessToEdit }}
        cancelButtonProps={{ disabled: false }}
      >
        <Form>
          <Fieldset>
            <FormItem label="Название" hasFeedback>
              <Input
                placeholder="Название"
                value={modalName}
                onChange={(e) => setModalName(e.target.value)}
              />
            </FormItem>
            <FormItem label="Тип" hasFeedback>
              <Select
                dropdownMatchSelectWidth={false}
                defaultValue={pestTypes[0]}
                value={selectedPestType || "Ничего не выбрано"}
                onChange={setSelectedPestType}
              >
                {_.map(pestTypes, (t) => (
                  <Option value={t} key={t}>
                    {t === "cucumber" ? "Огурец" : "Томат"}
                  </Option>
                ))}
              </Select>
            </FormItem >
          </Fieldset>
          <Fieldset>
            <FormItem
              label={
                <>
                  Статус
                  <StatusTag
                    className={modalStatus ? 'active' : 'inactive'}
                  >
                    {modalStatus ? 'активный' : 'не активный'}
                  </StatusTag>
                </>
              }
              hasFeedback
            >
              <Switch
                checked={modalStatus}
                onChange={(isValue) => setModalStatus(isValue)}
              />
            </FormItem>
          </Fieldset>
        </Form>
      </Modal>
    </>
  );
};

export default DeseasesAndPests;
