import React, { useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Grid } from "react-flexbox-grid";
import Switch from "@iso/components/uielements/switch";
import Modal from "@iso/components/Feedback/Modal";
import Form from "@iso/components/uielements/form";
import Input from "@iso/components/uielements/input";
import {
  TableWrapper,
  ActionWrapper,
  StatusTag,
  Fieldset,
} from "./PlantProtection.styles";
import actions from "../../redux/plantProtection/actions";
import FormItem from "antd/lib/form/FormItem";
import cn from "classnames";

const Status = ({ isActive }) => (
  <StatusTag className={cn({ active: isActive, inactive: !isActive })}>
    {isActive ? "активный" : "не активный"}
  </StatusTag>
);

const ListOfWorks = () => {
  const works = useSelector((state) => state.PlantProtection.works);
  const dispatch = useDispatch();
  const { deleteWork, updateWork } = actions;

  const [modalActive, setModalActive] = useState(false);
  const [modalWork, setModalWork] = useState({});

  const handleModal = (work) => {
    setModalWork(work);
    setModalActive(true);
  };
  const handleDelete = (work) => {
    dispatch(deleteWork(work));
  };

  const handleUpdate = (work) => {
    dispatch(updateWork(work));
  };
  const columnsListOfWorks = [
    {
      title: "Названия",
      key: "works",
      render: (text, row) => {
        return row.name;
      },
    },
    {
      title: "Статус",
      key: "isActive",
      width: "100px",
      className: "noWrapCell",
      render: (text, row) => <Status isActive={row.isActive} />,
    },
    {
      title: "Изменить",
      key: "change",
      width: "60px",
      className: "noWrapCell",
      render: (text, row) => {
        return (
          <ActionWrapper>
            <a onClick={() => handleModal(row)} href="# ">
              <i className="ion-android-create" />
            </a>
          </ActionWrapper>
        );
      },
    },
    {
      title: "Удалить",
      key: "delete",
      width: "60px",
      className: "noWrapCell",
      render: (text, row) => {
        return (
          <a onClick={() => handleDelete(row)} href="# ">
            X
          </a>
        );
      },
    },
  ];

  return (
    <>
      <Modal
        visible={modalActive}
        onClose={() => setModalActive(false)}
        title={
          <>
            <br />
            <small>{"Вид работ"}</small>
          </>
        }
        okText={"Сохранить"}
        onOk={() => {
          handleUpdate(modalWork);
          setModalActive(false);
        }}
        onCancel={() => setModalActive(false)}
        okButtonProps={{ disabled: false }}
        cancelButtonProps={{ disabled: false }}
      >
        <Form>
          <Fieldset>
            <FormItem label="Название" hasFeedback>
              <Input
                placeholder="Название"
                value={modalWork.name}
                onChange={(e) =>
                  setModalWork({ ...modalWork, name: e.target.value })
                }
              />
            </FormItem>
          </Fieldset>
          <Fieldset>
            <FormItem
              label={
                <>
                  Статус
                  <Status isActive={modalWork.isActive} />
                </>
              }
              hasFeedback
            >
              <Switch
                checked={modalWork.isActive}
                onChange={(isValue) => {
                  setModalWork({ ...modalWork, isActive: isValue });
                }}
              />
            </FormItem>
          </Fieldset>
        </Form>
      </Modal>
      <Grid fluid>
        <TableWrapper
          rowKey="name"
          columns={columnsListOfWorks}
          bordered={true}
          dataSource={works}
          className="isoSimpleTable"
          pagination={{
            hideOnSinglePage: true,
            total: works.length,
          }}
        />
      </Grid>
    </>
  );
};

export default ListOfWorks;
