import React, { useState, useEffect } from "react";
import { useSelector } from "react-redux";

import { TitleWrapper, ComponentTitle } from "./PlantProtection.styles";

import _ from "lodash";
import LayoutContentWrapper from "@iso/components/utility/layoutWrapper";
import Box from "@iso/components/utility/box";
import ContentHolder from "@iso/components/utility/contentHolder";
import DeseasesAndPests from "./DeseasesAndPests";
import MonitoringInfo from "@iso/containers/MonitoringInfo/MonitoringInfo";
import IntensityInterface from "./IntensityInterface";
import MonitoringGraph from "@iso/containers/MonitoringGraph/MonitoringGraph";
import IntensityDescriptions from "../IntensityDescriptions/IntensityDescriptions";

import Select, { SelectOption } from "@iso/components/uielements/select";

const Option = SelectOption;

export default function PlantProtection() {
  const {
    blocksPermissions: { ["plant-protection"]: plantProtectionPermissions },
  } = useSelector((state) => _.get(state, "Auth.userPermissions"));

  const {
    ["diseases-and-pests"]: { read: hasAccessToDiseasesAndPestsRead },
    ["intensity"]: { read: hasAccessToIntensityRead },
    ["intensity-by-diseases"]: { read: hasAccessToIntensityByDiseasesRead },
    ["monitoring"]: { read: hasAccessToMonitoringRead },
    ["charts"]: { read: hasAccessToChartsRead },
  } = plantProtectionPermissions.blocks;

  const [selectedPage, setSelectedPage] = useState(null);

  const pages = _.compact([
    hasAccessToDiseasesAndPestsRead
      ? { name: "Болезни и вредители томатов и огурцов", pageId: 1 }
      : null,
    hasAccessToIntensityRead
      ? { name: "Интенсивность поражения", pageId: 2 }
      : null,
    hasAccessToIntensityByDiseasesRead
      ? { name: "Интенсивность поражения по болезням", pageId: 3 }
      : null,
    hasAccessToMonitoringRead
      ? { name: "Информация по мониторингу", pageId: 4 }
      : null,
    hasAccessToChartsRead ? { name: "Графики", pageId: 5 } : null,
  ]);

  useEffect(() => {
    if (!_.isEmpty(plantProtectionPermissions)) {
      setSelectedPage(pages[0]?.pageId);
    }
  }, [plantProtectionPermissions]);

  return (
    <LayoutContentWrapper>
      <Box>
        <ContentHolder style={{ marginTop: 0, overflow: "hidden" }}>
          <TitleWrapper>
            <ComponentTitle>Защита растений</ComponentTitle>
          </TitleWrapper>

          <Select
            style={{ marginBottom: "34px" }}
            dropdownMatchSelectWidth={false}
            defaultValue="Ничего не выбрано"
            value={_.get(
              _.find(pages, (page) => page.pageId === selectedPage),
              "name",
              "Ничего не выбрано"
            )}
            onChange={setSelectedPage}
          >
            {_.map(pages, (g) => (
              <Option value={g.pageId} key={g.pageId}>
                {" "}
                {g.name}{" "}
              </Option>
            ))}
          </Select>

          <>
            {selectedPage === 1 && <DeseasesAndPests />}
            {selectedPage === 2 && <IntensityInterface />}
            {selectedPage === 3 && <IntensityDescriptions />}
            {selectedPage === 4 && <MonitoringInfo />}
            {selectedPage === 5 && <MonitoringGraph />}
          </>
        </ContentHolder>
      </Box>
    </LayoutContentWrapper>
  );
}
