import React, { useState, useEffect } from "react";
import { useSelector } from "react-redux";
import _ from "lodash";
import LayoutContentWrapper from "@iso/components/utility/layoutWrapper";
import Box from "@iso/components/utility/box";
import ContentHolder from "@iso/components/utility/contentHolder";
import { TitleWrapper, ComponentTitle } from "./QualityControl.styles";
import { Spin } from "antd";

import Select, { SelectOption } from "@iso/components/uielements/select";
import CheckLists from "@iso/containers/CheckLists/CheckLists";
import HistoricalCheckLists from "@iso/containers/HistoricalCheckLists/HistoricalCheckLists";
import TaskQuality from "@iso/containers/TaskQuality/TaskQuality";

import CheckSheet from "./CheckSheet";

const Option = SelectOption;

export default function QualityControl() {
  const { isLoadingGreenhouses } = useSelector((state) => _.get(state, "App"));

  const {
    blocksPermissions: { ["quality-control"]: qualityControlPermissions },
  } = useSelector((state) => _.get(state, "Auth.userPermissions"));

  const {
    ["check-metrics"]: { read: hasAccessToCheckMetricsRead },
    ["check-lists"]: { read: hasAccessToCheckListsRead },
  } = qualityControlPermissions.blocks;

  const pages = _.compact([
    hasAccessToCheckMetricsRead ? { name: "Списки проверок", pageId: 1 } : null,
    hasAccessToCheckListsRead ? { name: "Чек-листы", pageId: 2 } : null,
    // TODO: Уровень доступа изменить
    hasAccessToCheckListsRead ? { name: "Исторические данные по сотруднику", pageId: 3 } : null,
    // TODO: поменять доступ
    hasAccessToCheckListsRead ? { name: "Справочник пороговых значений", pageId: 4 } : null,
  ]);

  const [selectedPage, setSelectedPage] = useState(null);

  useEffect(() => {
    if (!_.isEmpty(qualityControlPermissions)) {
      setSelectedPage(pages[0]?.pageId);
    }
  }, [qualityControlPermissions]);

  return (
    <LayoutContentWrapper>
      <Box>
        <ContentHolder style={{ marginTop: 0, overflow: "hidden" }}>
          <TitleWrapper>
            <ComponentTitle>Контроль качества</ComponentTitle>
          </TitleWrapper>
          {isLoadingGreenhouses ? (
            <Spin
              style={{ textAlign: "center", width: "100%", margin: "20px 0" }}
            />
          ) : (
            <>
              <Select
                style={{ marginBottom: "34px" }}
                dropdownMatchSelectWidth={false}
                defaultValue="Ничего не выбрано"
                value={_.get(
                  _.find(pages, (page) => page.pageId === selectedPage),
                  "name",
                  "Ничего не выбрано"
                )}
                onChange={setSelectedPage}
              >
                {_.map(pages, (g) => (
                  <Option value={g.pageId} key={g.pageId}>
                    {" "}
                    {g.name}{" "}
                  </Option>
                ))}
              </Select>
              {selectedPage === 1 && <CheckSheet />}
              {selectedPage === 2 && <CheckLists />}
              {selectedPage === 3 && <HistoricalCheckLists />}
              {selectedPage === 4 && <TaskQuality />}
            </>
          )}
        </ContentHolder>
      </Box>
    </LayoutContentWrapper>
  );
}
