import React, {useState, useEffect} from 'react';
import { useDispatch, useSelector } from 'react-redux';
import plantProtectionActions from '@iso/redux/qualityLesion/actions';
import _ from 'lodash';
import { Grid } from 'react-flexbox-grid';
import Modal from '@iso/components/Feedback/Modal';
import Form from '@iso/components/uielements/form';
import {pests as hardCodedPests} from '@iso/containers/PlantProtection/hardCodedData';

import {
  TableWrapper,
  Fieldset,
  ActionWrapper,
} from './QualityLesion.styles';

import Select, { SelectOption } from '@iso/components/uielements/select';

const Option = SelectOption;
const FormItem = Form.Item;

export default function QualityLesion() {
  const {
    pest,
    pests,
    modalActiveLesion
  } = useSelector(
    state => state.QualityLesion
  );

  const [lesionData, setLesionData] = useState(null);
  const [modalName, setModalName] = useState('')
  const [modalStatus, setModalStatus] = useState('')
  const [modalQuality, setModalQuality] = useState('')

  const dispatch = useDispatch();

  const {
    loadFromAgroInvest,
    toggleModal,
    rowsLoadFromAgroInvest,
    saveIntoAgroInvest,
    update,
    deletePest
  } = plantProtectionActions;

  React.useEffect(() => {
    dispatch(loadFromAgroInvest());
  }, [dispatch, loadFromAgroInvest]);

  useEffect(() => {
    pests && setLesionData(pests)
  }, [pests])

  const pages = [
    {name: 'Низкая', pageId: 1, lesionColor: '#ffff00', points: '1',quality: 'Низская'},
    {name: 'Средняя', pageId: 2, lesionColor: '#00b050', points: '2', quality: 'Среднеяя'},
    {name: 'Сильная', pageId: 3, lesionColor: '#f00', points: '3',quality: "Сильная"},
  ]

  const pestUpdate = (key, value) => {
    if (key) pest[key] = value;
    dispatch(update(pest));
  };

  const handleRecord = (actionName, pest) => {
    pestUpdate('name', modalName)
    pestUpdate('isActive', modalStatus)
    pestUpdate('quality', modalQuality)
    dispatch(saveIntoAgroInvest(pest, actionName));
  };

  const handleModal = async (pest = null) => {
    if(pest){
      setModalName(pest.name)
      setModalStatus(pest.isActive)
      setModalQuality(pest.quality)
    } else{
      setModalName('')
      setModalStatus(true)
      setModalQuality('');
    }
    await dispatch(toggleModal(pest));
    dispatch(rowsLoadFromAgroInvest());
  };

  const handlePests = (pest) => {
    dispatch(deletePest(pest))
  }

  const generateActionButtons = (row) => {
    return (
      <ActionWrapper>
        <a onClick={() => handleModal(row)} href="# ">
          <i className="ion-android-create" />
        </a>
      </ActionWrapper>
    )
  }

  const columnLeft = [
    {
      title: 'Названия',
      key: 'pest',
      render: (text, row) => {
        return (
          row.name
        )
      },
    },
    {
      title: "Интенсивность поражение",
      key: 'quality',
      width: '200px',
      render: (text, row) => {
        return (
          (row.quality === 1) ? 'Низкая' : (row.quality === 2) ? 'Средняя' : 'Сильная'
        )
      }
    },
    {
      title: 'Значение цвета',
      key: 'color',
      width: '120px',
      align: 'center',
      render: (text,row) => {
        let color = (row.quality === 1) ? '#ffff00' : (row.quality === 2) ? '#00b050' : '#f00'
        return (
          <span style={{marginRight: '5px',verticalAlign: 'text-bottom',width: '16px',height: '16px',background: color, display: 'inline-block',borderRadius: '50px' }}></span>
        )
      }
    },
    {
      title: 'Баллы',
      key: 'points',
      width: '100px',
      align: 'center',
      render: (text, row) => {
        return row.quality
      }
    },
    {
      title: 'Изменить',
      key: 'change',
      width: '60px',
      className: 'noWrapCell',
      render: (text, row) => {
        return generateActionButtons(row)
      },
    },
    {
      title: 'Удалить',
      key: 'delete',
      width: '60px',
      className: 'noWrapCell',
      render: (text, row) => {
        return (
          <a onClick={() => handlePests(row)} href="# ">X</a>
        )
      },
    },
  ];

  return (
    <>
          {/* <TitleWrapper style={{marginLeft: 15}}>
            <ComponentTitle>Интенсивность поражения</ComponentTitle>
            <div>
              <Button type="primary" shape="circle" loading={isLoading} icon="plus" onClick={() => handleModal()} style={{ marginLeft: '10px' }} />
              <Button type="primary" shape="circle" loading={isLoading} icon="reload" style={{ marginLeft: '10px' }} />
            </div>
          </TitleWrapper> */}
          <Modal
            visible={modalActiveLesion}
            onClose={() => dispatch(toggleModal(null))}
            title={
              (<>
                {
                  pest.id
                    ? `Изменить параметр "${pest.name}"`
                    : 'Добавить'
                }
                <br />
                <small>{pest.id ? pest.id : 'n/a'}</small>
              </>)
            }
            okText={'Сохранить'}
            onOk={() => handleRecord('PATCH', pest)}
            onCancel={() => dispatch(toggleModal(null))}
            okButtonProps={{ disabled: false }}
            cancelButtonProps={{ disabled: false }}
          >
            <Form>
              <Fieldset>
                <FormItem label="Интенсивность поражения" hasFeedback>
                  <Select dropdownMatchSelectWidth={false}
                    value={(modalQuality === 1) ?
                      <div>
                        <span style={{
                          marginRight: '5px',
                          verticalAlign: 'text-bottom',
                          width: '16px',height: '16px',
                          background: '#ffff00',
                          display: 'inline-block',
                          borderRadius: '50px'
                        }} className=""></span>
                        {'Низкая'}
                      </div> : (modalQuality === 2) ?
                      <div>
                        <span style={{
                          marginRight: '5px',
                          verticalAlign: 'text-bottom',
                          width: '16px',height: '16px',
                          background: '#00b050',
                          display: 'inline-block',
                          borderRadius: '50px'
                        }} className=""></span>
                      {'Средняя'}
                    </div> :
                    <div>
                      <span style={{
                        marginRight: '5px',
                        verticalAlign: 'text-bottom',
                        width: '16px',height: '16px',
                        background: '#f00',
                        display: 'inline-block',
                        borderRadius: '50px'
                      }} className=""></span>
                      {'Сильная'}
                    </div>
                    } onChange={e => {setModalQuality(e);console.log(e)}}>
                    {
                      _.map(pages,g => <Option value={g.pageId} key={g.pageId}><span style={{marginRight: '5px',verticalAlign: 'text-bottom',width: '16px',height: '16px',background: g.lesionColor,display: 'inline-block',borderRadius: '50px' }} className=""></span>{g.name}</Option>)
                    }
                  </Select>
                </FormItem>
              </Fieldset>
              <Fieldset>
              </Fieldset>
            </Form>
          </Modal>
          {lesionData && (
            <Grid fluid>
              <TableWrapper
                rowKey="name"
                columns={columnLeft}
                bordered={true}
                dataSource={hardCodedPests}
                className="isoSimpleTable"
                pagination={{
                  hideOnSinglePage: true,
                  total: lesionData.length,
                }}
              />
              {console.log(lesionData)}
            </Grid>
          )}
    </>
  );
}
