import React, { useState, useMemo, useEffect } from "react";
import Button from "@iso/components/uielements/button";
import { useDispatch, useSelector } from "react-redux";
import LayoutContentWrapperScrollable from "@iso/components/utility/layoutWrapperScrollable";
import Box from "@iso/components/utility/box";
import sectionActions from "@iso/redux/section/actions";
import ContentHolder from "@iso/components/utility/contentHolder";
import Tabs, { TabPane } from "@iso/components/uielements/tabs";
import { Icon, Input } from "antd";
import InputNumber from "@iso/components/InputNumber";
import _ from "lodash";
import "react-flexbox-grid/dist/react-flexbox-grid.css";
import { Grid, Row, Col } from "react-flexbox-grid";
// import { quarantineRows } from '@iso/config/sections.config';
import Form from "@iso/components/uielements/form";
import Radio, { RadioGroup } from "@iso/components/uielements/radio";
import { IconSvg } from "@iso/components/ScrumBoard/IconSvg/IconSvg";
import TransferWithinAstationBlack from "@iso/assets/images/icon/transfer_within_a_station-black-18dp.svg";
import moment from "../../library/helpers/moment";
import planActions from "@iso/redux/plan/actions";
import { request } from "@iso/lib/helpers/utility";
import isTimeBetween from "@iso/lib/helpers/isTimeBetween";
import { getBlocksPermissions } from "@iso/lib/helpers/getBlocksPermissions";

import ModalTask from "@iso/components/ModalTask/ModalTask";

import DatePicker from "@iso/components/uielements/datePicker";

import locale from "antd/lib/locale-provider/ru_RU";

import { ConfigProvider } from "antd";

import {
  DateCell,
  ImageCell,
  LinkCell,
  TextCell,
  BlockCell,
} from "@iso/components/Tables/HelperCells";

import {
  TitleWrapper,
  ComponentTitle,
  TableWrapper,
  StatusTag,
  ActionWrapper,
} from "./Section.styles";

import Select, { SelectOption } from "@iso/components/uielements/select";

const Option = SelectOption;
const FormItem = Form.Item;

const {
  loadFromAgroInvest,
  loadLastFinishedTaskFromAgroInvest,
  selectTasks,
  selectWorkers,
  enableTasks,
  disableTasks,
  selectDay,
  setDetails,
  setPage,
  refreshTasks,
  getSectionsGreenhouse,
  checkTaskPass,
  setRows,
  setPass,
  getSections,
  getTask,
  changeTask,
  changeProperties,
  patchTask,
} = sectionActions;

const { setSection } = planActions;

export default function Section(props) {
  const {
    tasks,
    workers,
    isLoading,
    isLoadingLastFinishedTask,
    totalItems,
    day,
    shift,
    direction,
    planDay,
    keepPlanDay,
    keepOrderBy,
    keepWorkerId,
    keepExclusive,
    exclusive,
    greenhouseSections,
    taskPass,
    rowFrom,
    rowTo,
    pass,
    sections,
    task,
    updateTask,
  } = useSelector((state) => state.Section);

  const { greenhouses, greenhouseId, appSettings } = useSelector(
    (state) => state.App
  );
  const [technicalWindowRange, setTechnicalWindow] = useState(_.get(appSettings, "workingTimeConfig", {}))
  const { role } = useSelector((state) => state.Auth);

  const [lightEditSectionPermissions] = getBlocksPermissions("section", [
    "light-edit",
  ]);
  const [lightEditTasksPermissions, hardEditTasksPermissions] =
    getBlocksPermissions("tasks", ["light-edit", "hard-edit"]);

  const {
    edit: hasAccessToSectionLightEdit,
    sectionsEdit: accessSectionsForSectionLightEdit,
  } = lightEditSectionPermissions;
  const {
    edit: hasAccessToTasksLightEdit,
    sectionsEdit: accessSectionsForTasksLightEdit,
  } = lightEditTasksPermissions;
  const { edit: hasAccessToTasksHardEdit } = hardEditTasksPermissions;

  // const { autocomplete } = useSelector((state) => state.Workers);

  const dispatch = useDispatch();
  const [section, updateSection] = useState({});
  const [innerLoading, setInnerLoading] = useState(true);
  const [dataSource, setDataSource] = useState({});
  const [isModalTask, setIsModalTask] = useState(false);

  const hasAccessToEditBySectionModule =
    !_.isEmpty(section) &&
    hasAccessToSectionLightEdit &&
    (!accessSectionsForSectionLightEdit ||
      _.includes(accessSectionsForSectionLightEdit, _.get(section, "module")));

  React.useEffect(() => {
    dispatch(getSectionsGreenhouse());
    dispatch(disableTasks());
    dispatch(getSections());
  }, [dispatch, greenhouseId]);

  React.useEffect(() => {
    dispatch(checkTaskPass(section.sectionId, day, 16));
  }, [dispatch, day, section]);

  React.useEffect(() => {
    dispatch(refreshTasks());
    dispatch(loadFromAgroInvest(null));
  }, [dispatch, greenhouseId]);

  React.useEffect(() => {
    if (!_.isEmpty(greenhouseSections)) {
      const lastFilterId = localStorage.getItem("sectionId");
      const greenhouseSection = greenhouseSections.find(
        (item) => item.sectionId === lastFilterId
      );
      if (greenhouseSection) {
        updateSection(greenhouseSection);
        return;
      }
      updateSection(greenhouseSections[0]);
    } else if (greenhouseSections !== null) {
      updateSection({});
    }
  }, [greenhouseSections]);

  React.useEffect(() => {
    if (!_.isEmpty(tasks) && !isLoading) {
      setInnerLoading(true);

      let minOrdering = 1;
      let maxOrdering = 2;

      const maxTask = _.maxBy(_.toArray(tasks), "rowOrderBy");
      if (maxTask) {
        maxOrdering = maxTask.rowOrderBy;
      }

      const minTask = _.minBy(_.toArray(tasks), "rowOrderBy");
      if (minTask) {
        minOrdering = minTask.rowOrderBy;
      }

      if (minOrdering % 2 === 0) {
        minOrdering--;
      }

      const rowSelection = (selectedRowKeys, selectedRows, section) => {
        dispatch(selectTasks(section, selectedRows));
      };

      const newData = {
        1: {
          range: _.range(minOrdering, maxOrdering + 1, 2),
          rows: [],
          rowSelection: {
            onChange: (selectedRowKeys, selectedRows) => {
              rowSelection(selectedRowKeys, selectedRows, 1);
            },
          },
        },
        2: {
          range: _.range(minOrdering + 1, maxOrdering + 1, 2),
          rows: [],
          rowSelection: {
            onChange: (selectedRowKeys, selectedRows) => {
              rowSelection(selectedRowKeys, selectedRows, 2);
            },
          },
        },
      };

      _.each(Object.keys(newData), (section) => {
        _.each(newData[section].range, (rowOrderBy) => {
          const rowTask = _.find(tasks, (t) => t.rowOrderBy === rowOrderBy);

          const taskGreenhouseId = _.get(rowTask, "greenhouseId");

          newData[section].rows.push({
            id: _.get(rowTask, "rowOrderBy", rowOrderBy),
            key: _.get(rowTask, "rowOrderBy", rowOrderBy),
            taskId: _.get(rowTask, "id", null),
            startAt: _.get(rowTask, "startAt", null),
            finishAt: _.get(rowTask, "finishAt", null),
            startedAt: _.get(rowTask, "startedAt", null),
            finishedAt: _.get(rowTask, "finishedAt", null),
            isFinished: _.get(rowTask, "isFinished", null),
            lockedTill: _.get(rowTask, "lockedTill", null),
            sectionName: _.get(rowTask, "sectionName", null),
            day: _.get(rowTask, "day", null),
            shift: _.get(rowTask, "shift", null),
            direction: _.get(rowTask, "direction", null),
            name: _.get(rowTask, "name", "N/A"),
            greenhouseName: _.get(
              _.keyBy(greenhouses, "id"),
              "[" + taskGreenhouseId + "].description",
              "n/a"
            ),
            workerId: _.get(rowTask, "workerId", null),
            workerName: _.get(rowTask, "workerName", null),
            isActive: _.get(rowTask, "isActive", false),
            exclusive: _.get(rowTask, "exclusive", 0),
            inProgress: _.get(rowTask, "inProgress", null),
            color: rowTask
              ? rowTask.isActive
                ? moment(rowTask.startAt)
                    .utc()
                    .isSameOrBefore(moment(day).utc())
                  ? "#90EE90"
                  : "#83e3ff"
                : "#ddd"
              : "#fff",
            rowNumber: _.get(rowTask, "rowNumber", 0),
          });
        });
      });

      const rowsOne = [];
      const rowsTwo = [];
      const data = {
        color: "#fff",
        day: null,
        direction: null,
        exclusive: 0,
        finishAt: null,
        finishedAt: null,
        greenhouseName: "n/a",
        inProgress: null,
        isActive: false,
        isFinished: null,
        lockedTill: null,
        name: "N/A",
        rowNumber: 0,
        sectionName: null,
        shift: null,
        startAt: null,
        startedAt: null,
        taskId: null,
        workerId: null,
        workerName: null,
      };

      for (let i = 0; i < newData[1].rows.length; i++) {
        const oneTaskId = _.get(newData[1].rows[i], "taskId", null);
        const twoTaskId = _.get(newData[2].rows[i], "taskId", null);
        if (!_.isNull(oneTaskId) || !_.isNull(twoTaskId)) {
          if (!_.isNull(oneTaskId)) {
            rowsOne.push(newData[1].rows[i]);
          } else {
            const currentId = _.get(newData[1].rows[i], "id", 1);

            rowsOne.push({ ...data, id: currentId, key: currentId });
          }

          if (!_.isNull(twoTaskId)) {
            rowsTwo.push(newData[2].rows[i]);
          } else {
            const currentId = _.get(newData[2].rows[i], "id", 0);

            rowsTwo.push({ ...data, id: currentId, key: currentId });
          }
        }
      }

      const newDataSource = {
        1: { ...newData[1], rows: [...rowsOne] },
        2: { ...newData[2], rows: [...rowsTwo] },
      };

      setDataSource({ ...newDataSource });
      setInnerLoading(false);
    } else {
      setInnerLoading(false);
    }
  }, [dispatch, day, isLoading, greenhouses, tasks]);

  useEffect(() => {
    const fetchTechnicalWindowSections = async () => {
      if (task.id) {
        const response = await request('technical_window_sections', {
          sectionId: task.sectionId,
          'technicalWindow.greenhouseId': task.greenhouseId,
          page: 1,
        });
        
        const technicalWindowRange =
          response['hydra:member'].length === 0
            ?   _.get(appSettings, "workingTimeConfig", {})
            : {
                start: moment.utc(response['hydra:member'][0].technicalWindow.start).format('HH:mm'),
                finish: moment.utc(response['hydra:member'][0].technicalWindow.finish).format('HH:mm'),
              };
        setTechnicalWindow(technicalWindowRange);
      }
    };

    fetchTechnicalWindowSections();
  }, [appSettings, task.greenhouseId, task.id, task.sectionId]);

  const isWorkingTime = () => {
    const { start, finish } = technicalWindowRange;
    if (!start || !finish) return false;
    const currentTime = moment().utc().format("HH:mm");
    return isTimeBetween(start, finish, currentTime);
  };

  const hasAccessToEditWorker =
    isWorkingTime() || _.includes(["superuser", "tech-support"], role);

  const onModalTask = () => {
    setIsModalTask((isPrev) => !isPrev);
  };

  const onOkModal = () => {
    setIsModalTask((isPrev) => !isPrev);
    if (_.size(updateTask)) {
      dispatch(patchTask(updateTask));
    }
  };

  const reload = () => {
    dispatch(refreshTasks());
    dispatch(loadFromAgroInvest(section.sectionId));
  };

  const loadLastFinishedTask = (sectionId, rowNumber) => {
    dispatch(loadLastFinishedTaskFromAgroInvest(sectionId, rowNumber));
  };

  const callEnableTasks = () => {
    dispatch(enableTasks());
  };

  const callDisableTasks = () => {
    dispatch(disableTasks());
  };

  const changeDay = (date, dateString) => {
    dispatch(selectDay(date.utc().format()));
  };

  const onChangeTask = (entity, value) => {
    dispatch(changeTask(entity, value));
  };

  const onChangeProperties = (id, value) => {
    dispatch(changeProperties(id, value));
  };

  const handleWorkerSelect = (id, name) => {
    onChangeTask("workerId", id ? id : null);
    onChangeTask("workerName", name ? name : null);
  };

  const handleRangeSelect = (value) => {
    if (_.isEmpty(value)) {
      onChangeTask("startedAt", null);
      onChangeTask("finishedAt", null);
    } else {
      onChangeTask("startedAt", value[0].format());
      onChangeTask("finishedAt", value[1].format());
    }
  };

  const rowSelectionWorkers = {
    onChange: (selectedRowKeys, selectedRows) => {
      dispatch(selectWorkers(selectedRows));
    },
  };

  const rowClassName = (record, index) => {
    //console.log(record, index)
  };

  const setDetailsForm = (e) => {
    const { name, value } = e.target;

    dispatch(setDetails(name, value));
  };

  const handleSetRows = (e) => {
    const { name, value } = e.target;

    dispatch(setRows(name, value));
  };

  const hanbleTabSelectionsClick = (page) => {
    const lastTaskIndex = tabsSections[page - 1].name.split("-")[1];

    if (tasks[lastTaskIndex]) {
      return false;
    }

    if (!_.isNaN(page)) {
      dispatch(setPage(page));
    }
  };

  const handleChangeSection = React.useCallback(
    (sectionId) => {
      const newSection = _.find(sections, (item) => item.id === sectionId);
      updateSection({
        title: newSection.name,
        sectionId: newSection.id,
        module: newSection.module,
      });
      dispatch(setSection(sectionId));
      localStorage.setItem("sectionId", sectionId);
    },
    [dispatch, sections]
  );

  const handleChangePass = React.useCallback(
    (pass) => {
      dispatch(setPass(pass));
    },
    [dispatch]
  );

  const tabsSections = [
    {
      name: "РАБОТЫ",
      value: [1, 2],
    },
  ];

  const generateActionButtons = (row) => {
    const onClick = () => {
      dispatch(getTask(row.taskId));
      onModalTask();
    };

    const sectionModule = _.get(row, "section.module");
    const hasAccessToEdit =
      hasAccessToTasksLightEdit &&
      (!accessSectionsForTasksLightEdit ||
        (accessSectionsForTasksLightEdit &&
          _.includes(accessSectionsForTasksLightEdit, sectionModule)));

    return (
      <ActionWrapper>
        {hasAccessToEdit ? (
          <a
            href="# "
            style={{
              marginRight: "8px",
            }}
            onClick={onClick}
          >
            <i className="ion-android-create" />
          </a>
        ) : (
          <a
            href="# "
            disabled
            style={{
              marginRight: "8px",
            }}
          >
            <i className="ion-android-create" style={{ color: "#aaa" }} />
          </a>
        )}

        {row.sectionName}
      </ActionWrapper>
    );
  };

  const renderCell = (object, type, key) => {
    const value = object[key];

    const isEmptyObject = _.isNil(object.taskId);
    switch (type) {
      case "ImageCell":
        return ImageCell(value);
      case "DateCell":
        return DateCell(value);
      case "LinkCell":
        return LinkCell(value);
      case "StatusCell":
        return BlockCell(
          !isEmptyObject && (
            <>
              <big>{object.name}</big>
              <br />
              {object.greenhouseName}
              <br />
              {object.isActive || object.isFinished ? (
                <StatusTag
                  className={
                    object.isFinished
                      ? "success"
                      : object.startedAt
                      ? "warning"
                      : object.isActive
                      ? moment()
                          .utc()
                          .startOf("day")
                          .isAfter(moment(object.startAt))
                        ? "error"
                        : "info"
                      : null
                  }
                >
                  {object.isFinished
                    ? "Завершен"
                    : object.startedAt
                    ? object.finishedAt
                      ? "ПАУЗА"
                      : "В работе"
                    : object.isActive
                    ? moment()
                        .utc()
                        .startOf("day")
                        .isAfter(moment(object.startAt))
                      ? "Просрочен"
                      : "Запланирован"
                    : null}
                </StatusTag>
              ) : null}
              &nbsp;
              {!object.isActive ? (
                <StatusTag className="error">ИСКЛЮЧЕН</StatusTag>
              ) : null}
              &nbsp;
              <StatusTag className="info">
                {object.shift}&nbsp;
                <Icon type={object.direction ? "arrow-down" : "arrow-up"} />
              </StatusTag>
            </>
          )
        );
      case "InfoCell":
        return BlockCell(
          !isEmptyObject ? (
            <div
              style={{
                height: 165,
              }}
            >
              <h2
                style={{
                  width: "350px",
                  // whiteSpace: 'nowrap',
                  textOverflow: "ellipsis",
                  overflow: "hidden",
                  // textAlign: 'right',
                }}
              >
                {generateActionButtons(object)}
              </h2>
              <br />
              <h3>
                {object.isFinished ? "Завершено: " : "План: "}
                <b>
                  {object.isFinished
                    ? moment(object.finishedAt).format("LLL")
                    : moment(object.startAt).format("LL")}
                </b>
              </h3>
              <br />
              <big
                style={{
                  width: "350px",
                  // whiteSpace: 'nowrap',
                  textOverflow: "ellipsis",
                  overflow: "hidden",
                  // textAlign: 'right',
                }}
              >
                {value ? <b>{value}</b> : "-- Не назначено --"}
              </big>
              {moment(object.lockedTill).isAfter(moment()) &&
              object.workerName ? (
                <div>
                  <Icon type="star" className="warning" />
                  &nbsp;
                  <small>
                    закреплено до {moment(object.lockedTill).format("LLLL")}
                  </small>
                </div>
              ) : (
                <div>
                  <small>-- не закреплено --</small>
                </div>
              )}
              <small>-- статус работы --&nbsp;</small>
              {object.inProgress && (
                <IconSvg
                  src={TransferWithinAstationBlack}
                  border="none"
                  alt="TransferWithinAstationBlack Icon"
                />
              )}
            </div>
          ) : (
            <div style={{ height: 165 }} />
          )
        );
      case "RowCell":
        return (
          !isEmptyObject && (
            <>
              <h2 style={{ fontSize: "30px" }}>Ряд {value}</h2>
              <big>
                <b>{object.name}</b>
              </big>
              <br />
              {object.greenhouseName}
              <br />
              <br />
              {/* {value > 0 ? _.includes(quarantineRows, value) ? (
              <StatusTag className="rowNumberQuarantine">
                Ряд: {value}
                &nbsp;
                <Icon type="warning" />
              </StatusTag>
            ) : (
                <StatusTag className="rowNumber">
                  Ряд: {value}
                </StatusTag>
              ) : null} */}
              {value > 0 ? (
                <StatusTag className={"rowNumberExclusive-" + object.exclusive}>
                  Группа: {object.exclusive}
                </StatusTag>
              ) : null}
              <br />
              <br />
              {object.isActive || object.isFinished ? (
                <StatusTag
                  className={
                    object.isFinished
                      ? "success"
                      : object.startedAt
                      ? "warning"
                      : object.isActive
                      ? moment()
                          .utc()
                          .startOf("day")
                          .isAfter(moment(object.startAt))
                        ? "error"
                        : "info"
                      : null
                  }
                >
                  {object.isFinished
                    ? "Завершен"
                    : object.startedAt
                    ? object.finishedAt
                      ? "ПАУЗА"
                      : "В работе"
                    : object.isActive
                    ? moment()
                        .utc()
                        .startOf("day")
                        .isAfter(moment(object.startAt))
                      ? "Просрочен"
                      : "Запланирован"
                    : null}
                </StatusTag>
              ) : null}
              &nbsp;
              {!object.isActive ? (
                <StatusTag className="error">ИСКЛЮЧЕН</StatusTag>
              ) : null}
              &nbsp;
              <StatusTag className="info">
                {object.shift}&nbsp;
                <Icon type={object.direction ? "arrow-down" : "arrow-up"} />
              </StatusTag>
            </>
          )
        );
      default:
        return TextCell(value);
    }
  };

  const columnsLeft = [
    {
      title: "Номер ряда",
      key: "rowNumber",
      width: 200,
      align: "center",
      render: (object) => {
        return {
          props: {
            style: { background: object.color },
          },
          children: renderCell(object, "RowCell", "rowNumber"),
        };
      },
    },
    {
      title: "Инфо",
      key: "info",
      align: "left",
      render: (object) => {
        return {
          props: {
            style: {
              background: object.isFinished ? "#90EE90" : undefined,
            },
          },
          children: renderCell(object, "InfoCell", "workerName"),
        };
      },
    },
  ];

  const columnsRight = [
    {
      title: "Номер ряда",
      key: "rowNumber",
      width: 200,
      align: "center",
      render: (object) => {
        return {
          props: {
            style: { background: object.color },
          },
          children: renderCell(object, "RowCell", "rowNumber"),
        };
      },
    },
    {
      title: "Инфо",
      key: "info",
      align: "left",
      render: (object) => {
        return {
          props: {
            style: {
              background: object.isFinished ? "#90EE90" : undefined,
            },
          },
          children: renderCell(object, "InfoCell", "workerName"),
        };
      },
    },
  ];

  const columnsWorkers = [
    {
      title: "Статус",
      key: "spreadTill",
      width: 100,
      align: "left",
      sorter: (a, b) => {
        if (moment(a.spreadTill) < moment(b.spreadTill)) return 1;
        if (moment(a.spreadTill) > moment(b.spreadTill)) return -1;
        return 0;
      },
      render: (object) => {
        let className;
        if (moment(object.spreadTill) > moment()) {
          className = "success";
        } else {
          className = "error";
        }
        return (
          <div>
            <StatusTag className={className}>
              {moment(object.spreadTill) > moment() ? "Онлайн" : "Оффлайн"}
            </StatusTag>
          </div>
        );
      },
    },
    {
      title: "Имя",
      key: "name",
      align: "left",
      sorter: (a, b) => {
        if (a.name < b.name) return -1;
        if (a.name > b.name) return 1;
        return 0;
      },
      render: (object) => renderCell(object, "TextCell", "name"),
    },
    {
      title: "Код СУРВ",
      key: "code",
      width: 100,
      align: "right",
      sorter: (a, b) => {
        if (a.code < b.code) return -1;
        if (a.code > b.code) return 1;
        return 0;
      },
      render: (object) => renderCell(object, "TextCell", "code"),
    },
    {
      title: "Заметки",
      key: "notes",
      align: "left",
      render: (object) => renderCell(object, "TextCell", "notes"),
    },
  ];

  const margin = {
    margin: "0 0 8px 8px",
  };

  const operations = (
    <>
      <Button
        type="primary"
        disabled={!hasAccessToEditBySectionModule}
        style={margin}
        onClick={callEnableTasks}
      >
        Включить в план
      </Button>
      <Button
        type="danger"
        disabled={!hasAccessToEditBySectionModule}
        style={margin}
        onClick={callDisableTasks}
      >
        Исключить из плана
      </Button>
    </>
  );

  const planContent =
    !isLoading && !innerLoading ? (
      <Tabs
        defaultActiveKey="1"
        tabBarExtraContent={operations}
        onTabClick={(e) => e <= 6 && hanbleTabSelectionsClick(e)}
      >
        {_.map(tabsSections, (rows, key) => (
          <TabPane
            tab={
              <span>
                <Icon type="arrow-down" />
                {rows.name}
              </span>
            }
            key={key + 1}
          >
            <Grid fluid>
              <Row>
                <Col xs={12} md={6}>
                  <TableWrapper
                    rowSelection={
                      dataSource[2] ? dataSource[2].rowSelection : undefined
                    }
                    pagination={false}
                    columns={columnsRight}
                    dataSource={dataSource[2] ? dataSource[2].rows : undefined}
                    className="isoSimpleTable"
                  />
                </Col>
                <Col xs={12} md={6}>
                  <TableWrapper
                    rowSelection={
                      dataSource[1] ? dataSource[1].rowSelection : undefined
                    }
                    pagination={false}
                    columns={columnsLeft}
                    dataSource={dataSource[1] ? dataSource[1].rows : undefined}
                    className="isoSimpleTable"
                    rowClassName={rowClassName}
                  />
                </Col>
              </Row>
            </Grid>
          </TabPane>
        ))}

        <TabPane
          tab={
            <span>
              <Icon type="user" />
              СОТРУДНИКИ
            </span>
          }
          key="7"
        >
          <TableWrapper
            scroll={{ x: false, y: 600 }}
            rowSelection={rowSelectionWorkers}
            pagination={false}
            columns={columnsWorkers}
            dataSource={_.map(workers, (w) => {
              return {
                ...w,
                key: w.id,
              };
            })}
            className="isoSimpleTable"
          />
        </TabPane>
        <TabPane
          tab={
            <span>
              <Icon type="audit" />
              ДЕТАЛИ
            </span>
          }
          key="8"
        >
          <Form>
            <FormItem label="Сохранить день" hasFeedback>
              <RadioGroup
                onChange={setDetailsForm}
                name="keepPlanDay"
                value={keepPlanDay}
              >
                <Radio value={true}>Да</Radio>
                <Radio value={false}>Нет</Radio>
              </RadioGroup>
            </FormItem>
            <FormItem label="День работ" hasFeedback>
              <RadioGroup
                onChange={setDetailsForm}
                name="planDay"
                value={planDay}
                disabled={keepPlanDay}
              >
                <Radio value={1}>ПН</Radio>
                <Radio value={2}>ВТ</Radio>
                <Radio value={3}>СР</Radio>
                <Radio value={4}>ЧТ</Radio>
                <Radio value={5}>ПТ</Radio>
                <Radio value={6}>CБ</Radio>
                <Radio value={7}>ВС</Radio>
              </RadioGroup>
            </FormItem>
            <FormItem label="Сохранить сотрудников, если есть" hasFeedback>
              <RadioGroup
                onChange={setDetailsForm}
                name="keepWorkerId"
                value={keepWorkerId}
              >
                <Radio value={true}>Да</Radio>
                <Radio value={false}>Нет</Radio>
              </RadioGroup>
            </FormItem>
            <FormItem label="Сохранить порядок" hasFeedback>
              <RadioGroup
                onChange={setDetailsForm}
                name="keepOrderBy"
                value={keepOrderBy}
              >
                <Radio value={true}>Да</Radio>
                <Radio value={false}>Нет</Radio>
              </RadioGroup>
            </FormItem>
            <FormItem label="Порядок выполнения" hasFeedback>
              <RadioGroup
                onChange={setDetailsForm}
                name="shift"
                value={shift}
                disabled={keepOrderBy}
              >
                <Radio value={0}>0</Radio>
                <Radio value={1}>1</Radio>
                <Radio value={2}>2</Radio>
                <Radio value={3}>3</Radio>
                <Radio value={4}>4</Radio>
                <Radio value={5}>5</Radio>
                <Radio value={6}>6</Radio>
                <Radio value={7}>7</Radio>
                <Radio value={8}>8</Radio>
                <Radio value={9}>9</Radio>
              </RadioGroup>
            </FormItem>
            <FormItem label="Направление" hasFeedback>
              <RadioGroup
                onChange={setDetailsForm}
                name="direction"
                value={direction}
                disabled={keepOrderBy}
              >
                <Radio value={true}>Прямое</Radio>
                <Radio value={false}>Обратное</Radio>
              </RadioGroup>
            </FormItem>
            <FormItem label="Сохранить группу" hasFeedback>
              <RadioGroup
                onChange={setDetailsForm}
                name="keepExclusive"
                value={keepExclusive}
              >
                <Radio value={true}>Да</Radio>
                <Radio value={false}>Нет</Radio>
              </RadioGroup>
            </FormItem>
            <FormItem label="Группа" hasFeedback>
              <InputNumber
                name="exclusive"
                min={0}
                max={999}
                style={{ width: 200 }}
                disabled={keepExclusive}
                value={exclusive}
                onChange={setDetailsForm}
              />
            </FormItem>
          </Form>
        </TabPane>
      </Tabs>
    ) : null;

  return (
    <LayoutContentWrapperScrollable>
      <Box>
        <ContentHolder style={{ marginTop: 0, overflow: "hidden" }}>
          <ModalTask
            task={task}
            hasAccessToEditWorker={hasAccessToEditWorker}
            hasAccessToLightEdit={hasAccessToTasksLightEdit}
            hasAccessToHardEdit={hasAccessToTasksHardEdit}
            isWorkingTime={isWorkingTime()}
            isModalTask={isModalTask}
            onSelectQualitySection={loadLastFinishedTask}
            isLoadingLastFinishedTask={isLoadingLastFinishedTask}
            greenhouseSections={greenhouseSections}
            onOkModal={onOkModal}
            onModalTask={onModalTask}
            onChangeTask={onChangeTask}
            handleRangeSelect={handleRangeSelect}
            onChangeProperties={onChangeProperties}
            handleWorkerSelect={handleWorkerSelect}
          />
          <TitleWrapper>
            <ComponentTitle>
              Вид работ: &nbsp;
              {greenhouseSections && (
                <Select
                  dropdownMatchSelectWidth={false}
                  value={section.sectionId}
                  onChange={handleChangeSection}
                  disabled={isLoading}
                >
                  {_.map(_.sortBy(greenhouseSections, ["name"]), (g) => (
                    <Option value={g.sectionId} key={g.sectionId}>
                      {" "}
                      {g.name}{" "}
                    </Option>
                  ))}
                </Select>
              )}
              &nbsp; Неделя: &nbsp;
              <ConfigProvider picker="week" locale={locale}>
                <DatePicker
                  locale={locale}
                  picker="week"
                  value={moment(day)}
                  onChange={changeDay}
                  allowClear={false}
                  disabled={isLoading}
                />
              </ConfigProvider>
              &nbsp; Ряд от: &nbsp;
              <Input
                style={{ width: 50 }}
                placeholder="От"
                name="rowFrom"
                defaultValue={rowFrom}
                onBlur={(e) => handleSetRows(e)}
                disabled={isLoading}
              />
              &nbsp; Ряд до: &nbsp;
              <Input
                style={{ width: 50 }}
                placeholder="До"
                name="rowTo"
                defaultValue={rowTo}
                onBlur={(e) => handleSetRows(e)}
                disabled={isLoading}
              />
              &nbsp; Проход: &nbsp;
              <Select
                dropdownMatchSelectWidth={false}
                defaultValue={pass}
                onChange={handleChangePass}
                disabled={isLoading}
              >
                {_.map(taskPass, (isPass, index) => (
                  <Option key={index} disabled={!isPass} value={index}>
                    {index + 1} Проход
                  </Option>
                ))}
              </Select>
              <br />
              <small> Всего найдено: {totalItems || 0}</small>
            </ComponentTitle>

            <Button
              type="primary"
              shape="circle"
              loading={isLoading || innerLoading}
              icon="reload"
              onClick={reload}
            />
          </TitleWrapper>
        </ContentHolder>

        {planContent}
      </Box>
    </LayoutContentWrapperScrollable>
  );
}
