import styled from 'styled-components';
import { palette } from 'styled-theme';
import Table from '../Tables/AntTables/AntTables.styles';

const TitleWrapper = styled.div`
  display: flex;
  justify-content: space-between;
  margin-bottom: 20px;
  flex-wrap: wrap;
  align-items: center;
`;

const ComponentTitle = styled.h3`
  font-size: 16px;
  font-weight: 500;
  color: ${palette('text', 0)};
  margin: 5px 0;
`;

const TableWrapper = styled(Table)`
  .ant-table-bordered .ant-table-thead > tr > th,
  .ant-table-bordered .ant-table-tbody > tr > td {
    white-space: normal;
    &.noWrapCell {
      white-space: nowrap;
    }

    .ant-table-column-sorters {
      display: flex;
      flex-wrap: nowrap;
      align-items: center;
    }

    .ant-table-placeholder, .ant-table-body {
      min-height: 600px;
    }

    @media only screen and (max-width: 920px) {
      white-space: nowrap;
    }
  }
`;

const StatusTag = styled.span`
  padding: 0 5px;
  height: 20px;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  border-radius: 2px;
  background-color: ${palette('primary', 0)};
  font-size: 12px;
  color: #ffffff;
  text-transform: capitalize;

  &.success {
    background-color: ${palette('success', 0)};
  }

  &.warning {
    background-color: ${palette('warning', 0)};
  }

  &.info {
    background-color: ${palette('info', 0)};
  }

  &.error {
    background-color: ${palette('error', 0)};
  }

  &.rowNumber {
    background-color: ${palette('info', 0)};
  }

  &.rowNumberQuarantine {
    background-color: ${palette('error', 0)};
  }

  &.rowNumberExclusive {
    background-color: ${palette('warning', 0)};
    margin-left: 10px;
  }

  &.rowNumberExclusive-0 {
    background-color: #d64161;
    color: #ffffff;
    margin-left: 10px;
  }

  &.rowNumberExclusive-1 {
    background-color: #ff7b25;
    color: #ffffff;
    margin-left: 10px;
  }

  &.rowNumberExclusive-2 {
    background-color: #6b5b95;
    color: #ffffff;
    margin-left: 10px;
  }

  &.rowNumberExclusive-3 {
    background-color: #feb236;
    color: #000000;
    margin-left: 10px;
  }

  &.rowNumberExclusive-4 {
    background-color: #3e4444;
    color: #ffffff;
    margin-left: 10px;
  }

  &.rowNumberExclusive-5 {
    background-color: #82b74b;
    color: #ffffff;
    margin-left: 10px;
  }
`;

const ActionWrapper = styled.div`
  display: flex;
  align-content: center;

  a {
    margin-right: 12px;
    &:last-child {
      margin-right: 0;
    }

    i {
      font-size: 18px;
      color: ${palette('primary', 0)};

      &:hover {
        color: ${palette('primary', 4)};
      }
    }

    &.deleteBtn {
      i {
        color: ${palette('error', 0)};

        &:hover {
          color: ${palette('error', 2)};
        }
      }
    }
  }
`;

const Fieldset = styled.div`
  width: 100%;
  display: flex;
  flex-direction: column;
  margin-bottom: 20px;

  &:last-child {
    margin-bottom: 0;
  }
`;

const Label = styled.label`
  font-size: 13px;
  color: ${palette('text', 1)};
  line-height: 1.5;
  font-weight: 500;
  padding: 0;
  margin: 0 0 8px;
`;


export {
  TitleWrapper,
  ComponentTitle,
  TableWrapper,
  StatusTag,
  ActionWrapper,
  Label,
  Fieldset,
};
