import React, { useState, useMemo, useEffect } from 'react';

import AutoComplete, {
  AutoCompleteOption,
} from '@iso/components/uielements/autocomplete';

import _ from 'lodash';
import { request } from '@iso/lib/helpers/utility';
import moment from 'moment';
import { Badge } from 'antd';

const TaskWorkerSelector = ({
  greenhouseId,
  greenhouses,
  taskId,
  handleAssignTaskToWorker,
  setCurrentRowSelected,
}) => {
  const NOT_ASSIGNED = 'NOT_ASSIGNED';

  const [autoComplete, setAutoComplete] = useState([]);
  const [query, setQuery] = useState('');
  const fetchAutoComplite = async (query, greenhouseId) => {
    const response = await request('workers', {
      order: {
        name: 'asc',
      },
      greenhouseId,
      properties: ['id', 'name', 'code', 'spreadTill'],
      searchable: query,
      isActive: true,
      itemsPerPage: 20,
      page: 1,
    });
    setAutoComplete(response['hydra:member']);
  };

  const throttledFetchAutoComplite = useMemo(
    () =>
      _.throttle(fetchAutoComplite, 500, {
        leading: false,
      }),
    []
  );

  useEffect(() => {
    throttledFetchAutoComplite(query, greenhouseId);
  }, [greenhouseId, query, throttledFetchAutoComplite]);

  const currentGreenhouse = useMemo(
    () => _.filter(greenhouses, (item) => item.id === greenhouseId),
    [greenhouses, greenhouseId]
  );

  return (
    <AutoComplete
      onBlur={() => setCurrentRowSelected(null)}
      dropdownMatchSelectWidth={false}
      autoFocus={true}
      onSearch={setQuery}
      onSelect={(workerId) => handleAssignTaskToWorker(taskId, workerId)}
      placeholder="[не назначено]"
    >
      <AutoCompleteOption value={NOT_ASSIGNED} key={0}>
        [не назначено]
      </AutoCompleteOption>
      {_.map(autoComplete, (w) => (
        <AutoCompleteOption value={w.id} key={w.id}>
          {moment(w.spreadTill) > moment() ? (
            <Badge status="success" />
          ) : (
            <Badge status="default" />
          )}
          {` ${w.code} | ${currentGreenhouse[0].description} | ${w.name}`}
        </AutoCompleteOption>
      ))}
    </AutoComplete>
  );
};

export default TaskWorkerSelector;
