import React, { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import Modal from '@iso/components/Feedback/Modal';
import { TableWrapper, ComponentTitle, TitleWrapper } from './TaskQuality.styles';
import { Input, Select } from 'antd';
import { Grid } from 'react-flexbox-grid';
import actions from '@iso/redux/taskQuality/actions';
import Form from '@iso/components/uielements/form';
import _ from 'lodash';
import moment from 'moment';
import 'moment/locale/ru';

moment.locale('ru');

const { Option } = Select;
const {
  loadFromAgroInvest,
  setFilters,
  saveIntoAgroInvestCheckMetricLimits,
  saveIntoAgroInvestSectionLimits,
  sectionsLoadFromAgroInvest,
} = actions;

const isNotValidDigital = (str) => /\D/.test(str);

const ModalCheckMetricLimit = ({
  checkMetricLimit,
  setModalCheckMetric,
  setSelectedCheckMetricLimit,
}) => {
  const dispatch = useDispatch();
  const closeModal = () =>
    setModalCheckMetric((prevState) => ({
      ...prevState,
      active: false,
    }));
  return (
    <Modal
      visible
      onClose={closeModal}
      title={`${checkMetricLimit.checkMetric.name} - балл: ${checkMetricLimit.mark}`}
      okText="Сохранить"
      okButtonProps={{
        // TODO: okButtonProps={{ disabled: !hasAccessToEdit }}
        disabled: checkMetricLimit.minQuality.length < 1 || checkMetricLimit.maxQuality.length < 1,
      }}
      onOk={() => {
        dispatch(saveIntoAgroInvestCheckMetricLimits(checkMetricLimit));
        setModalCheckMetric({ active: false });
      }}
      onCancel={closeModal}
    >
      <Form>
        <Form.Item
          label="От"
          hasFeedback
          validateStatus={checkMetricLimit.minQuality.length < 1 ? 'error' : 'success'}
        >
          <Input
            value={checkMetricLimit.minQuality}
            onChange={(e) => {
              e.persist();
              if (isNotValidDigital(e.target.value)) {
                return;
              }
              setSelectedCheckMetricLimit((prevState) => ({
                ...prevState,
                minQuality: e.target.value,
              }));
            }}
          />
        </Form.Item>
        <Form.Item
          label="До"
          hasFeedback
          validateStatus={checkMetricLimit.maxQuality.length < 1 ? 'error' : 'success'}
        >
          <Input
            value={checkMetricLimit.maxQuality}
            onChange={(e) => {
              e.persist();
              if (isNotValidDigital(e.target.value)) {
                return;
              }
              setSelectedCheckMetricLimit((prevState) => ({
                ...prevState,
                maxQuality: e.target.value,
              }));
            }}
          />
        </Form.Item>
      </Form>
    </Modal>
  );
};

const ModalSectionLimit = ({ sectionLimit, setModalSection, setSelectedSectionLimit }) => {
  const dispatch = useDispatch();
  const closeModal = () =>
    setModalSection((prevState) => ({
      ...prevState,
      active: false,
    }));

  const { type } = sectionLimit;
  if (sectionLimit.name === 'Сумма баллов') {
    return (
      <Modal
        visible
        onClose={closeModal}
        title={`${sectionLimit.name} - балл: ${sectionLimit.mark}`}
        okText="Сохранить"
        okButtonProps={{
          // TODO: okButtonProps={{ disabled: !hasAccessToEdit }}
          disabled: sectionLimit[`min${type}`].length < 1 || sectionLimit[`max${type}`].length < 1,
        }}
        onOk={() => {
          dispatch(saveIntoAgroInvestSectionLimits(sectionLimit));
          setModalSection({ active: false });
        }}
        onCancel={closeModal}
      >
        <Form>
          <Form.Item
            label="От"
            hasFeedback
            validateStatus={sectionLimit[`min${type}`].length < 1 ? 'error' : 'success'}
          >
            <Input
              value={sectionLimit[`min${type}`]}
              onChange={(e) => {
                e.persist();
                if (isNotValidDigital(e.target.value)) {
                  return;
                }
                setSelectedSectionLimit((prevState) => ({
                  ...prevState,
                  [`min${type}`]: e.target.value,
                }));
              }}
            />
          </Form.Item>
          <Form.Item
            label="До"
            hasFeedback
            validateStatus={sectionLimit[`max${type}`].length < 1 ? 'error' : 'success'}
          >
            <Input
              value={sectionLimit[`max${type}`]}
              onChange={(e) => {
                e.persist();
                if (isNotValidDigital(e.target.value)) {
                  return;
                }
                setSelectedSectionLimit((prevState) => ({
                  ...prevState,
                  [`max${type}`]: e.target.value,
                }));
              }}
            />
          </Form.Item>
        </Form>
      </Modal>
    );
  }
  return (
    <Modal
      visible
      onClose={closeModal}
      title={`${sectionLimit.name} - балл: ${sectionLimit.mark}`}
      okText="Сохранить"
      okButtonProps={{
        // TODO: okButtonProps={{ disabled: !hasAccessToEdit }}
        disabled: sectionLimit[`min${type}`].length < 1 || sectionLimit[`max${type}`].length < 1,
      }}
      onOk={() => {
        dispatch(saveIntoAgroInvestSectionLimits(sectionLimit));
        setModalSection({ active: false });
      }}
      onCancel={closeModal}
    >
      <Form>
        <Form.Item
          label="От"
          hasFeedback
          validateStatus={sectionLimit[`min${type}`].length < 1 ? 'error' : 'success'}
        >
          <Input
            value={Math.floor(sectionLimit[`min${type}`] / 60)}
            onChange={(e) => {
              e.persist();
              if (isNotValidDigital(e.target.value)) {
                return;
              }
              setSelectedSectionLimit((prevState) => ({
                ...prevState,
                [`min${type}`]: (e.target.value * 60).toString(),
              }));
            }}
          />
        </Form.Item>
        <Form.Item
          label="До"
          hasFeedback
          validateStatus={sectionLimit[`max${type}`].length < 1 ? 'error' : 'success'}
        >
          <Input
            value={Math.floor(sectionLimit[`max${type}`] / 60)}
            onChange={(e) => {
              e.persist();
              if (isNotValidDigital(e.target.value)) {
                return;
              }
              setSelectedSectionLimit((prevState) => ({
                ...prevState,
                [`max${type}`]: (e.target.value * 60 + 59).toString(),
              }));
            }}
          />
        </Form.Item>
      </Form>
    </Modal>
  );
};

const TaskQuality = () => {
  const dispatch = useDispatch();
  const { greenhouseId } = useSelector((state) => state.App);
  const { isLoading, isLoadingSections, sections, filters, qualityLimits, timeLimits } =
    useSelector((state) => state.TaskQuality);

  const [modalCheckMetric, setModalCheckMetric] = useState({ active: false });
  const [selectedCheckMetricLimit, setSelectedCheckMetricLimit] = useState(null);

  const [modalSection, setModalSection] = useState({ active: false });
  const [selectedSectionLimit, setSelectedSectionLimit] = useState(null);

  useEffect(() => {
    if (filters.sectionId) {
      dispatch(loadFromAgroInvest());
    }
    dispatch(sectionsLoadFromAgroInvest());
  }, [dispatch, greenhouseId, filters.sectionId]);

  const handleSetFilters = (key, value) => {
    dispatch(
      setFilters({
        ...filters,
        [key]: value,
      }),
    );
  };

  const SectionLimitsColumns = [
    {
      title: 'Характеристики общие для вида работ',
      dataIndex: 'name',
      align: 'center',
      width: '400px',
    },
    ..._.range(5, 0).map((el) => ({
      title: el,
      dataIndex: `${el}[0]`,
      onCell: (record) => ({
        onClick: () => {
          setSelectedSectionLimit({
            ...record[el][0],
            type: record.type,
            name: record.name,
          });
          setModalSection({ active: true });
        },
      }),
      render: ({ minQuality, maxQuality, minTime, maxTime }, record) => {
        switch (record.type) {
          case 'Time':
            return `${Math.floor(minTime / 60)} - ${Math.floor(maxTime / 60)}`;
          case 'Quality':
            return `${minQuality} - ${maxQuality}`;
          default:
            return 'errorType';
        }
      },

      align: 'center',
      width: '200px',
    })),
  ];
  const CheckMetricLimitsColumns = [
    {
      title: 'Название проверки',
      dataIndex: 'name',
      align: 'center',
      width: '400px',
    },
    {
      title: 'Бальная шкала',
      children: [
        ..._.range(5, 0).map((el) => ({
          title: el,
          dataIndex: `${el}[0]`,
          onCell: (record) => ({
            onClick: () => {
              setSelectedCheckMetricLimit(record[el][0]);
              setModalCheckMetric({ active: true });
            },
          }),
          render: ({ minQuality, maxQuality }) => `${minQuality} - ${maxQuality}`,
          align: 'center',
          width: '200px',
        })),
      ],
    },
  ];

  return (
    <Grid fluid>
      <TitleWrapper>
        <ComponentTitle>
          Вид работ: &nbsp;
          <Select
            disabled={isLoadingSections}
            dropdownMatchSelectWidth={false}
            loading={isLoadingSections}
            style={{ width: 600 }}
            value={_.get(
              _.find(sections, (section) => section.sectionId === filters.sectionId),
              'name',
              '',
            )}
            onChange={(value) => handleSetFilters('sectionId', value)}
          >
            {_.compact(
              _.map(_.sortBy(sections, ['name']), (section) => {
                if (section.isQuality) return null;

                return (
                  <Option key={section.sectionId} value={section.sectionId}>
                    {section.name}
                  </Option>
                );
              }),
            )}
          </Select>
        </ComponentTitle>
      </TitleWrapper>

      {modalSection.active && (
        <ModalSectionLimit
          sectionLimit={selectedSectionLimit}
          setModalSection={setModalSection}
          setSelectedSectionLimit={setSelectedSectionLimit}
        />
      )}
      {modalCheckMetric.active && (
        <ModalCheckMetricLimit
          checkMetricLimit={selectedCheckMetricLimit}
          setModalCheckMetric={setModalCheckMetric}
          setSelectedCheckMetricLimit={setSelectedCheckMetricLimit}
        />
      )}
      <TableWrapper
        loading={isLoading}
        columns={CheckMetricLimitsColumns}
        dataSource={qualityLimits}
        pagination={false}
        bordered
        rowKey={(record) => record.id}
      />

      <TableWrapper
        loading={isLoading}
        columns={SectionLimitsColumns}
        dataSource={timeLimits}
        pagination={false}
        bordered
        rowKey={(record) => record.type}
      />
    </Grid>
  );
};

export default TaskQuality;
