import React from "react";
import crypto from "crypto";
import { useHistory } from "react-router-dom";
import { useSelector, useDispatch } from "react-redux";
import { Layout } from "antd";
import appActions from "@iso/redux/app/actions";
import sectionActions from "@iso/redux/section/actions";
import dashboardActions from "@iso/redux/dashboard/actions";
import TopbarUser from "./TopbarUser";
import TopbarWrapper, { TopbarSelect } from "./Topbar.styles";

import _ from "lodash";
import moment from "moment";

import { getBlocksPermissions } from "@iso/lib/helpers/getBlocksPermissions";

import { SelectOption } from "@iso/components/uielements/select";
const Option = SelectOption;

const { Header } = Layout;
const { toggleCollapsed, setGreenhouse } = appActions;

const { refreshTasks } = sectionActions;

const AVATAR_SIZE = "360";

export default function Topbar() {
  const dispatch = useDispatch();
  const history = useHistory();

  const customizedTheme = useSelector(
    (state) => state.ThemeSwitcher.topbarTheme
  );

  const { collapsed, openDrawer } = useSelector((state) => state.App);

  const {
    allowedGreenhouses,
    greenhouseId,
    isLoadingGreenhouses,
    appSettings,
  } = useSelector((state) => state.App);

  const [workTimePermissions] = getBlocksPermissions("dashboard", [
    "work-time",
  ]);

  const { email = "" } = useSelector((state) => state.Auth);
  const handleToggle = React.useCallback(() => dispatch(toggleCollapsed()), [
    dispatch,
  ]);

  const { workingTimeConfig } = appSettings;

  const isCollapsed = collapsed && !openDrawer;
  const styling = {
    background: customizedTheme.backgroundColor,
    position: "fixed",
    width: "100%",
    height: 70,
  };

  const handleChange = React.useCallback(
    (greenhouseId) => {
      dispatch(setGreenhouse(greenhouseId));
      dispatch(refreshTasks());
      if (history.location.pathname === "/dashboard") {
        dispatch(dashboardActions.loadFromAgroInvest());
      }
    },
    [dispatch, history]
  );

  const hashEmail = crypto
    .createHash("md5")
    .update(email.toLowerCase())
    .digest("hex");
  const gravatarUrl = `https://www.gravatar.com/avatar/${hashEmail}?s=${AVATAR_SIZE}`;

  return (
    <TopbarWrapper>
      <Header
        style={styling}
        className={
          isCollapsed ? "isomorphicTopbar collapsed" : "isomorphicTopbar"
        }
      >
        <div className="isoLeft">
          <button
            className={
              isCollapsed ? "triggerBtn menuCollapsed" : "triggerBtn menuOpen"
            }
            style={{ color: customizedTheme.textColor }}
            onClick={handleToggle}
          />
        </div>

        <div className="isoCenter">
          <TopbarSelect
            dropdownMatchSelectWidth={false}
            value={
              isLoadingGreenhouses
                ? "Загрузка..."
                : _.isEmpty(allowedGreenhouses)
                ? "Теплицы не назначены"
                : greenhouseId
            }
            onChange={handleChange}
            disabled={_.isEmpty(allowedGreenhouses)}
            loading={isLoadingGreenhouses}
          >
            {_.map(allowedGreenhouses, (g) => (
              <Option value={g.id} key={g.id}>
                {" "}
                {g.description}{" "}
              </Option>
            ))}
          </TopbarSelect>
          {workTimePermissions.read && workingTimeConfig && (
            <div className="working-time">
              <span>рабочие часы:</span>
              <span>
                {`${moment
                  .utc(workingTimeConfig.start, "HH:mm")
                  .local()
                  .format("HH:mm")} - ${moment
                  .utc(workingTimeConfig.finish, "HH:mm")
                  .local()
                  .format("HH:mm")}`}
              </span>
            </div>
          )}
        </div>

        <ul className="isoRight">
          <li className="isoUser">
            <TopbarUser avatarSrc={gravatarUrl} />
          </li>
        </ul>
      </Header>
    </TopbarWrapper>
  );
}
