import React from 'react';
import { Popover } from 'antd';
import { useSelector, useDispatch } from 'react-redux';
import _ from 'lodash';
import { Link } from 'react-router-dom';

import chatActions from '@iso/redux/chat/actions';

import IntlMessages from '@iso/components/utility/intlMessages';
import Scrollbar from '@iso/components/utility/customScrollBar';
import { timeDifference } from '@iso/lib/helpers/utility';
import TopbarDropdownWrapper from './TopbarDropdown.styles';

const TopbarMessage = (props) => {
  const [visible, setVisiblity] = React.useState(false);

  const dispatch = useDispatch();

  const customizedTheme = useSelector(state => state.ThemeSwitcher.topbarTheme);
  const newMessages = useSelector(state => ({
    pool: state.Chat.generalMessagesPool,
    poolCount: state.Chat.generalMessagesPool.length
  }));
  const chatUsers = useSelector(state => state.Chat.users);
  const chatRooms = useSelector(state => state.Chat.chatRooms);

  const handleVisibleChange = () => {
    setVisiblity(visible => !visible);
  }

  const selectChatroom = (message) => {
    const roomId = `worker.${message.sender}`;
    const chatRoom = _.find(chatRooms, (r) => r.id === roomId);

    if (!_.isNil(chatRoom) && !_.isEmpty(chatRoom)) {
      dispatch(chatActions.setSelectedChatroom(chatRoom));
    }
  }

  const content = (
    <TopbarDropdownWrapper className="topbarMessage withImg">
      <div className="isoDropdownHeader">
        <h3>
          <IntlMessages id="sidebar.message" />
        </h3>
      </div>
      <div className="isoDropdownBody">
        <Scrollbar style={{ height: 300 }}>
          {newMessages.pool.map(message => (
            <Link to={`/dashboard/chat`} onClick={() => selectChatroom(message)} className="isoDropdownListItem" key={message._id}>
              <div className="isoImgWrapper">
                <img alt="#" src={props.avatarSrc} />
              </div>

              <div className="isoListContent">
                <div className="isoListHead">
                  <h5>{_.get(_.find(chatUsers, { id: message.sender }), 'name')}</h5>
                  <span className="isoDate">{timeDifference(message.messageTime)}</span>
                </div>
                <p>{message.text}</p>
              </div>
            </Link>
          ))}
        </Scrollbar>
      </div>
    </TopbarDropdownWrapper>
  );
  return (
    <Popover
      content={content}
      trigger="click"
      visible={visible}
      onVisibleChange={handleVisibleChange}
      placement="bottomLeft"
    >
      <div className="isoIconWrapper">
        <i
          className="ion-chatbubbles"
          style={{ color: customizedTheme.textColor }}
        />
        <span>{newMessages.poolCount}</span>
      </div>
    </Popover>
  );
}

export default TopbarMessage;
