import React, { useEffect } from "react";
import { useSelector, useDispatch } from "react-redux";
import { Spin } from "antd";

import { AreaOfWorkWidgetWrapper } from "./AreaOfWorkWidget.styles";

import _ from "lodash";

import { TableViews } from "@iso/containers/Tables/AntTables/AntTables";
import { normalize } from "@iso/lib/helpers/Ranges";

import actions from "@iso/redux/dashboard/actions";

const { loadTasksAreaOfWorkFromAgroinvest } = actions;

const AreaOfWorkWidget = ({ areaOfWorkPermissions }) => {
  const { sectionsRead } = areaOfWorkPermissions;

  const { tasksAreaOfWork, isTasksAreaOfWorkLoading } = useSelector(
    (state) => state.Dashboard
  );

  const { greenhouseId } = useSelector((state) => state.App);

  const dispatch = useDispatch();

  useEffect(() => {
    dispatch(loadTasksAreaOfWorkFromAgroinvest());
  }, [greenhouseId, dispatch]);

  const filteredTasksAreaOfWork = _.isNil(sectionsRead)
    ? tasksAreaOfWork
    : _.filter(tasksAreaOfWork, (item) =>
        _.includes(sectionsRead, _.get(item, "module"))
      );

  const columns = [
    {
      title: "Вид работ",
      dataIndex: "typeOfWork",
      key: "typeOfWork",
      width: 100,
      render: (text, row) => {
        return row.sectionName;
      },
    },
    {
      title: "Общая длина в метрах",
      dataIndex: "lengthOfWorkArea",
      key: "lengthOfWorkArea",
      width: 60,
      render: (text, row) => {
        return row.result;
      },
    },
  ];

  return (
    <AreaOfWorkWidgetWrapper>
      <div className="isoProgressWidgetTopbar" style={{ marginBottom: "30px" }}>
        <h3>Метраж выполненных работ</h3>
      </div>
      {isTasksAreaOfWorkLoading ? (
        <Spin />
      ) : (
        <TableViews.EditView
          bordered
          pagination={false}
          normalize={normalize}
          columns={columns}
          dataSource={filteredTasksAreaOfWork}
        ></TableViews.EditView>
      )}
    </AreaOfWorkWidgetWrapper>
  );
};

export { AreaOfWorkWidget };
