import React, { useEffect } from "react";
import { useDispatch } from "react-redux";

import { ReportWidgetWrapper, TableWrapper } from "./ReportWidget.styles";
import SingleProgressWidget from "../Progress/ProgressSingle";
import { Spin } from "antd";
import _ from "lodash";

import dashboardActions from "@iso/redux/dashboard/actions";

const { loadFromAgroInvest } = dashboardActions;

export default function ({
  label,
  details,
  dayProgress,
  isLoading,
  reportsWeekPermissions,
  reportsPermissions,
  greenhouseSections,
}) {
  const dispatch = useDispatch();

  useEffect(() => {
    if (!_.isEmpty(greenhouseSections) && !reportsPermissions.read) {
      dispatch(loadFromAgroInvest());
    }
  }, [greenhouseSections, dispatch]);

  const { sectionsRead } = reportsWeekPermissions;

  const filteredDayProgress = _.isNil(sectionsRead)
    ? dayProgress
    : _.filter(dayProgress, (item) => _.includes(sectionsRead, item.module));

  const columns = [
    {
      title: "Прогресс",
      dataIndex: "progress",
      key: "progress",
      render: (text, row) => {
        const titleAction =
          row.totalFinished > row.totalAll ? "перевыполнение" : "осталось";
        const title = (
          <div>
            {row.name}{" "}
            <small>
              {row.totalFinished +
                " из " +
                row.totalAll +
                `, ${titleAction} ` +
                Math.abs(row.totalAll - row.totalFinished)}
            </small>
          </div>
        );
        const percent = _.round((100 * row.totalFinished) / row.totalAll);
        return (
          <SingleProgressWidget
            key={row.id}
            label={title}
            percent={percent}
            barHeight={7}
            status={"active"}
            info={true} // Boolean: true, false
          />
        );
      },
    },
  ];

  return (
    <ReportWidgetWrapper className="isoReportsWidget">
      <h3 className="isoWidgetLabel">{label}</h3>
      <div className="isoReportsWidgetBar">
        {isLoading ? (
          <Spin />
        ) : (
          <TableWrapper
            rowKey={() => _.uniqueId()}
            dataSource={filteredDayProgress}
            columns={columns}
            pagination={false}
          />
        )}
      </div>

      <p className="isoDescription">{details}</p>
    </ReportWidgetWrapper>
  );
}
