import React, { useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";

import { ReportWidgetWrapper, TableWrapper } from "./ReportWidget.styles";
import SingleProgressWidget from "../Progress/ProgressSingle";
import { Spin, Switch } from "antd";

import dashboardActions from "@iso/redux/dashboard/actions";

import _ from "lodash";
import moment from "moment";
import { Link } from "react-router-dom";

const { loadFromAgroInvest } = dashboardActions;

export default function ({
  label,
  details,
  dayProgress,
  isLoading,
  selectedDay,
  reportsPermissions,
  greenhouseSections,
}) {
  const dispatch = useDispatch();

  useEffect(() => {
    if (!_.isEmpty(greenhouseSections)) {
      dispatch(loadFromAgroInvest());
    }
  }, [greenhouseSections, dispatch]);

  const { email: managerEmail } = useSelector((state) => state.Auth);

  const {
    edit: hasAccessToEdit,
    sectionsEdit,
    sectionsRead,
  } = reportsPermissions;

  const filteredDayProgress = _.isNil(sectionsRead)
    ? dayProgress
    : _.filter(dayProgress, (item) => _.includes(sectionsRead, item.module));

  const handleSwitchOnPause = (id, onPause) => {
    const data = {
      onPause: !onPause,
    };

    if (!onPause) {
      data.pauseChangedAt = moment().format();
      data.manager = managerEmail;
    }

    dispatch(dashboardActions.saveGreenhouseSectionToAgroInvest(id, data));
  };

  const columns = [
    {
      title: "Прогресс",
      dataIndex: "progress",
      key: "progress",
      render: (text, row) => {
        const titleAction =
          row.totalFinished > row.totalAll ? "перевыполнение" : "осталось";
        const title = (
          <Link
            to={{
              pathname: "/dashboard/tasks",
              state: { sectionId: row.id, selectedDay: selectedDay },
            }}
          >
            {row.name}{" "}
            <small>
              {row.totalFinished +
                " из " +
                row.totalAll +
                `, ${titleAction} ` +
                Math.abs(row.totalAll - row.totalFinished)}
            </small>
          </Link>
        );
        const percent = _.round((100 * row.totalFinished) / row.totalAll);
        return (
          <SingleProgressWidget
            key={row.id}
            label={title}
            percent={percent}
            barHeight={7}
            status={"active"}
            info={false} // Boolean: true, false
            customPercent={true}
          />
        );
      },
    },
    {
      title: "Дата последней остановки",
      dataIndex: "greenhouseSection.pauseChangedAt",
      key: "pausedAt",
      align: "center",
      render: (pausedAt, row) => {
        return pausedAt ? moment(pausedAt).format("DD MMMM YYYY HH:mm") : null;
      },
    },
    {
      title: "Кто остановил",
      dataIndex: "greenhouseSection.manager",
      key: "manager",
      align: "center",
      render: (manager, row) => {
        return manager ? manager : null;
      },
    },
    {
      title: "Активен",
      dataIndex: "greenhouseSection",
      key: "isActive",
      render: (greenhouseSection, row) => {
        if (!greenhouseSection) {
          return null;
        }
        const id = greenhouseSection.id;
        const isActive = !greenhouseSection.onPause;

        const hasAccessToSwitch =
          hasAccessToEdit && _.includes(sectionsEdit, greenhouseSection.module);

        return (
          <Switch
            defaultChecked={isActive}
            disabled={!hasAccessToSwitch}
            onChange={(value) => handleSwitchOnPause(id, value)}
          />
        );
      },
    },
  ];

  return (
    <ReportWidgetWrapper className="isoReportsWidget">
      <h3 className="isoWidgetLabel">{label}</h3>

      <div className="isoReportsWidgetBar">
        {isLoading ? (
          <Spin />
        ) : (
          <TableWrapper
            rowKey={() => _.uniqueId()}
            dataSource={filteredDayProgress}
            columns={columns}
            pagination={false}
          />
        )}
      </div>

      <p className="isoDescription">{details}</p>
    </ReportWidgetWrapper>
  );
}
