import React, { useEffect } from 'react';
import { useSelector, useDispatch } from 'react-redux';

import { SectionsOnPauseWidgetWrapper } from './SectionsOnPauseWidget.styles';
import { Spin, Switch, Table } from 'antd';

import dashboardActions from '@iso/redux/dashboard/actions'

import _ from 'lodash'
import moment from 'moment'

export default function () {
  const {
    greenhouseSections,
    isLoadingGreenhouseSections
  } = useSelector(state => state.Dashboard)

  const {
    greenhouseId
  } = useSelector(state => state.App)

  const dispatch = useDispatch()

  const handleSwitchOnPause = (row, value) => {
    const onPause = value
    const id = row.key

    const data = {
      onPause: !onPause,
    }

    if (!value) data.pauseChangedAt = moment().format()

    dispatch(dashboardActions.saveGreenhouseSectionToAgroInvest(id, data))
  }

  useEffect(() => {
    if (greenhouseId) {
      dispatch(dashboardActions.loadGreenhouseSectionsFromAgroInvest(greenhouseId))
    }
  }, [dispatch, greenhouseId])

  const columns = [
    {
      title: 'Вид работ',
      dataIndex: 'section',
      key: 'section',
    },
    {
      title: 'Дата последней остановки',
      dataIndex: 'pausedAt',
      key: 'pausedAt',
      align: 'center',
      render: (pausedAt, row) => {
        return pausedAt
          ? moment(pausedAt).format('DD MMMM YYYY HH:mm')
          : null
      }
    },
    {
      title: 'Активен',
      dataIndex: 'isActive',
      key: 'isActive',
      render: (isActive, row) => {
        return (
          <Switch
            defaultChecked={isActive}
            onChange={(value) => handleSwitchOnPause(row, value)}
          />
        )
      }
    }
  ]

  const data = _.map(_.sortBy(greenhouseSections, s => s.name), section => {
    return {
      key: section.id,
      section: section.name,
      pausedAt: section.pauseChangedAt,
      isActive: !section.onPause,
    }
  })

  return (
    <SectionsOnPauseWidgetWrapper className="isoSectionsOnPauseWidget">
      {
        isLoadingGreenhouseSections
          ? <Spin />
          : (
            <Table
              dataSource={data}
              columns={columns}
              pagination={false}
            />
          )
      }
    </SectionsOnPauseWidgetWrapper>
  );
}
