import React from "react";
import { useDispatch, useSelector } from "react-redux";
import { Row, Col, Icon, Tabs } from "antd";
import LayoutWrapper from "@iso/components/utility/layoutWrapper";
import basicStyle from "@iso/assets/styles/constants";
import IsoWidgetsWrapper from "./WidgetsWrapper";
import IsoWidgetBox from "./WidgetBox";
import ReportsWidget from "./Report/ReportWidget";
import ReportsWeekWidget from "./Report/ReportWeekWidget";
import { PlanWidget } from "./Plan/PlanWidget";
import { AreaOfWorkWidget } from "./AreaOfWork/AreaOfWorkWidget";
import { TableViews } from "../Tables/AntTables/AntTables";
// import GoogleChart from 'react-google-charts';
// import * as googleChartConfigs from '../Charts/GoogleChart/config';

import dashboardActions from "@iso/redux/dashboard/actions";

import Button, { ButtonGroup } from "@iso/components/uielements/button";

import _ from "lodash";
import moment from "moment-timezone";
import "moment/locale/ru";

import { getBlocksPermissions } from "@iso/lib/helpers/getBlocksPermissions";
moment.tz.setDefault("Europe/Moscow");
moment.locale("ru");
const { TabPane } = Tabs;
const { loadGreenhouseSectionsFromAgroInvest, selectDay, setModule } = dashboardActions;

const moduleName = {
  "regular": "Общий блок МУП",
  "phenology": "Фенология",
  "guarding": "Защита",
  // "quality": "Контроль качества",
}

const moduleSections = {
  "regular": ["regular", "harvesting"],
  "phenology": ["phenology"],
  "guarding": ["guarding", "spraying", "monitoring"],
  // "quality": ["quality"],
}

const columns = [
  {
    title: "День недели",
    dataIndex: "key",
    key: "key",
    sorter: (a, b) => {
      if (a.key < b.key) return -1;
      if (a.key > b.key) return 1;
      return 0;
    },
    render: (text, row) => {
      return moment().day() === row.key ? <b>{row.name}</b> : row.name;
    },
  },
  {
    title: "Всего",
    dataIndex: "totalAll",
    key: "totalAll",
    sorter: (a, b) => {
      if (a.totalAll < b.totalAll) return -1;
      if (a.totalAll > b.totalAll) return 1;
      return 0;
    },
    render: (text, row) => {
      return _.get(row, "totalAll", 0);
    },
  },
  {
    title: "Завершено",
    dataIndex: "totalFinished",
    key: "totalFinished",
    sorter: (a, b) => {
      if (a.totalFinished < b.totalFinished) return -1;
      if (a.totalFinished > b.totalFinished) return 1;
      return 0;
    },
    render: (text, row) => {
      return _.get(row, "totalFinished", 0);
    },
  },
  {
    title: "Не завершено",
    dataIndex: "totalNotFinished",
    key: "totalNotFinished",
    sorter: (a, b) => {
      if (a.totalFinished < b.totalFinished) return 1;
      if (a.totalFinished > b.totalFinished) return -1;
      return 0;
    },
    render: (text, row) => {
      return _.get(row, "totalAll", 0) - _.get(row, "totalFinished", 0);
    },
  },
  {
    title: "Выполнено",
    dataIndex: "totalCompleted",
    key: "totalCompleted",
    sorter: (a, b) => {
      if (a.totalCompleted < b.totalCompleted) return 1;
      if (a.totalCompleted > b.totalCompleted) return -1;
      return 0;
    },
    render: (text, row) => {
      return _.get(row, "totalCompleted", 0);
    },
  },
];

export default function () {
  const {
    isLoading,
    dayProgress,
    isLoadingTasksWeek,
    tasksWeekProgress,
    weekProgress,
    selectedDay,
    greenhouseSections,
    module
  } = useSelector((state) => state.Dashboard);

  const dispatch = useDispatch();

  const { greenhouseId } = useSelector((state) => state.App);
  const { role } = useSelector((state) => state.Auth);

  const { rowStyle, colStyle } = basicStyle;

  React.useEffect(() => {
    dispatch(loadGreenhouseSectionsFromAgroInvest(greenhouseId));
    if (role === 'main-guardian') {
      dispatch(setModule('guarding'))
    }
  }, [dispatch, greenhouseId]);

  const [
    reportsPermissions,
    reportsWeekPermissions,
    areaOfWorkPermissions,
    planPermissions,
  ] = getBlocksPermissions("dashboard", [
    "reports",
    "reports-week",
    "area-of-work",
    "plan",
  ]);

  const reportTitle = (
    <div>
      {moment().day(selectedDay).format("LL") + " "}
      <ButtonGroup size="default">
        <Button
          type="primary"
          onClick={() => dispatch(selectDay(selectedDay - 1))}
        >
          <Icon type="left" />
          Предыдущий день
        </Button>
        <Button
          type="primary"
          onClick={() => dispatch(selectDay(selectedDay + 1))}
        >
          Следующий день
          <Icon type="right" />
        </Button>
      </ButtonGroup>
    </div>
  );

  const reportWeekTitle = (
    <div>
      {moment().startOf("week").format("LL") +
        " - " +
        moment().endOf("week").format("LL")}
    </div>
  );

  return (
    <LayoutWrapper>
      <Row style={rowStyle} gutter={0} justify="start">
        {reportsPermissions.read && (
          <Col lg={24} md={24} sm={24} xs={24} style={colStyle}>
            <IsoWidgetsWrapper>
              {/* Report Widget */}
              <ReportsWidget
                greenhouseId={greenhouseId}
                selectedDay={selectedDay}
                label={reportTitle}
                details="Прогресс выполнения з-н по видам работ за сегодня"
                dayProgress={dayProgress}
                isLoading={isLoading}
                reportsPermissions={reportsPermissions}
                greenhouseSections={greenhouseSections}
              />
            </IsoWidgetsWrapper>
          </Col>
        )}
        {reportsWeekPermissions.read && (
          <>
            <Col lg={24} md={24} sm={24} xs={24} style={colStyle}>
              <IsoWidgetsWrapper>
                {/* Report Widget */}
                <ReportsWeekWidget
                  greenhouseId={greenhouseId}
                  label={reportWeekTitle}
                  details="Прогресс выполнения з-н по видам работ за неделю"
                  dayProgress={tasksWeekProgress}
                  isLoading={isLoadingTasksWeek}
                  reportsWeekPermissions={reportsWeekPermissions}
                  reportsPermissions={reportsPermissions}
                  greenhouseSections={greenhouseSections}
                />
              </IsoWidgetsWrapper>
            </Col>
            <Col lg={12} md={12} sm={24} xs={24} style={colStyle}>
              <IsoWidgetsWrapper>
                <IsoWidgetBox>
                  {/* TABLE */}
                  <TableViews.SimpleView
                    rowKey="key"
                    columns={columns}
                    dataSource={weekProgress}
                    loading={isLoading}
                    className="isoSimpleTable"
                  />
                </IsoWidgetBox>
              </IsoWidgetsWrapper>
            </Col>
          </>
        )}

        {planPermissions.read && (
          <Col lg={24} md={24} sm={24} xs={24} style={colStyle}>
            <IsoWidgetsWrapper>
              <IsoWidgetBox>
                <Tabs
                  type="card"
                  destroyInactiveTabPane={true}
                  activeKey={module}
                  onChange={(key) => {
                    dispatch(setModule(key));
                  }}
                >
                  {_.keys(moduleName)
                  .filter(module => (
                    planPermissions.tabsRead === null
                      || (
                        Array.isArray(planPermissions.tabsRead)
                          && planPermissions.tabsRead.includes(module)
                      )
                  ))
                  .map((key) => (
                    <TabPane tab={moduleName[key]} key={key}>
                      <PlanWidget
                        tab={key}
                        planPermissions={planPermissions}
                        modules={moduleSections[key]}
                      />
                    </TabPane>
                  ))}
                </Tabs>
              </IsoWidgetBox>
            </IsoWidgetsWrapper>
          </Col>
        )}

        {areaOfWorkPermissions.read && (
          <Col lg={24} md={24} sm={24} xs={24} style={colStyle}>
            <IsoWidgetsWrapper>
              <IsoWidgetBox>
                <AreaOfWorkWidget
                  isLoading={isLoading}
                  areaOfWorkPermissions={areaOfWorkPermissions}
                />
              </IsoWidgetBox>
            </IsoWidgetsWrapper>
          </Col>
        )}

        {/* {   Виджет постановки задач на паузу (v1)
          greenhouseId
            ? (
              <Col lg={12} md={12} sm={24} xs={24} style={colStyle}>
                <IsoWidgetsWrapper>
                  <IsoWidgetBox>
                    <SectionsOnPauseWidget />
                  </IsoWidgetBox>
                </IsoWidgetsWrapper>
              </Col>
            ) : null
        } */}
      </Row>
    </LayoutWrapper>
  );
}
