import React, { useEffect, useState } from 'react';
import { Link } from 'react-router-dom';
import { useDispatch, useSelector } from 'react-redux';
import workerActions from '@iso/redux/workers/actions';
import ratingActions from '@iso/redux/rating/actions';
import checkPriorityActions from '@iso/redux/checkPriority/actions';
import tasksActions from '@iso/redux/tasks/actions';
import _ from 'lodash';
import Button, { ButtonGroup } from '@iso/components/uielements/button';
import LayoutContentWrapperScrollable from '@iso/components/utility/layoutWrapperScrollable';
import Box from '@iso/components/utility/box';
import ContentHolder from '@iso/components/utility/contentHolder';
import { FilterDropdown } from '@iso/components/Tables/HelperCells';
import { Icon, List } from 'antd';
import Modal from '@iso/components/Feedback/Modal';
import Form from '@iso/components/uielements/form';
import Radio, { RadioGroup } from '@iso/components/uielements/radio';
import Timeline, { TimelineItem } from '@iso/components/uielements/timeline';
import Spin from '@iso/containers/Feedback/Spin/Spin.styles';
import ReactJson from 'react-json-view';
import { Input } from 'antd';
import InputNumber from '@iso/components/InputNumber';
import { Textarea } from '@iso/components/uielements/input';
import Switch from '@iso/components/uielements/switch';
import { Button as ButtonAntd } from 'antd';

import Select, { SelectOption } from '@iso/components/uielements/select';
import Collapse from '@iso/components/uielements/collapse';

import {
  TitleWrapper,
  ComponentTitle,
  TableWrapper,
  StatusTag,
  ActionWrapper,
  Label,
  Fieldset,
  TruncatedBlock,
} from './Worker.styles';

import moment from 'moment-timezone';
import 'moment/locale/ru';

const { Panel } = Collapse;
const Option = SelectOption;

moment.tz.setDefault('Europe/Moscow');
moment.locale('ru');

const FormItem = Form.Item;

const TaskItem = ({ task }) => {
  let statusText;
  const { rowNumber, isActive, workerName } = task;

  const isFinished = _.get(task, 'isFinished');
  const startedAt = _.get(task, 'startedAt', null);
  const finishedAt = _.get(task, 'finishedAt', null);

  if (isFinished) {
    statusText = 'Завершена';
  } else if (_.isNull(startedAt) && _.isNull(finishedAt)) {
    statusText = 'Запланирована';
  } else if (!_.isNull(startedAt) && _.isNull(finishedAt)) {
    statusText = 'В работе';
  } else if (!_.isNull(startedAt) && !_.isNull(finishedAt)) {
    statusText = 'ПАУЗА';
  }

  const [showJSON, setShowJSON] = useState(false);
  return (
    <List.Item>
      <a onClick={() => setShowJSON(!showJSON)} href="# ">
        Номер ряда: {rowNumber}
      </a>
      {showJSON && <ReactJson src={task} theme="monokai" enableClipboard />}
      <div>
        Название вида работ: <b>{task.sectionName}</b>
      </div>
      <div>
        Текущий назначенный сотрудник: <b>{workerName}</b>
      </div>
      <div>
        Статус задачи: <b>{statusText} </b>
      </div>
      <div>
        Флаг isActive: <b>{isActive ? 'Активен' : 'Неактивен'}</b>
      </div>
    </List.Item>
  );
};

const HistoryTaskItem = ({ task }) => {
  const { rowNumber, startedAt, finishedAt, workerName } = task;

  const [showJSON, setShowJSON] = useState(false);
  return (
    <List.Item>
      <a onClick={() => setShowJSON(!showJSON)} href="# ">
        Номер ряда: {rowNumber}
      </a>
      {showJSON && <ReactJson src={task} theme="monokai" enableClipboard />}
      <div>
        Название вида работ: <b>{task.sectionName}</b>
      </div>
      <div>
        Текущий назначенный сотрудник: <b>{workerName}</b>
      </div>
      <div>
        Время начала: <b>{moment(startedAt).format('LLLL')}</b>
      </div>
      <div>
        Время завершения: <b>{moment(finishedAt).format('LLLL')} </b>
      </div>
    </List.Item>
  );
};

const TrolleyHistoryItem = ({ trolley }) => {
  const { registeredAt } = trolley;
  const [showJSON, setShowJSON] = useState(false);

  return (
    <List.Item>
      <a onClick={() => setShowJSON(!showJSON)} href="# ">
        Номер тележки: {trolley.trolley}
      </a>
      {showJSON && <ReactJson src={trolley} theme="monokai" enableClipboard />}
      <div>
        Время отвязки: <b>{moment(registeredAt).format('LLLL')}</b>
      </div>
    </List.Item>
  );
};

const {
  loadFromAgroInvest,
  load1C,
  loadCamunda1C,
  switchNfc,
  assignTasks,
  trolleyUnbind,
  setFilters,
  saveIntoAgroInvest,
  toggleModalLoad,
  toggleTimeline,
  toggleAddWorker,
  setTimelineDay,
  update,
  load1CData,
  toggle1CData,
  makeScreenshot,
  uploadBackup,
  signOut,
  changeRating,
  addRating,
  getSections,
  addCheckPriority,
  changeCheckPriority,
  toggleModalCache,
  loadCache,
} = workerActions;

export default function Workers() {
  const [state, setState] = useState({});
  const [workerCode, setWorkerCode] = useState('');

  const { greenhouses, greenhouseId, allowedGreenhouses } = useSelector((state) => state.App);

  const tasksStore = useSelector((state) => state.Tasks);

  const {
    blocksPermissions: { workers: workersPermissions },
  } = useSelector((state) => _.get(state, 'Auth.userPermissions'));

  const hasMainAccessToEdit = _.get(workersPermissions, 'edit', false);

  const {
    'worker-logs': { read: hasAccessToWorkerLogsRead },
    cache: { read: hasAccessToCacheRead },
    checkPriority: { read: hasAccessToCheckPriorityRead },
    ratings: {
      edit: hasAccessToRatingsEdit,
      sectionEditAlways: accessSectionsForRatingsEditAlways,
      sectionsEdit: accessSectionsForRatingsEdit,
    },
    'login-operations': {
      edit: hasAccessToLoginOperationsEdit,
      read: hasAccessToLoginOperationsRead,
    },
    'nfc-mode': { edit: hasAccessToNfcModeEdit, read: hasAccessToNfcModeRead },
    'trolley-unlink': { edit: hasAccessToTrolleyUnlinkEdit, read: hasAccessToTrolleyUnlinkRead },
    'greenhouse-migration': {
      edit: hasAccessToGreenhouseMigrationEdit,
      read: hasAccessToGreenhouseMigrationRead,
    },
    notes: { edit: hasAccessToNotesEdit, read: hasAccessToNotesRead },
    'day-history': { read: hasAccessToDayHistoryRead },
    'add-worker': { edit: hasAccessToAddWorkerEdit, read: hasAccessToAddWorkerRead },
  } = workersPermissions.blocks;

  const {
    workers,
    isLoading,
    isLoading1C,
    isLoadingWorker,
    totalItems,
    itemsPerPage,
    page,
    filters,
    modalActive,
    timelineActive,
    addWorkerActive,
    timeline,
    timelineDay,
    worker,
    oneCLoading,
    oneCActive,
    oneCJson,
    newRatings,
    sections,
    newCheckPriorities,
    changedCheckPriorities,
    modalActiveCache,
    cache,
    cacheStatus,
  } = useSelector((state) => state.Workers);

  const dispatch = useDispatch();

  useEffect(() => {
    dispatch(getSections());
    dispatch(loadFromAgroInvest());
  }, [dispatch]);

  const dataSource = [];
  Object.keys(workers).map((worker, index) =>
    dataSource.push({
      ...workers[worker],
      key: worker,
    }),
  );

  const handleRecord = (actionName, worker) => {
    dispatch(saveIntoAgroInvest(worker, actionName));

    if (_.size(newRatings)) {
      const workerId = worker.id;
      dispatch(ratingActions.create({ newRatings, workerId }));
    }

    if (_.size(newCheckPriorities)) {
      dispatch(checkPriorityActions.create({ newCheckPriorities }));
    }
  };

  const handleModal = (worker = null) => {
    dispatch(toggleModalLoad(worker));
  };

  const handleTimeline = (worker = null) => {
    dispatch(toggleTimeline(worker));
  };

  const handleModalCache = (worker = null) => {
    dispatch(toggleModalCache(worker));
    dispatch(loadCache());
  };

  const handleAddWorker = () => {
    dispatch(
      load1CData(
        `Catalog_Сотрудники?$format=json&$orderby=Ref_Key&$filter=ДополнительныеРеквизиты/any(d: d/Значение eq '${workerCode}')`,
      ),
    );
    dispatch(toggleAddWorker());
  };

  const handleAddWorkerImport = (refKey) => {
    dispatch(loadCamunda1C(refKey, greenhouseId));
    dispatch(toggleAddWorker(null));
  };

  const onRatingChange = (e, worker, rating, ratingGreenhouse, isQuality = false) => {
    const { value } = e.target;
    const ratingId = _.get(rating, 'id', null);
    const workerId = worker.id;

    if (!_.isNull(ratingId)) {
      dispatch(changeRating({ value, workerId, ratingId, isQuality }));
    } else {
      const ratingInt = value;
      const pushRating = { ...ratingGreenhouse, ratingInt, isQuality };

      dispatch(addRating(pushRating));
    }
  };

  const onCheckPriorityChange = (props) => {
    const { priority, workerId, sectionId, checkPriority } = props;
    const checkPriorityId = _.get(checkPriority, 'id', null);

    if (_.isNull(checkPriorityId)) {
      dispatch(addCheckPriority({ priority, workerId, sectionId }));
    } else {
      dispatch(
        changeCheckPriority({
          priority,
          workerId,
          sectionId,
          id: checkPriorityId,
        }),
      );
    }
  };

  const workerUpdate = (name, value) => {
    dispatch(update(name, value));
  };

  const callToggle1CModal = (e, path) => {
    e.preventDefault();

    dispatch(toggle1CData());
    dispatch(load1CData(path));
  };

  const callLoad1C = () => {
    dispatch(load1C(worker.id));
  };

  const callSwitchNfc = () => {
    dispatch(switchNfc(worker));
  };

  const callAssignTasks = () => {
    dispatch(assignTasks(worker.id));
  };

  const callMakeScreenshot = () => {
    dispatch(makeScreenshot(worker.id));
  };

  const callTrolleyUnbind = () => {
    dispatch(trolleyUnbind(worker));
  };

  const callUploadBackup = () => {
    dispatch(uploadBackup(worker.id));
  };

  const callSignOut = () => {
    dispatch(signOut(worker.id));
  };

  const reload = () => {
    dispatch(loadFromAgroInvest());
  };

  const dropFilters = () => {
    setState({});
    dispatch(setFilters({}, 1));
  };

  function onInputChange(event, type) {
    setState({ ...state, [type]: event.target.value });
  }

  function onSearch() {
    const { searchText, searchCode, searchVersionName } = state;

    setState({
      ...state,
      filterDropdownNameVisible: false,
      filterDropdownCodeVisible: false,
      filterDropdownVersionVisible: false,
    });

    const newFilters = _.cloneDeep(filters);
    newFilters.searchable = searchText;
    newFilters.code = searchCode;
    newFilters.versionName = searchVersionName;

    dispatch(setFilters(newFilters, 1));
  }

  const handleTableChange = (pagination, newFilters, sorter) => {
    newFilters.searchable = filters.searchable;
    newFilters.code = filters.code;
    if (newFilters['ratings.sectionId'].length) newFilters['ratings.ratingInt[gte]'] = 2;

    dispatch(setFilters(newFilters, pagination.current));
  };

  const timelineRow = (timeline) => {
    const timelineInfos = {
      trolley: {
        entityName: 'Тележка',
        icon: 'ion-android-cart',
        types: {
          start: {
            operation: 'взята в работу',
            color: 'red',
          },
          finish: {
            operation: 'отвязана',
            color: 'green',
          },
        },
      },
      task: {
        entityName: 'Дорожка',
        icon: 'ion-clipboard',
        types: {
          start: {
            operation: 'взята в работу',
            color: 'red',
          },
          finish: {
            operation: 'закончена',
            color: 'green',
          },
        },
      },
      mobileLogin: {
        entityName: 'МП',
        icon: 'ion-person',
        types: {
          signIn: {
            operation: 'вход',
            color: 'red',
          },
          signOut: {
            operation: `выход ${timeline.reason && ` (${timeline.reason})` || ''}`,
            color: 'green',
          },
        },
      },
    };

    const info = timelineInfos[timeline.entity];
    const type = info.types[timeline.type];

    const result = {
      ...info,
      operation: type?.operation,
      color: type?.color,
      date: timeline.date,
    };

    return result;
  };

  const taskCountArray = [0, 1, 2, 3, 4, 5];

  const columnsSizes = {
    name: 150,
    greenhouse: 120,
    code: 90,
    department: 110,
    ratings: 280,
    taskCount: 120,
    status: 140,
    online: 110,
    actions: 90,
    versionName: 150,
  };

  const hasQualityCheckSectionIds = sections
    .filter(({ hasQualityCheck }) => hasQualityCheck === true)
    .map(({ id }) => id);

  const qualityCheckSections = worker?.greenhouse?.greenhouseSections.filter(({ sectionId }) =>
    hasQualityCheckSectionIds.includes(sectionId),
  );

  const sumWidthAllColumns = _.sum(_.values(columnsSizes));
  const boxWrapper = document.querySelector('.isoBoxWrapper');
  const boxHeight = boxWrapper ? boxWrapper.clientHeight : 0;

  const generateActionButtons = (row) => {
    const allowedGreenhouseIds = _.map(allowedGreenhouses, (g) => g.id);
    const isAttachedUser = !row.greenhouseId || _.includes(allowedGreenhouseIds, row.greenhouseId);

    const style =
      isAttachedUser || hasAccessToDayHistoryRead
        ? {}
        : {
            opacity: '0.3',
          };

    return (
      <ActionWrapper>
        <a
          onClick={() => handleModal(row)}
          disabled={!isAttachedUser || !hasMainAccessToEdit}
          href="# "
        >
          <i className="ion-android-create" style={{ ...style }} />
        </a>

        <a
          onClick={() => handleTimeline(row)}
          disabled={!isAttachedUser || !hasAccessToDayHistoryRead}
          href="# "
        >
          <i className="ion-android-time" style={{ ...style }} />
        </a>

        {hasAccessToCacheRead && (
          <a onClick={() => handleModalCache(row)} href="# ">
            <i className="ion-ios-list" style={{ ...style }} />
          </a>
        )}
      </ActionWrapper>
    );
  };

  const columns = [
    {
      title: 'ФИО',
      dataIndex: 'searchable',
      key: 'searchable',
      width: columnsSizes.name,
      filterDropdown: (
        <FilterDropdown
          searchText={state.searchText}
          onInputChange={(e) => onInputChange(e, 'searchText')}
          onSearch={onSearch}
        />
      ),
      filterIcon: <Icon type="search" style={{ color: filters.searchable ? '#108ee9' : '#aaa' }} />,
      filterDropdownVisible: state.filterDropdownNameVisible,
      onFilterDropdownVisibleChange: (visible) => {
        setState({ ...state, filterDropdownNameVisible: visible });
        document.getElementById('tableFilterInput').focus();
      },
      sorter: (a, b) => {
        if (a.name < b.name) return -1;
        if (a.name > b.name) return 1;
        return 0;
      },
      render: (text, row) => (
        <>
          <div style={{ display: 'flex' }}>
            <a
              href={`${process.env.REACT_APP_ONEC_URL}/Catalog_Сотрудники(guid:'${row.id}')?$format=json`}
              rel="noopener noreferrer"
              target="_blank"
              onClick={(e) =>
                callToggle1CModal(e, `Catalog_Сотрудники(guid:'${row.id}')?$format=json`)
              }
            >
              {row.name}
            </a>
            <p
              style={{
                marginLeft: '14px',
              }}
            >
              {hasAccessToWorkerLogsRead ? (
                <Link to={`/dashboard/audit/${row.id}`}>
                  <i className="ion-android-time" />
                </Link>
              ) : (
                <Link to="#" disabled style={{ color: 'gray' }}>
                  <i className="ion-android-time" />
                </Link>
              )}
            </p>
          </div>
          <br />
          <div>
            Дата рождения: {moment(_.get(row, 'birthDate')).format('DD.MM.YYYY') || 'n/a'}
            <br />
            График работы: {_.get(row, 'schedule', 'n/a')}
          </div>
          <small>{_.get(row, 'notes', 'n/a')}</small>
        </>
      ),
    },
    {
      title: 'Теплица',
      dataIndex: 'greenhouse',
      key: 'greenhouseId',
      width: columnsSizes.greenhouse,
      align: 'center',
      filters: _.map(greenhouses, (g) => ({
        text: g.description,
        value: g.id,
      })),
      filteredValue: filters.greenhouseId || [],
      filterMultiple: false,
      sorter: (a, b) => {
        if (_.get(a, 'greenhouse.description', '') < _.get(b, 'greenhouse.description', ''))
          return -1;
        if (_.get(a, 'greenhouse.description', '') > _.get(b, 'greenhouse.description', ''))
          return 1;
        return 0;
      },
      render: (text, row) => <>{_.get(row, 'greenhouse.description', 'n/a')}</>,
    },
    {
      title: 'Код',
      dataIndex: 'code',
      key: 'code',
      width: columnsSizes.code,
      align: 'center',
      filterDropdown: (
        <FilterDropdown
          searchText={state.searchCode}
          onInputChange={(e) => onInputChange(e, 'searchCode')}
          onSearch={onSearch}
        />
      ),
      filterIcon: <Icon type="search" style={{ color: filters.code ? '#108ee9' : '#aaa' }} />,
      filterDropdownVisible: state.filterDropdownCodeVisible,
      onFilterDropdownVisibleChange: (visible) => {
        setState({ ...state, filterDropdownCodeVisible: visible });
        document.getElementById('tableFilterInput').focus();
      },
      sorter: (a, b) => {
        if (a.code < b.code) return -1;
        if (a.code > b.code) return 1;
        return 0;
      },
      render: (text, row) => row.code,
    },
    {
      title: 'Отдел',
      dataIndex: 'department',
      key: 'exclusive',
      width: columnsSizes.department,
      align: 'center',
      filters: _.map(Array(8), (g, i) => ({
        text: `Группа ${i}`,
        value: i,
      })),
      filteredValue: filters.exclusive || [],
      filterMultiple: false,
      sorter: (a, b) => {
        if (_.get(a, 'department.name', '') < _.get(b, 'department.name', '')) return -1;
        if (_.get(a, 'department.name', '') > _.get(b, 'department.name', '')) return 1;
        return 0;
      },
      render: (text, row) => (
        <>
          {_.get(row, 'department.name', 'n/a')}&nbsp;/&nbsp;
          <a
            href={
              `${process.env.REACT_APP_ONEC_URL}/InformationRegister_КадроваяИсторияСотрудников_RecordType` +
              `?$format=json` +
              `&$filter=Сотрудник_Key eq guid'${row.id}'` +
              `&$top=1` +
              `&$orderby=Period desc`
            }
            rel="noopener noreferrer"
            target="_blank"
            onClick={(e) =>
              callToggle1CModal(
                e,
                `${
                  'InformationRegister_КадроваяИсторияСотрудников_RecordType' +
                  '?$format=json' +
                  "&$filter=Сотрудник_Key eq guid'"
                }${row.id}'` +
                  `&$top=1` +
                  `&$orderby=Period desc`,
              )
            }
          >
            {_.get(row, 'position.name', 'n/a')}
          </a>
          <div>
            <StatusTag className={`workerExclusive-${row.exclusive}`}>
              Группа: {row.exclusive}
            </StatusTag>
          </div>
        </>
      ),
    },
    {
      title: 'Рейтинг',
      dataIndex: 'ratings',
      key: 'ratings.sectionId',
      width: columnsSizes.ratings,
      filters: _.map(
        _.orderBy(
          sections.filter(({ module }) => module !== 'quality'),
          ['name'],
          ['asc'],
        ),
        (s) => ({
          text: s.name,
          value: s.id,
        }),
      ),
      filterTextInput: <input />,
      filteredValue: filters['ratings.sectionId'] || [],
      filterMultiple: false,
      sorter: (a, b) => {
        if (a.name < b.name) return -1;
        if (a.name > b.name) return 1;
        return 0;
      },
      render: (text, row) => {
        let spacer = null;
        let greenhouseSections = _.get(row, 'greenhouse.greenhouseSections', null);

        if (greenhouseSections) {
          greenhouseSections = _.map(
            greenhouseSections.filter(({ module }) => module !== 'quality'),
            (g) => {
              const rating =
                _.find(
                  row.ratings,
                  (item) => item.sectionId === g.sectionId && item.isQuality === false,
                ) || {};

              return {
                ...g,
                rating: rating.rating || 0,
                ratingInt: rating.ratingInt || 1,
              };
            },
          );
        }

        return (
          <>
            {_.map(
              _.orderBy(greenhouseSections, ['ratingInt', 'name'], ['desc', 'asc']),
              (r, i) => {
                const ratings = (
                  <div key={r.id}>
                    {spacer !== r.ratingInt && spacer !== null ? <br /> : null}
                    {r.ratingInt > 1 ? <b>{r.ratingInt}</b> : 1}:
                    <a
                      href={
                        `${process.env.REACT_APP_ONEC_URL}/InformationRegister_актРейтингСотрудниковМУП` +
                        `?$format=json` +
                        `&$filter=Сотрудник_Key eq guid'${row.id}'` +
                        ` and ВидРабот_Key eq guid'${r.sectionId}'` +
                        `&$top=1` +
                        `&$orderby=Period desc`
                      }
                      rel="noopener noreferrer"
                      target="_blank"
                      onClick={(e) =>
                        callToggle1CModal(
                          e,
                          `${
                            'InformationRegister_актРейтингСотрудниковМУП' +
                            '?$format=json' +
                            "&$filter=Сотрудник_Key eq guid'"
                          }${row.id}'` +
                            ` and ВидРабот_Key eq guid'${r.sectionId}'` +
                            `&$top=1` +
                            `&$orderby=Period desc`,
                        )
                      }
                    >
                      {r.name}
                    </a>
                  </div>
                );

                spacer = r.ratingInt;

                return ratings;
              },
            )}
          </>
        );
      },
    },
    {
      title: 'Кол-во задач',
      dataIndex: 'taskCount',
      key: 'taskCount',
      width: columnsSizes.taskCount,
      align: 'center',
      filters: _.map(taskCountArray, (g, i) => {
        if (i >= taskCountArray.slice(-1)) {
          return {
            text: `${i}+`,
            value: JSON.stringify({
              gte: i,
            }),
          };
        }
        return {
          text: `${i}`,
          value: JSON.stringify({
            lte: i,
            gte: i,
          }),
        };
      }),

      filteredValue: filters.taskCount || [],
      filterMultiple: false,
      sorter: (a, b) => {
        if (a.taskCount < b.taskCount) return -1;
        if (a.taskCount > b.taskCount) return 1;
        return 0;
      },
      render: (text, row) => {
        const onClick = (data) => {
          dispatch(
            tasksActions.setFilters({ ...tasksStore.filters, 'worker.searchable': name }, 1),
          );
        };
        const name = _.get(row, 'name', null);
        const isDisabled = greenhouseId !== row.greenhouseId;
        return (
          <div style={{ textAlign: 'center' }}>
            <div>
              <ButtonAntd disabled={isDisabled} type="link" onClick={() => onClick(name)}>
                <Link to="/dashboard/tasks">{row.taskCount}</Link>
              </ButtonAntd>
            </div>
          </div>
        );
      },
    },
    {
      title: 'Статус',
      dataIndex: 'isActive',
      className: 'noWrapCell',
      width: columnsSizes.status,
      align: 'center',
      key: 'isActive',
      sorter: (a, b) => {
        if (a.isActive < b.isActive) return -1;
        if (a.isActive > b.isActive) return 1;
        return 0;
      },
      filters: [
        {
          text: 'Активный',
          value: true,
        },
        {
          text: 'Отключен',
          value: false,
        },
      ],
      filteredValue: filters.isActive || [],
      filterMultiple: false,
      render: (text, row) => {
        let className;
        if (row.isActive) {
          className = 'active';
        } else {
          className = 'inactive';
        }

        let nfcClass;
        if (row.nfcMode) {
          nfcClass = 'nfcOn';
        } else {
          nfcClass = 'nfcOff';
        }

        let phoneClass;
        if (row.phoneMode) {
          phoneClass = 'nfcOn';
        } else {
          phoneClass = 'nfcOff';
        }

        const trolleyName = _.get(row, 'trolleyName', null);
        const rowNumber = _.get(row, 'rowNumber', null);
        return (
          <>
            <div>
              <StatusTag className={className}>{row.isActive ? 'Активный' : 'Отключен'}</StatusTag>
              <div style={{ marginBottom: '10px' }} />
              <StatusTag className={nfcClass}>
                {row.nfcMode ? 'Только NFC' : 'NFC & Ручной ввод'}
              </StatusTag>
              <div style={{ marginBottom: '10px' }} />
              <StatusTag className={phoneClass}>
                {row.phoneMode ? 'Логин привязан' : 'Логин не привязан'}
              </StatusTag>
            </div>
            {trolleyName && (
              <div style={{ marginTop: '4px' }}>
                <StatusTag className="active">
                  <small>
                    Тележка:&nbsp;
                    {trolleyName}
                  </small>
                </StatusTag>
              </div>
            )}
            {rowNumber && (
              <div style={{ marginTop: '4px' }}>
                <StatusTag className="active">
                  <small>Ряд:&nbsp;{rowNumber}</small>
                </StatusTag>
              </div>
            )}
          </>
        );
      },
    },
    {
      title: 'Номер версии',
      dataIndex: 'versionName',
      key: 'versionName',
      align: 'left',
      width: columnsSizes.versionName,
      filterDropdown: (
        <FilterDropdown
          searchText={state.searchVersionName}
          onInputChange={(e) => onInputChange(e, 'searchVersionName')}
          onSearch={onSearch}
        />
      ),
      filterIcon: (
        <Icon type="search" style={{ color: filters.versionName ? '#108ee9' : '#aaa' }} />
      ),
      filterDropdownVisible: state.filterDropdownVersionVisible,
      onFilterDropdownVisibleChange: (visible) => {
        setState({ ...state, filterDropdownVersionVisible: visible });
        document.getElementById('tableFilterInput').focus();
      },
      sorter: (a, b) => {
        if (a.versionName < b.versionName) return -1;
        if (a.versionName > b.versionName) return 1;
        return 0;
      },
      render: (text, row) => {
        if (row.versionName !== 'empty') return row.versionName;
      },
    },
    {
      title: 'Онлайн',
      dataIndex: 'spreadTill',
      className: 'noWrapCell',
      key: 'spreadTill',
      width: columnsSizes.online,
      align: 'center',
      filters: [
        {
          text: 'Онлайн',
          value: JSON.stringify({
            after: moment().utc().toISOString().slice(0, -4),
          }),
        },
        {
          text: 'Оффлайн',
          value: JSON.stringify({
            before: moment().utc().toISOString().slice(0, -4),
          }),
        },
      ],
      filteredValue: filters.spreadTill || [],
      filterMultiple: false,
      sorter: (a, b) => {
        if (a.spreadTill < b.spreadTill) return -1;
        if (a.spreadTill > b.spreadTill) return 1;
        return 0;
      },

      render: (text, row) => {
        let className;
        if (moment(row.spreadTill) > moment()) {
          className = 'active';
        } else {
          className = 'inactive';
        }

        return (
          <div>
            <StatusTag className={className}>
              {moment(row.spreadTill) > moment() ? 'Онлайн' : 'Оффлайн'}
            </StatusTag>
          </div>
        );
      },
    },
    {
      title: 'Действия',
      key: 'action',
      className: 'noWrapCell',
      width: columnsSizes.actions,
      align: 'center',
      render: (text, row) => generateActionButtons(row),
    },
  ];

  const style = {
    textAlign: 'center',
    paddingBottom: '30px',
    paddingTop: '30px',
  };

  const popupTitle = (
    <>
      {worker.name}
      <br />
      <br />
      <Button
        type="primary"
        shape="circle"
        loading={isLoading1C}
        onClick={callLoad1C}
        icon="reload"
        title="Загрузить из 1С"
        style={{ marginLeft: '10px' }}
      />
      {hasAccessToTrolleyUnlinkRead && (
        <Button
          type="danger"
          shape="circle"
          loading={isLoadingWorker}
          onClick={callTrolleyUnbind}
          disabled={!hasAccessToTrolleyUnlinkEdit}
          icon="shopping-cart"
          title="Отвязать текущую тележку"
          style={{ marginLeft: '10px' }}
        />
      )}
      {hasAccessToNfcModeRead && (
        <Button
          type="success"
          shape="circle"
          loading={isLoadingWorker}
          onClick={callSwitchNfc}
          disabled={!hasAccessToNfcModeEdit}
          icon="fork"
          title="Переключить режим NFC"
          style={{ marginLeft: '10px' }}
        />
      )}
      <Button
        type="success"
        shape="circle"
        loading={isLoadingWorker}
        onClick={callAssignTasks}
        icon="plus"
        title="Распределить задачи"
        style={{ marginLeft: '10px' }}
      />
      <Button
        type="primary"
        shape="circle"
        loading={isLoadingWorker}
        onClick={callMakeScreenshot}
        icon="picture"
        title="Сделать скриншот экрана"
        style={{ marginLeft: '10px' }}
      />
      <Button
        type="primary"
        shape="circle"
        loading={isLoadingWorker}
        onClick={callUploadBackup}
        icon="database"
        title="Выгрузить базу данных"
        style={{ marginLeft: '10px' }}
      />
      <Button
        type="danger"
        shape="circle"
        loading={isLoadingWorker}
        onClick={callSignOut}
        icon="logout"
        title="Выход из приложения"
        style={{ marginLeft: '10px' }}
      />
      <br />
      <br />
      <small>{worker.id}</small>
    </>
  );

  return (
    <LayoutContentWrapperScrollable>
      <Box>
        <ContentHolder style={{ marginTop: 0, overflow: 'hidden' }}>
          <TitleWrapper>
            <ComponentTitle>
              Сотрудники <small>всего найдено: {totalItems}</small>
            </ComponentTitle>

            <div>
              {hasAccessToAddWorkerRead && (
                <>
                  <Input
                    placeholder="Добавить из 1С по табелю"
                    value={workerCode}
                    style={{ width: '250px' }}
                    onChange={({ target: { value } }) => setWorkerCode(value)}
                    disabled={isLoading || !hasAccessToAddWorkerEdit}
                  />
                  <Button
                    type="primary"
                    shape="circle"
                    loading={isLoading}
                    disabled={isLoading || !workerCode || !hasAccessToAddWorkerEdit}
                    icon="plus"
                    onClick={() => handleAddWorker()}
                    style={{ marginLeft: '10px' }}
                  />
                </>
              )}

              <Button
                type="primary"
                shape="circle"
                loading={isLoading}
                icon="filter"
                onClick={dropFilters}
                style={{ marginLeft: '10px' }}
              />
              <Button
                type="primary"
                shape="circle"
                loading={isLoading}
                icon="reload"
                onClick={reload}
                style={{ marginLeft: '10px' }}
              />
            </div>
          </TitleWrapper>

          <Modal
            visible={timelineActive}
            onClose={() => dispatch(toggleTimeline(null))}
            title={worker.name}
            okText="Закрыть"
            onOk={() => dispatch(toggleTimeline(null))}
            onCancel={() => dispatch(toggleTimeline(null))}
          >
            <div style={{ paddingBottom: '20px' }}>
              {`${moment().day(timelineDay).format('LL')} `}
              <ButtonGroup size="default" style={{ paddingLeft: '50px' }}>
                <Button type="primary" onClick={() => dispatch(setTimelineDay(timelineDay - 1))}>
                  <Icon type="left" />
                  Предыдущий день
                </Button>
                <Button type="primary" onClick={() => dispatch(setTimelineDay(timelineDay + 1))}>
                  Следующий день
                  <Icon type="right" />
                </Button>
              </ButtonGroup>
            </div>
            <Timeline pending>
              {_.map(_.map(timeline, timelineRow), (t, i) => (
                <TimelineItem
                  key={i}
                  dot={<i className={t.icon} style={{ fontSize: '16px' }} />}
                  color={t.color}
                >
                  <i>{moment(t.date).format('LLL')}:</i>
                  &nbsp;
                  <b>{t.number}</b>
                  &nbsp;
                  {t.entityName}
                  &nbsp;
                  {t.operation}
                </TimelineItem>
              ))}
            </Timeline>
          </Modal>

          <Modal
            visible={modalActiveCache}
            onClose={() => dispatch(toggleModalCache(null))}
            title={
              <>
                {worker.name}
                <br />
                <small>{worker.id}</small>
              </>
            }
            okText="Закрыть"
            onOk={() => dispatch(toggleModalCache(null))}
            onCancel={() => dispatch(toggleModalCache(null))}
          >
            <div style={{ borderBottom: 'solid 2px black' }}>
              <h3>Текущие задачи сотрудника</h3>
              {cache.tasks && (
                <List
                  loading={cacheStatus === 'loading'}
                  itemLayout="vertical"
                  dataSource={[...cache.tasks].sort(
                    (a, b) => Number(a.rowNumber) - Number(b.rowNumber),
                  )}
                  renderItem={(task) => <TaskItem task={task} />}
                />
              )}
            </div>
            <div style={{ borderBottom: 'solid 2px black' }}>
              <h3 style={{ marginTop: 16 }}>История задач сотрудника</h3>
              {cache.taskHistories && (
                <List
                  loading={cacheStatus === 'loading'}
                  itemLayout="vertical"
                  split
                  dataSource={[...cache.taskHistories].sort(
                    (a, b) => Number(a.rowNumber) - Number(b.rowNumber),
                  )}
                  renderItem={(task) => <HistoryTaskItem task={task} />}
                />
              )}
            </div>
            <div style={{ borderBottom: 'solid 2px black' }}>
              <h3 style={{ marginTop: 16 }}>История тележек</h3>
              {cache.trolleyHistories && (
                <List
                  loading={cacheStatus === 'loading'}
                  itemLayout="vertical"
                  dataSource={[...cache.trolleyHistories].sort(
                    (a, b) => Number(a.trolley) - Number(b.trolley),
                  )}
                  renderItem={(trolley) => <TrolleyHistoryItem trolley={trolley} />}
                />
              )}
            </div>
            <div style={{ borderBottom: 'solid 2px black' }}>
              <h3 style={{ marginTop: 16, marginBottom: 16 }}>Статус</h3>
              {cache.status && (
                <ReactJson src={cache.status} theme="monokai" collapsed={false} enableClipboard />
              )}
            </div>
          </Modal>

          <Modal
            visible={addWorkerActive}
            onClose={() => dispatch(toggleAddWorker(null))}
            title="Добавить сотрудника из 1С"
            okText="Импорт"
            onOk={() => handleAddWorkerImport(_.get(oneCJson, 'value.0.Ref_Key', null))}
            onCancel={() => dispatch(toggleAddWorker(null))}
            width={900}
            okButtonProps={{
              disabled: !_.get(oneCJson, 'value.0.Ref_Key', null),
            }}
          >
            {oneCLoading ? (
              <div style={style}>
                <Spin />
              </div>
            ) : (
              <ReactJson src={oneCJson} theme="monokai" collapsed={false} enableClipboard />
            )}
          </Modal>

          <Modal
            visible={modalActive}
            onClose={() => dispatch(toggleModalLoad(null))}
            title={popupTitle}
            okText="Сохранить"
            onOk={() => handleRecord('update', worker)}
            onCancel={() => dispatch(toggleModalLoad(null))}
            width={530}
          >
            <Form>
              <Fieldset>
                <Label>Параметры</Label>
                <FormItem
                  label={
                    <>
                      Статус
                      <StatusTag className={worker.isActive ? 'active' : 'inactive'}>
                        {worker.isActive ? 'активный' : 'не активный'}
                      </StatusTag>
                    </>
                  }
                  hasFeedback
                >
                  <Switch
                    checked={worker.isActive}
                    onChange={(isValue) => workerUpdate('isActive', isValue)}
                  />
                </FormItem>
                <div>
                  Дата рождения: {moment(worker.birthDate).format('DD.MM.YYYY') || 'n/a'}
                  <br />
                  Код СУРВ: {worker.code || 'n/a'}
                  <br />
                  График работы: {worker.schedule || 'n/a'}
                </div>
                <FormItem label="Группа" hasFeedback>
                  <InputNumber
                    name="exclusive"
                    min={0}
                    max={999}
                    value={worker.exclusive}
                    onChange={({ target: { value } }) => workerUpdate('exclusive', value)}
                  />
                </FormItem>
                {hasAccessToGreenhouseMigrationRead && (
                  <FormItem label="Теплица" hasFeedback>
                    <Select
                      value={worker.greenhouseId}
                      onChange={(value) => workerUpdate('greenhouseId', value)}
                      disabled={!hasAccessToGreenhouseMigrationEdit}
                    >
                      {_.map(greenhouses, (g) => (
                        <Option value={g.id} key={g.id}>
                          {' '}
                          {g.description}{' '}
                        </Option>
                      ))}
                    </Select>
                  </FormItem>
                )}
              </Fieldset>
              <Fieldset>
                <Collapse accordion>
                  <Panel header="Рейтинги" key="1">
                    {_.size(worker.greenhouse) &&
                      _.map(
                        _.orderBy(
                          worker.greenhouse.greenhouseSections.filter(
                            ({ module }) => module !== 'quality',
                          ),
                          ['ratingInt', 'name'],
                          ['desc', 'asc'],
                        ),
                        (greenhouseSection) => {
                          const rating = _.filter(
                            worker.ratings,
                            (item) =>
                              item.name === greenhouseSection.name && item.isQuality === false,
                          );
                          const ratingValue = _.map(rating, 'ratingInt', 1);

                          const newRatingValue = _.map(
                            _.filter(
                              newRatings,
                              (newR) =>
                                newR.id === greenhouseSection.id && newR.isQuality === false,
                            ),
                            'ratingInt',
                          );
                          // const isChangedRating = !!ratingValue[0];
                          // const canChangeAfterInitial =
                          //   !greenhouseSection.section.hasQualityCheck ||
                          //   (!isChangedRating && greenhouseSection.section.hasQualityCheck);
                          const canChangeAfterInitial = true;
                          const isAllowedSectionForChange =
                            hasAccessToRatingsEdit &&
                            canChangeAfterInitial &&
                            (!accessSectionsForRatingsEdit ||
                              _.includes(accessSectionsForRatingsEdit, greenhouseSection.module));

                          return (
                            <FormItem
                              label={greenhouseSection.name}
                              key={greenhouseSection.id}
                              style={{ overflow: 'hidden' }}
                              hasFeedback
                            >
                              <RadioGroup
                                onChange={(e) =>
                                  onRatingChange(e, worker, rating[0], greenhouseSection)
                                }
                                name={`ratings[${greenhouseSection.index}]`}
                                value={
                                  ratingValue[0]
                                    ? ratingValue[0]
                                    : newRatingValue[0]
                                    ? newRatingValue[0]
                                    : 1
                                }
                              >
                                {_.map(Array(10), (item, index) => (
                                  <Radio
                                    disabled={
                                      !(
                                        accessSectionsForRatingsEditAlways ||
                                        isAllowedSectionForChange
                                      )
                                    }
                                    value={index + 1}
                                    key={index}
                                  >
                                    {index + 1}
                                  </Radio>
                                ))}
                              </RadioGroup>
                            </FormItem>
                          );
                        },
                      )}
                  </Panel>
                </Collapse>
              </Fieldset>
              <Fieldset>
                <Collapse accordion>
                  <Panel header="Рейтинги на проверку" key="1">
                    {_.size(worker.greenhouse) &&
                      _.map(
                        _.orderBy(qualityCheckSections, ['ratingInt', 'name'], ['desc', 'asc']),
                        (r, i) => {
                          const rating = _.filter(
                            worker.ratings,
                            (item) => item.name === r.name && item.isQuality,
                          );

                          const ratingValue = _.map(rating, 'ratingInt', 1);
                          const newRatingValue = _.map(
                            _.filter(
                              newRatings,
                              (newR) => newR.id === r.id && newR.isQuality === true,
                            ),
                            'ratingInt',
                          );

                          const isAllowedSectionForChange =
                            hasAccessToRatingsEdit &&
                            (!accessSectionsForRatingsEdit ||
                              _.includes(accessSectionsForRatingsEdit, r.module));
                          return (
                            <FormItem
                              label={r.name}
                              key={r.id}
                              style={{ overflow: 'hidden' }}
                              hasFeedback
                            >
                              <RadioGroup
                                onChange={(e) => onRatingChange(e, worker, rating[0], r, true)}
                                name={`ratings[${r.index}]`}
                                value={
                                  ratingValue[0]
                                    ? ratingValue[0]
                                    : newRatingValue[0]
                                    ? newRatingValue[0]
                                    : 1
                                }
                              >
                                {_.map(Array(10), (item, index) => (
                                  <Radio
                                    disabled={!isAllowedSectionForChange}
                                    value={index + 1}
                                    key={index}
                                  >
                                    {index + 1}
                                  </Radio>
                                ))}
                              </RadioGroup>
                            </FormItem>
                          );
                        },
                      )}
                  </Panel>
                </Collapse>
                {hasAccessToLoginOperationsRead && (
                  <>
                    <FormItem label="ID Устройства" hasFeedback>
                      <Input
                        placeholder="ID Устройства"
                        value={worker.phoneName}
                        disabled={!hasAccessToLoginOperationsEdit}
                        onChange={({ target: { value } }) => workerUpdate('phoneName', value)}
                      />
                    </FormItem>
                    <FormItem
                      label={
                        <>
                          Логин привязан к телефону
                          <StatusTag className={worker.phoneMode ? 'active' : 'inactive'}>
                            {worker.phoneMode ? 'Да' : 'Нет'}
                          </StatusTag>
                        </>
                      }
                      hasFeedback
                    >
                      <Switch
                        checked={worker.phoneMode}
                        disabled={!hasAccessToLoginOperationsEdit}
                        onChange={(isValue) => workerUpdate('phoneMode', isValue)}
                      />
                    </FormItem>
                  </>
                )}
                {hasAccessToNotesRead && (
                  <FormItem label="Пометки" hasFeedback>
                    <Textarea
                      value={worker.notes}
                      onChange={(e) => workerUpdate('notes', e.target.value)}
                      disabled={!hasAccessToNotesEdit}
                      rows={6}
                    />
                  </FormItem>
                )}
              </Fieldset>
              {hasAccessToCheckPriorityRead && (
                <Fieldset>
                  <Collapse accordion>
                    <Panel header="Приоритет на проверку" key="1">
                      {_.size(worker.greenhouse) &&
                        _.map(_.orderBy(qualityCheckSections, ['name'], ['asc']), (r, i) => {
                          const checkPriorities = _.filter(
                            worker.checkPriorities,
                            (item) => item.sectionId === r.sectionId,
                          );
                          const priority =
                            checkPriorities.length === 0 ? '1' : checkPriorities[0].priority;
                          return (
                            <TruncatedBlock key={r.id}>
                              <span>{r.name}</span>:
                              <StatusTag className="online">{priority}</StatusTag>
                            </TruncatedBlock>
                          );
                        })}
                    </Panel>
                  </Collapse>
                </Fieldset>
              )}
            </Form>
          </Modal>

          <Modal
            visible={oneCActive}
            onClose={() => dispatch(toggle1CData())}
            title="Данные 1С"
            width={900}
            onCancel={() => dispatch(toggle1CData())}
            okButtonProps={{
              disabled: true,
            }}
          >
            {oneCLoading ? (
              <div style={style}>
                <Spin />
              </div>
            ) : (
              <ReactJson src={oneCJson} theme="monokai" collapsed={false} enableClipboard />
            )}
          </Modal>

          <TableWrapper
            style={{ minHeight: '100vh' }}
            rowKey="key"
            columns={columns}
            scroll={{ y: boxHeight - 200, x: sumWidthAllColumns }}
            bordered
            dataSource={dataSource}
            loading={isLoading}
            className="isoSearchableTable"
            onChange={handleTableChange}
            pagination={{
              defaultPageSize: itemsPerPage,
              hideOnSinglePage: true,
              total: totalItems,
              current: page,
              showTotal: (total, range) =>
                `Показано ${range[0]}-${range[1]} из ${totalItems} записей`,
            }}
          />
        </ContentHolder>
      </Box>
    </LayoutContentWrapperScrollable>
  );
}
