import _ from 'lodash';
import rangeParser from 'parse-numeric-range';

class Ranges {
  static verify(str) {
    const valid = str.replace(/[^\d,-/]/g, '');
    return valid.length === str.length;
  }

  static rangeToString(range) {
    let prevNum = range[0];
    let interval = `${range[0]}`;
    let intervalLength = -1;
    let res = '';

    range.forEach((num, i) => {
      ++intervalLength;

      if (num > prevNum + 1) {
        if (intervalLength > 1) {
          interval += intervalLength > 2 ? `-${prevNum}` : `,${prevNum}`;
        }
        res += interval;

        interval = `,${num}`;
        intervalLength = 0;
      }

      if (i >= range.length - 1) {
        if (intervalLength > 1) {
          interval += intervalLength > 1 ? `-${num}` : `,${num}`;
        }
        res += interval;
      }

      prevNum = num;
    });

    return res;
  }

  static rangesFromDublicates(flat, result) {
    const sorted = flat.sort((a, b) => a - b);

    const dublicates = _.filter(sorted, (val, i, iteratee) => _.includes(iteratee, val, i + 1));

    result.push([...new Set(sorted)]);

    if (!_.isEmpty(dublicates)) {
      Ranges.rangesFromDublicates(dublicates, result);
    }

    return result;
  }

  constructor(str) {
    if (!Ranges.verify(str)) {
      return false;
    }

    const nums = rangeParser(str);

    this.ranges = Ranges.rangesFromDublicates(nums, []);
    this.origin = str;
    this.string = str; // this.toString();
  }

  get ranges() {
    return this._ranges;
  }

  set ranges(ranges) {
    this._ranges = ranges;
  }

  toString() {
    const result = _.reduce(
      this.ranges,
      (res, range) => (res += `${Ranges.rangeToString(range)}|`),
      '',
    ).slice(0, -1);

    return result;
  }
}

const isRange = (str) => str.includes('-');
const isEvenOrOddRange = (str) => str.includes('..');

const normalizeWhiteSpace = (str) => str.replace(/\s+/g, '');

const normalizeRange = (arr) =>
  arr.map((el) => {
    if (isRange(el)) {
      const [begin, end] = el.split('-');
      return begin === end ? begin : el;
    }
    return el;
  });

const normalize = (str) => normalizeRange(normalizeWhiteSpace(str).split(',')).join(',');

const isValid = (str) => {
  if (str === '') {
    return true;
  }
  const normalized = normalizeWhiteSpace(str);
  const isMatchSymbols = (str) => /(^\d+([-]|\.\.)?\d+$)|(^[0-9]+$)/g.test(str);

  const regexGetNumber = /(\d+)/g;
  const limit = 600;
  const isNotHaveNumberMoreLimit = !str.match(regexGetNumber).some((el) => Number(el) > limit);
  return (
    normalized.split(',').filter((el) => !isMatchSymbols(el)).length === 0 &&
    isNotHaveNumberMoreLimit
  );
};

const getCountRow = (str) => {
  if (!isValid(str) || str === '') {
    return '';
  }
  const ranges = str.split(',').map((el) => {
    if (isRange(el)) {
      const [first, second] = el.split('-');
      return Math.abs(Number(first) - Number(second)) + 1;
    }
    if (isEvenOrOddRange(el)) {
      const [first, second] = el.split('..');
      const count = (Math.abs(Number(first) - Number(second)) + 1) / 2;
      return Math.ceil(count);
    }
    return 1;
  });
  return _.sumBy(ranges, Number);
};

export { Ranges, normalize, isValid, getCountRow };
