import { getCountRow, isValid } from './Ranges';

describe('getCountRow', () => {
  test('1-100', () => {
    expect(getCountRow('1-100')).toBe(100);
  });
  test('100-55', () => {
    expect(getCountRow('100-55')).toBe(46);
  });
  test('1-100,1,2,3,4,5,6', () => {
    expect(getCountRow('1-100,1,2,3,4,5,6')).toBe(106);
  });
  test('1,2,3,4,5,105-100', () => {
    expect(getCountRow('1,2,3,4,5,105-100')).toBe(11);
  });
  test('1..9', () => {
    expect(getCountRow('1..9')).toBe(5);
  });
  test('1..10', () => {
    expect(getCountRow('1..10')).toBe(5);
  });
  test('1..11', () => {
    expect(getCountRow('1..11')).toBe(6);
  });
  test('2..9', () => {
    expect(getCountRow('2..9')).toBe(4);
  });
  test('2..10', () => {
    expect(getCountRow('2..10')).toBe(5);
  });
  test('2..11', () => {
    expect(getCountRow('2..11')).toBe(5);
  });
  test('1,2,3,4,5,100-150,105-100,2..11', () => {
    expect(getCountRow('1,2,3,4,5,100-150,105-100,2..11')).toBe(67);
  });
});

describe('isValid', () => {
  test('1-601', () => {
    expect(isValid('1-601')).toBe(false);
  });
  test('1-4k', () => {
    expect(isValid('1-4k')).toBe(false);
  });
  test('1-601,333,3330', () => {
    expect(isValid('1-601,333,3330')).toBe(false);
  });
  test('1^6,333', () => {
    expect(isValid('1^601,333')).toBe(false);
  });

  test('empty', () => {
    expect(isValid('')).toBe(true);
  });
  test('1-599', () => {
    expect(isValid('1-599')).toBe(true);
  });
  test('1-600', () => {
    expect(isValid('1-600')).toBe(true);
  });
  test('1,2,3,4,5,100-150,105-100,2..11', () => {
    expect(isValid('1,2,3,4,5,100-150,105-100,2..11')).toBe(true);
  });
});
