import _ from "lodash";
import { segregation } from "@iso/config/roles.config";

export const getUserPermissions = (role) => {
  const result = {
    allowedRoutes: [],
    blocksPermissions: {},
  };

  const segregationKeys = _.keys(segregation);

  const routeKeys = _.filter(
    segregationKeys,
    (key) => _.split(key, ".").length === 1
  );

  const blockKeys = _.filter(
    segregationKeys,
    (key) => _.split(key, ".").length > 1
  );

  const allowedRoutes = _.compact(
    // Получение разрешённых путей
    _.map(routeKeys, (key) => {
      const allPermissions = segregation[key];
      const hasAccess = allPermissions[role].read;

      return hasAccess ? key : null;
    })
  );

  if (_.includes(allowedRoutes, "dashboard")) {
    // Путь dashboard заменяется на пустую строку
    allowedRoutes[
      _.findIndex(allowedRoutes, (route) => route === "dashboard")
    ] = "";
  }

  const getBlocksPermissions = () => {
    // Получение состояния разрешений по всем пунктам меню
    const result = {};

    _.forEach(routeKeys, (key) => {
      result[key] = {
        read: segregation[key][role].read,
        edit: segregation[key][role].edit,
        sectionsRead: segregation[key][role].sectionsRead,
        sectionsEdit: segregation[key][role].sectionsEdit,
        blocks: {},
      };
    });

    _.forEach(blockKeys, (key) => {
      const allBlockPermissions = segregation[key];
      const userBlockPermissions = allBlockPermissions[role];

      const route = _.split(key, ".")[0];
      const block = _.split(key, ".")[1];
      const userEditPermissionByRoute = _.get(
        segregation,
        `[${route}][${role}].edit`,
        false
      );

      if (!userEditPermissionByRoute) {
        userBlockPermissions.edit = false;
      }

      result[route].blocks[block] = userBlockPermissions;
    });

    return result;
  };

  result.allowedRoutes = allowedRoutes;
  result.blocksPermissions = getBlocksPermissions();

  return result;
};
