import { getDefaultPath } from "@iso/lib/helpers/url_sync";
import actions, { getView } from "./actions";
import { isServer } from "@iso/lib/helpers/isServer";

const preKeys = getDefaultPath();
const initState = {
  collapsed: !isServer && window.innerWidth > 1920 ? false : true,
  view: !isServer && getView(window.innerWidth),
  height: !isServer && window.innerHeight,
  openDrawer: false,
  openKeys: preKeys,
  current: preKeys,
  greenhouseId: null,
  greenhouses: [],
  allowedGreenhouses: [],
  phenologyGroups: [],
  isLoading: false,
  isLoadingGreenhouses: false,
  isLoadingAppSettings: false,
  appSettings: {},
  errorMessage: false,
  page: 1,
  orderBy: {
    description: "asc",
  },
  totalItems: 0,
  itemsPerPage: 30,
};

export default function appReducer(state = initState, action) {
  switch (action.type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        isLoadingGreenhouses: true,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        isLoadingGreenhouses: false,
        greenhouses: action.payload.greenhouses,
        totalItems: action.payload.totalItems,
        allowedGreenhouses: action.payload.allowedGreenhouses,
        phenologyGroups: action.payload.groups,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        isLoadingGreenhouses: false,
        errorMessage: "There is a loading problem",
      };
    case actions.LOAD_APP_SETTINGS_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingAppSettings: true,
        errorMessage: false,
      };
    case actions.LOAD_APP_SETTINGS_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingAppSettings: false,
        appSettings: action.payload.settings,
        errorMessage: false,
      };
    case actions.SET_GREENHOUSE:
      localStorage.setItem("greenhouseId", action.payload.greenhouseId);

      return {
        ...state,
        greenhouseId: action.payload.greenhouseId,
      };
    case actions.COLLPSE_CHANGE:
      return {
        ...state,
        collapsed: !state.collapsed,
      };
    case actions.COLLPSE_OPEN_DRAWER:
      return {
        ...state,
        openDrawer: !state.openDrawer,
      };
    case actions.TOGGLE_ALL:
      if (state.view !== action.view || action.height !== state.height) {
        const height = action.height ? action.height : state.height;
        return {
          ...state,
          collapsed: action.collapsed,
          view: action.view,
          height,
        };
      }
      break;
    case actions.CHANGE_OPEN_KEYS:
      return {
        ...state,
        openKeys: action.openKeys,
      };
    case actions.CHANGE_CURRENT:
      return {
        ...state,
        current: action.current,
      };
    case actions.SET_ERROR:
      return {
        ...state,
        errorMessage: action.payload.error,
      };
    case actions.CLEAR_MENU:
      return {
        ...state,
        openKeys: [],
        current: [],
      };
    default:
      return state;
  }
  return state;
}
