import { all, takeEvery, put, call, select } from "redux-saga/effects";
import actions from "./actions";
import _ from "lodash";
import { request } from "@iso/lib/helpers/utility";

/**
 * DOC: https://redux-saga-firebase.js.org/reference/dev/AGROINVEST
 */

const COLLECTION_NAME = "greenhouses"; // change your collection
const COLLECTION_SETTINGS = "configurations"; // change your collection

const getPage = (state) => state.App.page;
const getItemsPerPage = (state) => state.App.itemsPerPage;
const getOrderBy = (state) => state.App.orderBy;

const getCurrentUser = (state) => state.Auth;

function* loadFromAgroinvest() {
  try {
    const page = yield select(getPage);
    const itemsPerPage = yield select(getItemsPerPage);
    const orderBy = yield select(getOrderBy);
    const currentUser = yield select(getCurrentUser);

    const params = {
      exists: {
        parentId: false,
      },
      properties: ["id", "name", "description"],
      itemsPerPage: itemsPerPage,
      page: page,
      order: orderBy,
    };

    const greenhouses = yield call(request, COLLECTION_NAME, params);
    const allowedGreenhouseIds = _.map(currentUser.greenhouses, (g) => {
      if (g.isActive) return g.greenhouseId;
    });
    const allowedGreenhouses = greenhouses["hydra:member"]
      ? _.filter(
          greenhouses["hydra:member"],
          (g) =>
            _.includes(allowedGreenhouseIds, g.id) ||
            currentUser.role === "superuser" ||
            currentUser.role === "reader"
        )
      : [];

    const groups = yield call(request, "collectables", { type: "group" });

    yield put(
      actions.loadFromAgroInvestSuccess(
        greenhouses["hydra:member"],
        greenhouses["hydra:totalItems"],
        allowedGreenhouses,
        groups["hydra:member"]
      )
    );
  } catch (error) {
    yield put(actions.loadFromAgroInvestError(error));
  }
}

function* loadAppSettingsFromAgroinvest() {
  try {
    const params = {
      properties: ["id", "config"],
      id: ["workingTimeConfig"],
    };

    const settingsData = yield call(request, COLLECTION_SETTINGS, params);

    const settings = {};

    const settingsIds = _.map(
      settingsData["hydra:member"],
      (setting) => setting.id
    );

    _.forEach(settingsIds, (id) => {
      const currentSetting = _.find(
        settingsData["hydra:member"],
        (setting) => setting.id === id
      );

      settings[id] = currentSetting.config;
    });

    yield put(actions.loadAppSettingsFromAgroInvestSuccess(settings));
  } catch (error) {
    yield put(actions.loadFromAgroInvestError(error));
  }
}

export default function* rootSaga() {
  yield all([takeEvery(actions.LOAD_FROM_AGROINVEST, loadFromAgroinvest)]);
  yield all([
    takeEvery(
      actions.LOAD_APP_SETTINGS_FROM_AGROINVEST,
      loadAppSettingsFromAgroinvest
    ),
  ]);
}
