import { all, takeEvery, put, call, select } from 'redux-saga/effects';
import actions from './actions';
import _ from 'lodash';
import { isJSON, request } from '@iso/lib/helpers/utility';
import uuidV4 from 'uuid/v4';

/**
 * DOC: https://redux-saga-firebase.js.org/reference/dev/AGROINVEST
 */

const COLLECTION_NAME = 'applications'; // change your collection

const getPage = state => state.Audit.page;
const getItemsPerPage = state => state.Audit.itemsPerPage;
const getOrderBy = state => state.Audit.orderBy;
const getFilters = state => state.Audit.filters;

function* loadFromAgroinvest() {
  try {
    const page = yield select(getPage);
    const itemsPerPage = yield select(getItemsPerPage);
    const orderBy = yield select(getOrderBy);
    const filters = yield select(getFilters);

    const params = {}

    Object.keys(filters).flatMap(key => {
      if (!_.isEmpty(filters[key])) {
        if (_.isArray(filters[key])) {
          _.each(filters[key], (v, k) => {
            if (_.isString(v) && isJSON(v)) {
              params[key] = _.merge(params[key], JSON.parse(v));
            } else if(_.isString(v)) {
              _.merge(params, _.zipObject(key.split('|'), v.split('|')));
            } else {
              params[key] = _.isObject(v) ? _.merge(params[key], v) : v;
            }
          })
        } else {
          params[key] = _.isObject(filters[key]) ? _.merge(params[key], filters[key]) : filters[key];
        }
      }
    });  
    
    params.itemsPerPage = itemsPerPage;
    params.page = page;
    params.order = orderBy;

    console.log(COLLECTION_NAME, params)
    
    let data = yield call(request, COLLECTION_NAME, params);
    yield put(actions.loadFromAgroInvestSuccess(data['hydra:member'], data['hydra:totalItems']));
  } catch (error) {
    yield put(actions.loadFromAgroInvestError(error));
  }
}

function* storeIntoAgroinvest({ payload }) {
  const { data } = payload;
  try {
    const params = {
      type: data.type,
      name: data.name,
    }

    if(!data.id) {
      yield call(request, COLLECTION_NAME, {
        ...params,
        id: uuidV4(),
      }, 'POST');
    } else {
      yield call(request, COLLECTION_NAME + '/' + data.id, params, 'PATCH');
    }

    yield put({ type: actions.LOAD_FROM_AGROINVEST });
  } catch (error) {
    console.log(error);
    yield put(actions.saveIntoAgroInvestError(error));
  }
}

export default function* rootSaga() {
  yield all([
    takeEvery(actions.LOAD_FROM_AGROINVEST, loadFromAgroinvest),
    takeEvery(actions.SET_PAGINATION, loadFromAgroinvest),
    takeEvery(actions.SAVE_INTO_AGROINVEST, storeIntoAgroinvest),
    takeEvery(actions.SET_FILTERS, loadFromAgroinvest),
  ]);
}
