import _ from 'lodash'
import actions from './actions';

const initState = {
  users: null,
  chatRooms: [],
  messages: [],
  generalMessagesPool: [],
  selectedChatRoom: null,
  viewProfile: false,
  loading: true,
  error: false,
  mobileActiveList: true,
  mobileActiveProfile: false,
  restoringData: false,
  addNewUsersProp: {
    modalActive: false,
  },
};

export default function reducer(state = initState, action) {
  switch (action.type) {
    case actions.CHAT_INIT_SAGA: {
      return {
        ...state,
        userId: action.userId,
        user: action.user,
        users: action.users,
        chatRooms: action.chatRooms,
        messages: action.messages,
        selectedChatRoom: action.chatRooms[0],
        loading: false,
      };
    }
    case actions.CHAT_UPDATE_CHATROOM: {
      const { chatRoom, messages, selected } = action;
      return {
        ...state,
        chatRooms: state.chatRooms
          .map(chatroom =>
            chatroom.id === chatRoom.id
              ? {
                  ...chatroom,
                  lastMessage: chatRoom.lastMessage,
                  lastMessageTime: chatRoom.lastMessageTime,
                }
              : chatroom
          ),
        selectedChatRoom: selected ? chatRoom : state.selectedChatRoom,
        viewProfile: selected ? false : state.viewProfile,
        messages: messages ? messages : state.messages,
      };
    }
    case actions.CHAT_SET_TOGGLE_VIEW_PROFILE:
      return {
        ...state,
        viewProfile: action.viewProfile,
      };
    case actions.TOGGLE_MOBILE_LIST:
      return {
        ...state,
        mobileActiveList: action.mobileActiveList,
      };
    case actions.TOGGLE_MOBILE_PROFILE:
      return {
        ...state,
        mobileActiveProfile: action.mobileActiveProfile,
      };
    case actions.UPDATE_NEW_USER_PROPS:
      return {
        ...state,
        addNewUsersProp: action.addNewUsersProp,
      };
    case actions.ADD_NEW_USER_SAGA:
      return {
        ...state,
        addNewUsersProp: { modalActive: false },
        users: [action.user, ...state.users],
        chatRooms: [action.chatRoom, ...state.chatRooms],
      };
    case actions.GET_LAST_MESSAGE: {
      const { room, text, messageTime } = action.payload;

      let newGeneralMessagesPool = [
        ...state.generalMessagesPool.slice(0, state.generalMessagesPool.length),
      ];

      if (action.payload.sender !== 'manager') {
        newGeneralMessagesPool = [
          ...state.generalMessagesPool.slice(state.generalMessagesPool.length),
          action.payload,
          ...state.generalMessagesPool.slice(0, state.generalMessagesPool.length),
        ]
      }

      if (state.selectedChatRoom.id === room) {
        return {
          ...state,
          messages: [
            ...state.messages.slice(0, state.messages.length),
            action.payload,
            ...state.messages.slice(state.messages.length),
          ],
          selectedChatRoom: {
            ...state.selectedChatRoom,
            lastMessage: text,
            lastMessageTime: messageTime
          },
          generalMessagesPool: newGeneralMessagesPool
        };
      }

      const neededChatroomIndex = _.findIndex(state.chatRooms, (c) => c.id === room);
      const oldChatRooms = state.chatRooms.slice(0, state.chatRooms.length + 1);

      oldChatRooms[neededChatroomIndex] = {
        ...oldChatRooms[neededChatroomIndex],
        lastMessage: text,
        lastMessageTime: messageTime,
      };

      return {
        ...state,
        chatRooms: oldChatRooms,
        generalMessagesPool: newGeneralMessagesPool,
      };
    }
    case actions.SET_ALL_UNREAD_MESSAGES: {
      const messages = action.payload;
      const chatRooms = [ ...state.chatRooms ];

      _.forEach(chatRooms, (room, i) => {
        const messagesDates = _.map(_.filter(messages, m => m.room === room.id) , 'messageTime');
        chatRooms[i].lastMessageTime = _.max(messagesDates);
      })

      chatRooms.sort((a, b) => new Date(b.lastMessageTime) - new Date(a.lastMessageTime));

      return {
        ...state,
        chatRooms,
        generalMessagesPool: _.reverse(_.filter(messages, m => m.sender !== 'manager')),
      };
    }

    default:
      return state;
  }
}
