import actions from "./actions";
import moment from "moment";
import _ from "lodash";

import { replaceRowRange } from "./rowPlan.helper";
const emptyPlan = {
  id: null,
  description: null,
};

const initState = {
  isLoading: false,
  isLoadingTasksWeek: false,
  isLoadingRowPlan: false,
  errorMessage: false,
  greenhouseSections: [],
  isLoadingGreenhouseSections: false,
  isTasksAreaOfWorkLoading: false,
  dayProgress: [],
  tasksWeekProgress: [],
  rowPlan: [],
  miniPlans: [],
  isLoadingModule: false,
  module: "regular",
  tasksAreaOfWork: [],
  selectedDay: moment().day(),
  selectedPlan: emptyPlan,
  weekProgress: [
    {
      key: 1,
      name: "ПН",
    },
    {
      key: 2,
      name: "ВТ",
    },
    {
      key: 3,
      name: "СР",
    },
    {
      key: 4,
      name: "ЧТ",
    },
    {
      key: 5,
      name: "ПТ",
    },
    {
      key: 6,
      name: "СБ",
    },
    {
      key: 7,
      name: "ВС",
    },
  ],
};

export default function reducer(state = initState, { type, payload }) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        dayProgress: initState.dayProgress,
        weekProgress: initState.weekProgress,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        dayProgress: payload.dayProgress,
        weekProgress: payload.weekProgress,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: "There is a loading problem",
      };
    case actions.LOAD_TASKS_WEEK_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingTasksWeek: true,
        tasksWeekProgress: initState.tasksWeekProgress,
        errorMessage: false,
      };
    case actions.LOAD_TASKS_WEEK_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingTasksWeek: false,
        tasksWeekProgress: payload.tasksWeekProgress,
        errorMessage: false,
      };
    case actions.LOAD_TASKS_WEEK_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingTasksWeek: false,
        errorMessage: "There is a loading problem",
      };
    case actions.LOAD_MINI_PLANS_FROM_AGROINVEST:
      return {
        ...state,
      };
    case actions.LOAD_MINI_PLANS_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingModule: false,
        miniPlans: payload.miniPlans,
      };
    case actions.LOAD_MINI_PLANS_FROM_AGROINVEST_ERROR:
      return {
        isLoadingModule: false,
        ...state,
      };
    case actions.LOAD_ROW_PLAN_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingRowPlan: true,
        rowPlan: initState.rowPlan,
        weekProgress: initState.weekProgress,
        errorMessage: false,
      };
    case actions.LOAD_ROW_PLAN_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingRowPlan: false,
        rowPlan: payload.rowPlan,
        errorMessage: false,
      };
    case actions.LOAD_TASKS_AREA_OF_WORK:
      return {
        ...state,
        isTasksAreaOfWorkLoading: true,
        errorMessage: false,
      };
    case actions.LOAD_TASKS_AREA_OF_WORK_SUCCESS:
      return {
        ...state,
        isTasksAreaOfWorkLoading: false,
        tasksAreaOfWork: payload.tasksAreaOfWork,
        errorMessage: false,
      };
    case actions.LOAD_GREENHOUSE_SECTIONS_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingGreenhouseSections: true,
        errorMessage: false,
      };
    case actions.LOAD_GREENHOUSE_SECTIONS_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingGreenhouseSections: false,
        greenhouseSections: payload.greenhouseSections,
        errorMessage: false,
      };
    case actions.SAVE_ROW_RANGE_TO_AGROINVEST:
      return { ...state };
    case actions.SAVE_ROW_RANGE_TO_AGROINVEST_SUCCESS:
      return {
        ...state,
        rowPlan: replaceRowRange({
          newRowRange: payload.rowRange,
          rowPlan: state.rowPlan,
        }),
        errorMessage: false,
      };
    case actions.SAVE_GREENHOUSE_SECTION_TO_AGROINVEST:
      return {
        ...state,
      };
    case actions.SAVE_GREENHOUSE_SECTION_TO_AGROINVEST_SUCCESS:
      const actuallyDayProgress = state.dayProgress;

      const currentDayProgressIndex = _.findIndex(
        actuallyDayProgress,
        (dp) => dp.id === payload.greenhouseSection.sectionId
      );

      actuallyDayProgress[currentDayProgressIndex].greenhouseSection =
        payload.greenhouseSection;

      return {
        ...state,
        dayProgress: actuallyDayProgress,
        errorMessage: false,
      };
    case actions.SELECT_DAY:
      return {
        ...state,
        selectedDay: payload,
        isLoading: true,
        dayProgress: initState.dayProgress,
        weekProgress: initState.weekProgress,
        errorMessage: false,
      };
    case actions.SET_MODULE:
      return {
        ...state,
        selectedPlan: emptyPlan,
        isLoadingModule: true,
        miniPlans: [],
        rowPlan: [],
        module: payload.module,
      };
    case actions.SELECT_PLAN:
      return {
        ...state,
        selectedPlan: payload.plan,
      };
    case actions.CHANGE_PLAN_TO_AGROINVEST_SUCCESS:
      return {
        ...state,
        selectedPlan: payload.plan,
      };
    case "APP_SET_GREENHOUSE":
      return {
        ...state,
        selectedPlan: emptyPlan,
        rowPlan: [],
        miniPlans: [],
      };
    default:
      return state;
  }
}
