import _ from "lodash";
import { request } from "@iso/lib/helpers/utility";
import "moment/locale/ru";
import { Ranges } from "../../library/helpers/Ranges";

const COLLECTION_ROW_RANGES = "row_ranges";

export const findRowRangeIndexes = ({ rowRange, rowPlan }) => {
  const sectionIndex = _.findIndex(
    rowPlan,
    (sectionPlan) =>
      sectionPlan.greenhouseSection.sectionId === rowRange.sectionId
  );

  const sectionPlan = rowPlan[sectionIndex];

  const dayIndex = _.findKey(sectionPlan, (existedRange) => {
    return existedRange.key === rowRange.key;
  });

  return {
    sectionIndex,
    dayIndex,
  };
};

export const replaceRowRange = ({ newRowRange, rowPlan }) => {
  const newRowPlan = [...rowPlan];

  const { sectionIndex, dayIndex } = findRowRangeIndexes({
    rowRange: newRowRange,
    rowPlan: newRowPlan,
  });

  _.set(newRowPlan[sectionIndex], dayIndex, newRowRange);

  return newRowPlan;
};

export const sectionRowPlan = ({ greenhouseSection, rowRanges }) => {
  const daysPlan = _.map(_.range(0, 7), (dow) => {
    const rowRange = _.find(rowRanges, (r) => {
      return r.dow === dow;
    });

    const result = rowRange || {
      dow,
      sectionId: greenhouseSection.sectionId,
      range: "",
    };

    const key = `${result.sectionId}${result.dow}`;

    const ranges = new Ranges(result.range);

    return { ...result, ranges, key };
  });

  const plan = {
    key: greenhouseSection.sectionId,
    greenhouseSection,
    ...daysPlan,
  };

  return plan;
};

export const loadWeekRowRanges = async (greenhouseId) => {
  const response = await request(COLLECTION_ROW_RANGES, {
    greenhouseId,
  });

  return response["hydra:member"];
};
