import { all, takeEvery, put, call, select } from "redux-saga/effects";
import actions from "./actions";
import _ from "lodash";
import { request } from "@iso/lib/helpers/utility";

import { sectionRowPlan } from "./rowPlan.helper";

import moment from "moment-timezone";
import "moment/locale/ru";

/**
 * DOC: https://redux-saga-firebase.js.org/reference/dev/AGROINVEST
 */

const COLLECTION_TASKS = "tasks"; // change your collection
const COLLECTION_SECTIONS = "sections";
const COLLECTION_SETTINGS = "configurations";
const COLLECTION_MINI_PLANS = "mini_plans";
const COLLECTION_ROW_RANGES = "row_ranges";

const getWeekProgress = (state) => state.Dashboard.weekProgress;
const getSelectedDay = (state) => state.Dashboard.selectedDay;
const getGreenhouseId = (state) => state.App.greenhouseId;
const getSelectedPlan = (state) => state.Dashboard.selectedPlan;
const getMiniPlans = (state) => state.Dashboard.miniPlans;
const getGreenhouseSections = (state) => state.Dashboard.greenhouseSections;
const getModule = (state) => state.Dashboard.module;
const getRole = (state) => state.Auth.role;
// const getRowPlan = (state) => state.Dashboard.rowPlan;

// const greenhouseRowPlan = async ({ greenhouseId, date, allSections }) => {
//   const dates = _.range(7).map((dayIndex) =>
//     moment(date).utc().day(dayIndex).startOf('day').format()
//   );

//   const after = dates[0];
//   const before = dates[dates.length - 1];

//   const weekRowRanges = await loadWeekRowRanges({
//     greenhouseId,
//     after,
//     before,
//   });

//   const greenhouseSections = await request(COLLECTION_GREENHOUSE_SECTIONS, {
//     greenhouseId,
//   });

//   const sections = _.map(greenhouseSections['hydra:member'], (gs) =>
//     _.find(allSections, (s) => s.id === gs.sectionId)
//   );

//   return _.map(sections, (section) =>
//     sectionRowPlan({ section, rowRanges: weekRowRanges, dates })
//   );
// };

function* loadTasksWeeksFromAgroinvest() {
  try {
    yield put(actions.loadTasksWeekFromAgroInvest());

    const greenhouseId = yield select(getGreenhouseId);
    const tasksWeekProgress = [];
    const requestsTasksWeekAll = [];
    const requestsTasksWeekFinished = [];

    const paramsTemplate = {
      itemsPerPage: 0,
      isActive: true,
      page: 1,
      properties: ["id"],
      exists: {
        parentId: true,
      },
      greenhouseId: greenhouseId,
    };

    const sectionsResponce = yield call(
      request,
      COLLECTION_SECTIONS,
      { isActive: true, itemsPerPage: 100 },
      "GET"
    );

    const sections = sectionsResponce["hydra:member"];
    _.map(sections, (section) => {
      const paramsAll = _.cloneDeep(paramsTemplate);

      paramsAll.sectionId = section.id;

      paramsAll.startAt = {
        before: moment().utc().endOf("week").format(),
        after: moment().utc().startOf("week").format(),
      };

      section.totalAll = 0;
      section.totalFinished = 0;

      const paramsFinished = _.cloneDeep(paramsAll);
      paramsFinished.isFinished = true;
      paramsFinished.finishedAt = {
        before: moment().utc().endOf("week").format(),
        after: moment().utc().startOf("week").format(),
      };
      delete paramsFinished.startAt;

      tasksWeekProgress.push(section);
      requestsTasksWeekAll.push(paramsAll);
      requestsTasksWeekFinished.push(paramsFinished);
    });

    const responseTasksWeekAll = yield all(
      requestsTasksWeekAll.map((params) =>
        call(request, COLLECTION_TASKS, params)
      )
    );
    const responseTasksWeekFinished = yield all(
      requestsTasksWeekFinished.map((params) =>
        call(request, COLLECTION_TASKS, params)
      )
    );

    _.map(tasksWeekProgress, (s, i) => {
      s.totalAll = _.get(
        responseTasksWeekAll,
        "[" + i + "][hydra:totalItems]",
        0
      );
      s.totalFinished = _.get(
        responseTasksWeekFinished,
        "[" + i + "][hydra:totalItems]",
        0
      );
    });

    const filteredTasksWeekProgress = _.filter(
      tasksWeekProgress,
      (progress) => progress.totalFinished > 0 || progress.totalAll > 0
    );

    _.forEach(filteredTasksWeekProgress, (section, index) => {
      const greenhouseSection = _.find(
        section.greenhouseSections,
        (gs) => gs.greenhouseId === greenhouseId
      );

      filteredTasksWeekProgress[index].greenhouseSection = greenhouseSection;
    });

    const sortedTasksWeekProgress = _.sortBy(filteredTasksWeekProgress, "name");

    yield put(
      actions.loadTasksWeekFromAgroInvestSuccess({
        tasksWeekProgress: sortedTasksWeekProgress,
      })
    );
  } catch (error) {
    yield put(actions.loadTasksWeekFromAgroInvestError(error));
  }
}

function* loadFromAgroinvest() {
  try {
    const dayProgress = [];
    const weekProgress = yield select(getWeekProgress);
    const selectedDay = yield select(getSelectedDay);
    const greenhouseId = yield select(getGreenhouseId);
    const selectedDate = moment().utc().day(selectedDay).startOf("day");
    // const rowPlan = [];

    const requestsDayAll = [];
    const requestsDayFinished = [];

    const requestsWeekAll = [];
    const requestsWeekFinished = [];
    const requestsWeekCompleted = [];

    const paramsTemplate = {
      itemsPerPage: 0,
      page: 1,
      properties: ["id"],
      isActive: true,
      startAt: {
        after: selectedDate.format(),
        before: selectedDate.endOf("day").format(),
      },
      exists: {
        parentId: true,
      },
      greenhouseId: greenhouseId,
    };

    _.map(weekProgress, (day) => {
      const paramsAll = _.cloneDeep(paramsTemplate);

      day.totalAll = 0;
      day.totalFinished = 0;
      day.totalCompleted = 0;

      paramsAll.startAt = {
        before: moment().utc().isoWeekday(day.key).endOf("day").format(),
        after: moment().utc().isoWeekday(day.key).startOf("day").format(),
      };

      const paramsFinished = _.cloneDeep(paramsAll);
      paramsFinished.isFinished = true;
      paramsFinished.finishedAt = {
        before: moment().utc().isoWeekday(day.key).endOf("day").format(),
        after: moment().utc().isoWeekday(day.key).startOf("day").format(),
      };

      const paramsCompleted = _.cloneDeep(paramsTemplate);
      paramsCompleted.isFinished = true;
      paramsCompleted.finishedAt = {
        before: moment().utc().isoWeekday(day.key).endOf("day").format(),
        after: moment().utc().isoWeekday(day.key).startOf("day").format(),
      };
      delete paramsCompleted.startAt;

      requestsWeekAll.push(paramsAll);
      requestsWeekFinished.push(paramsFinished);
      requestsWeekCompleted.push(paramsCompleted);
    });

    const sectionsResponce = yield call(
      request,
      COLLECTION_SECTIONS,
      { isActive: true, itemsPerPage: 100 },
      "GET"
    );

    const sections = sectionsResponce["hydra:member"];

    _.map(sections, (section) => {
      const paramsAll = _.cloneDeep(paramsTemplate);

      paramsAll.sectionId = section.id;

      section.totalAll = 0;
      section.totalFinished = 0;

      const paramsFinished = _.cloneDeep(paramsAll);
      paramsFinished.isFinished = true;
      paramsFinished.finishedAt = {
        after: selectedDate.startOf("day").format(),
        before: selectedDate.endOf("day").format(),
      };
      delete paramsFinished.startAt;

      dayProgress.push(section);
      requestsDayAll.push(paramsAll);
      requestsDayFinished.push(paramsFinished);
    });

    const responseDayAll = yield all(
      requestsDayAll.map((params) => call(request, COLLECTION_TASKS, params))
    );
    const responseDayFinished = yield all(
      requestsDayFinished.map((params) =>
        call(request, COLLECTION_TASKS, params)
      )
    );

    // const paramsTaskAreaOfWork = {
    //   properties: [
    //     "id",
    //     "greenhouse",
    //     "isFinished",
    //     "sectionName",
    //     "section",
    //     "sectionId",
    //   ],
    // };
    // paramsTaskAreaOfWork.isFinished = true;

    // const paramsTaskAreaOfWorkWithDate = {
    //   ...paramsTaskAreaOfWork,
    // };
    // paramsTaskAreaOfWorkWithDate.finishAt = {
    //   before: selectedDate.endOf("week").format(),
    //   after: selectedDate.startOf("week").format(),
    // };
    // paramsTaskAreaOfWork.finishAt = {
    //   before: selectedDate.endOf('week').format(),
    //   after: selectedDate.startOf('week').format(),
    // };

    // id's видов работ для дашборда Метраж работ
    // Опускание/поднятие лент: id = '719726ed-0353-4f1b-8ae7-eb625b7c36ba'
    // Опрыскивание растений против вредителей либо болезней: id = 'c49cdddd-4f91-4917-9e52-f9a11bd14439'
    // Натягивание лент: id = 'ffbebede-dd2e-4270-9e8c-e3e26799f042'

    // const tasksTypeMovingTapes = yield call(request, COLLECTION_TASKS, {
    //   ...paramsTaskAreaOfWorkWithDate,
    //   sectionId: "719726ed-0353-4f1b-8ae7-eb625b7c36ba",
    // });
    // const tasksTypeMovingTapesWithoutParams = yield call(
    //   request,
    //   COLLECTION_TASKS,
    //   { sectionId: "719726ed-0353-4f1b-8ae7-eb625b7c36ba" }
    // );
    // const tasksTypeSprayingPlants = yield call(request, COLLECTION_TASKS, {
    //   ...paramsTaskAreaOfWork,
    //   sectionId: "c49cdddd-4f91-4917-9e52-f9a11bd14439",
    // });
    // const tasksTypeSprayingPlantsWithDate = yield call(
    //   request,
    //   COLLECTION_TASKS,
    //   {
    //     ...paramsTaskAreaOfWorkWithDate,
    //     sectionId: "c49cdddd-4f91-4917-9e52-f9a11bd14439",
    //   }
    // );
    // const tasksTypeTensioningTapes = yield call(request, COLLECTION_TASKS, {
    //   ...paramsTaskAreaOfWorkWithDate,
    //   sectionId: "ffbebede-dd2e-4270-9e8c-e3e26799f042",
    // });
    // // создано для нахождения ошибки
    // const tasksDeleteLowSheet = yield call(request, COLLECTION_TASKS, {
    //   ...paramsTaskAreaOfWork,
    //   sectionId: "4ba55350-2254-11ea-b818-00505696ff79",
    // });
    // const tasksDeleteLowSheetWithDate = yield call(request, COLLECTION_TASKS, {
    //   ...paramsTaskAreaOfWorkWithDate,
    //   sectionId: "4ba55350-2254-11ea-b818-00505696ff79",
    // });

    // const tasksToAreaOfWork = [
    //   {
    //     tasks: tasksTypeMovingTapes["hydra:member"],
    //     name: "Опускание/поднятие ленты",
    //   },
    //   {
    //     tasks: tasksTypeMovingTapesWithoutParams["hydra:member"],
    //     name: "Опускание/поднятие ленты,  без параметров",
    //   },
    //   {
    //     tasks: tasksTypeSprayingPlants["hydra:member"],
    //     name: "Опрыскивание растений против вредителей либо болезней, без даты",
    //   },
    //   {
    //     tasks: tasksTypeSprayingPlantsWithDate["hydra:member"],
    //     name: "Опрыскивание растений против вредителей либо болезней, с датой",
    //   },
    //   {
    //     tasks: tasksTypeTensioningTapes["hydra:member"],
    //     name: "Натягивание лент",
    //   },
    //   {
    //     tasks: tasksDeleteLowSheet["hydra:member"],
    //     name: "Удаление нижнего листа (3-4 листа), без даты",
    //   },
    //   {
    //     tasks: tasksDeleteLowSheetWithDate["hydra:member"],
    //     name:
    //       "Удаление нижнего листа (3-4 листа) указан диапазон времение тек. неделя",
    //   },
    // ];

    const responseWeekAll = yield all(
      requestsWeekAll.map((params) => call(request, COLLECTION_TASKS, params))
    );
    const responseWeekFinished = yield all(
      requestsWeekFinished.map((params) =>
        call(request, COLLECTION_TASKS, params)
      )
    );
    const responseWeekCompleted = yield all(
      requestsWeekCompleted.map((params) =>
        call(request, COLLECTION_TASKS, params)
      )
    );

    _.map(dayProgress, (s, i) => {
      s.totalAll = _.get(responseDayAll, "[" + i + "][hydra:totalItems]", 0);
      s.totalFinished = _.get(
        responseDayFinished,
        "[" + i + "][hydra:totalItems]",
        0
      );
    });

    const filteredDayProgress = _.filter(
      dayProgress,
      (progress) => progress.totalFinished > 0 || progress.totalAll > 0
    );

    _.forEach(filteredDayProgress, (section, index) => {
      const greenhouseSection = _.find(
        section.greenhouseSections,
        (gs) => gs.greenhouseId === greenhouseId
      );

      filteredDayProgress[index].greenhouseSection = greenhouseSection;
    });

    _.map(weekProgress, (d, i) => {
      d.totalAll = _.get(responseWeekAll, "[" + i + "][hydra:totalItems]", 0);
      d.totalFinished = _.get(
        responseWeekFinished,
        "[" + i + "][hydra:totalItems]",
        0
      );
      d.totalCompleted = _.get(
        responseWeekCompleted,
        "[" + i + "][hydra:totalItems]",
        0
      );
    });

    const sortedDayProgress = _.sortBy(filteredDayProgress, "name");

    yield put(
      actions.loadFromAgroInvestSuccess({
        dayProgress: sortedDayProgress,
        weekProgress,
      })
    );
  } catch (error) {
    yield put(actions.loadFromAgroInvestError(error));
  }
}

function* loadRowPlanFromAgroinvest() {
  try {
    const greenhouseSections = yield select(getGreenhouseSections);
    const selectedPlan = yield select(getSelectedPlan);

    const rowRanges = yield all(
      _.map(greenhouseSections, (greenhouseSection) => {
        return call(request, COLLECTION_ROW_RANGES, {
          mini_planId: selectedPlan.id,
          sectionId: greenhouseSection.sectionId,
        });
      })
    );

    const rowPlan = _.map(greenhouseSections, (greenhouseSection, i) =>
      sectionRowPlan({
        greenhouseSection,
        rowRanges: rowRanges[i]["hydra:member"],
      })
    );

    yield put(actions.loadRowPlanFromAgroinvestSuccess(rowPlan));
  } catch (error) {
    yield put(actions.loadFromAgroInvestError(error));
  }
}

function* loadMiniPlansFromAgroinvest() {
  try {
    let module = yield select(getModule);
    const role = yield select(getRole);
    const greenhouseId = yield select(getGreenhouseId);

    if (role === 'main-guardian') {
      module = 'guarding'
    }

    const miniPlans = yield call(request, COLLECTION_MINI_PLANS, {
      greenhouseId: greenhouseId,
      module,
      isDeleted: false,
    });

    yield put(
      actions.loadMiniPlansFromAgroInvestSuccess(miniPlans["hydra:member"])
    );
  } catch (error) {
    yield put(actions.loadMiniPlansFromAgroInvestError(error));
  }
}

function* loadTasksAreaOfWorkFromAgroinvest() {
  // Фильтр задач на текущую неделю
  // paramsTaskAreaOfWork.finishAt = {
  //   before: selectedDate.endOf('week').format(),
  //   after: selectedDate.startOf('week').format(),
  // };

  // id's видов работ для дашборда метраж работ
  // Опускание/поднятие лент: id = 'c75883e1-7cc1-11eb-b8a0-00505696f325'
  // Опрыскивание растений против вредителей либо болезней: id = '71a4ba81-7cc1-11eb-b8a0-00505696f325'
  // Натягивание лент: id = '7805ec0b-7cc1-11eb-b8a0-00505696f325'

  try {
    const sections = [
      "c75883e1-7cc1-11eb-b8a0-00505696f325",
      "71a4ba81-7cc1-11eb-b8a0-00505696f325",
      "7805ec0b-7cc1-11eb-b8a0-00505696f325",
    ];

    const tasksFinishedAt = {
      before: moment().endOf("week").format(),
      after: moment().startOf("week").format(),
    };

    const greenhouseId = yield select(getGreenhouseId);

    if (!greenhouseId) return;

    const greenhouse = yield call(
      request,
      "greenhouses/" + greenhouseId,
      "GET"
    );

    const greenhouseSections = greenhouse.greenhouseSections;

    const accessibleSections = _.filter(greenhouseSections, (gs) =>
      _.includes(sections, gs.sectionId)
    );

    const greenhouseRowLength = _.get(greenhouse, "length");

    const tasksArrayResponse = yield all(
      _.map(accessibleSections, (section) => {
        return call(request, COLLECTION_TASKS, {
          greenhouseId,
          sectionId: section.sectionId,
          finishedAt: tasksFinishedAt,
          isFinished: true,
          itemsPerPage: 0,
          page: 1,
        });
      })
    );

    const reportData = _.map(tasksArrayResponse, (taskData, index) => {
      const totalTasks = _.get(taskData, "[hydra:totalItems]", 0);
      const sectionId = accessibleSections[index].id;
      const sectionName = accessibleSections[index].name;
      const module = accessibleSections[index].module;

      return {
        key: sectionId,
        sectionId,
        sectionName,
        module,
        result: greenhouseRowLength
          ? greenhouseRowLength * totalTasks
          : "Длина рядов не указана",
      };
    });

    const sortedBySectionNameReportData = _.sortBy(reportData, "sectionName");

    yield put(
      actions.loadTasksAreaOfWorkFromAgroinvestSuccess(
        sortedBySectionNameReportData
      )
    );
  } catch (error) {
    yield put(actions.loadFromAgroInvestError(error));
    console.log(error);
  }
}

function* saveRowRangeToAgroinvest({ payload }) {
  try {
    const selectedPlan = yield select(getSelectedPlan);
    const { rowRange } = payload;

    let method = "POST";
    let dto = {};

    const persistent = !!rowRange.id;
    const empty = !rowRange.range;

    let url = COLLECTION_ROW_RANGES;

    if (!persistent) {
      if (empty) {
        return;
      } else {
        method = "POST";
        dto = {
          dow: rowRange.dow,
          range: rowRange.range,
          section: `${COLLECTION_SECTIONS}/${rowRange.sectionId}`,
          miniPlan: `${COLLECTION_MINI_PLANS}/${selectedPlan.id}`,
        };
      }
    } else {
      url = `${COLLECTION_ROW_RANGES}/${rowRange.id}`;

      if (!empty) {
        method = "PATCH";
        dto = { range: rowRange.range };
      } else {
        method = "DELETE";
        dto = {};
      }
    }

    yield call(request, url, dto, method);
    yield call(loadRowPlanFromAgroinvest);
  } catch (err) {
    console.log(err);
    yield put(actions.loadFromAgroInvestError(err));
  }
}

function* loadGreenhouseSections({ payload }) {
  try {
    const { greenhouseId } = payload;

    const greenhouse = yield call(
      request,
      "greenhouses/" + greenhouseId,
      "GET"
    );

    yield put(
      actions.loadGreenhouseSectionsFromAgroInvestSuccess(
        _.sortBy(greenhouse.greenhouseSections, "name")
      )
    );
  } catch (err) {
    console.log(err);
    yield put(actions.loadFromAgroInvestError(err));
  }
}

function* saveGreenhouseSection({ payload }) {
  try {
    const { greenhouseSectionId: id, data } = payload;

    const greenhouseSection = yield call(
      request,
      `greenhouse_sections/${id}`,
      data,
      "PATCH"
    );

    yield put(
      actions.saveGreenhouseSectionToAgroInvestSuccess(greenhouseSection)
    );
  } catch (err) {
    console.log(err);
    yield put(actions.loadFromAgroInvestError(err));
  }
}

function* changePlanToAgroinvest({ payload }) {
  try {
    const { action, plan } = payload;
    let method = "";
    let url = "";
    let data = {};
    switch (action) {
      case "changeDescription":
        method = "PUT";
        url = `${COLLECTION_MINI_PLANS}/${plan.id}`;
        data = { description: plan.description };
        const updatedPlan = yield call(request, url, data, method);
        yield call(loadMiniPlansFromAgroinvest);
        yield put(actions.changePlanToAgroInvestSuccess({ plan: updatedPlan }));
        break;
      case "addPlan":
        method = "POST";
        url = COLLECTION_MINI_PLANS;
        data = plan;
        const createdPlan = yield call(request, url, data, method);
        yield call(loadMiniPlansFromAgroinvest);
        yield put(actions.changePlanToAgroInvestSuccess({ plan: createdPlan }));
        break;
      case "setActive":
        method = "PATCH";
        url = `${COLLECTION_MINI_PLANS}/${plan.id}`;
        data = { isActive: plan.isActive };
        const miniPlans = yield select(getMiniPlans);
        yield all(
          miniPlans
            .filter(({ id }) => id !== plan.id)
            .map((plan) =>
              call(
                request,
                `${COLLECTION_MINI_PLANS}/${plan.id}`,
                { isActive: false },
                method
              )
            )
        );
        const activePlan = yield call(request, url, data, method);

        yield call(loadMiniPlansFromAgroinvest);
        yield put(actions.changePlanToAgroInvestSuccess({ plan: activePlan }));
        break;
      case "removePlan":
        method = "PATCH";
        url = `${COLLECTION_MINI_PLANS}/${plan.id}`;
        data = { isDeleted: plan.isDeleted };
        yield call(request, url, data, method);

        yield call(loadMiniPlansFromAgroinvest);
        const updatedMiniPlans = yield select(getMiniPlans);
        const updatedActivePlan = _.find(updatedMiniPlans, "isActive");

        yield put(
          actions.changePlanToAgroInvestSuccess({ plan: updatedActivePlan })
        );
        break;

      default:
        console.error("undefined changePlan action: ", action);
        break;
    }
  } catch (err) {
    console.log(err);
    yield put(actions.loadFromAgroInvestError(err));
  }
}

export default function* rootSaga() {
  yield all([
    takeEvery(actions.LOAD_FROM_AGROINVEST, loadFromAgroinvest),
    takeEvery(actions.LOAD_FROM_AGROINVEST, loadTasksWeeksFromAgroinvest),
    takeEvery(actions.LOAD_ROW_PLAN_FROM_AGROINVEST, loadRowPlanFromAgroinvest),
    takeEvery(
      actions.LOAD_MINI_PLANS_FROM_AGROINVEST,
      loadMiniPlansFromAgroinvest
    ),
    takeEvery(
      actions.LOAD_TASKS_AREA_OF_WORK,
      loadTasksAreaOfWorkFromAgroinvest
    ),
    takeEvery(actions.SAVE_ROW_RANGE_TO_AGROINVEST, saveRowRangeToAgroinvest),
    takeEvery(
      actions.LOAD_GREENHOUSE_SECTIONS_FROM_AGROINVEST,
      loadGreenhouseSections
    ),
    takeEvery(
      actions.SAVE_GREENHOUSE_SECTION_TO_AGROINVEST,
      saveGreenhouseSection
    ),
    takeEvery(actions.SELECT_DAY, loadFromAgroinvest),
    takeEvery(actions.CHANGE_PLAN_TO_AGROINVEST, changePlanToAgroinvest),
  ]);
}
