import actions from "./actions";
import moment from "moment-timezone";
import "moment/locale/ru";

moment.tz.setDefault("Europe/Moscow");
moment.locale("ru");

const initState = {
  isLoading: false,
  errorMessage: false,
  empases: [],
  page: 1,
  isDisabled: true,
  orderBy: {
    registeredAt: "asc",
    empas: "asc",
  },
  modalActive: false,
  empas: {
    key: null,
    id: null,
    workerId: null,
  },
  filters: {
    registeredAt: [
      JSON.stringify({
        before: moment().utc().endOf("week").format(),
        after: moment().utc().startOf("week").format(),
      }),
    ],
    type: ["refill"],
  },
  totalItems: 0,
  itemsPerPage: 30,
};

export default function reducer(state = initState, { type, payload }) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        empases: payload.data,
        totalItems: payload.totalItems,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: "There is a loading problem",
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        filters: payload.filters,
        isLoading: true,
        page: payload.page,
      };
    case actions.TOGGLE_HANDLE_MODAL:
      return {
        ...state,
        modalActive: !state.modalActive,
        isDisabled: !state.modalActive,
        empas: payload.data == null ? initState.empas : payload.data,
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        empas: payload.data,
      };
    case actions.TOGGLE_DISABLED:
      return {
        ...state,
        isDisabled: !state.isDisabled,
      };
    case actions.SYNC_1C:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.SYNC_1C_SUCCESS:
      return {
        ...state,
        isLoading: false,
        errorMessage: false,
      };
    case actions.SYNC_1C_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: "There is a loading problem",
      };
    default:
      return state;
  }
}
