import actions from './actions';
import _ from 'lodash'

const initState = {
  isLoading: false,
  errorMessage: false,
  greenhouses: [],
  page: 1,
  orderBy: {
    createdAt: 'desc',
    name: 'asc',
  },
  modalActive: false,
  greenhouse: {
    key: null,
    id: null,
  },
  filters: {
    type: ['group'],
  },
  filterParent: {
    value: false
  },
  sections: [],
  totalItems: 0,
  itemsPerPage: 30,
  newSectionName: ''
};

export default function reducer(
  state = initState,
  { type, payload }
) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        greenhouses: payload.data,
        totalItems: payload.totalItems,
        errorMessage: false,
        newSectionName: ''
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        filters: payload.filters,
        isLoading: true,
        page: payload.page,
      };
    case actions.TOGGLE_HANDLE_MODAL:
      return {
        ...state,
        modalActive: !state.modalActive,
        greenhouse: payload.data == null ? initState.greenhouse : payload.data,
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        greenouse: payload.data,
      };
    case actions.GET_SECTION_SUCCESS:
      return {
        ...state, sections: payload
      }
    case actions.REMOVE_GREENHOUSE_SECTION: {
      const section = payload;

      const prevGreenhouseSections = [...state.greenhouse.greenhouseSections]

      const newGreenhouseSections = _.filter(prevGreenhouseSections, item => item.id !== section.id)

        return {
          ...state, greenhouse: {
            ...state.greenhouse, greenhouseSections: newGreenhouseSections
          }
        }
      }
    case actions.ADD_FILTER_PARENT: {
      return {
      ...state, filterParent: {
        ...state.filterParent, ...payload
      }
    }
  }
    case actions.ADD_NEW_SECTION_GREENHOUSE: {
      return { ...state, newSectionName: payload}
    }


    default:
      return state;
  }
}
