import actions from './actions';
import moment from 'moment';
const getCurrentDate = () => moment().utc().endOf('day').format();
const getPreviousWeek = () =>
  moment(getCurrentDate()).utc().subtract(52, 'weeks').startOf('day').format();

const initState = {
  isLoading: false,
  errorMessage: false,
  dateBefore: getCurrentDate(),
  dateAfter: getPreviousWeek(),
  pestInfestations: [],
  isLoadingPestInfestations: false,
  intensitys: [],
  pests: [],
  pestId: null,
  rowsTotal: 0,
  isLoadingRows: false,
  page: 1,
  modalActive: false,
  filters: {
    type: ['group'],
  },
  totalItems: 0,
  itemsPerPage: 1000,
};

export default function reducer(state = initState, { type, payload }) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.REFRESH:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SAVE_INTO_AGROINVEST:
      return {
        ...state,
        modalActive: false,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        filters: payload.filters,
        page: payload.page,
      };
    case actions.RESET_FILTERS:
      return {
        ...state,
        pestId: null,
      };

    case actions.SET_WORKER_ID:
      return {
        ...state,
        workerId: payload.data,
      };
    case actions.SET_PEST_ID:
      return {
        ...state,
        pestId: payload.data,
      };
    case actions.SET_DATE_BEFORE:
      return {
        ...state,
        dateBefore: payload.data,
      };
    case actions.SET_DATE_AFTER:
      return {
        ...state,
        dateAfter: payload.data,
      };

    case actions.TOGGLE_HANDLE_MODAL:
      return {
        ...state,
        modalActive: !state.modalActive,
        cell: payload.data === null ? [] : payload.data,
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        cell: payload.data,
      };
    case actions.PESTS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingPests: true,
        errorMessage: false,
      };
    case actions.PESTS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        pests: payload,
        pestId: state.pestId || (payload.length > 0 && payload[0]?.id),
        isLoadingPests: false,
        errorMessage: false,
      };
    case actions.PESTS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingPests: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.PEST_INFESTATIONS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingPestInfestations: true,
        errorMessage: false,
      };
    case actions.PEST_INFESTATIONS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingPestInfestations: false,
        pestInfestations: payload,
        errorMessage: false,
      };
    case actions.PEST_INFESTATIONS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingPestInfestations: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.INTENSITYS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        errorMessage: false,
      };
    case actions.INTENSITYS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        intensitys: payload,
        errorMessage: false,
      };
    case actions.INTENSITYS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        errorMessage: 'There is a loading problem',
      };
    case actions.ROWS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingRows: true,
        errorMessage: false,
      };
    case actions.ROWS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingRows: false,
        rowsTotal: payload,
        errorMessage: false,
      };
    case actions.ROWS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingRows: false,
        errorMessage: 'There is a loading problem',
      };
    default:
      return state;
  }
}
