import actions from './actions';
import moment from 'moment';
const getCurrentDate = () => moment().utc().endOf('day').format();
const getPreviousWeek = () =>
  moment(getCurrentDate()).utc().subtract(1, 'weeks').startOf('day').format();

export const initState = {
  isLoading: false,
  errorMessage: false,
  dateBefore: getCurrentDate(),
  dateAfter: getPreviousWeek(),
  rowStart: '1',
  rowEnd: '10',
  pestId: null,
  pests: [],
  isLoadingPests: false,
  intensitys: [],
  workerId: null,
  workers: [],
  isLoadingWorkers: false,
  rows: [],
  fillRows: [],
  pestInfestations: [],
  isLoadingPestInfestations: false,
  page: 1,
  orderBy: {
    createdAt: 'desc',
    name: 'asc',
  },
  cell: [],
  modalActive: false,
  filters: {
    type: ['group'],
  },
  totalItems: 0,
  itemsPerPage: 1000,
};

export default function reducer(state = initState, { type, payload }) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.REFRESH:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SAVE_INTO_AGROINVEST:
      return {
        ...state,
        modalActive: false,
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        // isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        filters: payload.filters,
        page: payload.page,
      };
    case actions.RESET_FILTERS:
      return {
        ...state,
        filters: {
          ...state.filters,
          workerId: initState.workerId,
          pestId: initState.pestId,
          registeredAt: {
            before: initState.dateBefore,
            after: initState.dateAfter,
          },
          exists: {
            curedAt: false,
          },
        },
        worker: initState.worker,
        pest: initState.pest,
        workerId: initState.workerId,
        pestId: initState.pestId,
        dateBefore: initState.dateBefore,
        dateAfter: initState.dateAfter,
        rowStart: initState.rowStart,
        rowEnd: initState.rowEnd,
      };

    case actions.SET_WORKER_ID:
      return {
        ...state,
        workerId: payload.data,
      };
    case actions.SET_PEST_ID:
      return {
        ...state,
        pestId: payload.data,
      };
    case actions.SET_DATE_BEFORE:
      return {
        ...state,
        dateBefore: payload.data,
      };
    case actions.SET_DATE_AFTER:
      return {
        ...state,
        dateAfter: payload.data,
      };
    case actions.SET_ROW_START:
      return {
        ...state,
        rowStart: payload.data,
      };
    case actions.SET_ROW_END:
      return {
        ...state,
        rowEnd: payload.data,
      };
    case actions.SET_FILL_ROWS:
      return {
        ...state,
        fillRows: payload.data,
      };
    case actions.TOGGLE_HANDLE_MODAL:
      return {
        ...state,
        modalActive: !state.modalActive,
        cell: payload.data === null ? [] : payload.data,
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        cell: payload.data,
      };

    case actions.ROWS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingRows: true,
        errorMessage: false,
      };
    case actions.ROWS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingRows: false,
        rows: payload,
        errorMessage: false,
      };
    case actions.ROWS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingRows: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.PEST_INFESTATIONS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingPestInfestations: true,
        errorMessage: false,
      };
    case actions.PEST_INFESTATIONS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingPestInfestations: false,
        pestInfestations: payload,
        errorMessage: false,
      };
    case actions.PEST_INFESTATIONS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingPestInfestations: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.PESTS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingPests: true,
        errorMessage: false,
      };
    case actions.PESTS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        pests: payload,
        isLoadingPests: false,
        errorMessage: false,
      };
    case actions.PESTS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingPests: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.INTENSITYS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        errorMessage: false,
      };
    case actions.INTENSITYS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        intensitys: payload,
        errorMessage: false,
      };
    case actions.INTENSITYS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        errorMessage: 'There is a loading problem',
      };
    case actions.WORKERS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingWorkers: true,
        errorMessage: false,
      };
    case actions.WORKERS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        workers: payload,
        isLoadingWorkers: false,
        errorMessage: false,
      };
    case actions.WORKERS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingWorkers: false,
        errorMessage: 'There is a loading problem',
      };

    default:
      return state;
  }
}
