import { all, takeEvery, put, call, select } from 'redux-saga/effects';
import actions from './actions';
import { request } from '@iso/lib/helpers/utility';

/**
 * DOC: https://redux-saga-firebase.js.org/reference/dev/AGROINVEST
 */

const COLLECTION_NAME = 'rows'; // change your collection

const getItemsPerPage = state => state.Ordering.itemsPerPage;

function* loadFromAgroinvest({ payload }) {
  try {
    const { greenhouseId } = payload;

    const itemsPerPage = yield select(getItemsPerPage);

    const params = {
      greenhouseId,
      itemsPerPage,
      order: {
        orderBy: 'asc',
      }
    }

    const data = yield call(request, COLLECTION_NAME, params);

    yield put(actions.loadFromAgroInvestSuccess(data['hydra:member'],
      data['hydra:totalItems']));

  } catch (error) {
    yield put(actions.loadFromAgroInvestError(error));
  }
}

function* saveToAgroinvest({ payload }) {
  try {
    const { rows } = payload;
    
    yield all(rows.map((row) => call(request, COLLECTION_NAME + '/' + row.id, {orderBy: row.orderBy, isBlockEnd: row.isBlockEnd}, 'PATCH')));

    yield put(actions.saveToAgroInvestSuccess());

  } catch (error) {
    yield put(actions.saveToAgroInvestError(error));
  }
}

export default function* rootSaga() {
  yield all([
    takeEvery(actions.LOAD_FROM_AGROINVEST, loadFromAgroinvest),
    takeEvery(actions.SAVE_TO_AGROINVEST, saveToAgroinvest),
  ]);
}
