import moment from 'moment';

import actions from './actions';

const initState = {
  isLoading: false,
  errorMessage: false,
  collectables: [],
  page: 1,
  orderBy: {
    createdAt: 'desc',
    name: 'asc',
  },
  modalActive: false,
  collectable: {
    key: null,
    id: null,
    parentId: null,
    type: 'group',
    category: '',
  },
  filters: {
    type: ['group'],
  },
  totalItems: 0,
  itemsPerPage: 100,

  historicalValves: {
    items: [],
    pagination: {
      page: 1,
      itemsPerPage: 30,
      totalItems: 0,
    },
    filters: {
      registeredAt: [
        JSON.stringify({
          before: moment().utc().endOf("day").format(),
          after: moment().utc().startOf("day").format(),
        }),
      ],
    },
  },
};

export default function reducer(
  state = initState,
  { type, payload }
) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        collectables: payload.data,
        totalItems: payload.totalItems,
        valves: payload.valves,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        filters: payload.filters,
        isLoading: true,
        page: payload.page,
      };
    case actions.TOGGLE_HANDLE_MODAL:
      return {
        ...state,
        modalActive: !state.modalActive,
        collectable: payload.data == null ? initState.collectable : payload.data,
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        collectable: payload.data,
      };

    case actions.SET_REFERENCE_BOOK_TABLE_VALUE: {
      return {
        ...state,
        valves: state.valves.map(valve => {
          if (valve.id === payload.id) {
            return {
              ...valve,
              ...payload,
            };
          }

          return valve;
        }),
      };
    }

    case actions.UPDATE_REFERENCE_BOOK_REQUEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: null,
      };

    case actions.UPDATE_REFERENCE_BOOK_SUCCESS:
      return {
        ...state,
        isLoading: false,
        errorMessage: null,
      };

    case actions.UPDATE_REFERENCE_BOOK_FAIL:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'Error is occured'
      };

    case actions.GET_HISTORICAL_VALVES_REQUEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: null,
      };

    case actions.GET_HISTORICAL_VALVES_SUCCESS:
      return {
        ...state,
        isLoading: false,
        historicalValves: {
          ...state.historicalValves,
          items: payload.items,
          pagination: {
            ...state.historicalValves.pagination,
            totalItems: payload.totalItems,
          },
        },
      };

    case actions.GET_HISTORICAL_VALVES_FAIL:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'Error is occurred',
      };

    case actions.SET_HISTORICAL_VALVES:
      return {
        ...state,
        historicalValves: {
          ...state.historicalValves,
          items: state.historicalValves.items.map((item) => {
            if (item.id === payload.id) {
              return {
                ...item,
                ...payload,
              };
            }

            return item;
          })
        },
      };

    case actions.UPDATE_HISTORICAL_VALVES_REQUEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: null,
      };

    case actions.UPDATE_HISTORICAL_VALVES_SUCCESS:
      return {
        ...state,
        isLoading: false,
        errorMessage: null,
      };

    case actions.UPDATE_HISTORICAL_VALVES_FAIL:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'Error is occured'
      };

    case actions.SET_HISTORICAL_VALVES_FILTERS:
      return {
        ...state,
        isLoading: true,
        historicalValves: {
          ...state.historicalValves,
          pagination: {
            ...state.historicalValves.pagination,
            page: payload.page,
          },
          filters: payload.filters,
        },
      };

    default:
      return state;
  }
}
