import actions from './actions';
import _ from 'lodash';

const initState = {
  isLoading: false,
  errorMessage: false,
  sectionId: localStorage.getItem('sectionId') || null,
  plans: [],
  rows: {},
  page: 1,
  day: 0,
  greenhouseSections: null,
  orderBy: {
    rowNumber: 'asc',
  },
  filters: {
    type: ['group'],
  },
  totalItems: 0,
  itemsPerPage: 540,
  shift: 0,
  pass: 0,
  keepShift: true,
  keepDay: true,
  exclusive: 0,
  keepExclusive: true,
  direction: 1,
  keepDirection: true,
  templates: [],
  templateId: null,
  keepTemplate: true,
  templateJson: null,
  templateViewModal: false,
  templateEditModal: false,
  templateEditing: {
    greenhouseId: localStorage.getItem('greenhouseId') || null,
    templates: [],
    templateEdit: {},
    isLoadingTemplates: false,
    isSavingTemplate: false,
    errorMessage: null
  },
  selectedRows: {
    1: [],
    2: [],
  },
  planRowFrom: localStorage.getItem('planRowFrom') || 0,
  planRowTo: localStorage.getItem('planRowTo') || 540,
};

export default function reducer(
  state = initState,
  { type, payload }
) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        rows: {},
        isLoading: true,
        errorMessage: false,
        modalActive: false,
        selectedRows: initState.selectedRows,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      const currentRows = _.keyBy(payload.data, 'rowNumber')
      return {
        ...state,
        isLoading: false,
        rows: {
          ...state.rows,
          ...currentRows,
        },
        templates: payload.templates,
        totalItems: payload.totalItems,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.LOAD_TEMPLATES_FROM_AGROINVEST:
      return {
        ...state,
        templateEditing: {
          ...state.templateEditing,
          isLoadingTemplates: true,
          errorMessage: false,
          templates: []
        }
      };
    case actions.LOAD_TEMPLATES_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        templateEditing: {
          ...state.templateEditing,
          isLoadingTemplates: false,
          errorMessage: false,
          templates: payload
        }
      };
    case actions.LOAD_TEMPLATES_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        templateEditing: {
          ...state.templateEditing,
          isLoadingTemplates: false,
          errorMessage: payload.error,
        }
      };
    case actions.SAVE_TEMPLATE_INTO_AGROINVEST:
      return {
        ...state,
        templateEditing: {
          ...state.templateEditing,
          isSavingTemplate: true,
          errorMessage: false,
          templateEdit: {
            ...state.templateEditing.templateEdit,
            name: payload.name,
            template: payload.template
          }
        }
      };
    case actions.SAVE_TEMPLATE_INTO_AGROINVEST_SUCCESS:
      return {
        ...state,
        templateEditing: {
          ...state.templateEditing,
          isSavingTemplate: false
        }
      };
    case actions.SAVE_TEMPLATE_INTO_AGROINVEST_ERROR:
      return {
        ...state,
        templateEditing: {
          ...state.templateEditing,
          isSavingTemplate: true,
          errorMessage: payload.error
        }
      };
    case actions.ENABLE_ROWS:
    case actions.DISABLE_ROWS:
    case actions.DELETE_ROWS:
      return {
        ...state,
        errorMessage: false,
        rows: {}
      };
    case actions.ROWS_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SELECT_ROWS:
      return {
        ...state,
        selectedRows: {
          ...state.selectedRows,
          [payload.section]: payload.selection,
        },
      };
    case actions.SET_PAGE:
      return {
        ...state,
        page: payload,
      }
    case actions.SET_SECTION:
      return {
        ...state,
        isLoading: true,
        rows: {},
        sectionId: payload,
        page: initState.page,
        errorMessage: false,
      }
    case actions.SET_PASS:
      return {
        ...state,
        isLoading: true,
        rows: {},
        pass: payload,
        page: initState.page,
        errorMessage: false,
      }
    case actions.SET_DETAILS:
      return {
        ...state,
        [payload.name]: payload.value
      }
    case actions.SET_TEMPLATE:
      return {
        ...state,
        templateId: payload
      }
    case actions.TOGGLE_TEMPLATE_VIEW_MODAL:
      return {
        ...state,
        templateViewModal: payload,
      }
    case actions.TOGGLE_TEMPLATE_EDIT_MODAL:
      return {
        ...state,
        templateEditModal: payload,
      }
    case actions.SET_TEMPLATE_JSON:
      return {
        ...state,
        templateJson: payload,
        templateViewModal: true
      }
    case actions.SET_TEMPLATE_EDITING_OPTIONS:
      return {
        ...state,
        templateEditing: {
          ...state.templateEditing,
          [payload.field]: payload.value,
          templates: [],
          templateEdit: {}
        }
      }
    case actions.SET_TEMPLATE_EDIT:
      return {
        ...state,
        templateEditing: {
          ...state.templateEditing,
          templateEdit: payload
        }
      }
    case actions.SET_DEFAULT_TEMPLATE_FIELDS:
      return {
        ...state,
        templateEditing: {
          ...state.templateEditing,
          templateEdit: {
            name: '',
            template: ''
          }
        }
      }
    case actions.CLEAR_TEMPLATE_EDIT:
      return {
        ...state,
        templateEditing: {
          ...state.templateEditing,
          templateEdit: {}
        }
      }
    case actions.RESET_TEMPLATE_ID:
      return {
        ...state,
        templateId: null
      }
    case actions.REFRESH_ROWS:
      return {
        ...state,
        rows: {},
      }
    case actions.SET_IS_LOADING:
      return {
        ...state,
        isLoading: true,
        page: 1
      }
    case actions.DISABLE_LOADING:
      return {
        ...state,
        isLoading: false,
      }
    case actions.SECTIONS_GREENHOUSE_SUCCESS:
      return {
        ...state,
        greenhouseSections: payload
      }
    case actions.GET_ID_SUCCESS: 
      return {
        ...state,
        plans: [payload]
      }

    case actions.SET_ROWS:
      localStorage.setItem([payload.rowName], payload.rowValue);

      return {
        ...state,
        isLoading: true,
        rows: {},
        [payload.rowName]: payload.rowValue,
      };

    default:
      return state;
  }
}
