import actions from './actions';
import _ from 'lodash';

const initState = {
  isLoading: false,
  errorMessage: false,
  plants: [],
  page: 1,
  orderBy: {
    createdAt: 'desc',
    name: 'asc',
  },
  modalActive: false,
  plant: {
    key: null,
    id: null,
  },
  rows: [],
  isLoadingRows: false,
  greenhouseId: null,
  filters: {
    greenhouseId: [localStorage.getItem('greenhouseId')] || [],
    type: ['group'],
  },
  totalItems: 0,
  itemsPerPage: 100,
};

export default function reducer(
  state = initState,
  { type, payload }
) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        plants: payload.data,
        totalItems: payload.totalItems,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.ROWS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingRows: true,
        rows: [],
        errorMessage: false,
      };
    case actions.ROWS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingRows: false,
        rows: payload,
        errorMessage: false,
      };
    case actions.ROWS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingRows: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        filters: payload.filters,
        isLoading: true,
        page: payload.page,
      };
    case actions.TOGGLE_HANDLE_MODAL:
      const plant = payload.data == null
        ? { key: null, id: null }
        : {
          ...payload.data,
          greenhouseId: _.get(payload, 'data.row.greenhouseId', null)
        }

      return {
        ...state,
        modalActive: !state.modalActive,
        plant
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        greenouse: payload.data,
      };
    case actions.RESET_PLANT:
      return {
        ...state,
        plant: {
          key: null,
          id: null,
        },
      };
    default:
      return state;
  }
}
