import actions from "./actions";

const initState = {
  isLoading: false,
  isLoadingRows: false,
  isLoadingIntensityDescriptions: false,
  errorMessage: false,
  pests: [],
  intensities: [],
  intensityDescriptions: [],
  page: 1,
  orderBy: {
    createdAt: "desc",
    name: "asc",
  },
  modalActive: false,
  modalActiveIntensity: false,
  pest: {
    name: "",
    isActive: true,
    key: null,
    id: null,
    parentId: null,
    type: "group",
    quality: null,
  },
  intensity: {
    name: "",
    color: "",
    orderBy: "",
    id: null,
  },
  filters: {},
  totalItems: 0,
  itemsPerPage: 100,
};

export default function reducer(state = initState, { type, payload }) {
  switch (type) {
    case actions.DELETE_PEST:
      const updPests = state.pests.filter((item) => item.id !== payload.id);
      return {
        ...state,
        pests: updPests,
      };
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
        modalActiveIntensity: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        pests: payload.data,
        totalItems: payload.totalItems,
        intensities: payload.intensities,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: "There is a loading problem",
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        filters: payload.filters,
        isLoading: true,
        page: payload.page,
      };
    case actions.TOGGLE_HANDLE_MODAL:
      const updPest = payload.data == null ? { name: "" } : payload.data;
      return {
        ...state,
        modalActive: !state.modalActive,
        pest: updPest,
      };
    case actions.TOGGLE_HANDLE_MODAL_INTENSITY:
      const updIntensity = payload.data == null ? { name: "" } : payload.data;
      return {
        ...state,
        modalActiveIntensity: !state.modalActiveIntensity,
        intensity: updIntensity,
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        pest: payload.data,
      };
    case actions.MODAL_UPDATE_INTENSITY:
      return {
        ...state,
        intensity: payload.data,
      };

    case actions.ROWS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingRows: true,
        rows: [],
        errorMessage: false,
      };
    case actions.ROWS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingRows: false,
        rows: payload,
        errorMessage: false,
      };
    case actions.ROWS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingRows: false,
        errorMessage: "There is a loading problem",
      };

      case actions.INTENSITY_DESCRIPTIONS_LOAD_FROM_AGROINVEST:
        return {
          ...state,
          isLoadingIntensityDescriptions: true,
          intensityDescriptions: [],
          errorMessage: false,
        };
      case actions.INTENSITY_DESCRIPTIONS_LOAD_FROM_AGROINVEST_SUCCESS:
        return {
          ...state,
          isLoadingIntensityDescriptions: false,
          intensityDescriptions: payload,
          errorMessage: false,
        };
      case actions.INTENSITY_DESCRIPTIONS_LOAD_FROM_AGROINVEST_ERROR:
        return {
          ...state,
          isLoadingIntensityDescriptions: false,
          errorMessage: "There is a loading problem",
        };
    default:
      return state;
  }
}
