import actions from './actions';

const initState = {
  isLoading: false,
  errorMessage: false,
  pests: [],
  page: 1,
  orderBy: {
    createdAt: 'desc',
    name: 'asc',
  },
  modalActiveLesion: false,
  pest: {
    name: '',
    isActive: true,
    key: null,
    id: null,
    parentId: null,
    type: 'group',
    lesionColor: '',
    points: null,
    quality: null
  },
  filters: {
    type: ['group'],
  },
  totalItems: 0,
  itemsPerPage: 100,
};

export default function reducer(
  state = initState,
  { type, payload }
) {
  switch (type) {
    case actions.DELETE_PEST:
      const updPests = state.pests.filter(item => item.id !== payload.id)
      return {
        ...state,
        pests: updPests
      }
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActiveLesion: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        pests: payload.data,
        totalItems: payload.totalItems,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        filters: payload.filters,
        isLoading: true,
        page: payload.page,
      };
    case actions.TOGGLE_HANDLE_MODAL:
      const guard = payload.data == null ? {name: ""} : payload.data
      return {
        ...state,
        modalActiveLesion: !state.modalActiveLesion,
        pest: guard,
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        pest: payload.data,
      };

      case actions.ROWS_LOAD_FROM_AGROINVEST:
        return {
          ...state,
          isLoadingRows: true,
          rows: [],
          errorMessage: false,
        };
      case actions.ROWS_LOAD_FROM_AGROINVEST_SUCCESS:
        return {
          ...state,
          isLoadingRows: false,
          rows: payload,
          errorMessage: false,
        };
      case actions.ROWS_LOAD_FROM_AGROINVEST_ERROR:
        return {
          ...state,
          isLoadingRows: false,
          errorMessage: 'There is a loading problem',
        };
    default:
      return state;
  }
}
