import actions from "./actions";
import _ from "lodash";
import moment from "moment";

const initState = {
  isLoading: false,
  isLoadingLastFinishedTask: false,
  sectionId: null,
  greenhouseSections: null,
  errorMessage: false,
  tasks: {},
  task: {
    key: null,
    id: null,
    workerId: null,
  },
  updateTask: {},
  taskPass: [],
  workers: {},
  page: 1,
  day: moment().utc().startOf("day").format(),
  shift: 0,
  pass: 0,
  direction: true,
  planDay: moment().utc().isoWeekday(),
  keepPlanDay: false,
  keepOrderBy: true,
  keepWorkerId: true,
  keepExclusive: true,
  exclusive: 0,
  selectedTasks: {
    1: [],
    2: [],
  },
  selectedWorkers: [],
  sections: [],
  totalItems: 0,
  itemsPerPage: 100,
  totalRows: 540,
  rowFrom: localStorage.getItem("rowFrom") || 0,
  rowTo: localStorage.getItem("rowTo") || 540,
};

export default function reducer(state = initState, { type, payload }) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        tasks: {},
        sectionId: payload.sectionId,
        isLoading: true,
        totalItems: initState.totalItems,
        selectedTasks: initState.selectedTasks,
        selectedWorkers: initState.selectedWorkers,
        errorMessage: false,
        page: 1,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      const currentTasks = _.keyBy(payload.tasks, "rowNumber");
      return {
        ...state,
        isLoading: false,
        tasks: {
          ...state.tasks,
          ...currentTasks,
        },
        workers: payload.workers,
        totalItems: payload.totalItems,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: "There is a loading problem",
      };
    case actions.LOAD_LAST_FINISHED_TASK_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingLastFinishedTask: true,
        errorMessage: false,
      };
    case actions.LOAD_LAST_FINISHED_TASK_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingLastFinishedTask: false,
        task: {
          ...state.task,
          qualityTaskId: _.get(payload, "data.id", null),
          qualityTask: payload.data,
        },
        errorMessage: false,
      };
    case actions.SELECT_TASKS:
      return {
        ...state,
        selectedTasks: {
          ...state.selectedTasks,
          [payload.section]: payload.selection,
        },
      };
    case actions.SELECT_WORKERS:
      return {
        ...state,
        selectedWorkers: payload.selection,
      };
    case actions.ENABLE_TASKS:
    case actions.DISABLE_TASKS:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        tasks: {},
      };
    case actions.TASKS_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: "There is a loading problem",
      };
    case actions.SELECT_DAY:
      return {
        ...state,
        errorMessage: false,
        day: payload,
        tasks: {},
        page: initState.page,
      };
    case actions.SET_DETAILS:
      return {
        ...state,
        [payload.name]: payload.value,
      };
    case actions.SET_PAGE:
      return {
        ...state,
        isLoading: true,
        page: payload,
      };
    case actions.REFRESH_TASKS:
      return {
        ...state,
        isLoading: true,
        tasks: {},
      };
    case actions.SECTIONS_GREENHOUSE_SUCCESS:
      return {
        ...state,
        greenhouseSections: payload,
      };
    case actions.CHECK_PRESENCE_TASK_PASS_SUCCESS:
      return {
        ...state,
        taskPass: payload,
      };
    case actions.SET_ROWS:
      const { rowName, rowValue } = payload;
      const purifiedRowValue = _.trim(rowValue);

      localStorage.setItem([rowName], purifiedRowValue);

      return {
        ...state,
        tasks: {},
        [rowName]: purifiedRowValue,
      };
    case actions.SET_PASS:
      const { pass } = payload;

      return {
        ...state,
        pass,
      };
    case actions.GET_SECTIONS_SUCCESS:
      return {
        ...state,
        sections: payload,
      };
    case actions.GET_SECTIONS_FAILURE:
      return {
        ...state,
        isLoading: false,
        errorMessage: payload,
      };
    case actions.GET_SELECTED_TASK_SUCCESS:
      return {
        ...state,
        task: payload,
      };
    case actions.CHANGE_TASK: {
      const { entity, value } = payload;
      return {
        ...state,
        updateTask: {
          ...state.updateTask,
          [entity]: value,
        },
        task: {
          ...state.task,
          [entity]: value,
        },
      };
    }
    case actions.CHANGE_PROPERTIES: {
      const { id, value } = payload;
      const prevProperties = [...state.task.properties];

      const newProperties = _.map(prevProperties, (item) => {
        if (item.id === id) {
          item.value = value;
          return item;
        }
        return item;
      });

      const prevUpdateProperties = [...state.updateTask.properties];
      const newUpdateTask = _.filter(
        prevUpdateProperties,
        (item) => item.id !== id
      );

      return {
        ...state,
        task: {
          ...state.task,
          properties: [...newProperties],
        },
        updateTask: {
          ...state.updateTask,
          properties: [...newUpdateTask, { id, value }],
        },
      };
    }
    case actions.PATCH_TASK_SUCCESS:
      let updTasks = Object.entries(state.tasks).map((task) => {
        if (task[1].id === payload.id) {
          const keys = Object.keys(task[1]);
          keys.forEach((key) => {
            task[1][key] = payload[key];
          });
          if (payload.workerId) {
            task[1].workerName = payload.workerName;
            task[1].workerId = payload.workerId;
          }
        }
        return task;
      });
      updTasks = Object.fromEntries(updTasks);
      return {
        ...state,
        tasks: updTasks,
        updateTask: {},
      };
    default:
      return state;
  }
}
