import actions from './actions';

const initState = {
  isLoading: false,
  isSaving: false,
  errorMessage: false,
  settings: {
    numberOfTask: {},
    numberOfTaskForController: {},
    freqRating: {}
  },
  technicalWindows: [],
  greenhouseSections: [],
  redifinedSections: [],
  statusTechnicalWindows: 'idle',
};

export default function reducer(state = initState, { type, payload }) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        settings: payload.settings,
        errorMessage: false,
      };
    case actions.SAVE_INTO_AGROINVEST:
      return {
        ...state,
        isSaving: true,
        errorMessage: false,
      };
    case actions.SAVE_INTO_AGROINVEST_SUCCESS:
      return {
        ...state,
        settings: payload.settings,
        isSaving: false,
        errorMessage: false,
      };
    case actions.SAVE_INTO_AGROINVEST_ERROR:
      return {
        ...state,
        isSaving: false,
        errorMessage: payload.error,
      };

    case actions.CHANGE_TECHNICAL_WINDOW_SUCCESS:
      const filteredTechnicalWindows = state.technicalWindows.filter(
        ({ id }) => id !== payload.technicalWindow.id
      );
      return {
        ...state,
        technicalWindows: [
          ...filteredTechnicalWindows,
          payload.technicalWindow,
        ],
      };
    case actions.CHANGE_TECHNICAL_WINDOW_ERROR:
      return {
        ...state,
        statusTechnicalWindows: 'error',
      };

    case actions.ADD_TECHNICAL_WINDOW_SUCCESS:
      return {
        ...state,
        technicalWindows: [...state.technicalWindows, payload.technicalWindow],
      };
    case actions.ADD_TECHNICAL_WINDOW_ERROR:
      return {
        ...state,
        statusTechnicalWindows: 'error',
      };

    case actions.REMOVE_TECHNICAL_WINDOW_SUCCESS:
      return {
        ...state,
        technicalWindows: [
          ...state.technicalWindows.filter((t) => t.id !== payload.id),
        ],
      };
    case actions.REMOVE_TECHNICAL_WINDOWS_ERROR:
      return {
        ...state,
        statusTechnicalWindows: 'error',
      };

    case actions.LOAD_TECHNICAL_WINDOWS:
      return {
        ...state,
        statusTechnicalWindows: 'loading',
      };
    case actions.LOAD_TECHNICAL_WINDOWS_SUCCESS:
      return {
        ...state,
        statusTechnicalWindows: 'success',
        technicalWindows: payload.technicalWindows,
      };
    case actions.LOAD_TECHNICAL_WINDOWS_ERROR:
      return {
        ...state,
        statusTechnicalWindows: 'error',
        errorMessage: payload.error,
      };

    case actions.ADD_TECHNICAL_WINDOW_SECTIONS:
      return {
        ...state,
        statusTechnicalWindows: 'loading',
      };
    case actions.ADD_TECHNICAL_WINDOW_SECTIONS_SUCCESS:
      return {
        ...state,
        statusTechnicalWindows: 'success',
      };
    case actions.ADD_TECHNICAL_WINDOW_SECTIONS_ERROR:
      return {
        ...state,
        statusTechnicalWindows: 'error',
      };
    case actions.LOAD_SECTIONS:
      return {
        ...state,
        statusTechnicalWindows: 'loading',
      };
    case actions.LOAD_SECTIONS_SUCCESS:
      return {
        ...state,
        statusTechnicalWindows: 'success',
        redifinedSections: payload.redifinedSections,
        greenhouseSections: payload.greenhouseSections,
      };
    case actions.LOAD_SECTIONS_ERROR:
      return {
        ...state,
        statusTechnicalWindows: 'error',
        errorMessage: payload.error,
      };
    default:
      return state;
  }
}
