import actions from "./actions";

const initState = {
  isLoading: false,
  errorMessage: false,
  metrics: [],
  greenhouseSections: [],
  page: 1,
  orderBy: {
    createdAt: "desc",
    name: "asc",
  },
  modalActive: false,
  currentPlants: [],
  isLoadingCurrentPlants: false,
  metric: {
    key: null,
    id: null,
  },
  filters: {},
  totalItems: 0,
  itemsPerPage: 100,
  csvColumns: null,
  csvRows: null,
};

export default function reducer(state = initState, { type, payload }) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        metrics: payload.data,
        totalItems: payload.totalItems,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: "There is a loading problem",
      };
    case actions.LOAD_CURRENT_PLANTS_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingCurrentPlants: true,
        errorMessage: false,
      };
    case actions.LOAD_CURRENT_PLANTS_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingCurrentPlants: false,
        currentPlants: payload,
        errorMessage: false,
      };
    case actions.LOAD_CURRENT_PLANTS_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingCurrentPlants: false,
        errorMessage: "There is a loading problem",
      };
    case actions.LOAD_SECTIONS_GREENHOUSE_SUCCESS:
      return {
        ...state,
        greenhouseSections: payload.data,
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        filters: payload.filters,
        isLoading: true,
        page: payload.page,
      };
    case actions.TOGGLE_HANDLE_MODAL:
      return {
        ...state,
        modalActive: !state.modalActive,
        metric: payload.data == null ? initState.metric : payload.data,
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        greenouse: payload.data,
      };
    case actions.PREPARE_DOWNLOAD:
      return {
        ...state,
        isLoading: true,
      };
    case actions.PREPARE_DOWNLOAD_SUCCESS:
      return {
        ...state,
        csvColumns: payload.csvColumns,
        csvRows: payload.csvRows,
        isLoading: false,
      };
    default:
      return state;
  }
}
