import actions from "./actions";

const defaultFilters = {
  type: ["group"],
  itemsPerPage: 1000,
};

const initState = {
  isLoading: false,
  isLoadingSections: false,
  errorMessage: false,
  isLoadedCheckMetric: false,
  page: 1,
  orderBy: {
    createdAt: "desc",
    name: "asc",
  },
  modalActive: false,
  sections: [],
  qualityLimits: [],
  timeLimits: [],
  filters: defaultFilters,
  totalItems: 0,
  itemsPerPage: 1000,
};

export default function reducer(state = initState, { type, payload }) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        qualityLimits: payload.qualityLimits,
        timeLimits: payload.timeLimits,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: "There is a loading problem",
      };

    case actions.SECTIONS_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingSections: true,
        errorMessage: false,
      };
    case actions.SECTIONS_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingSections: false,
        sections: payload,
        errorMessage: false,
      };
    case actions.SECTIONS_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadingSections: false,
        errorMessage: "There is a loading problem",
      };
    case actions.CHECK_METRIC_LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoadedCheckMetric: false,
        errorMessage: false,
      };
    case actions.CHECK_METRIC_LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadedCheckMetric: true,
        checkMetric: payload,
        errorMessage: false,
      };
    case actions.CHECK_METRIC_LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoadedCheckMetric: false,
        errorMessage: "There is a loading problem",
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        isLoading: true,
        filters: payload.filters,
        page: payload.page,
      };
    case actions.RESET_FILTERS:
      return {
        ...state,
        isLoading: true,
        filters: defaultFilters,
      };
    case actions.SET_SELECTOR:
      return {
        ...state,
        [payload.type]: payload.data,
      };
    default:
      return state;
  }
}
