import actions from "./actions";
import moment from "moment";
import _ from "lodash";

export const defaultFilters = {
  startAt: [
    JSON.stringify({
      before: moment().utc().endOf("day").format(),
      after: moment().utc().startOf("day").format(),
    }),
  ],
  isFinished: [false],
  isActive: [true],
};

const initState = {
  isLoading: false,
  isLoadingLastFinishedTask: false,
  errorMessage: false,
  tasks: [],
  workers: [],
  greenhouseSections: [],
  page: 1,
  orderBy: {
    startAt: "asc",
    sectionId: "asc",
    orderBy: "asc",
    rowNumber: "asc",
  },
  modalActive: false,
  task: {
    key: null,
    id: null,
    workerId: null,
  },
  filters: defaultFilters,
  totalItems: 0,
  itemsPerPage: 30,
  greenhouseSections: null,
  csvColumns: null,
  csvRows: null,
};

export default function reducer(state = initState, { type, payload }) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        tasks: payload.data,
        totalItems: payload.totalItems,
        errorMessage: false,
      };
    case actions.LOAD_LAST_FINISHED_TASK_FROM_AGROINVEST:
      return {
        ...state,
        isLoadingLastFinishedTask: true,
        errorMessage: false,
      };
    case actions.LOAD_LAST_FINISHED_TASK_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoadingLastFinishedTask: false,
        task: {
          ...state.task,
          qualityTaskId: _.get(payload, "data.id", null),
          qualityTask: payload.data,
        },
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        isLoadingLastFinishedTask: false,
        errorMessage: "There is a loading problem",
      };
    case actions.ASSIGN_TASK_TO_WORKER:
      return {
        ...state,
      };
    case actions.ASSIGN_TASK_TO_WORKER_SUCCESS:
      const tasks = state.tasks;
      const currentTaskIndex = _.findIndex(
        tasks,
        (task) => task.id === payload.task.id
      );

      if (currentTaskIndex > -1) {
        tasks[currentTaskIndex] = payload.task;
      }

      return {
        ...state,
        tasks,
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        filters: payload.filters,
        page: payload.page,
        isLoading: true,
      };
    case actions.RESET_FILTERS:
      return {
        ...state,
        filters: defaultFilters,
        isLoading: true,
      };
    case actions.TOGGLE_HANDLE_MODAL:
      return {
        ...state,
        modalActive: !state.modalActive,
        task: payload.data == null ? initState.task : payload.data,
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        task: payload.data,
      };
    case actions.SYNC_1C:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.SYNC_1C_SUCCESS:
      return {
        ...state,
        isLoading: false,
        errorMessage: false,
      };
    case actions.SYNC_1C_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: "There is a loading problem",
      };
    case actions.SECTIONS_GREENHOUSE_SUCCESS:
      return {
        ...state,
        greenhouseSections: payload.data,
      };
    case actions.GET_WORKERS_GREENHOUSE_SUCCESS:
      return {
        ...state,
        workers: payload,
      };
    case actions.PREPARE_DOWNLOAD:
      return {
        ...state,
        isLoading: true,
      };
    case actions.PREPARE_DOWNLOAD_SUCCESS:
      return {
        ...state,
        csvColumns: payload.csvColumns,
        csvRows: payload.csvRows,
        isLoading: false,
      };
    default:
      return state;
  }
}
