import { all, takeEvery, put, call, select } from 'redux-saga/effects';
import actions from './actions';
import _ from 'lodash';
import { isJSON, request } from '@iso/lib/helpers/utility';

/**
 * DOC: https://redux-saga-firebase.js.org/reference/dev/AGROINVEST
 */

const COLLECTION_NAME = 'trolleys'; // change your collection
const COLLECTION_SYNC_NAME = 'syncs'; // change your collection

const getPage = state => state.Trolleys.page;
const getItemsPerPage = state => state.Trolleys.itemsPerPage;
const getOrderBy = state => state.Trolleys.orderBy;
const getFilters = state => state.Trolleys.filters;

function* loadFromAgroinvest() {
  try {
    const page = yield select(getPage);
    const itemsPerPage = yield select(getItemsPerPage);
    const orderBy = yield select(getOrderBy);
    const filters = yield select(getFilters);

    const params = {}

    Object.keys(filters).flatMap(key => {
      if (!_.isEmpty(filters[key])) {
        if (_.isArray(filters[key])) {
          _.each(filters[key], (v, k) => {
            if (_.isString(v) && isJSON(v)) {
              params[key] = _.merge(params[key], JSON.parse(v));
            } else if(_.isString(v)) {
              _.merge(params, _.zipObject(key.split('|'), v.split('|')));
            } else {
              params[key] = _.isObject(v) ? _.merge(params[key], v) : v;
            }
          })
        } else {
          params[key] = _.isObject(filters[key]) ? _.merge(params[key], filters[key]) : filters[key];
        }
      }
    });  
    
    params.itemsPerPage = itemsPerPage;
    params.page = page;
    params.order = orderBy;
    
    let data = yield call(request, COLLECTION_NAME, params);
    yield put(actions.loadFromAgroInvestSuccess(data['hydra:member'], data['hydra:totalItems']));
  } catch (error) {
    yield put(actions.loadFromAgroInvestError(error));
  }
}

function* sync1C({ payload }) {
  try {
    const params = {
      toSend: true,
    }

    const data = yield call(request, COLLECTION_SYNC_NAME + '/' + payload.syncId, params, 'PATCH');

    console.log(data)

    yield put(actions.sync1CSuccess());
  } catch (error) {
    yield put(actions.sync1CError(error));
  }
}

function* storeIntoAgroinvest({ payload }) {
  const { data, actionName } = payload;
  try {
    switch (actionName) {
      case 'update':
        yield call(request, COLLECTION_NAME + '/' + data.id, {
          workerId: data.workerId,
          registeredAt: data.registeredAt,
        }, 'PATCH');
        break;
      default:
        break;
    }
    yield put({ type: actions.LOAD_FROM_AGROINVEST });
  } catch (error) {
    console.log(error);
    yield put(actions.saveIntoAgroInvestError(error));
  }
}

export default function* rootSaga() {
  yield all([
    takeEvery(actions.LOAD_FROM_AGROINVEST, loadFromAgroinvest),
    takeEvery(actions.SET_PAGINATION, loadFromAgroinvest),
    takeEvery(actions.SAVE_INTO_AGROINVEST, storeIntoAgroinvest),
    takeEvery(actions.SYNC_1C, sync1C),
    takeEvery(actions.SYNC_1C_SUCCESS, loadFromAgroinvest),
    takeEvery(actions.SET_FILTERS, loadFromAgroinvest),
  ]);
}
