import actions from './actions';
import _ from 'lodash';

const initState = {
  isLoading: false,
  errorMessage: false,
  users: [],
  page: 1,
  orderBy: {
    createdAt: 'desc',
    name: 'asc',
  },
  modalActive: false,
  user: {
    key: null,
    id: null,
  },
  rows: [],
  isLoadingRows: false,
  greenhouseId: null,
  filters: {
    greenhouseId: [localStorage.getItem('greenhouseId')] || [],
    type: ['group'],
  },
  totalItems: 0,
  itemsPerPage: 30,
};

export default function reducer(
  state = initState,
  { type, payload }
) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        users: payload.data,
        totalItems: payload.totalItems,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SAVE_INTO_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: null,
      };
    case actions.SAVE_INTO_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: payload.error,
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        filters: payload.filters,
        isLoading: true,
        page: payload.page,
      };
    case actions.TOGGLE_HANDLE_MODAL:
      const greenhouses = _.map(_.get(payload, 'data.greenhouses', []), g => {
        if (g.isActive) return g.greenhouseId
      })
      const user = payload.data == null
        ? { key: null, id: null }
        : {
          ...payload.data,
          greenhouses: _.compact(greenhouses)
        }

      return {
        ...state,
        modalActive: !state.modalActive,
        errorMessage: payload.error,
        user
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        user: payload.data,
        errorMessage: null
      };
    case actions.RESET_USER:
      return {
        ...state,
        user: {
          key: null,
          id: null,
        },
      };
    case actions.DELETE_USER:
      return {
        ...state,
        errorMessage: payload.error
      };
    default:
      return state;
  }
}
