import { all, takeEvery, put, call, select } from 'redux-saga/effects';
import actions from './actions';
import { request } from '@iso/lib/helpers/utility';

/**
 * DOC: https://redux-saga-firebase.js.org/reference/dev/AGROINVEST
 */

const COLLECTION_NAME = 'valve_limits'; // change your collection

const getPage = (state) => state.ValveLimit.page;
const getItemsPerPage = (state) => state.ValveLimit.itemsPerPage;
const getOrderBy = (state) => state.ValveLimit.orderBy;

function* loadFromAgroinvest() {
  try {
    const page = yield select(getPage);
    const itemsPerPage = yield select(getItemsPerPage);
    const orderBy = yield select(getOrderBy);
    const params = { itemsPerPage, page, order: orderBy };

    const data = yield call(request, COLLECTION_NAME, params);
    yield put(actions.loadFromAgroInvestSuccess(data['hydra:member'], data['hydra:totalItems']));
  } catch (error) {
    yield put(actions.loadFromAgroInvestError(error));
  }
}

function* storeIntoAgroinvest({ payload }) {
  const { data } = payload;
  try {
    yield call(
      request,
      `${COLLECTION_NAME}/${data.id}`,
      { minLimit: data.minLimit, maxLimit: data.maxLimit },
      'PATCH',
    );
    yield put({ type: actions.LOAD_FROM_AGROINVEST });
  } catch (error) {
    console.log(error);
    yield put(actions.saveIntoAgroInvestError(error));
  }
}

export default function* rootSaga() {
  yield all([
    takeEvery(actions.LOAD_FROM_AGROINVEST, loadFromAgroinvest),
    takeEvery(actions.SET_PAGINATION, loadFromAgroinvest),
    takeEvery(actions.SAVE_INTO_AGROINVEST, storeIntoAgroinvest),
    takeEvery(actions.SET_FILTERS, loadFromAgroinvest),
  ]);
}
