import actions from './actions';
import _ from 'lodash';
import moment from 'moment';

export const initState = {
  isLoading: false,
  isLoading1C: false,
  isLoadingWorker: false,
  errorMessage: false,
  workers: [],
  autocomplete: [],
  query: null,
  filters: {
    greenhouseId: [localStorage.getItem('greenhouseId')] || [],
    isActive: [true],
  },
  page: 1,
  totalItems: 0,
  itemsPerPage: 30,
  modalActive: false,
  modalActiveCache: false,
  cacheStatus: 'idle',
  cache: {},
  timelineActive: false,
  timeline: [],
  timelineDay: moment().day(),

  addWorkerActive: false,
  workerCode: '', // not used yet

  oneCLoading: false,
  oneCActive: false,
  oneCJson: null,
  worker: {
    key: null,
    id: null,
  },
  sections: [],
  newRatings: [],
  changeRatings: [],
  newCheckPriorities: [],
  changedCheckPriorities: [],
};

export default function reducer(state = initState, { type, payload }) {
  switch (type) {
    case actions.LOAD_FROM_AGROINVEST:
      return {
        ...state,
        isLoading: true,
        errorMessage: false,
        modalActive: false,
        timelineActive: false,
      };
    case actions.LOAD_FROM_AGROINVEST_SUCCESS:
      return {
        ...state,
        isLoading: false,
        workers: payload.data,
        totalItems: payload.totalItems,
        errorMessage: false,
      };
    case actions.LOAD_FROM_AGROINVEST_ERROR:
      return {
        ...state,
        isLoading: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SAVE_INTO_AGROINVEST_SUCCESS:
      return {
        ...state,
        changeRatings: [],
      };
    case actions.LOAD_AUTOCOMPLETE:
      return {
        ...state,
        errorMessage: false,
      };
    case actions.LOAD_AUTOCOMPLETE_SUCCESS:
      return {
        ...state,
        autocomplete: payload.data,
        errorMessage: false,
      };
    case actions.LOAD_AUTOCOMPLETE_ERROR:
      return {
        ...state,
        errorMessage: 'There is a loading problem',
      };
    case actions.LOAD_1C:
      return {
        ...state,
        isLoading1C: true,
        errorMessage: false,
      };
    case actions.LOAD_1C_SUCCESS:
      return {
        ...state,
        isLoading1C: false,
        errorMessage: false,
      };
    case actions.LOAD_1C_ERROR:
      return {
        ...state,
        isLoading1C: false,
        errorMessage: 'There is a loading problem',
      };

    case actions.LOAD_CACHE:
      return {
        ...state,
        cacheStatus: 'loading',
      };
    case actions.LOAD_CACHE_SUCCESS:
      return {
        ...state,
        cache: payload.data,
        cacheStatus: 'success',
      };
    case actions.LOAD_CACHE_ERROR:
      return {
        ...state,
        cacheStatus: 'error',
        errorMessage: payload,
      };

    case actions.LOAD_CAMUNDA_1C:
      return {
        ...state,
        isLoading1C: true,
        errorMessage: false,
      };
    case actions.LOAD_CAMUNDA_1C_SUCCESS:
      return {
        ...state,
        isLoading1C: false,
        errorMessage: false,
      };
    case actions.LOAD_CAMUNDA_1C_ERROR:
      return {
        ...state,
        isLoading1C: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.ASSIGN_TASKS:
      return {
        ...state,
        isLoadingWorker: true,
        errorMessage: false,
      };
    case actions.ASSIGN_TASKS_SUCCESS:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: false,
      };
    case actions.ASSIGN_TASKS_ERROR:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SWITCH_NFC:
      return {
        ...state,
        isLoadingWorker: true,
        errorMessage: false,
      };
    case actions.SWITCH_NFC_SUCCESS:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: false,
      };
    case actions.SWITCH_NFC_ERROR:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.TROLLEY_UNBIND:
      return {
        ...state,
        isLoadingWorker: true,
        errorMessage: false,
      };
    case actions.TROLLEY_UNBIND_SUCCESS:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: false,
      };
    case actions.TROLLEY_UNBIND_ERROR:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SET_PAGINATION:
      return {
        ...state,
        isLoading: true,
        page: payload.page,
      };
    case actions.SET_FILTERS:
      return {
        ...state,
        isLoading: true,
        filters: payload.filters,
        page: payload.page,
      };
    case actions.SET_AUTOCOMPLETE:
      return {
        ...state,
        query: payload,
      };
    case actions.TOGGLE_HANDLE_MODAL_LOAD_SUCCESS:
      return {
        ...state,
        modalActive: !state.modalActive,
        worker: payload.worker,
        newRatings: [],
        changeRatings: [],
        newCheckPriorities: [],
        changedCheckPriorities: [],
      };
    case actions.TOGGLE_HANDLE_MODAL_LOAD_ERROR:
      return {
        ...state,
        modalActive: false,
        worker: initState.worker,
        newRatings: [],
        changeRatings: [],
        newCheckPriorities: [],
        changedCheckPriorities: [],
      };

    case actions.TOGGLE_HANDLE_MODAL_CACHE:
      return {
        ...state,
        modalActiveCache: !state.modalActiveCache,
        worker: payload.data == null ? initState.worker : payload.data,
      };

    case actions.TOGGLE_TIMELINE:
      return {
        ...state,
        timelineActive: !state.timelineActive,
        worker: payload.data == null ? initState.worker : payload.data,
      };
    case actions.TOGGLE_ADD_WORKER:
      return {
        ...state,
        addWorkerActive: !state.addWorkerActive,
        workerCode: payload.code,
      };
    case actions.LOAD_TIMELINE_SUCCESS:
      return {
        ...state,
        timeline: payload.data,
        errorMessage: false,
      };
    case actions.LOAD_TIMELINE_ERROR:
      return {
        ...state,
        errorMessage: 'There is a loading problem',
      };
    case actions.SET_TIMELINE_DAY:
      return {
        ...state,
        timelineDay: payload.day,
      };
    case actions.MODAL_UPDATE:
      return {
        ...state,
        worker: _.update(state.worker, payload.name, (r) =>
          _.isObject(r) ? _.merge(r, payload.value) : payload.value,
        ),
      };
    case actions.TOGGLE_1C_DATA:
      return {
        ...state,
        oneCActive: !state.oneCActive,
      };
    case actions.LOAD_1C_DATA:
      return {
        ...state,
        oneCLoading: true,
        // oneCActive: true,
        oneCJson: null,
        errorMessage: false,
      };
    case actions.LOAD_1C_DATA_SUCCESS:
      return {
        ...state,
        oneCLoading: false,
        oneCJson: payload.data,
        errorMessage: false,
      };
    case actions.LOAD_1C_DATA_ERROR:
      return {
        ...state,
        oneCLoading: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.MAKE_SCREENSHOT:
      return {
        ...state,
        isLoadingWorker: true,
        errorMessage: false,
      };
    case actions.MAKE_SCREENSHOT_SUCCESS:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: false,
      };
    case actions.MAKE_SCREENSHOT_ERROR:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.UPLOAD_BACKUP:
      return {
        ...state,
        isLoadingWorker: true,
        errorMessage: false,
      };
    case actions.UPLOAD_BACKUP_SUCCESS:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: false,
      };
    case actions.UPLOAD_BACKUP_ERROR:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.SIGN_OUT:
      return {
        ...state,
        isLoadingWorker: true,
        errorMessage: false,
      };
    case actions.SIGN_OUT_SUCCESS:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: false,
      };
    case actions.SIGN_OUT_ERROR:
      return {
        ...state,
        isLoadingWorker: false,
        errorMessage: 'There is a loading problem',
      };
    case actions.CHANGE_WORKER_RATING: {
      const { value, workerId, ratingId, isQuality } = payload;

      const ratings = _.map(state.worker.ratings, (r) => {
        if (r.id === ratingId) {
          return { ...r, ratingInt: value, isQuality };
        }
        return r;
      });

      const prevChangeRatings = [...state.changeRatings, payload];

      const newChangeRatings = _.filter(prevChangeRatings, (prev) => prev.ratingId !== ratingId);

      return {
        ...state,
        worker: { ...state.worker, ratings },
        changeRatings: [...newChangeRatings, { ...payload }],
      };
    }

    case actions.ADD_RATING_USER: {
      const pushRating = payload;
      const newRatings = _.filter(
        state.newRatings,
        (prev) => !(prev.id === pushRating.id && prev.isQuality === pushRating.isQuality),
      );
      return { ...state, newRatings: [...newRatings, pushRating] };
    }

    case actions.CHANGE_WORKER_CHECK_PRIORITY: {
      const { priority, workerId, id } = payload;
      const prevWorkers = [...state.workers];
      const newWorkers = _.map(prevWorkers, (worker) => {
        if (worker.id === workerId) {
          worker.checkPriorities = _.map(worker.checkPriorities, (r) => {
            if (r.id === id) {
              r.priority = priority;
            }
            return r;
          });
        }
        return worker;
      });

      const updatedCheckPriority = _.filter(state.changedCheckPriorities, (prev) => prev.id !== id);
      return {
        ...state,
        workers: newWorkers,
        changedCheckPriorities: [...updatedCheckPriority, payload],
      };
    }

    case actions.ADD_WORKER_CHECK_PRIORITY: {
      const { sectionId } = payload;
      const newCheckPriorities = _.filter(
        state.newCheckPriorities,
        (prev) => prev.sectionId !== sectionId,
      );
      return { ...state, newCheckPriorities: [...newCheckPriorities, payload] };
    }

    case actions.SECTIONS_GREENHOUSE_SUCCESS: {
      return { ...state, sections: payload };
    }

    default:
      return state;
  }
}
