const _ = require('lodash');
const moment = require('moment');
const fs = require('fs');
const { Parser } = require('json2csv');
const {Client} = require("pg");

const result = {
  tomato: {},
  cucumber: {},
}

const limit = 1000;

const analDensities = async () => {
  let counter = 0;

  const query = "t.is_finished=true and t.started_at IS NOT NULL and t.finished_at IS NOT NULL";

  const totalCount = await client.query(`select count(*) from task t where ${query}`).then((r) => r.rows[0].count);

  let skip = 0;
  let processed = 0;

  while(skip < totalCount) {
    const tasks = await client.query(`SELECT t.id, t.row_number, t.started_at, t.finished_at, t.greenhouse_id, t.section_id, t.raw->>'ПосевнаяПлощадь_Key' as structure_id, t.raw->>'ТехнологическаяКарта_Key' as tech_id, s.name as section, g.description as greenhouse FROM task t LEFT JOIN section s on t.section_id=s.id LEFT JOIN greenhouse g on t.greenhouse_id=g.id WHERE ${query} LIMIT ${limit} OFFSET ${skip}`).then(res => res.rows);

    processed += tasks.length;

    skip += limit;

    if (_.isEmpty(tasks)) {
      console.log('NO TASKS');

      return false;
    }

    for(const task of tasks) {
      if(!task.structure_id) {
        continue;
      }

      const structure = await client.query(`SELECT * FROM structure WHERE id='${task.structure_id}'`).then(res => res.rows[0]);

      if (_.isEmpty(structure)) {
        console.log('NO STRUCTURE');

        return false;
      }    

      const rawdataTechCard = fs.readFileSync(`./data/techcard-${task.tech_id}.json`);

      const techcard = JSON.parse(rawdataTechCard);

      if(_.isEmpty(techcard)) {
        console.log('NO TECH CARD');

        return false;
      }    

      let startAt = null;
      let finishAt = null;

      for(const section of techcard.Товары) {
        const _startAt = moment(section.ДатаНачала);
        const _finishAt = moment(section.ДатаОкончания);

        if(!startAt || startAt >= _startAt) {
          startAt = _startAt;
        }

        if(!finishAt || finishAt <= _finishAt) {
          finishAt = _finishAt;
        }      
      }

      if(!startAt || !finishAt) {
        console.log('NO TECH DATES');

        return false;
      }

      const rawdataDensity = fs.readFileSync(`./data/densities-${task.structure_id}.json`);

      const densities = _.sortBy(JSON.parse(rawdataDensity), ['Date']);

      if(_.isEmpty(densities)) {
        console.log('NO DENSITIES');

        return false;
      }

      let density = null;

      for(const _density of densities) {
        const densityDate = moment(_density.Date);

        if(density && densityDate <= moment(density.Date)) {
          console.log(densities);
          console.log('WRONG DENSITY ORDER');

          return false;
        }

        if(densityDate <= moment(task.started_at)) {
          density = _density;
        }
      }

      if(!density) {
      // console.log(task);
      // console.log(density);

        console.log(`EMPTY DENSITY [${task.section}]`);

        continue;
        // return false;
      }

      let amount = null;

      for(const topology of density.Топология) {
        if(task.row_number >= parseInt(topology.ОрдинатаНачальнаяПозиция) && task.row_number <= parseInt(topology.ОрдинатаКонечнаяПозиция)) {
          amount = parseInt(topology.Количество);
        }
      }

      if(!amount) {
      // console.log(task);
      // console.log(density);

        console.log(`EMPTY AMOUNT [${task.section}]`);

        continue;
        // return false;
      }

      task.amount = amount;
      task.tech_start = startAt.toISOString();
      task.tech_finish = finishAt.toISOString();

      const duration = moment.duration(moment(task.finished_at).diff(moment(task.started_at)));
      const minutes = duration.asMinutes();

      task.duration = minutes;

      task.duration_100 = minutes * 100 / task.amount;

      if(task.duration <= 2) {
        console.log(`WRONG DURATION`);

        continue;
      }

      counter += 1;

      if(moment(task.tech_finish) <= moment(task.tech_start)) {
        console.log(`WRONG TIMEFRAME`);

        return false;
      }

      const techDuration = moment.duration(moment(task.tech_finish).diff(moment(task.tech_start)));
      const techMinutes = techDuration.asMinutes();

      const INTERVAL = 10;

      const intervalMinutes = techMinutes / INTERVAL;

      const startInterval = moment(task.tech_start);

      task.interval = null;

      for(let i=0;i<INTERVAL;i+=1) {
        const finishInterval = moment(startInterval).add(intervalMinutes, 'minute');

        if(moment(task.started_at).isBetween(startInterval, finishInterval)) {
          task.interval = i;
        }

        startInterval.add(intervalMinutes, 'minute');
      }

      if(task.interval === null) {
        console.log(`WRONG INTERVAL`);

        continue;
        //return false;
      }

      const isTomato = _.includes(task.greenhouse, 'Томаты');
      const isCucumber = _.includes(task.greenhouse, 'Огурцы');

      if(!isTomato && !isCucumber) {
        console.log(`WRONG GREENHOUSE`);

        return false;
      }

      const area = isTomato ? result.tomato : result.cucumber;

      if(!area[task.section_id]) {
        area[task.section_id] = {
          name: task.section,
          min: null,
          max: null,
          counter: null,
          timeframe_0: [],
          timeframe_1: [],
          timeframe_2: [],
          timeframe_3: [],
          timeframe_4: [],
          timeframe_5: [],
          timeframe_6: [],
          timeframe_7: [],
          timeframe_8: [],
          timeframe_9: [],
        };
      }

      area[task.section_id][`timeframe_${task.interval}`].push(task.duration_100);

      area[task.section_id].counter += 1;

      if(!area[task.section_id].max || task.duration_100 > area[task.section_id].max) {
        area[task.section_id].max = task.duration_100;
      }

      if(!area[task.section_id].min || task.duration_100 < area[task.section_id].min) {
        area[task.section_id].min = task.duration_100;
      }

      // console.log(techcard);
      // console.log(task);
      // console.log(area);
      // console.log(density);
      // console.log(densities);
      // if(counter > 1000) {
      //   break;
      // }
    }
  }

  const csv = [];

  for(const sectionId in result.tomato) {
    const r = {
      type: 'Томат',
      name: result.tomato[sectionId].name,
      // min: result.tomato[sectionId].min,
      // max: result.tomato[sectionId].max,
      counter: result.tomato[sectionId].counter,
      timeframe_0: sortAndNormalize(result.tomato[sectionId].timeframe_0),
      timeframe_1: sortAndNormalize(result.tomato[sectionId].timeframe_1),
      timeframe_2: sortAndNormalize(result.tomato[sectionId].timeframe_2),
      timeframe_3: sortAndNormalize(result.tomato[sectionId].timeframe_3),
      timeframe_4: sortAndNormalize(result.tomato[sectionId].timeframe_4),
      timeframe_5: sortAndNormalize(result.tomato[sectionId].timeframe_5),
      timeframe_6: sortAndNormalize(result.tomato[sectionId].timeframe_6),
      timeframe_7: sortAndNormalize(result.tomato[sectionId].timeframe_7),
      timeframe_8: sortAndNormalize(result.tomato[sectionId].timeframe_8),
      timeframe_9: sortAndNormalize(result.tomato[sectionId].timeframe_9),
    }

    if(
      r.timeframe_0 > 0
      || r.timeframe_1 > 0
      || r.timeframe_2 > 0
      || r.timeframe_3 > 0
      || r.timeframe_4 > 0
      || r.timeframe_5 > 0
      || r.timeframe_6 > 0
      || r.timeframe_7 > 0
      || r.timeframe_8 > 0
      || r.timeframe_9 > 0
    ) {
      csv.push(r);
    }
  }

  for(const sectionId in result.cucumber) {
    const r = {
      type: 'Огурец',
      name: result.cucumber[sectionId].name,
      // min: result.cucumber[sectionId].min,
      // max: result.cucumber[sectionId].max,
      counter: result.cucumber[sectionId].counter,
      timeframe_0: sortAndNormalize(result.cucumber[sectionId].timeframe_0),
      timeframe_1: sortAndNormalize(result.cucumber[sectionId].timeframe_1),
      timeframe_2: sortAndNormalize(result.cucumber[sectionId].timeframe_2),
      timeframe_3: sortAndNormalize(result.cucumber[sectionId].timeframe_3),
      timeframe_4: sortAndNormalize(result.cucumber[sectionId].timeframe_4),
      timeframe_5: sortAndNormalize(result.cucumber[sectionId].timeframe_5),
      timeframe_6: sortAndNormalize(result.cucumber[sectionId].timeframe_6),
      timeframe_7: sortAndNormalize(result.cucumber[sectionId].timeframe_7),
      timeframe_8: sortAndNormalize(result.cucumber[sectionId].timeframe_8),
      timeframe_9: sortAndNormalize(result.cucumber[sectionId].timeframe_9),
    }

    if(
      r.timeframe_0 > 0
      || r.timeframe_1 > 0
      || r.timeframe_2 > 0
      || r.timeframe_3 > 0
      || r.timeframe_4 > 0
      || r.timeframe_5 > 0
      || r.timeframe_6 > 0
      || r.timeframe_7 > 0
      || r.timeframe_8 > 0
      || r.timeframe_9 > 0
    ) {
      csv.push(r);
    }
  }

  const parser = new Parser({});
  const csvOut = parser.parse(csv);
  console.log(csvOut);

  fs.writeFileSync('result.csv', csvOut);

  return true;
};

const sortAndNormalize = (arr) => {
  if(arr.length < 10) {
    return 0;
  }

  const truncAmount = Math.floor(arr.length / 3) ;

  arr.sort((a,b) => a - b);

  const slice1 = _.slice(arr, truncAmount);

  const slice2 = _.slice(slice1, 0, slice1.length - truncAmount);

  return _.sum(slice2) / slice2.length;
}

const client = new Client({
  user: "api-platform",
  host: "localhost",
  database: "api",
  password: "!ChangeMe!",
  port: 5432,
});

client.connect();

analDensities().then(s => {
  client.end();
  console.log(s ? 'OK' : 'NOT OK');
  process.exit();
}).catch(e => {
  console.error(e);
  client.end();
  console.log('NOT OK');
  process.exit();  
});

