const _ = require("lodash");
const { v4: uuidv4 } = require("uuid");
const getUuid = require("uuid-by-string");
const moment = require("moment");
const axios = require("axios");
const fs = require("fs");

const { Client } = require("pg");

const readFromUrl = true;

const url1C =
  "http://srvapp1cmleto03.avilon-nymm.ru/agroholding/odata/standard.odata/";
const entity1COrg = "Catalog_ПодразделенияОрганизаций";
const entity1CBus = "Catalog_СтруктураПредприятия";

const instance = axios.create({
  baseURL: `${url1C}`,
  timeout: 60000,
  headers: {
    "Content-Type": "application/json",
  },
});

const grabDepartment = async () => {
  let departments = [];

  if (readFromUrl) {
    const departmentsOrg = await instance
      .get(encodeURI(`${entity1COrg}?$format=json&$orderby=Ref_Key asc`))
      .then((response) => response.data.value)
      .then((departments) => {
        fs.writeFileSync(
          `./departments-org.json`,
          JSON.stringify(departments, null, 2)
        );

        return departments;
      })
      .catch((err) => {
        console.error("GET DEPARTMENT [FAIL]", err);

        throw err;
      });

    const departmentsBus = await instance
      .get(encodeURI(`${entity1CBus}?$format=json&$orderby=Ref_Key asc`))
      .then((response) => response.data.value)
      .then((departments) => {
        fs.writeFileSync(
          `./departments-bus.json`,
          JSON.stringify(departments, null, 2)
        );

        return departments;
      })
      .catch((err) => {
        console.error("GET DEPARTMENT [FAIL]", err);

        throw err;
      });

    departments = _.concat(departmentsOrg, departmentsBus);
  } else {
    const rawdataOrg = fs.readFileSync(`./departments-org.json`);
    const rawdataBus = fs.readFileSync(`./departments-bus.json`);

    const departmentsOrg = JSON.parse(rawdataOrg);
    const departmentsBus = JSON.parse(rawdataBus);

    departments = _.concat(departmentsOrg, departmentsBus);
  }

  console.log(`GET DEPARTMENTS [OK] SIZE [${_.size(departments)}]`);

  for (const department of departments) {
    let altId = null;

    const altDep = _.find(department["ДополнительныеРеквизиты"], {
      //Свойство_Key: "ee26efed-2541-11e9-a2df-005056a3cd19", // || "c4568c94-53dc-11e8-a2c8-005056a3cd19"
      Значение_Type: "StandardODATA.Catalog_СтруктураПредприятия",
    });

    if (!!altDep) {
      altId = !_.isEmpty(altDep["Значение"]) ? altDep["Значение"] : null;
    }

    parentId =
      department["Parent_Key"] === "00000000-0000-0000-0000-000000000000"
        ? null
        : department["Parent_Key"];

    altId === "00000000-0000-0000-0000-000000000000" ? null : altId;

    const count = await client
      .query(`SELECT count(*) FROM department WHERE id='${department.Ref_Key}'`)
      .then((data) => data.rows)
      .then((rows) => rows[0])
      .then((row) => row.count)
      .then((count) => parseInt(count));

    if (count <= 0) {
      const departmentEntity = [
        department.Ref_Key, // id
        parentId, // parent_id,
        department.Description, // name
        altId, // alt_id,
        moment().format(), // created_at
        moment().format(), // updated_at
        department, // raw
        parentId, // raw_parent_id,
        altId, // raw_alt_id,
      ];

      const query =
        "INSERT INTO department (id, parent_id, name, alt_id, created_at, updated_at, raw, raw_parent_id, raw_alt_id) VALUES ($1, $2, $3, $4, $5, $6, $7, $8, $9)";

      try {
        await client.query(query, departmentEntity);

        console.log(
          `DEPARTMENT INSERT: [${department.Ref_Key}] [${department.Code}] [${department.Description}] OK`
        );
      } catch (e) {
        console.error(e.detail);
      }
    } else {
      const departmentEntity = [
        department.Ref_Key, // id
        parentId, // parent_id,
        department.Description, // name
        altId, // alt_id,
        department, // raw
        parentId, // raw_parent_id,
        altId, // raw_alt_id,
      ];

      const query =
        "UPDATE department SET parent_id=$2, name=$3, alt_id=$4, raw=$5, raw_parent_id=$6, raw_alt_id=$7 WHERE id=$1";

      try {
        await client.query(query, departmentEntity);

        console.log(
          `DEPARTMENT UPDATE: [${department.Ref_Key}] [${department.Code}] [${department.Description}] OK`
        );
      } catch (e) {
        console.error(e.detail);
      }
    }
  }

  return true;
};

const client = new Client({
  user: "api-platform",
  host: "localhost",
  database: "api",
  password: "!ChangeMe!",
  port: 5432,
});

client.connect();

grabDepartment()
  .then((s) => {
    client.end();
    console.log(s ? "OK" : "NOT OK");
    process.exit();
  })
  .catch((e) => {
    console.error(e);
    client.end();
    console.log("NOT OK");
    process.exit();
  });
