const _ = require('lodash');
const {v4: uuidv4} = require("uuid");
const getUuid = require('uuid-by-string');
const moment = require('moment');
const axios = require('axios');
const fs = require('fs');

const {Client} = require("pg");

const readFromUrl = true;

const url1C = "http://srvapp1cmleto03.avilon-nymm.ru/agroholding/odata/standard.odata/";
const entity1C = "Catalog_актСтруктураТеплиц";

const instance = axios.create({
  baseURL: `${url1C}`,
  timeout: 60000,
  headers: {
    'Content-Type': 'application/json',
  }
});

const init = async () => {
  let greenhouses = [];

  if(readFromUrl) {
    greenhouses = await instance.get(encodeURI(`${entity1C}?$format=json&$orderby=Ref_Key asc`))
      .then(response => response.data.value)
      .then(greenhouses => {
        fs.writeFileSync(`./greenhouses.json`, JSON.stringify(greenhouses, null, 2));

        return greenhouses;
      })
      .catch(err => {
        console.error('GET GREENHOUSE [FAIL]', err);

        throw err;
      });    
  } else {
    const rawdata = fs.readFileSync(`./greenhouses.json`);

    greenhouses = JSON.parse(rawdata);
  }

  console.log(`GET GREENHOUSES [OK] SIZE [${_.size(greenhouses)}]`);

  for(const greenhouse of greenhouses) {

    const count = await client.query(`SELECT count(*) FROM greenhouse WHERE id='${greenhouse.Ref_Key}'`).then(data => data.rows).then(rows => rows[0]).then(row => row.count).then(count => parseInt(count));

    if(count <= 0) {
    const greenhouseEntity = [
	          greenhouse.Ref_Key, // 1 id
	     greenhouse.Parent_Key, // 2 parent_id               | uuid                        |           |          |
	     greenhouse.Code, // 3 name                    | character varying(128)      |           |          | NULL::character varying
	     greenhouse.Parent_Key, // 4 raw_parent_id           | uuid                        |           |          |
	     greenhouse.IsFolder, // 5 is_folder               | boolean                     |           | not null | false
	     greenhouse.Description, // 6 description             | text                        |           |          |
	     greenhouse.Подразделение_Key, // 7 department_id           | uuid                        |           |          |
	     greenhouse.Подразделение_Key, // 8 raw_department_id       | uuid                        |           |          |
	     greenhouse.Комментарий, // 9 comment                 | text                        |           |          |
	     greenhouse.ПосевнаяПлощадь, // 10 sown_area               | character varying(255)      |           |          | NULL::character varying
	     null, //greenhouse.ТопологияТеплицы, // 11 raw_greenhouse_topology | jsonb                       |           |          |
	     null, //greenhouse.ТопологияТеплицы, // 12 green_house_topology    | jsonb                       |           |          |
	     null, //greenhouse.НастройкиПараметровВыполненияРабот, // 13 raw_work_parameters     | jsonb                       |           |          |
	     null, //greenhouse.НастройкиПараметровВыполненияРабот, // 14 work_parameters         | jsonb                       |           |          |
	     greenhouse, // 15 raw                     | jsonb                       |           |          |
	     moment().format(), // 16 created_at              | timestamp(0) with time zone |           | not null |
	     moment().format(), // 17 updated_at              | timestamp(0) with time zone |           | not null |
	     null, // 18 length                  | smallint                    |           |          |
    ];
      const query = 'INSERT INTO greenhouse (id, parent_id, name, raw_parent_id, is_folder, description, department_id, raw_department_id, comment, sown_area, raw_greenhouse_topology, green_house_topology, raw_work_parameters, work_parameters, raw, created_at, updated_at, length) VALUES ($1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, $14, $15, $16, $17, $18)';	  

      await client.query(query, greenhouseEntity);

      console.log(`GREENHOUSE INSERT: [${greenhouse.Ref_Key}] [${greenhouse.Code}] [${greenhouse.Description}] OK`);
    } else {
    const greenhouseEntity = [
	          greenhouse.Ref_Key, // id
	          greenhouse, // raw
	        ];
	    
      const query = 'UPDATE greenhouse SET raw=$2 WHERE id=$1';
      await client.query(query, greenhouseEntity);

      console.log(`GREENHOUSE UPDATE: [${greenhouse.Ref_Key}] [${greenhouse.Code}] [${greenhouse.Description}] OK`);
    }
  }

  return true;
};

const client = new Client({
  user: "api-platform",
  host: "localhost",
  database: "api",
  password: "!ChangeMe!",
  port: 5432,
});

client.connect();

init().then(s => {
  client.end();
  console.log(s ? 'OK' : 'NOT OK');
  process.exit();
}).catch(e => {
  console.error(e);
  client.end();
  console.log('NOT OK');
  process.exit();  
});
