const _ = require('lodash');
const {v4: uuidv4} = require("uuid");

const {Client} = require("pg");

const qualityLimitsDefault = [
  { mark: "5", minQuality: "0", maxQuality: "2" },
  { mark: "4", minQuality: "3", maxQuality: "6" },
  { mark: "3", minQuality: "7", maxQuality: "8" },
  { mark: "2", minQuality: "9", maxQuality: "10" },
  { mark: "1", minQuality: "11", maxQuality: "12" },
];

const timeLimitsDefault = [
  { mark: "5", minQuality: "0", maxQuality: "5", minTime: "120", maxTime: "300" },
  { mark: "4", minQuality: "6", maxQuality: "10", minTime: "120", maxTime: "300" },
  { mark: "3", minQuality: "11", maxQuality: "12", minTime: "120", maxTime: "300" },
  { mark: "2", minQuality: "13", maxQuality: "15", minTime: "120", maxTime: "300" },
  { mark: "1", minQuality: "16", maxQuality: "18", minTime: "120", maxTime: "300" },
];

const categories = ["cucumber", "tomato"]

const routine = async () => {
  const sections = await client.query(`SELECT * FROM section WHERE is_active=true`).then(res => res.rows);

  for (const section of sections) {
    for (const category of categories) {
      const timeLimits = await client.query(`SELECT * FROM section_quality_time_limit WHERE section_id='${section.id}' AND category='${category}'`).then((res) => res.rows);
    
      if(timeLimits.length === 5) {
        continue;
      }

      if(timeLimits.length > 0) {
        throw `WRONG LIMITS COUNT [${timeLimits.length}] @ [${section.name}]`;
      }
      
      for(const limit of timeLimitsDefault) {
        const query = `INSERT INTO 
        section_quality_time_limit 
        (id, section_id, mark, min_quality, max_quality, min_time, max_time, created_at, updated_at, category) 
        VALUES 
        ('${uuidv4()}', '${section.id}', '${limit.mark}', '${limit.minQuality}', '${limit.maxQuality}', '${limit.minTime}', '${limit.maxTime}', now(), now(), '${category}')`;

        await client.query(query);
      }
    }
  };

  const checkMetrics = await client.query(`SELECT * FROM check_metric WHERE true`).then(res => res.rows);

  for (const checkMetric of checkMetrics) {
    const qualityLimits = await client.query(`SELECT * FROM check_metric_quality_limit WHERE check_metric_id='${checkMetric.id}'`).then(res => res.rows);

    if(qualityLimits.length === 5) {
      continue;
    }

    if(qualityLimits.length > 0) {
      throw `WRONG LIMITS COUNT [${qualityLimits.length}] @ [${checkMetric.name}]`;
    }

    for(const limit of qualityLimitsDefault) {
      const query = `INSERT INTO 
        check_metric_quality_limit 
        (id, check_metric_id, mark, min_quality, max_quality, created_at, updated_at) 
        VALUES 
        ('${uuidv4()}', '${checkMetric.id}', '${limit.mark}', '${limit.minQuality}', '${limit.maxQuality}', now(), now())`;

      await client.query(query);
    }

    console.log(checkMetric.name, qualityLimits)
  }

  return true;
};

const client = new Client({
  user: "api-platform",
  host: "localhost",
  database: "api",
  password: "!ChangeMe!",
  port: 5432,
});

client.connect();

routine().then(s => {
  client.end();
  console.log(s ? 'OK' : 'NOT OK');
  process.exit();
}).catch(e => {
  console.error(e);
  client.end();
  console.log('NOT OK');
  process.exit();  
});

