const _ = require('lodash');
const {v4: uuidv4} = require("uuid");
const getUuid = require('uuid-by-string');
const moment = require('moment');
const { keys, isEmpty } = require('lodash');

const {Client} = require("pg");

const greenhouses = {
  1: {
    id: '1abec4c4-0d22-11e6-942a-005056ac0e86',
    plantsAmount: 12,
    rows: [45, 46, 125, 126, 191, 192],
  },
  2: {
    id: '10a6ab25-0d22-11e6-942a-005056ac0e86',
    plantsAmount: 12,
    rows: [57, 58, 189, 190, 317, 318, 447, 448],
  },
  3: {
    id: '230e8905-ff37-11e6-80fe-40a8f0260032',
    plantsAmount: true,
    rows: {56: 6, 57: 6, 186: 12, 187: 12, 316: 6, 317: 6, 446: 12, 447: 12},
  },
  4: {
    id: '2b8e7299-ff37-11e6-80fe-40a8f0260032',
    plantsAmount: 12,
    rows: [],
  },
  5: {
    id: 'ab4581b0-9f8b-11e8-a2d6-005056a3e110',
    plantsAmount: 6,
    rows: [132, 133, 414, 415],
  },
  6: {
    id: '7698def5-d66c-11e7-8110-40a8f0260033',
    plantsAmount: 12,
    rows: [45,46,207,208,319,320,487,488],
  },
  7: {
    id: '880954d5-d66c-11e7-8110-40a8f0260033',
    plantsAmount: 12,
    rows: [39, 40, 207, 208, 311, 312, 483, 484],
  },
  8: {
    id: '9890c293-da19-11e9-a2f2-005056a3e110',
    plantsAmount: 6,
    //rows: [134, 135, 232, 233, 496, 497, 414, 415],
    rows: [48, 49, 133, 216, 217, 314, 315, 412, 496, 497],
  },
  9: {
    id: 'a5ae0818-da19-11e9-a2f2-005056a3e110',
    plantsAmount: 6,
    //rows: [134, 135, 232, 233, 414, 415, 496, 497],
    rows: [48, 49, 133, 216, 217, 314, 315, 412, 496, 497],
  },
};

const greenhouseIndex = process.argv[2] || 0;

const greenhouse = greenhouses[greenhouseIndex] || null;

if(!greenhouse) {
  console.log('NO GREENHOUSE');

  return;
}

if(!greenhouse.plantsAmount || _.isEmpty(greenhouse.rows)) {
  console.log('NO DATA');

  return;
}

const processPlant = async (rowId, rowNumber, plantNumber) => {
  const name = `Растение ТБ${greenhouseIndex}-р${rowNumber}-${plantNumber}`;

  const id = getUuid(
    _.toString(greenhouseIndex) + rowNumber + plantNumber
  );

  const plantId = await client.query(`SELECT id FROM plant_phenology WHERE name='${name}' AND row_id='${rowId}'`)
    .then(res => res.rows[0] && res.rows[0].id || null);

  if(!plantId) {
    console.log(
      `PLANT CREATION [${id}] [${rowNumber}] [${plantNumber}]: [${name}]`
    );

    await client.query(`INSERT INTO plant_phenology VALUES ('${id}', '${rowId}', '${name}', now(), now())`);
  }
}

const processRow = async (rowNumber, plantsAmount) => {
  const rowId = await client.query(`SELECT id FROM row WHERE greenhouse_id='${greenhouse.id}' AND row_number=${rowNumber}`)
    .then(res => res.rows[0].id);

  const promises = [];

  if(rowId) {
    _.range(1, plantsAmount + 1).forEach((plantNumber) => {
      promises.push(processPlant(rowId, rowNumber, plantNumber));
    });
  } else {
    throw 'MISSING ROW';
  }

  return await Promise.all(promises).then(() => true);
}

const makePlants = async () => {
  const promises = [];

  if(_.isArray(greenhouse.rows)) {
    _.each(greenhouse.rows, rowNumber => {
      promises.push(processRow(rowNumber, greenhouse.plantsAmount));
    });
  } else if(_.isObject(greenhouse.rows)) {
    _.each(greenhouse.rows, (plantsAmount, rowNumber) => {
      promises.push(processRow(rowNumber, plantsAmount));
    });
  }

  return await Promise.all(promises).then(() => true);
}

const client = new Client({
  user: "api-platform",
  host: "localhost",
  database: "api",
  password: "!ChangeMe!",
  port: 5432,
});

client.connect();

makePlants(greenhouse).then(s => {
  client.end();
  console.log(s ? 'OK' : 'NOT OK');
  process.exit();
}).catch(e => {
  console.error(e);
  client.end();
  console.log('NOT OK');
  process.exit();  
});
