const _ = require('lodash');
const {v4: uuidv4} = require("uuid");
const getUuid = require('uuid-by-string');
const moment = require('moment');
const { keys, isEmpty } = require('lodash');
const axios = require('axios');
const fs = require('fs');

const {Client} = require("pg");

const readFromUrl = true;

const url1C = "http://srvapp1cmleto03.avilon-nymm.ru/agroholding/odata/standard.odata/";
const entity1C = "Document_актЗаказНарядНаРаботы";
const request1C = "НовоеМУП eq true and Факт eq false and DeletionMark eq false and Подразделение_Key eq guid'%departmentId%' and Исполнитель_Type eq 'StandardODATA.Undefined'";

const HARVESTING_TYPE = 'HARVESTING';
const REGULAR_TYPE = 'REGULAR';

const instance = axios.create({
  baseURL: `${url1C}`,
  timeout: 60000,
  headers: {
    'Content-Type': 'application/json',
  }
});

const harvesting = [
	         'e85c18c5-a7f1-11eb-b8b3-00505696f325', // Сбор короткоплодных огурцов (110-120 гр) - Бьёрн
	                 '819b4af7-d646-11ea-b893-00505696ff79', // Сбор корнишон (40-60 гр) огурца
	                 'fda2a0d1-5326-11e6-80e2-40a8f0260033', // Сбор короткоплодных огурцов (80-100 г)
	                 'cb846c08-5326-11e6-80e2-40a8f0260033', // Сбор длинноплодных огурцов (310 - 330 гр)
	                 '5c85b2ef-d640-11ea-b893-00505696ff79', // Сбор среднеплодного томата штучно
	                 '8738c80f-c561-11e8-a2d8-005056a3e110', // Сбор коктейльного томата ветка
	                 '6dc31a42-c561-11e8-a2d8-005056a3e110', // Сбор коктейльного томата россыпь + удаление кисти
	                 'fb2a2d1f-21b8-11e6-80dc-40a8f0260033', // Сбор томатов
	                 'e0dfb0b5-5326-11e6-80e2-40a8f0260033', // Сбор среднеплодных огурцов (200 - 220 гр)
	                 'c2fe6b22-a9a8-11eb-b8b5-00505696f325', // Сбор томатов Черри Виноградный сингл
	                 'a915e2e1-3edf-11e6-80e0-40a8f0260033', // Сбор томатов черри (ветка, круглый)
	                 'a07ce8d2-a9a8-11eb-b8b5-00505696f325', // Сбор томатов Черри Виноградный ветка
	                 '4f9b1813-c561-11e8-a2d8-005056a3e110', // Сбор томатов черри россыпь + удаление кисти Свитель
	'f5be5cee-1155-11ec-b8e2-005056962066', // Сбор томатов черри россыпь + удаление кисти Тамаджина, Вилакс
];

const constants = {
  rowId: '20dc297d-b6cf-11e8-a2d2-005056a3cd19',
  trolleyId: '0cdeeb0c-aa5b-11e6-80f5-40a8f0260033',
};

const greenhouses = {
  1: {
    id: '1abec4c4-0d22-11e6-942a-005056ac0e86',
    departmentId: 'd92adf67-3760-11e7-b77d-005056ac182c',
  },
  2: {
    id: '10a6ab25-0d22-11e6-942a-005056ac0e86',
    departmentId: 'df65b893-3760-11e7-b77d-005056ac182c',
  },
  3: {
    id: '230e8905-ff37-11e6-80fe-40a8f0260032',
    departmentId: 'de965dd9-c104-11e6-80f8-40a8f0260032',
  },
  4: {
    id: '2b8e7299-ff37-11e6-80fe-40a8f0260032',
    departmentId: 'de965ddb-c104-11e6-80f8-40a8f0260032',
  },
  5: {
    id: 'ab4581b0-9f8b-11e8-a2d6-005056a3e110',
    departmentId: '27bdce5c-9566-11e8-a2d0-005056a398e7',
  },
  6: {
    id: '7698def5-d66c-11e7-8110-40a8f0260033',
    departmentId: '5f519a99-a9ae-11e7-a90f-005056ac182c',
  },
  7: {
    id: '880954d5-d66c-11e7-8110-40a8f0260033',
    departmentId: '7cf8a7ee-a9ae-11e7-a90f-005056ac182c',
  },
  8: {
    id: '9890c293-da19-11e9-a2f2-005056a3e110',
    departmentId: 'b95c5736-8397-11e9-a2e9-005056a3e110',
  },
  9: {
    id: 'a5ae0818-da19-11e9-a2f2-005056a3e110',
    departmentId: 'c64299dc-8397-11e9-a2e9-005056a3e110',
  },
};

const greenhouseIndex = process.argv[2] || 0;

const greenhouse = greenhouses[greenhouseIndex] || null;

if(!greenhouse) {
  console.log('NO GREENHOUSE');

  return;
}

const makePlanTemplates = async () => {

  let tasks = [];

  if(readFromUrl) {
    tasks = await instance.get(encodeURI(`${entity1C}?$format=json&$orderby=ДатаВыполнения desc,ВидРабот_Key asc&$filter=` + _.replace(request1C, '%departmentId%', greenhouse.departmentId)))
      .then(response => response.data.value)
      .then(tasks => {
        fs.writeFileSync(`./greenhouse${greenhouseIndex}.json`, JSON.stringify(tasks, null, 2));

        return tasks;
      })
      .catch(err => {
        console.error('GREENHOUSE [' + greenhouseIndex + '] [FAIL]', err);

        throw err;
      });    
  } else {
    const rawdata = fs.readFileSync(`./greenhouse${greenhouseIndex}.json`);

    tasks = JSON.parse(rawdata);
  }

  console.log('GREENHOUSE [' + greenhouseIndex + `] [OK] SIZE [${_.size(tasks)}]`);

  const sowingFields = {
    [HARVESTING_TYPE]: {},
    [REGULAR_TYPE]: {},
  };

  for(const task of tasks) {
    let isRegular = false;
    let isHarvesting = false;

    let taskType = null;

    for(const param of task.ПараметрыВыполненияРабот) {
      if(param.Параметр_Key === constants.rowId) {
        isRegular = true;
      }

      if(param.Параметр_Key === constants.trolleyId) {
        isHarvesting = true;
      }
    } 

    if(isRegular && isHarvesting) {
      taskType = HARVESTING_TYPE;
    } else if(isRegular) {
      taskType = REGULAR_TYPE;
    }

    const section = await client.query(`SELECT id, name, is_active, is_harvesting, is_phenology, is_guarding, is_spraying, is_quality, module FROM section WHERE id='${task.ВидРабот_Key}'`)
      .then(res => res.rows)
      .then(res => res[0]); 
      
    if(!section) {
      throw `MISSING SECTION [${task.ВидРабот_Key}]`;
    }

    if(taskType === HARVESTING_TYPE && (!_.includes(harvesting, section.id) || !section.is_harvesting)) {
      throw `UNKNOWN HARVESTING SECTION [${section.name}] [${section.is_harvesting}]`;
    }

    if(moment() >= moment(task.ДатаВыполнения) || moment() <= moment(task.ДатаНачала)) {
      console.error(`WRONG TASK TIMEFRAME [${task.ДатаНачала}] [${task.ДатаВыполнения}] [${moment()}]`);

      continue;
    }

    console.log(`TASK [${section.name} - ${section.module}] [${task.Date}] [${task.ДатаНачала}] [${task.ДатаВыполнения}] [${taskType}]`);

    if(!taskType) {
      console.error('TASK MISSING TYPE: SKIPPING');

      continue;
    }

    if(!section.is_active) {
      console.error(`INACTIVE SECTION [${section.name}]`);

      // !IMPORTANT: DB changes 
      await client.query(`UPDATE section SET is_active=true, module='regular' WHERE id='${section.id}'`);

      const exConnection = await client.query(`SELECT id FROM greenhousesection WHERE section_id='${section.id}' and greenhouse_id='${greenhouse.id}'`).then(res => res.rows).then(rows => !_.isEmpty(rows));

      if(!exConnection) {
        const greenhouseSection = [
          section.id,
          greenhouse.id,
          7,
          false,
          null,
          null,
          null,
        ];

        const query = 'INSERT INTO greenhousesection (id, section_id, greenhouse_id, created_at, updated_at, min_lead_time, on_pause, pause_changed_at, manager, max_lead_time) VALUES (uuid_generate_v4(), $1, $2, now(), now(), $3, $4, $5, $6, $7)';
        await client.query(query, greenhouseSection);
      }
    }    

    if(section.is_phenology || section.is_guarding || section.is_spraying || section.is_quality) {
      console.error(`WRONG SECTION TYPE [${section.name}]`);

      continue;
    }    

    if(!sowingFields[taskType][task.ПосевнаяПлощадь_Key]) {
      const actualGreenhouse = await client.query(`SELECT id, name, description FROM greenhouse WHERE id='${task.Теплица_Key}'`)
        .then(res => res.rows)
        .then(res => res[0]); 

      if(_.isEmpty(actualGreenhouse) || !actualGreenhouse.description) {
        throw `MISSING GREENHOUSE [${task.Теплица_Key}]`;
      }

      const structure = await client.query(`SELECT id, name, description, comment, started_at, finished_at, regular_expr FROM structure WHERE id='${task.ПосевнаяПлощадь_Key}'`)
        .then(res => res.rows)
        .then(res => res[0]); 

      if(_.isEmpty(structure) || !structure.description) {
        throw `MISSING STRUCTURE [${task.ПосевнаяПлощадь_Key}]`;
      }

      if(moment() >= moment(structure.finished_at)) {
        console.error(`WRONG SECTION TIMEFRAME [LEFT] [${structure.started_at}] [${structure.finished_at}]`);

        continue;
      }

      if(moment() <= moment(structure.started_at)) {
        console.error(`WRONG SECTION TIMEFRAME [RIGHT] [${structure.started_at}] [${structure.finished_at}]`);

        continue;
      }

      sowingFields[taskType][task.ПосевнаяПлощадь_Key] = {
        greenhouseName: actualGreenhouse.description,
        sowingName: structure.description,
        count: 0,
        task,
        regexp: task.ПараметрыВыполненияРабот[0]['РегулярноеВыражение'],
      };
    }

    sowingFields[taskType][task.ПосевнаяПлощадь_Key].count += 1;
  }

  //console.log('SOWING FIELDS', sowingFields);

  const rows = await client.query(`SELECT id, row_number FROM row WHERE greenhouse_id='${greenhouse.id}'`)
    .then(res => res.rows);

  for(const taskType of [REGULAR_TYPE, HARVESTING_TYPE]) {
    const rowsHash = {};

    for(const sowingId in sowingFields[taskType]) {
      for(const row of rows) {
        const rowNumber = row.row_number;

        const r = new RegExp('^(' 
          + sowingFields[taskType][sowingId].regexp 
          + ')$');

        if (r.test(rowNumber.toString())) {
          rowsHash[rowNumber] = rowsHash[rowNumber] && rowsHash[rowNumber] + 1 || 1;
        }  
      }
    }

    const doubleRows = _.filter(rowsHash, o => o > 1);

    if(!_.isEmpty(doubleRows)) {
      //console.error(rowsHash);
      throw 'DOUBLE ROWS DETECTED!';
    }

    console.log(`SOWING AREA: [${taskType}] TYPE [${_.size(rowsHash)}] ROWS OF [${_.size(rows)}] NO DUPLICATES`);
  }

  let cleanAndProceed = false;

  for(const taskType of [REGULAR_TYPE, HARVESTING_TYPE]) {
    if(_.isEmpty(sowingFields[taskType])) {
      console.log(`EMPTY SOWING, SKIPPING [${taskType}]`);

      continue;
    }

    cleanAndProceed = true;
  }

  if(cleanAndProceed) {
    console.log('CLEANING CURRENT TEMPLATES AND PLAN TEMPLATES');

    // !IMPORTANT: DB changes 
    await client.query(`UPDATE plan SET plan_template_id=null WHERE row_id IN (SELECT id FROM row WHERE greenhouse_id='${greenhouse.id}')`);
    await client.query(`DELETE FROM plan_template WHERE greenhouse_id='${greenhouse.id}'`);

    for(const taskType of [REGULAR_TYPE, HARVESTING_TYPE]) {

      for(const sowingId in sowingFields[taskType]) {
        const { task, sowingName, greenhouseName } = sowingFields[taskType][sowingId];
        const name = `${sowingName} Т${greenhouseIndex}.${_.last(_.trim(greenhouseName))}${taskType === HARVESTING_TYPE ? ' СБОР' : ''}`;

        const planTemplate = [
          task.Ref_Key,
          name,
          greenhouse.id,
          task,
        ];

        const query = 'INSERT INTO plan_template (id, name, greenhouse_id, template, created_at, updated_at) VALUES ($1, $2, $3, $4, now(), now())';
        await client.query(query, planTemplate);

        console.log(`TEMPLATE INSERT: [${task.Ref_Key}] [${name}] FOR GREENHOUSE [${greenhouse.id}] OK`);
      }
    }
  }

  return true;
};

const client = new Client({
  user: "api-platform",
  host: "localhost",
  database: "api",
  password: "!ChangeMe!",
  port: 5432,
});

client.connect();

makePlanTemplates().then(s => {
  client.end();
  console.log(s ? 'OK' : 'NOT OK');
  process.exit();
}).catch(e => {
  console.error(e);
  client.end();
  console.log('NOT OK');
  process.exit();  
});
