const _ = require('lodash');
const {v4: uuidv4} = require("uuid");
const moment = require('moment');
const rangeParser = require('parse-numeric-range');

const {Client} = require("pg");

const greenhouses = {
  1: {
    id: '1abec4c4-0d22-11e6-942a-005056ac0e86',
  },
  2: {
    id: '10a6ab25-0d22-11e6-942a-005056ac0e86',
  },
  3: {
    id: '230e8905-ff37-11e6-80fe-40a8f0260032',
  },
  4: {
    id: '2b8e7299-ff37-11e6-80fe-40a8f0260032',
  },
  5: {
    id: 'ab4581b0-9f8b-11e8-a2d6-005056a3e110',
  },
  6: {
    id: '7698def5-d66c-11e7-8110-40a8f0260033',
  },
  7: {
    id: '880954d5-d66c-11e7-8110-40a8f0260033',
  },
  8: {
    id: '9890c293-da19-11e9-a2f2-005056a3e110',
  },
  9: {
    id: 'a5ae0818-da19-11e9-a2f2-005056a3e110',
  },
};

const greenhouseIndex = process.argv[2] || 0;

const greenhouse = greenhouses[greenhouseIndex] || null;

if(!greenhouse) {
  console.log('NO GREENHOUSE');

  return;
}

const makePlanning = async (greenhouse) => {
  const miniPlans = await client.query(`SELECT * FROM mini_plan WHERE greenhouse_id='${greenhouse.id}' and is_active=true and is_deleted=false`).then(res => res.rows);

  if (_.isEmpty(miniPlans)) {
    console.log('NO MINI PLANS');

    return false;
  }
 
    await client.query(`UPDATE plan SET is_active=false WHERE row_id IN (SELECT id FROM row WHERE greenhouse_id='${greenhouse.id}')`);


  for(const miniPlan of miniPlans) {

    const ranges = await client.query(`SELECT * FROM row_range WHERE mini_plan_id='${miniPlan.id}' ORDER BY section_id, dow`).then(res => res.rows);

    const sections = {};

    if (_.isEmpty(ranges)) {
      console.log(`NO RANGES FOR [${miniPlan.description}] [${miniPlan.module}] [${miniPlan.id}]`);

      continue;
    }

  for(const range of ranges) {
    const dow = range.dow;
    // console.log(range, dow);

    if(_.isEmpty(sections[range.section_id])) {
      console.log(`CLEARING GREENHOUSE [${greenhouse.id}] SECTION [${range.section_id}]`);
      sections[range.section_id] = {
        hash: {},
      };

      await client.query(`UPDATE plan SET is_active=false WHERE section_id='${range.section_id}' AND row_id IN (SELECT id FROM row WHERE greenhouse_id='${greenhouse.id}')`)
    }

    let rows = []
    
    _.each(_.split(range.range, ','), diap => {
      const isEvenOdd = _.includes(diap, '..');

      let rowRange = rangeParser(diap);

      if(isEvenOdd) {
        rowRange = _.filter(rowRange, (r, i) => !(i%2));
      }

      rows = _.concat(rows, rowRange);
    }) ;

    let shift = 0;
    let direction = 1;

    for(let index in rows) {
      index = _.toNumber(index);
      const rowNumber = rows[index];

      const prevRowNumber = rows[index-1];
      const nextRowNumber = rows[index+1];

      const row = await client.query(`SELECT * FROM row WHERE greenhouse_id='${greenhouse.id}' AND row_number='${rowNumber}'`).then(res => res.rows[0]);

      if(!!row) {
        const pass = sections[range.section_id].hash[rowNumber] || 0;

        const plan = await client.query(`SELECT * FROM plan WHERE section_id='${range.section_id}' AND row_id = '${row.id}' AND pass='${pass}'`).then(res => res.rows[0]);

        if(_.isUndefined(prevRowNumber) || Math.abs(prevRowNumber - rowNumber) !== 1) {
          shift += 1;
          direction = 1;

          if(!_.isUndefined(nextRowNumber) && Math.abs(nextRowNumber - rowNumber) === 1) {
            direction = rowNumber === nextRowNumber-1 ? 1 : 0;
          }          
        }

        if(!!plan) {
          await client.query(`UPDATE plan SET is_active=true, dow='${dow}', direction='${direction}', shift='${shift}' WHERE id='${plan.id}'`);
        } else {
          await client.query(`INSERT INTO plan (id, row_id, section_id, is_active, dow, pass, direction, shift) VALUES (uuid_generate_v4(), '${row.id}', '${range.section_id}', true, '${dow}', '${pass}', '${direction}', '${shift}')`);
        }

        sections[range.section_id].hash[rowNumber] = pass+1;
        }
      }
    }
  }

  return true;
};

const client = new Client({
  user: "api-platform",
  host: "localhost",
  database: "api",
  password: "!ChangeMe!",
  port: 5432,
});

client.connect();

makePlanning(greenhouse).then(s => {
  client.end();
  console.log(s ? 'OK' : 'NOT OK');
  process.exit();
}).catch(e => {
  console.error(e);
  client.end();
  console.log('NOT OK');
  process.exit();  
});

