const _ = require('lodash');
const {v4: uuidv4} = require("uuid");
const getUuid = require('uuid-by-string');
const moment = require('moment');
const axios = require('axios');
const fs = require('fs');

const {Client} = require("pg");

const readFromUrl = true;

const url1C = "http://srvapp1cmleto03.avilon-nymm.ru/agroholding/odata/standard.odata/";
const entity1C = "Catalog_актСтруктураПосевныхПлощадей";

const density1C = 'Document_актУстановкаКоличестваРастений';

const instance = axios.create({
  baseURL: `${url1C}`,
  timeout: 60000,
  headers: {
    'Content-Type': 'application/json',
  }
});

const grabStructure = async () => {

  let structures = [];

  if(readFromUrl) {
    structures = await instance.get(encodeURI(`${entity1C}?$format=json&$orderby=Ref_Key asc`))
      .then(response => response.data.value)
      .then(structures => {
        fs.writeFileSync(`./structures.json`, JSON.stringify(structures, null, 2));

        return structures;
      })
      .catch(err => {
        console.error('GET STRUCTURE [FAIL]', err);

        throw err;
      });    
  } else {
    const rawdata = fs.readFileSync(`./structures.json`);

    structures = JSON.parse(rawdata);
  }

  console.log(`GET STRUCTURES [OK] SIZE [${_.size(structures)}]`);

  for(const structure of structures) {

    if(readFromUrl) {
      densities =  await instance.get(encodeURI(`${density1C}?$format=json&$filter=ПосевнаяПлощадь_Key eq guid'${structure.Ref_Key}'`))
        .then(response => response.data.value)
        .then(densities => {
          fs.writeFileSync(`./densities-${structure.Ref_Key}.json`, JSON.stringify(densities, null, 2));
          return densities;
        })
        .catch(err => {
          console.error(`GET DENSITY [FAIL] [${structure.Ref_Key}]`, err);
          throw err;
        });
    }

    const structureEntity = [
      structure.Ref_Key, // id
      null, // greenhouse_id
      null, // parent_id
      structure.Code, // name
      structure.Owner_Key, // raw_green_house_id
      structure.Parent_Key, // raw_parent_id
      structure.IsFolder, // is_folder
      structure.Description, // description
      structure.Комментарий, // comment
      structure.ДатаНачала, // started_at
      structure.ДатаОкончания, // finished_at
      structure.РегулярноеВыражение, // regular_expr
      structure.ПлощадьПосадки, // landing_area
      null, // batonical_variety_id
      structure.БотаническийСорт_Key, // raw_batonical_variety_id
      null, // green_house_topology
      JSON.stringify(structure.ТопологияТеплицы), // raw_green_house_topology
      structure, // raw
    ];

    await client.query(`DELETE FROM structure WHERE id='${structure.Ref_Key}'`);

    const query = 'INSERT INTO structure (id, greenhouse_id, parent_id, name, raw_green_house_id, raw_parent_id, is_folder, description, comment, started_at, finished_at, regular_expr, landing_area, batonical_variety_id, raw_batonical_variety_id, green_house_topology, raw_green_house_topology, raw, created_at, updated_at) VALUES ($1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, $14, $15, $16, $17, $18, now(), now())';
  
    await client.query(query, structureEntity);

    console.log(`STRUCTURE INSERT: [${structure.Ref_Key}] [${structure.Code}] [${structure.Description}] OK`);
  }

  return true;
};

const client = new Client({
  user: "api-platform",
  host: "localhost",
  database: "api",
  password: "!ChangeMe!",
  port: 5432,
});

client.connect();

grabStructure().then(s => {
  client.end();
  console.log(s ? 'OK' : 'NOT OK');
  process.exit();
}).catch(e => {
  console.error(e);
  client.end();
  console.log('NOT OK');
  process.exit();  
});
