const _ = require('lodash');
const { v4: uuidv4 } = require('uuid');
const { Client } = require('pg');

const greenhouses = {
  1: {
    id: '1abec4c4-0d22-11e6-942a-005056ac0e86',
  },
  2: {
    id: '10a6ab25-0d22-11e6-942a-005056ac0e86',
  },
  3: {
    id: '230e8905-ff37-11e6-80fe-40a8f0260032',
  },
  4: {
    id: '2b8e7299-ff37-11e6-80fe-40a8f0260032',
  },
  5: {
    id: 'ab4581b0-9f8b-11e8-a2d6-005056a3e110',
  },
  6: {
    id: '7698def5-d66c-11e7-8110-40a8f0260033',
  },
  7: {
    id: '880954d5-d66c-11e7-8110-40a8f0260033',
  },
  8: {
    id: '9890c293-da19-11e9-a2f2-005056a3e110',
  },
  9: {
    id: 'a5ae0818-da19-11e9-a2f2-005056a3e110',
  },
};

const greenhouseIndex = process.argv[2] || 0;

const greenhouse = greenhouses[greenhouseIndex] || null;

if (!greenhouse) {
  console.log('NO GREENHOUSE');

  return;
}

const switchToModules = async (greenhouse) => {
  const miniPlans = await client
    .query(
      `SELECT * FROM mini_plan WHERE greenhouse_id='${greenhouse.id}' and module='regular' and is_active=true and is_deleted=false`
    )
    .then((res) => res.rows);

  if (_.isEmpty(miniPlans)) {
    console.log('NO MINI PLANS');

    return false;
  }
  const modules = [
    { name: 'quality', uuid: uuidv4() },
    { name: 'phenology', uuid: uuidv4() },
    { name: 'guarding', uuid: uuidv4() },
  ];
  for (const module of modules) {
    // сбрасываем активный миниплан в модуле на случай если создан
    await client.query(
      `UPDATE mini_plan SET is_active=false WHERE greenhouse_id='${greenhouse.id}' and module='${module.name}' and is_active=true and is_deleted=false`
    );
    // создаем новый активный по умолчанию
    await client.query(
      `INSERT INTO mini_plan (id, greenhouse_id, description, is_active, is_deleted, module) VALUES ('${module.uuid}', '${greenhouse.id}', 'стандартный', true, false, '${module.name}')`
    );
  }

  for (const miniPlan of miniPlans) {
    const rowRanges = await client
      .query(`SELECT * FROM row_range WHERE mini_plan_id='${miniPlan.id}'`)
      .then((res) => res.rows);
    
    //распределяем записи из старого общего плана по модулям в новые активные
    for (const rowRange of rowRanges) {
      await client.query(
        `UPDATE row_range SET mini_plan_id='${modules[0].uuid}' WHERE id='${rowRange.id}' and section_id IN (SELECT id FROM section WHERE module='${modules[0].name}')`
      );
      await client.query(
        `UPDATE row_range SET mini_plan_id='${modules[1].uuid}' WHERE id='${rowRange.id}' and section_id IN (SELECT id FROM section WHERE module='${modules[1].name}')`
      );
      await client.query(
        `UPDATE row_range SET mini_plan_id='${modules[2].uuid}' WHERE id='${rowRange.id}' and section_id IN (SELECT id FROM section WHERE module='${modules[2].name}')`
      );
      await client.query(
        `UPDATE row_range SET mini_plan_id='${modules[2].uuid}' WHERE id='${rowRange.id}' and section_id IN (SELECT id FROM section WHERE module='spraying')`
      );
      await client.query(
        `UPDATE row_range SET mini_plan_id='${modules[2].uuid}' WHERE id='${rowRange.id}' and section_id IN (SELECT id FROM section WHERE module='monitoring')`
      );
    }
  }

  return true;
};

const client = new Client({
  user: 'api-platform',
  host: 'localhost',
  database: 'api',
  password: '!ChangeMe!',
  port: 5432,
});

client.connect();

switchToModules(greenhouse)
  .then((s) => {
    client.end();
    console.log(s ? 'OK' : 'NOT OK');
    process.exit();
  })
  .catch((e) => {
    console.error(e);
    client.end();
    console.log('NOT OK');
    process.exit();
  });
