#!/usr/bin/env node

const dotenv = require('dotenv');
dotenv.config();

const axios = require('axios');
const _ = require('lodash');

const greenhouses = {
  1: {
    id: '1abec4c4-0d22-11e6-942a-005056ac0e86',
  },
  2: {
    id: '10a6ab25-0d22-11e6-942a-005056ac0e86',
  },
  3: {
    id: '230e8905-ff37-11e6-80fe-40a8f0260032',
  },
  4: {
    id: '2b8e7299-ff37-11e6-80fe-40a8f0260032',
  },
  5: {
    id: 'ab4581b0-9f8b-11e8-a2d6-005056a3e110',
  },
  6: {
    id: '7698def5-d66c-11e7-8110-40a8f0260033',
  },
  7: {
    id: '880954d5-d66c-11e7-8110-40a8f0260033',
  },
  8: {
    id: '9890c293-da19-11e9-a2f2-005056a3e110',
  },
  9: {
    id: 'a5ae0818-da19-11e9-a2f2-005056a3e110',
  },
};

const apiHost = `${process.env.CAMUNDA_HOST}/engine-rest/process-definition`;
const businessKey = 'AGROINVEST';

const greenhouseIndex = process.argv[2] || 0;

const greenhouse = greenhouses[greenhouseIndex] || null;

if(!greenhouse) {
  console.log('NO GREENHOUSE');

  return;
}

const variables = {
  type: {
    value: 'startProcess',
    type: 'String',
  },
};

const instance = axios.create({
  baseURL: apiHost,
  timeout: 60000,
  headers: {
    'Content-Type': 'application/json',
  }
});

const generateTasks = async (greenhouse) => {
  try {
    const key = 'TasksGenerateByGreenhouse';

    variables.payload = {
      value: greenhouse.id,
      type: 'String',
    };

    const request = {
      variables: variables,
      businessKey,
    }

    console.log('/key/' + key + '/start', request);

    return await instance.post('/key/' + key + '/start', request)
      .then(response => { 
        console.log('PROCESS [' + key + '] [OK]: ' + response.data.id);

	return true;
      })
      .catch(err => { 
        console.log('PROCESS [' + key + '] [FAIL]: ' + (err.response && err.response.status) );
        
        throw err;
      });

  } catch (error) {
    throw error;
  }

  return false;
}

generateTasks(greenhouse).then(s => {
  console.log(s ? 'OK' : 'NOT OK');
  process.exit();
}).catch(e => {
  console.error(e);
  console.log('NOT OK');
  process.exit();  
});

// if(
//   _.startsWith(bpmn, "TasksGenerateBySection")
// ) {

//   const params = _.split(bpmn, "|", 3);

//   variables.payload = {
//     value: JSON.stringify({
//     sectionId: params[2],
//     greenhouseId: params[1],
//   }),
//     type: 'Object',
//     valueInfo: {
//       objectTypeName: 'java.util.HashMap<java.lang.Object,java.lang.Object>',
//       serializationDataFormat: 'application/json',
//     },
//   };

//   bpmn = params[0];

// }
