const _ = require('lodash');
const moment = require('moment');
const fs = require('fs');
const {Client} = require("pg");
const axios = require('axios');

const limit = 1000;

const greenhouses = {
  1: {
    id: '1abec4c4-0d22-11e6-942a-005056ac0e86',
    departmentId: 'd92adf67-3760-11e7-b77d-005056ac182c',
  },
  2: {
    id: '10a6ab25-0d22-11e6-942a-005056ac0e86',
    departmentId: 'df65b893-3760-11e7-b77d-005056ac182c',
  },
  3: {
    id: '230e8905-ff37-11e6-80fe-40a8f0260032',
    departmentId: 'de965dd9-c104-11e6-80f8-40a8f0260032',
  },
  4: {
    id: '2b8e7299-ff37-11e6-80fe-40a8f0260032',
    departmentId: 'de965ddb-c104-11e6-80f8-40a8f0260032',
  },
  5: {
    id: 'ab4581b0-9f8b-11e8-a2d6-005056a3e110',
    departmentId: '27bdce5c-9566-11e8-a2d0-005056a398e7',
  },
  6: {
    id: '7698def5-d66c-11e7-8110-40a8f0260033',
    departmentId: '5f519a99-a9ae-11e7-a90f-005056ac182c',
  },
  7: {
    id: '880954d5-d66c-11e7-8110-40a8f0260033',
    departmentId: '7cf8a7ee-a9ae-11e7-a90f-005056ac182c',
  },
  8: {
    id: '9890c293-da19-11e9-a2f2-005056a3e110',
    departmentId: 'b95c5736-8397-11e9-a2e9-005056a3e110',
  },
  9: {
    id: 'a5ae0818-da19-11e9-a2f2-005056a3e110',
    departmentId: 'c64299dc-8397-11e9-a2e9-005056a3e110',
  },
};

const init = async () => {
  let counter = 0;

  const query = "w.greenhouse_id IS NULL and w.department_id IS NOT NULL";

  const totalCount = await client.query(`select count(*) from worker w where ${query}`).then((r) => r.rows[0].count);

  let skip = 0;
  let processed = 0;

  while(skip < totalCount) {
    const workers = await client.query(`SELECT w.id, w.name, w.code, w.department_id FROM worker w WHERE ${query} LIMIT ${limit} OFFSET ${skip}`).then(res => res.rows);

    processed += workers.length;

    skip += limit;

    if (_.isEmpty(workers)) {
      console.log('NO WORKERS');

      return true;
    }

    for(const worker of workers) {

        let departmentId = worker.department_id;

        while(departmentId) {

	const greenhouse = _.find(greenhouses, g => g.departmentId === departmentId);

         departmentId = await client.query(`SELECT d.id, d.name, d.parent_id FROM department d WHERE id='${departmentId}'`)
		    .then(res => res.rows)
	            .then(res => res[0])
	            .then(res => res.parent_id);

        if(greenhouse) {

	const update = [
          worker.id,
          greenhouse.id,
        ]

                   const query = 'UPDATE worker SET greenhouse_id=$2 WHERE id=$1';
      await client.query(query, update);

            console.info(`WORKER [${worker.name}/${worker.code}] -> [${greenhouse.id}]: OK`);

	break;

        } else {

         console.info(`WORKER [${worker.name}/${worker.code}]: GREENHOUSE NOT FOUND`);

        }

	}

	counter += 1;
    }
  }

  console.log(`WORKERS PROCESSED [${counter}] of [${totalCount}]`);

  return true;
};

const client = new Client({
  user: "api-platform",
  host: "localhost",
  database: "api",
  password: "!ChangeMe!",
  port: 5432,
});

client.connect();

init().then(s => {
  client.end();
  console.log(s ? 'OK' : 'NOT OK');
  process.exit();
}).catch(e => {
  console.error(e);
  client.end();
  console.log('NOT OK');
  process.exit();  
});

