const _ = require('lodash');
const { v4: uuidv4 } = require('uuid');
const getUuid = require('uuid-by-string');
const moment = require('moment');
const axios = require('axios');
const fs = require('fs');

const dotenv = require('dotenv');
dotenv.config();

const { Client } = require('pg');

const readFromUrl = process.argv[2] === '1' || true;

const writeToService = process.argv[3] === '1' || false;

const top = 999999;

const url1C =
  'http://srvapp1cmleto03.avilon-nymm.ru/agroholding/odata/standard.odata/';
const entity1COrg = 'InformationRegister_КадроваяИсторияСотрудников_RecordType';

const instance = axios.create({
  baseURL: `${url1C}`,
  timeout: 60000,
  headers: {
    'Content-Type': 'application/json',
  },
});

const apiHost = `${process.env.CAMUNDA_HOST}/engine-rest/process-definition`;

const key = 'WorkerImport';
const businessKey = 'AGROINVEST';

const variables = {
  type: {
    value: 'startProcess',
    type: 'String',
  },
};

const camundaInstance = axios.create({
  baseURL: apiHost,
  timeout: 60000,
  headers: {
    'Content-Type': 'application/json',
  },
});

const init = async () => {
  let histories = [];
  
  const workerHistory = await client
    .query(`SELECT * FROM configuration WHERE id='workerHistory'`)
    .then((res) => res.rows);
  
  const isExistStartFrom = !!workerHistory[0];

  const now = moment();

  const startFromMoment = isExistStartFrom
    ? moment(workerHistory[0].config.startFrom)
    : moment(now);

  console.log(`CONFIGURATION USE workerHistory.startFromMoment: ${startFromMoment.format()}`);

  const startFrom = startFromMoment
    .utc()
    .subtract(1, 'day')
    .startOf('day')
    .utcOffset(0, true)
    .format('YYYY-MM-DDTHH:mm:ss');

  console.log(`CONFIGURATION USE workerHistory.startFrom: ${startFrom}`);

  if (readFromUrl) {
    histories = await instance
      .get(
        encodeURI(
          `${entity1COrg}?$format=json&$filter=Active eq true and Period ge datetime'${startFrom}' and (ВидСобытия eq 'Прием' or ВидСобытия eq 'Увольнение')&$top=${top}&$orderby=Period asc`
        )
      )
      .then((response) => response.data.value)
      .then((history) => {
        fs.writeFileSync(`./history.json`, JSON.stringify(history, null, 2));

        return history;
      })
      .catch((err) => {
        console.error('GET HISTORY [FAIL]', err);
        throw err;
      });
  } else {
    histories = JSON.parse(fs.readFileSync(`./history.json`));
  }

  console.log(`GET HISTORY [OK] SIZE [${_.size(histories)}]`);


  for (const history of histories) {
    const worker = {
      id: history.Сотрудник_Key,
      type: history.ВидСобытия, // <-- Прием или Увольнение
    };

    
    if (!writeToService) {
      console.log(`WORKER INFO: [${worker.id}] [${worker.type}]`);
      continue;
    }
    try {
      if (worker.type === 'Прием') {
        variables.payload = {
          value: worker.id,
          type: 'String',
        };

        const request = {
          variables: variables,
          businessKey,
        };

        // console.log('/key/' + key + '/start', request);

          await camundaInstance
            .post('/key/' + key + '/start', request)
            .then((response) => {
              console.log(
                'WORKER CAMUNDA PROCESS [' + key + '] [OK]: ' + response.data.id
              );
              return true;
            });

	  console.log(`WORKER INFO: [${worker.id}] [${worker.type}]`);
      } else if (worker.type === 'Увольнение') {
          await client.query(
            `UPDATE worker SET is_active=false, spread_till=null WHERE id='${worker.id}'`
          );
        console.log(`WORKER SQL PROCESS: [${worker.id}] [${worker.type}] OK`);
      } else {
        console.log(`WORKER PROCESS: [${worker.id}] [${worker.type}] NOT OK`);
      }
    } catch (e) {
      console.error(`WORKER PROCESS ERROR: ${e}`);
      throw e;
    }
  }
    // Если все ок, обновляем configurations, пишем туда startFrom
    if (writeToService) {
      const configData = JSON.stringify({
        startFrom: now.format(),
      });
      const query = `INSERT INTO configuration (id, config, created_at, updated_at) VALUES ('workerHistory','${configData}', now(), now()) ON CONFLICT (id) DO UPDATE
    SET config = '${configData}'`;
      await client.query(query);
      console.log(`CONFIGURATION SET workerHistory: ${configData}`);
    }

  return true;
};

const client = new Client({
  user: 'api-platform',
  host: 'localhost',
  database: 'api',
  password: '!ChangeMe!',
  port: 5432,
});

client.connect();

init()
  .then((s) => {
    client.end();
    console.log(s ? 'OK' : 'NOT OK');
    process.exit();
  })
  .catch((e) => {
    console.error(e);
    client.end();
    console.log('NOT OK');
    process.exit();
  });
