const _ = require('lodash');
const moment = require('moment');
const fs = require('fs');
const {Client} = require("pg");
const axios = require('axios');

const writeToService = process.argv[2] === '1' || false;

const dotenv = require('dotenv');
dotenv.config();

const limit = 1000;

const apiHost = `${process.env.CAMUNDA_HOST}/engine-rest/process-definition`;

const key = 'WorkerImport';
const businessKey = 'AGROINVEST';

const variables = {
  type: {
    value: 'startProcess',
    type: 'String',
  },
};

const camundaInstance = axios.create({
  baseURL: apiHost,
  timeout: 60000,
  headers: {
    'Content-Type': 'application/json',
  },
});


const init = async () => {
  let counter = 0;

  const query = "w.position_id IS NULL AND w.raw_position_id IS NULL OR w.department_id IS NULL and w.raw_department_id IS NULL OR code IS NULL OR code = ''";

  const totalCount = await client.query(`select count(*) from worker w where ${query}`).then((r) => r.rows[0].count);

  let skip = 0;
  let processed = 0;

  while(skip < totalCount) {
    const workers = await client.query(`SELECT w.id, w.name, w.code FROM worker w WHERE ${query} LIMIT ${limit} OFFSET ${skip}`).then(res => res.rows);

    processed += workers.length;

    skip += limit;

    if (_.isEmpty(workers)) {
      console.log('NO WORKERS');

      return true;
    }

    for(const worker of workers) {

        if(writeToService) {

        variables.payload = {
          value: worker.id,
          type: 'String',
        };

        const request = {
          variables,
          businessKey,
        };

        console.log('/key/' + key + '/start', request);

          await camundaInstance
            .post('/key/' + key + '/start', request)
            .then((response) => {
              console.log(
                'WORKER CAMUNDA PROCESS [' + key + '] [OK]: ' + response.data.id
              );
              return true;
            });

            console.info(`WORKER [${worker.name}/${worker.code}]: OK`);

        } else {

         console.info(`WORKER [${worker.name}/${worker.code}]: DRY RUN`);

        }

	counter += 1;
    }
  }

  console.log(`WORKERS PROCESSED [${counter}] of [${totalCount}]`);

  return true;
};

const client = new Client({
  user: "api-platform",
  host: "localhost",
  database: "api",
  password: "!ChangeMe!",
  port: 5432,
});

client.connect();

init().then(s => {
  client.end();
  console.log(s ? 'OK' : 'NOT OK');
  process.exit();
}).catch(e => {
  console.error(e);
  client.end();
  console.log('NOT OK');
  process.exit();  
});

