const _ = require('lodash');
const {v4: uuidv4} = require("uuid");
const getUuid = require('uuid-by-string');
const moment = require('moment');
const axios = require('axios');
const fs = require('fs');
const {Client} = require("pg");
const rangeParser = require('parse-numeric-range');

const dotenv = require('dotenv');
dotenv.config();

const codes = {
	1: {
		codes: [],
		ranges: [
		
		],
	},
	2: {
		codes: [],
		ranges: [
			'11135-11312',
		],
	},
	3: {
		codes: [],
		ranges: [
			
		],
	},
	4: {
		codes: [],
		ranges: [
			
		],
	},
	5: {
		codes: [],
		ranges: [
			
		],
	},
	6: {
		codes: [],
		ranges: [
			
		],
	},
	7: {
		codes: [],
		ranges: [
			
		],
	},
	8: {
		codes: [],
		ranges: [
			
		],
	},
	9: {
		codes: [],
		ranges: [
			
		],
	},
};

const url1C = "http://srvapp1cmleto03.avilon-nymm.ru/agroholding/odata/standard.odata/";
const entity1C = "Catalog_Сотрудники?$format=json&$orderby=Ref_Key&$filter=ДополнительныеРеквизиты/any(d: d/Значение eq '%workerCode%')";

const apiHost = `${process.env.CAMUNDA_HOST}/engine-rest/process-definition`;
const businessKey = 'AGROINVEST';

const variables = {
  type: {
    value: 'startProcess',
    type: 'String',
  },
};

const camundaInstance = axios.create({
  baseURL: apiHost,
  timeout: 60000,
  headers: {
    'Content-Type': 'application/json',
  }
});

const key = 'WorkerImport';

const instance = axios.create({
  baseURL: url1C,
  timeout: 60000,
  headers: {
    'Content-Type': 'application/json',
  }
});

const greenhouses = {
  1: {
    id: '1abec4c4-0d22-11e6-942a-005056ac0e86',
    departmentId: 'd92adf67-3760-11e7-b77d-005056ac182c',
  },
  2: {
    id: '10a6ab25-0d22-11e6-942a-005056ac0e86',
    departmentId: 'df65b893-3760-11e7-b77d-005056ac182c',
  },
  3: {
    id: '230e8905-ff37-11e6-80fe-40a8f0260032',
    departmentId: 'de965dd9-c104-11e6-80f8-40a8f0260032',
  },
  4: {
    id: '2b8e7299-ff37-11e6-80fe-40a8f0260032',
    departmentId: 'de965ddb-c104-11e6-80f8-40a8f0260032',
  },
  5: {
    id: 'ab4581b0-9f8b-11e8-a2d6-005056a3e110',
    departmentId: '27bdce5c-9566-11e8-a2d0-005056a398e7',
  },
  6: {
    id: '7698def5-d66c-11e7-8110-40a8f0260033',
    departmentId: '5f519a99-a9ae-11e7-a90f-005056ac182c',
  },
  7: {
    id: '880954d5-d66c-11e7-8110-40a8f0260033',
    departmentId: '7cf8a7ee-a9ae-11e7-a90f-005056ac182c',
  },
  8: {
    id: '9890c293-da19-11e9-a2f2-005056a3e110',
    departmentId: 'b95c5736-8397-11e9-a2e9-005056a3e110',
  },
  9: {
    id: 'a5ae0818-da19-11e9-a2f2-005056a3e110',
    departmentId: 'c64299dc-8397-11e9-a2e9-005056a3e110',
  },
};

const greenhouse = process.argv[2] || null;
const readFromUrl = process.argv[3] && true || false;
const callCamunda = process.argv[4] && true || false;

const getWorkers = async () => {
	for(const greenhouseIndex in codes) {
		if(greenhouse && greenhouseIndex !== greenhouse) {
			continue;
		}

		const greenhouseId = greenhouses[greenhouseIndex].id;
		const departmentId = greenhouses[greenhouseIndex].departmentId;

		console.log(`PROCESSING GREENHOUSE [${greenhouseIndex}]`);

		if(!greenhouseId) {
			throw 'MISSING INDEX';
		}

		const processingCodes = codes[greenhouseIndex];

		if(!processingCodes || !processingCodes.codes || !processingCodes.ranges) {
			throw 'MISSING CODES';
		}

		let parsedCodes = processingCodes.codes;

		for(let i=0; i<processingCodes.ranges.length; i++) {
			parsedCodes = _.union(parsedCodes, _.map(rangeParser(processingCodes.ranges[i]), o => o.toString()));
		}

		if(!_.isEmpty(parsedCodes)) {
			let worker = null;

			const importWorkers = [];

			for(const workerCode of parsedCodes) {	
				
				const apiCheck = await client.query(`SELECT id FROM worker WHERE code='${workerCode}'`)
					.then(ret => {
						if(ret.rows.length > 0) {
							console.log(`DUPLICATE API WORKER [${workerCode}]`);

							return false;
						}

						return true;
					});
				
				if(apiCheck) {				
					if(readFromUrl) {
						worker = await instance.get(encodeURI(_.replace(entity1C, '%workerCode%', workerCode)))
							.then(response => response.data.value)
							.then(workers => {
								if(workers.length === 0) {
									throw `MISSING WORKER [${workerCode}]`;
								}

								if(workers.length > 1) {
									throw `DUPLICATE WORKER [${workerCode}]`;
								}

								return workers[0];
							})
							.then(worker => {
								fs.writeFileSync(`./worker-${workerCode}-${greenhouseIndex}.json`, JSON.stringify(worker, null, 2));

								return worker;
							})
							.catch(err => {
								console.error('GET WORKER [FAIL]', err);

								throw err;
							});    
					} else {
						const rawdata = fs.readFileSync(`./worker-${workerCode}-${greenhouseIndex}.json`);

						worker = JSON.parse(rawdata);
					}	

					await client.query(`SELECT id FROM worker WHERE id='${worker.Ref_Key}'`)
						.then(ret => {
							if(ret.rows.length > 0) {
								throw `DUPLICATE API ID WORKER [${workerCode}]`;
							}

							return true;
						});

					worker.workerCode = workerCode;

					importWorkers.push(worker);
				}
			}

			if(importWorkers.length > 0) {
				const camundaImports = _.map(importWorkers, w => {
					return `./start.js "WorkerImport|${w.Ref_Key}";`;
				})

				fs.writeFileSync(`./camunda-${greenhouseIndex}.sh`, _.join(camundaImports, "\n"));

				console.log(`CAMUNDA FILE GENERATED [camunda-${greenhouseIndex}.sh]`);

				fs.writeFileSync(
					`./select-${greenhouseIndex}.sql`, 
					`SELECT id, name, code, greenhouse_id, department_id, position_id, is_active, spread_till, raw_department_id, raw_position_id FROM worker where ID IN ('${_.join(_.map(importWorkers, w => w.Ref_Key), "', '")}');`
				);

				console.log(`SELECT FILE GENERATED [select-${greenhouseIndex}.sh]`);

				fs.writeFileSync(
					`./update-${greenhouseIndex}.sql`, 
					`update worker set spread_till=now(), raw_department_id=${departmentId ? `'${departmentId}'` : 'null'}, greenhouse_id=${greenhouseId ? `'${greenhouseId}'` : 'null'}, is_active=true where ID IN ('${_.join(_.map(importWorkers, w => w.Ref_Key), "', '")}');`
				);

				console.log(`UPDATE FILE GENERATED [update-${greenhouseIndex}.sh]`);

				if(callCamunda) {
					for(const worker of importWorkers) {
						variables.payload = {
							value: worker.Ref_Key,
							type: 'String',
						};

						const request = {
							variables: variables,
							businessKey,
						}

						console.log('/key/' + key + '/start', request);

						await camundaInstance.post('/key/' + key + '/start', request)
							.then(response => { 
								console.log('PROCESS [' + key + '] [OK]: ' + response.data.id);

								return true;
							})
							.catch(err => { 
								console.log('PROCESS [' + key + '] [FAIL]: ' + (err.response && err.response.status) );
								
								throw err;
							});								
					}
				}		

				console.log(`TOTAL WORKERS TO IMPORT [${importWorkers.length}]`);

			} else {
				console.log(`NOTHING TO IMPORT IN [${greenhouseIndex}]`);
			}
		}
	}

  return true;
};

const client = new Client({
  user: "api-platform",
  host: "localhost",
  database: "api",
  password: "!ChangeMe!",
  port: 5432,
});

client.connect();

getWorkers().then(s => {
  client.end();
  console.log(s ? 'OK' : 'NOT OK');
  process.exit();
}).catch(e => {
  console.error(e);
  client.end();
  console.log('NOT OK');
  process.exit();  
});
